@@ -185,6 +185,21 @@ var SENSITIVITY_PERSONAL				= 0x00000001;
 var SENSITIVITY_PRIVATE					= 0x00000002;
 var SENSITIVITY_COMPANY_CONFIDENTIAL	= 0x00000003;
 
+// RecurrenceType
+var olRecursDaily = 0
+var olRecursWeekly = 1
+var olRecursMonthly = 2
+var olRecursMonthNth = 3
+var olRecursYearly = 5
+var olRecursYearNth = 6
+
+// TaskStatus
+var olTaskNotStarted = 0
+var olTaskInProgress = 1
+var olTaskComplete = 2
+var olTaskWaiting = 3
+var olTaskDeferred = 4
+
 // Access
 var MAPI_ACCESS_MODIFY				= 0x00000001;
 var MAPI_ACCESS_READ				= 0x00000002;
@@ -293,6 +308,7 @@ KEYS["new"]["contact"]			= 'N+C';		// New Contact
 KEYS["new"]["distlist"]			= 'N+D';		// New Distributionlist
 KEYS["new"]["folder"]			= 'N+F';		// New Folder
 KEYS["new"]["task"]				= 'N+K';		// New Task
+KEYS["new"]["taskrequest"]		= 'N+U';		// New Task Request
 KEYS["new"]["mail"]				= 'N+M';		// New Mail
 KEYS["new"]["meeting_request"]	= 'N+Q';		// New Meeting Request
 KEYS["new"]["note"]				= 'N+S';		// New Note
@@ -386,4 +402,35 @@ var DT_SEC_DISTLIST				= 0x00000009;
 // PR_OBJECT_TYPE values
 var MAPI_MESSAGE				= 5;
 var MAPI_MAILUSER				= 6;
-var MAPI_DISTLIST				= 8;
\ No newline at end of file
+var MAPI_DISTLIST				= 8;
+
+// Task request constants
+
+var tdmtNothing		= 0;
+var tdmtTaskReq		= 1;
+var tdmtTaskAcc		= 2;
+var tdmtTaskDec		= 3;
+var tdmtTaskUpd		= 4;
+var tdmtTaskSELF 	= 5;
+
+var thNone			= 0;
+var thAccepted		= 1;
+var thDeclined		= 2;
+var thUpdated		= 3;
+var thDueDateChanged = 4;
+var thAssigned		=5;
+
+var tdsNOM			= 0;
+var tdsOWNNEW		= 1;
+var tdsOWN			= 2;
+var tdsACC			= 3;
+var tdsDEC			= 4;
+
+var olNewTask		= 0;
+var olDelegatedTask	= 1;	// Task has been assigned
+var olOwnTask		= 3;	// Task owned
+
+var olTaskNotDelegated			= 0;
+var olTaskDelegationUnknown		= 1;	// After sending req
+var olTaskDelegationAccepted	= 2;	// After receiving accept
+var olTaskDelegationDeclined	= 3;	// After receiving decline
\ No newline at end of file
