@@ -716,3 +716,149 @@ function getDateRangeOfWeek(weekNo) {
 
 	return result;
 }
+
+/**
+ * global function to get date validation.
+ * @param integer day of the input date 
+ * @param integer month the input date. 
+ * @param integer year the input date.
+ * @return boolean true if the date is a valid date else false.
+ */
+function checkDateValidation(day, month, year)
+{
+	var startYearRange = 1900; // least year to consider
+	var endYearRange = 2100; // most year to consider
+	
+	if (month < 1 || month > 12) return false;
+	if (day < 1 || day > 31) return false;
+	if (year < startYearRange || year > endYearRange) return false;
+	//Check for months which have 30days like april,may,etc.
+	if ((month == 4 || month == 6 || month == 9 || month == 11) && (day == 31)) return false;
+	// Check for Feburary month, February has 29 days in any year evenly divisible by four,
+    // EXCEPT for centurial years which are not also divisible by 400
+	if (month == 2)
+	{	
+		var leapyear = parseInt(year/4,10);
+		if (isNaN(leapyear)) return false;
+		if (day > 29) return false;
+		if (day == 29 && ((year/4) != parseInt(year/4,10))) return false;
+	}
+	return true;
+}
+
+// global function to getTimezone and all dst props
+// This is a hard one. To create a recurring appointment, we need to save
+// the start and end time of the appointment in local time. So if I'm in 
+// GMT+8, and I want the appointment at 9:00, I will simply save 9*60 = 540
+// in the startDate. To make this usable for other users in other timezones,
+// we have to tell the server in which timezone this is. The timezone is normally
+// defined as a startdate and enddate for DST, the offset in minutes (so GMT+2 is 120)
+// plus the extra DST offset when DST is in effect. 
+//
+// We can't retrieve this directly from the browser, so we assume that the DST change
+// will occure on a Sunday at 2:00 or 3:00 AM, and simply scan all the sundays in a
+// year, looking for changes. We then have to guess which bit is DST and which is 'normal'
+// by assuming that the DST offset will be less than the normal offset. From this we
+// calculate the start and end dates of DST and the actuall offset in minutes.
+//
+// Unfortunately we can't detect the difference between 'the last week of october' and
+// 'the fourth week of october'. This can cause subtle problems, so we assume 'last week'
+// because this is most prevalent.
+// 
+// Note that this doesn't work for many strange DST changes, see 
+// http://webexhibits.org/daylightsaving/g.html
+
+function getTimeZone()
+{
+    var tzswitch = new Array();
+    var n = 0;
+    var lastoffset;
+    
+    var t = new Date();
+    
+    var tz = new Object();
+    
+    // We use the year 2000 to do the testing. No special reason.
+    t.setYear(2000);
+    t.setDate(2);
+    t.setMonth(0);
+    // Jan 2, 2000 was a sunday
+    t.setHours(5);
+    // Use 5:00 am because any change should have happened by then
+    t.setMinutes(0);
+    t.setSeconds(0);
+    t.setMilliseconds(0);
+    
+    lastoffset = t.getTimezoneOffset();
+    
+    for(i=0;i<52;i++) {
+        if(t.getTimezoneOffset() != lastoffset) {
+            // Found a switch
+            tzswitch[n] = new Object;
+            tzswitch[n].switchweek = t.getWeekNrOfMonth();
+            tzswitch[n].switchmonth = t.getMonth();
+            tzswitch[n].offset = t.getTimezoneOffset();
+            n++;
+            
+            // We assume DST is only set or removed once per year
+            if(n == 2)
+                break;
+                
+            lastoffset = t.getTimezoneOffset();
+        }
+        
+        // advance one week
+        t.setTime(t.getTime() + 7 * 24 * 60 * 60 * 1000);
+    }
+    
+    if(n == 0) {
+        // No DST in this timezone
+        tz.timezone = t.getTimezoneOffset();
+        tz.timezonedst = 0;
+        tz.dststartday = 0;
+        tz.dststartweek = 0;
+        tz.dststartmonth = 0;
+        tz.dststarthour = 0;
+        tz.dstendday = 0;
+        tz.dstendweek = 0;
+        tz.dstendmonth = 0;
+        tz.dstendhour = 0;
+        return tz;
+    } else if(n == 1) {
+        // This should be impossible unless DST started somewhere in the year 2000
+        // and ended more than a year later. This is an error.
+        return;
+    } else if(n == 2) {
+        if(tzswitch[0].offset < tzswitch[1].offset) {
+            // Northern hemisphere
+            tz.timezone = tzswitch[1].offset;
+            tz.timezonedst = tzswitch[0].offset - tzswitch[1].offset;
+            tz.dststartday = 0; // assume sunday
+            tz.dststartweek = tzswitch[0].switchweek == 4 ? 5 : tzswitch[0].switchweek; // assume 'last' week if week = 4
+            tz.dststartmonth = tzswitch[0].switchmonth + 1;
+            tz.dststarthour = 2; // Start at 02:00 AM
+            tz.dstendday = 0;
+            tz.dstendweek = tzswitch[1].switchweek == 4 ? 5 : tzswitch[1].switchweek;
+            tz.dstendmonth = tzswitch[1].switchmonth + 1;
+            tz.dstendhour = 3;
+            return tz;
+            
+        } else {
+            // Southern hemisphere
+            tz.timezone = tzswitch[0].offset;
+            tz.timezonedst = tzswitch[1].offset - tzswitch[0].offset;
+            tz.dststartday = 0; // assume sunday
+            tz.dststartweek = tzswitch[1].switchweek == 4 ? 5 : tzswitch[1].switchweek; // assume 'last' week if week = 4
+            tz.dststartmonth = tzswitch[1].switchmonth + 1;
+            tz.dststarthour = 2; // Start at 02:00 AM
+            tz.dstendday = 0;
+            tz.dstendweek = tzswitch[0].switchweek == 4 ? 5 : tzswitch[0].switchweek;
+            tz.dstendmonth = tzswitch[0].switchmonth + 1;
+            tz.dstendhour = 3;
+            return tz;
+        }
+    } else {
+        // Multi-DST timezone ? This is also an error.
+        return;
+    }
+}
\ No newline at end of file
