@@ -219,9 +219,14 @@ DHTML.prototype.getXMLValue = function(xml, tag, value)
 	}
 
 	var element = this.getXMLNode(xml, tag);
-	if (element && element.firstChild && typeof(element.firstChild.nodeValue)!="undefined"){
-		result = element.firstChild.nodeValue;
-	}
+	if(element) {
+		if(typeof(element.textContent) != "undefined") {
+			// use 'textContent' in FF, since 'nodeValue' is capped at 4k with multiple nodes
+			result = element.textContent;
+		} else if (element.firstChild && typeof(element.firstChild.nodeValue)!="undefined"){
+			result = element.firstChild.nodeValue;
+		}
+    }
 	return result;
 }
 
@@ -819,15 +824,14 @@ DHTML.prototype.getCaretPosAtTextField = function(obj){
 		if(document.selection) { // MSIE
 			/**
 			 * In MSIE the position is calculated by first creating a selection 
-			 * from the cursors position to the end of the string and 
+			 * from the cursors position to the start of the string and 
 			 * calculating the length of this selection string. This number is 
-			 * subtracted from the length of the entire string in the textfield 
-			 * and that results in the cursors position.
+			 * the actual position of cursor.
 			 */
 			obj.focus();
 			var range = document.selection.createRange().duplicate();
-			range.moveEnd("character", obj.value.length);
-			return (obj.value.length - range.text.length);
+			range.moveStart("character", -obj.value.length);
+			return range.text.length;
 		}else if (obj.selectionStart || (obj.selectionStart == "0")) { // Mozilla/Netscape
 			// Just use the kickass selectionStart property in FF.
 			return obj.selectionStart;
@@ -1163,3 +1167,27 @@ DHTML.prototype.clearBodySelection = function()
 		if(!selectionObject.isCollapsed && start == 0) selectionObject.removeAllRanges();
 	}
 }
+
+/**
+ * Basically used for enabling scrolling in FF3.6
+ * @param object event an event object.
+ * @return Boolean returns true if event is occurred on scrollbar, false otherwise.
+ */
+
+function eventCheckScrolling(event)
+{
+	// explicitOriginalTarget is Mozilla-specific property.
+	if(event && event.explicitOriginalTarget)
+	{
+		var topleft = dhtml.getElementTopLeft(event.explicitOriginalTarget);
+
+		// Get clientWidht and Height of the elment.
+		var clientWidth = event.explicitOriginalTarget.clientWidth;
+		var clientHeight = event.explicitOriginalTarget.clientHeight;
+		if(clientWidth > 0 && clientHeight >0 && (event.clientX-topleft[0] > clientWidth || event.clientY-topleft[1] > clientHeight)) {
+			// Clicking outside viewable area -> must be a click in the scrollbar, allow default action.
+			return true;
+		}
+	}
+	return false;
+}
