@@ -225,15 +225,21 @@ InputManager.prototype.changeFocus = function(element){
 		}
 	}
 
-	// Only fire focus/blur events when focus has actually shifted
-	if(this.focusId != objectId){
-		// Blur the old focus object
-		this.handleEvent(element, {type: "blur"});
-		// Change focus
-		this.focusId = objectId;
-		// Focus on the new object
-		this.handleEvent(element, {type: "focus"});
+	/**
+	 * If previewpane is there then there is a iframe,
+	 * so on focus change event first we have to blur the iframe
+	 * Then set focus on the window and selected element.
+	 * Iframe window events won't be bubbled to main WA widow.
+	 */
+	var htmlbody = dhtml.getElementById("html_body");
+	if(htmlbody) {
+		htmlbody.blur();
+		window.focus();
 	}
+	// Change focus
+	this.focusId = objectId;
+	// Focus on the new object
+	this.handleEvent(element, {type: "focus"});
 }
 
 
