@@ -536,6 +536,17 @@ function dialog(url, name, feature, isModal, resultCallBack, callBackData, windo
 			result = window.showModalDialog(url, dialogArgs, feature);
 		} else {
 			result = window.open(url, name, feature);
+
+			if(resultCallBack) {
+				result.resultCallBack = resultCallBack;
+
+				if(callBackData) 
+					result.callBackData = callBackData;
+			}
+			if(windowData){
+				result.windowData = windowData;
+			}
+
 		}
 	} else { // not IE
 		if(document.getBoxObjectFor && isModal) {
@@ -702,6 +713,15 @@ function iconIndexToClassName(icon_index,messageClass, isRead)
 		case 1280:
 			className += "icon_task";
 			break;
+		case 1281:
+			className += "icon_task_recurring";
+			break;
+		case 1282:
+			className += "icon_taskrequest_assigneecopy";
+			break;
+		case 1283:
+			className += "icon_taskrequest_assignercopy";
+			break;
 		case 512:
 			className += "icon_contact";
 			break;
@@ -750,6 +770,16 @@ function iconIndexToClassName(icon_index,messageClass, isRead)
 				case "IPM.Task":
 					className += "icon_task";
 					break;
+				case "IPM.TaskRequest":
+				case "IPM.TaskRequest.Update":
+					className += "icon_taskrequest";
+					break;
+				case "IPM.TaskRequest.Decline":
+					className += "icon_taskrequest_decline";
+					break;
+				case "IPM.TaskRequest.Accept":
+					className += "icon_taskrequest_accepted";
+					break;
 				case "IPM.StickyNote":
 					className += "icon_stickynote_yellow";
 					break;
@@ -789,6 +819,9 @@ function iconIndexToClassName(icon_index,messageClass, isRead)
 				case "IPM.Note.StorageQuotaWarning":
 					className += "icon_newmail";
 					break;
+				case "IPM.Zarafa.Stub":
+					className += "icon_msg_stub";
+					break;
 				default:
 					if (isRead){
 						className += "icon_mail";
@@ -874,6 +907,7 @@ function messageClassToMessageType(messageClass)
 
 function convertPlainToHtml(content)
 {
+	content = content.replace(/&/g, "&amp;");
 	content = content.replace(/</g, "&lt;");
 	content = content.replace(/>/g, "&gt;");
 				
@@ -887,7 +921,7 @@ function convertPlainToHtml(content)
 	content = content.replace(/(^|\b|\s)(mailto:){0,1}([a-z0-9_'+*$%\^&!\.\-]+\@(?:[a-z0-9\-]+\.)+[a-z]{2,})(\?subject=[a-z0-9\+\%]+){0,1}($|[\s,;>\]\)])/ig, "$1<a href=\"mailto:$3$4\" onclick=\"parent.eventReadmailClickEmail(false,this,\'click\');return false;\">$3$4</a>$5");
 
 	// url
-	content = content.replace(/(((https{0,1}|ftp):\/\/([a-z0-9\-\_]+@){0,1}|www\.)([a-z0-9\-]+[a-z0-9\.]*)+\.?[a-z0-9]+(:[0-9]{1,5}){0,1}(\/[a-z0-9\-_#&@\?=%+;:\.\[\]~\$!\*'\(\),\{\}|\^`]*)*)/ig, "<a href=\"$1\" target=\"_blank\">$1</a>");
+	content = content.replace(/(((https{0,1}|ftp):\/\/([a-z0-9\-\_]+@){0,1}|www\.)([a-z0-9\-]+[a-z0-9\.]*)+\.?[a-z0-9]+(:[0-9]{1,5}){0,1}(\/([a-z0-9\-_#@\?=%+;:\.\[\]~\$!\*'\(\),\{\}|\^`]|&amp;)*)*)/ig, "<a href=\"$1\" target=\"_blank\">$1</a>");
 	content = content.replace(/(<a href\=\"www)/ig, "<a href=\"http://www");
 		
 	return content;
@@ -1475,6 +1509,11 @@ Number.prototype.fromCharCode = function()
  * @return Boolean Result of the comparison 
  */
 function compareEntryIds(entryid1, entryid2){
+	// data type checking
+	if(typeof entryid1 != "string" || typeof entryid2 != "string") {
+		return false;
+	}
+
 	var eid1 = createEntryIdObj(entryid1);
 	var eid2 = createEntryIdObj(entryid2);
 
@@ -1550,4 +1589,123 @@ function checkFieldsForKeycontrol(event)
 		returnValue = (element.getAttribute("type") == "checkbox") ? true : false;
 	}
 	return returnValue;
+}
+
+function getTaskRecurrencePattern(recurr)
+{
+	// convert all to integer
+	for (var i in recurr)
+		recurr[i] = parseInt(recurr[i], 10);
+
+	var recurtext = "";
+	var startDate = new Date(recurr.start * 1000);
+
+	switch(parseInt(recurr.type)) {
+		case 10:
+			if(recurr.everyn == 1) {
+				recurtext += _("Due every weekday effective %s").sprintf(startDate.print(_("%d-%m-%Y")));
+			} else if(recurr.everyn == 1440 && !recurr.regen) {
+				recurtext += _("Due every day effective %s").sprintf(startDate.print(_("%d-%m-%Y")));
+			} else if (recurr.regen) {
+				if ((recurr.everyn / 1440) == 1)
+					recurtext += _("Due %d day after this task is completed effective %s").sprintf(1, startDate.print(_("%d-%m-%Y")));
+				else
+					recurtext += _("Due %d days after this task is completed effective %s").sprintf((recurr.everyn / 1440), startDate.print(_("%d-%m-%Y")));
+			} else {
+				recurtext += _("Due every %d days effective %s").sprintf((recurr.everyn / 1440), startDate.print(_("%d-%m-%Y")));
+			}
+			break;
+		case 11:
+			if (recurr.regen) {
+				if((recurr.everyn / (1440 * 7)) == 1)
+					recurtext += _("Due every week after this task is completed effective %s").sprintf(startDate.print(_("%d-%m-%Y")));
+				else {
+					recurtext += _("Due %s weeks after this task is completed effective %s").sprintf(recurr.everyn / (1440 * 7), startDate.print(_("%d-%m-%Y")));
+				}
+			} else {
+				if (recurr.everyn > 1)
+					recurtext += _("Due every %d weeks on").sprintf(recurr.everyn) +" ";
+				else
+					recurtext += _("Due every") +" ";
+
+				var week_days = [];
+				if (recurr.weekdays & 1) week_days.push(DAYS[0]);
+				if (recurr.weekdays & 2) week_days.push(DAYS[1]);
+				if (recurr.weekdays & 4) week_days.push(DAYS[2]);
+				if (recurr.weekdays & 8) week_days.push(DAYS[3]);
+				if (recurr.weekdays & 16) week_days.push(DAYS[4]);
+				if (recurr.weekdays & 32) week_days.push(DAYS[5]);
+				if (recurr.weekdays & 64) week_days.push(DAYS[6]);
+
+				if (week_days.length > 1) {
+					recurtext += (week_days.slice(0, week_days.length - 1)).join(", ");
+					recurtext += " "+ _("and") +" "+ week_days[week_days.length - 1];
+				} else {
+					recurtext += week_days;
+				}
+			}
+			break;
+		case 12:
+			if (!recurr.regen) {
+				if (recurr.subtype == 2)
+					recurtext += _("Due day %d every").sprintf(recurr.monthday) +" ";
+				else
+					recurtext += _("Due the %d %d of every").sprintf(getNDay(recurr.nday), getWeekDays(recurr.weekdays)) +" ";
+			}
+
+			if(recurr.everyn == 1)
+				recurtext += _("month");
+			else
+				recurtext += _("%d months").sprintf(recurr.everyn);
+
+			if (recurr.regen) recurtext += " "+ _("after this task is completed");
+
+			recurtext =+ " "+ _("effective %s").sprintf(startDate.print(_("%d-%m-%Y")));
+			break;
+		case 13:
+			if (!recurr.regen) {
+				if (recurr.subtype == 2)
+					recurtext += _("Due every %d %d").sprintf(((recurr.month == 0) ? MONTHS[0] : MONTHS[Math.floor(recurr.month / 44640) + 1]), recurr.monthday);
+				else
+					recurtext += _("Due the %d %d of %d").sprintf(getNDay(recurr.nday), getWeekDays(recurr.weekdays), ((recurr.month == 0) ? MONTHS[0] : MONTHS[Math.floor(recurr.month / 44640) + 1]));
+			} else {
+				if(recurr.everyn <= 12)
+					recurtext += _("Due every year");
+				else
+					recurtext += _("Due %d years").sprintf(recurr.everyn/12);
+			}
+			recurtext =+ " "+ _("effective %s").sprintf(startDate.print(_("%d-%m-%Y")));
+			break;
+	}
+
+	return recurtext;
+
+	function getNDay(nday)
+	{
+		var recurtext = "";
+		if (nday == 1) recurtext += _("first");
+		else if (nday == 2) recurtext += _("second");
+		else if (nday == 3) recurtext += _("third");
+		else if (nday == 4) recurtext += _("fourth");
+		else if (nday == 5) recurtext += _("last");
+
+		return recurtext;
+	}
+
+	function getWeekDays(weekdays)
+	{
+		var recurtext = "";
+		if (weekdays == 127) recurtext += _("day");
+		else if (weekdays == 62) recurtext += _("weekday");
+		else if (weekdays == 65) recurtext += _("weekend day");
+		else if (weekdays == 1) recurtext += _("Sunday");
+		else if (weekdays == 2) recurtext += _("Monday");
+		else if (weekdays == 4) recurtext += _("Tuesday");
+		else if (weekdays == 8) recurtext += _("Wednesday");
+		else if (weekdays == 16) recurtext += _("Thursday");
+		else if (weekdays == 32) recurtext += _("Friday");
+		else if (weekdays == 64) recurtext += _("Saturday");
+
+		return recurtext;
+	}
 }
\ No newline at end of file
