@@ -442,7 +442,7 @@ WebClient.prototype.deleteModule = function(module)
  * @param integer height height of the window
  * @param resizable boolean true - window is resizable, false - window is not resizable     
  */ 
-WebClient.prototype.openWindow = function(moduleObject, name, url, width, height, resizable) 
+WebClient.prototype.openWindow = function(moduleObject, name, url, width, height, resizable, callback, callbackdata, windowdata) 
 {
 	this.clearDialogs();
 
@@ -465,7 +465,7 @@ WebClient.prototype.openWindow = function(moduleObject, name, url, width, height
 	name = window.name + "_" + name + "_" + this.dialogid;
 	this.dialogid++;
 
-	var windowObj = dialog(url, name, "toolbar=0,scrollbars=0,location=0,status=1,menubar=0,resizable=" + windowresizable + ",width=" + windowwidth + ",height=" + windowheight + ",top=" + ((screen.height / 2) - (windowheight / 2)) + ",left=" + ((screen.width / 2) - (windowwidth / 2)));
+	var windowObj = dialog(url, name, "toolbar=0,scrollbars=0,location=0,status=1,menubar=0,resizable=" + windowresizable + ",width=" + windowwidth + ",height=" + windowheight + ",top=" + ((screen.height / 2) - (windowheight / 2)) + ",left=" + ((screen.width / 2) - (windowwidth / 2)), false, callback, callbackdata, windowdata);
 
 	this.registerDialog(moduleObject, name, windowObj);
 
