@@ -184,7 +184,7 @@ XMLRequest.prototype.readyStateChange = function()
 					if (requests[i].status != 0)
 						message += requests[i].status+" "+(requests[i].statusText==""?_("Unknown Error"):requests[i].statusText);
 					else
-						message += "Connection to server lost";
+						message += _("Connection to server lost");
 
 					webclient.xmlrequest.showError(message);
 					webclient.xmlrequest.hideLoader();
@@ -200,7 +200,7 @@ XMLRequest.prototype.readyStateChange = function()
 					// we have an error in the XML here, or no XML at all
 					// all "loading" modules must be informed about this,
 					// for now, just show the browser error...
-					webclient.xmlrequest.showError("Unknown server or connection problem");
+					webclient.xmlrequest.showError(_("Unknown server or connection problem"));
 
 					/*
 					if (e.description){
