@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -103,8 +105,8 @@
 			$filename = "client/layout/dialogs/" . $type . "/" . $task . ".php";
 			
 			if (!is_readable($filename)){
-				// fallback to IPM.Note if message_class is IPM.Note.*
-				if (substr($task,0,4)=="note"){
+				// fallback to IPM.Note if message_class is IPM.Note.* or IPM.Zarafa.Stub
+				if (substr($task,0,4)=="note" || $task=="zarafa_stub"){
 					$filename = "client/layout/dialogs/" . $type . "/readmail.php";
 				}else{
 					$filename = "client/layout/dialogs/not_implemented.php";
