@@ -56,6 +56,9 @@
 	*/
 	require_once("client/layout/dialogs/utils.php");
 
+	// include class file for creating a zip archive file for all attachments.
+	include_once("server/core/class.createZipArchive.php");
+
 	// Get store id
 	$storeid = false;
 	if(isset($_GET["store"])) {
@@ -73,6 +76,18 @@
 	if(isset($_GET["openType"])) {
 		$openType = get("openType", false, false, STRING_REGEX);
 	}
+
+	// Check download type isset
+	$downloadType = "";
+	if(isset($_GET["downloadType"])) {
+		$downloadType = get("downloadType", false, false, STRING_REGEX);
+	}
+		
+	// Check mailsubject is there or not
+	$mailSubject = "";
+	if(isset($_GET["mailSubject"])) {
+		$mailSubject = get("mailSubject", false, false, false);
+	}
 		
 	// Get number of attachment which should be opened.
 	$attachNum = false;
@@ -98,15 +113,19 @@
 		$attachCid = get("attachCid", false, false, FILENAME_REGEX);
 	}
 
-	// open already saved attachment
-	if($storeid && $entryid) {
-		if(!openSavedAttachments($storeid, $entryid, $openType, $attachNum, $attachCid)) {
-			// possibly we are accessing a temporary attachment in a saved message
+	if($downloadType == "downloadAll"){
+		downloadAllFilesInZipArchive($storeid, $entryid, $openType, $attachNum, $attachCid, $mailSubject);
+	}else{
+		// open already saved attachment
+		if($storeid && $entryid) {
+			if(!openSavedAttachments($storeid, $entryid, $openType, $attachNum, $attachCid)) {
+				// possibly we are accessing a temporary attachment in a saved message
+				openTemporaryAttachments($storeid, $entryid, $openType, $attachNum);
+			}
+		} else {
+			// Open recently uploaded (not saved) attachment
 			openTemporaryAttachments($storeid, $entryid, $openType, $attachNum);
 		}
-	} else {
-		// Open recently uploaded (not saved) attachment
-		openTemporaryAttachments($storeid, $entryid, $openType, $attachNum);
 	}
 
 	/*********** Internal Functions ***********/
@@ -118,10 +137,11 @@
 	 * @param String $openType can be inline / attachment (content disposition type)
 	 * @param Array $attachNum numeric indexes of attachments to be opened
 	 * @param String $attachCid attachment content id for inline images
+	 * @param Boolean $getContentsOnly contains true if we only wants the contents of a file, to create a zip file of all files.
 	 * 
 	 * @return Boolean true on success, false on failure
 	 */
-	function openSavedAttachments($storeid, $entryid, $openType, $attachNum, $attachCid) {
+	function openSavedAttachments($storeid, $entryid, $openType, $attachNum, $attachCid, $getContentsOnly=false) {
 		// Open the store
 		$store = $GLOBALS["mapisession"]->openMessageStore(hex2bin($storeid));
 
@@ -191,25 +211,8 @@
 						$filename = $props[PR_DISPLAY_NAME];
 					} 
 			
-					// Parse the extension of the filename to get the content type
-					if(strrpos($filename, ".") !== false) {
-						$extension = strtolower(substr($filename, strrpos($filename, ".")));
-						$contentType = "application/octet-stream";
-						if (is_readable(MIME_TYPES)){
-							$fh = fopen(MIME_TYPES,"r");
-							$ext_found = false;
-							while (!feof($fh) && !$ext_found){
-								$line = fgets($fh);
-								preg_match("/(\.[a-z0-9]+)[ \t]+([^ \t\n\r]*)/i", $line, $result);
-								if ($extension == $result[1]){
-									$ext_found = true;
-									$contentType = $result[2];
-								}
-							}
-							fclose($fh);
-						}
-					}
-					
+					$contentType = getMIMEType($filename);
+
 					// Set the headers
 					header("Pragma: public");
 					header("Expires: 0"); // set expiration time
@@ -224,6 +227,13 @@
 					$stream = mapi_openpropertytostream($attachment, PR_ATTACH_DATA_BIN);
 					$stat = mapi_stream_stat($stream);
 
+					// if we want only contents then pass the content writing on header
+					if($getContentsOnly){
+						if($stream) 
+							return array("content" => mapi_stream_read($stream, $stat["cb"]), "filename" => $filename);
+						return false;
+					}
+
 					// File length
 					header("Content-Length: " . $stat["cb"]);
 					for($i = 0; $i < $stat["cb"]; $i += BLOCK_SIZE) {
@@ -246,8 +256,9 @@
 	 * @param HexString $entryid entryid of message
 	 * @param String $openType can be inline / attachment (content disposition type)
 	 * @param Array $attachNum numeric indexes of attachments to be opened
+	 * @param Boolean $getContentsOnly contains true if we only wants the contents of a file, to create a zip file of all files.
 	 */
-	function openTemporaryAttachments($storeid, $entryid, $openType, $attachNum) {
+	function openTemporaryAttachments($storeid, $entryid, $openType, $attachNum, $getContentsOnly=false) {
 		if(isset($_GET["dialog_attachments"])) {
 			if(isset($_SESSION["files"])) {
 				// we can only open one attachment in a request,
@@ -256,7 +267,13 @@
 					// return recent uploaded file  
 					$tmpname = TMP_PATH."/".$attachNum[0];
 					$filename = $_SESSION["files"][get("dialog_attachments")][$attachNum[0]]["name"];
-
+					
+					// if we want only contents then pass the content writing on header
+					if($getContentsOnly){
+						if(is_file($tmpname)){
+							return array("content" => file_get_contents($tmpname), "filename" => $filename);
+						}
+					}
 					// Check if the file still exists
 					if(is_file($tmpname)) {
 						// Set the headers
@@ -277,4 +294,87 @@
 			}
 		}
 	}
+
+	/**
+	 * Function will create a zip file containing all attachments.
+	 * 
+	 * @param HexString $storeid store id
+	 * @param HexString $entryid entryid of message
+	 * @param String $openType can be inline / attachment (content disposition type)
+	 * @param Array $attachNum numeric indexes of attachments to be opened
+	 * @param String $attachCid attachment content id for inline images
+	 * @param String $mailSubject contains the subject of mail
+	 */
+	function downloadAllFilesInZipArchive($storeid, $entryid, $openType, $attachNum, $attachCid, $mailSubject) {
+		/**
+		 * @TODO :// Find some code, which can directly stream the data of zip file rather creating it in memory.
+		 * increase the memory for a longer file creation.
+		 * ini_set('memory_limit', '64M');
+		 */
+
+		$fileContents = array();
+
+		// create a object of creating Zip archive File
+		$createZipFile=new CreateZipFile;
+		
+		// set output directory
+		$outputDir="";
+		$fileNames = array();
+
+		$createZipFile->addDirectory($outputDir);
+
+		for($att=0;$att<count($attachNum);$att++){
+			if(is_numeric($attachNum[$att])){
+				$fileContent = openSavedAttachments($storeid, $entryid, $openType, array($attachNum[$att]), $attachCid, true);	
+			}else{
+				$fileContent = openTemporaryAttachments($storeid, $entryid, $openType, array($attachNum[$att]), true);
+			}
+
+			//check for the duplicate file name
+			if($fileContent){
+				$fileContent["filename"] = updateDuplicateName($fileContent["filename"], $fileNames);
+				array_push($fileNames, $fileContent["filename"]);
+				
+				// add the file into zip file.
+				$createZipFile->addFile($fileContent["content"], $outputDir.$fileContent["filename"]);
+			}
+		}
+
+		//create a zip file name from subject or from date.
+		$fileName = ($mailSubject) ? $mailSubject : date("h_i_s-j_m_Y");
+
+		// download the created zip file.
+		$zipName = TMP_PATH . "/" . $fileName . ".zip";
+		
+		$zipFile = fopen($zipName, "wb");
+		$out = fwrite($zipFile, $createZipFile->getZippedfile());
+		fclose($zipFile);
+		$createZipFile->forceDownload($zipName);
+		@unlink($zipName);
+	}
+
+	/**
+	 * Function which checks, if filename is already in filenames array or not.
+	 * If name found duplicate, it converts it to a unique name.
+	 * 
+	 * @param String $fileName file name to check for duplicate name
+	 * @param Array $fileNames fileNames array to be checked 
+	 * 
+	 * @return String $fileName changed file name
+	 */
+	function updateDuplicateName($fileName, $fileNames){
+		$tmpFileName = $fileName;
+		$duplicateCounter = 1;
+		while(in_array($tmpFileName, $fileNames)){
+			$fileNameArr = split("[/\\.]", $fileName);
+			if(count($fileNameArr) > 1){
+				$extension = array_pop($fileNameArr);
+				$fileNameArr[count($fileNameArr)-1] .= '_' . $duplicateCounter++;
+				$tmpFileName = join(".", $fileNameArr) . "." . $extension;
+			}else{
+				$tmpFileName = join("", $fileNameArr) . "_" . $duplicateCounter++;
+			}
+		}
+		return $tmpFileName;
+	}
 ?>
\ No newline at end of file
