@@ -81,6 +81,9 @@ function getJavaScript_onload(){ ?>
 
 					parentModule = windowData.parentModule;
 					
+					// This will set inbox folder as default selected folder
+					module.selectFolder("<?=get("parent_entryid", "none", false, ID_REGEX)?>");
+
 					var text;
 					if (parentModule.selectedMessages.length>1){
 						text = "<?=_("There are %s messages selected")?>";
@@ -96,18 +99,24 @@ function getJavaScript_onload(){ ?>
 <?php } // getJavaSctipt_onload	
 
 function getJavaScript_other(){ ?>
-			var source_entryid = "<?=get("source_entryid","none", false, ID_REGEX)?>";
-			var parent_entryid;
+			var parent_entryid = "<?=get("parent_entryid","none", false, ID_REGEX)?>";
 			var parentModule;
 			
 			function submit(type)
 			{
 				if (!type) type = "copy";
-				
+
 				var target_entryid = module.selectedFolder;
-                var target_store = module.selectedFolderStoreId;
-                
-				parentModule.copyMessages(target_store, target_entryid, type, false);
+				var target_store = module.selectedFolderStoreId;
+				
+				if(!target_entryid){
+					alert("<?=_("Please select the destination Folder to copy/move selected message/s")?>");
+				}else if(compareEntryIds(target_entryid, module.defaultstore.root.entryid)){
+					// this check whether the target folder is a root folder or not
+					alert("<?=_("Cannot move the items. The destination folder cannot contain messages/forms.")?>");
+				}else{
+					parentModule.copyMessages(target_store, target_entryid, type, false);
+				}
 				
 				window.close();
 			}
