@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -71,7 +73,7 @@ function getJavaScript_other(){ ?>
 				var basedate = dhtml.getElementById("basedate").value;
 				var parententryid = dhtml.getElementById("parententryid").value;
 				var meeting = dhtml.getElementById("meeting").value;
-				var send = dhtml.getElementById("send").value;
+				var elementid = dhtml.getElementById("elementid").value;
 
 				var uri = DIALOG_URL+"task=appointment_standard&storeid=" + storeid + "&entryid=" + entryid + "&parententryid=" + parententryid;
 				var dialogname = window.name;
@@ -79,51 +81,16 @@ function getJavaScript_other(){ ?>
 					dialogname = window.dialogArguments.dialogName;
 				}
 				
-				if(!parentWebclient.dialogs[dialogname]){
-				//it handles cancelinvitation for an item module appointments
-					var	parentModule = parentwindow.webclient.dialogs[dialogname].module;
-					if(send == "false"){
-						if(openOcc.checked) {
-							parentModule.deleteMessage(send,basedate);
-						} else {
-							parentModule.deleteMessage(send);
-						}
-					}
+				var parentModuleType = window.windowData.parentModuleType;
+				if(parentModuleType && parentModuleType == "item"){
+					//it handles cancelinvitation for an item module appointments
+					var parentModule = window.windowData.parentModule;
+					parentModule.deleteMessage(openOcc.checked ? basedate : false);
 					window.resultCallBack();
-
 				} else {
-				//it handles cancleinvitation for list module appointments
-					var	parentModule = parentWebclient.dialogs[dialogname].module;
-					if(send == "false"){
-						if (openOcc.checked) {
-							parentModule.deleteAppointment(entryid,basedate);
-						} else {
-							parentModule.deleteAppointment(entryid, false);
-						}
-					}
-				}
-
-				if((meeting == 1) && (send == "true")){
-					if(openOcc.checked) {
-						var data = new Array();
-						data["store"] = storeid;
-						data["entryid"] = entryid;
-						data["delete"] = true;
-						data["exception"] = true;
-						data["basedate"] = basedate;
-
-						// The cancel call will delete the meeting appointment for us
-						parentWebclient.xmlrequest.addData(parentModule, "cancelInvitation", data, webclient.modulePrefix);
-						parentWebclient.xmlrequest.sendRequest(true);
-					} else {
-						var data = new Array();
-						data["store"] = storeid;
-						data["entryid"] = entryid;
-
-						// The cancel call will delete the item for us
-						parentWebclient.xmlrequest.addData(parentModule, "cancelInvitation", data, webclient.modulePrefix);
-						parentWebclient.xmlrequest.sendRequest(true);
-					}
+					//it handles cancleinvitation for list module appointments
+					var parentModule = window.windowData.parentModule;
+					parentModule.deleteAppointment(entryid, openOcc.checked ? basedate : false, elementid);
 				}
 			}
 
@@ -141,7 +108,7 @@ function getBody(){ ?>
 			<input id="storeid"  type="hidden" name="storeid"  value="<?=htmlentities(get("storeid", false, false, ID_REGEX))?>">
 			<input id="basedate" type="hidden" name="basedate" value="<?=htmlentities(get("basedate", false, false, ID_REGEX))?>">
 			<input id="meeting" type="hidden" name="meeting" value="<?=htmlentities($_GET["meeting"])?>">
-			<input id="send" type="hidden" name="send" value="<?=htmlentities(get("send", false, false, STRING_REGEX))?>">
+			<input id="elementid" type="hidden" name="elementid" value="<?=htmlentities(get("elementid", false, false, ID_REGEX))?>">
 			</ul>
 			
 			<?=createConfirmButtons("deleteAppointment();window.close();")?>
