@@ -85,8 +85,13 @@ function getJavaScript_onload(){ ?>
 					} ?>
 					
 					<? } ?>
-					
-					module.open(<?=get("entryid","false", "'", ID_REGEX)?>, <?=get("entryid", "false", "'", ID_REGEX)?>, attachNum);
+					var entryid = "<?=get("entryid","", "", ID_REGEX)?>";
+					if(entryid != ""){
+						module.open(entryid, entryid, attachNum);
+					}else{
+						// if entryid is not there that means, the page is called to show unsaved data in printpreview.
+						module.printFromUnsaved(parentwindow);
+					}
 
 					window.onresize();
 <?php } // getJavaScript_onload						
