@@ -79,11 +79,30 @@ function compose_loadSettings(settings){
 	field = dhtml.getElementById("compose_autosave_interval");
 	field.value = value;
 
+	/**
+	 * When replying/forwarding a message whether original message
+	 * should be added with the prefix or without prefix.
+	 * Default is to add prefix i.e. "add_prefix".
+	 * Other option is "include_original_message" to only include a message in reply without prefix.
+	 */
+	value = settings.get("createmail/on_message_replies","add_prefix");
+	field = dhtml.getElementById("mail_reply_prefix");
+	field.value = value;
+
+	value = settings.get("createmail/on_message_forwards","add_prefix");
+	field = dhtml.getElementById("mail_forward_prefix");
+	field.value = value;
+
 	// cursor position when replying to mail
 	value = settings.get("createmail/cursor_position", "start");
 	field = dhtml.getElementById("compose_cursorposition");
 	field.value = value;
 
+	// maximum height of TO/CC/BCC fields
+	value = settings.get("createmail/toccbcc_maxrows", "3");
+	field = dhtml.getElementById("compose_toccbcc_maxrows");
+	field.value = value;
+
 	// from address
 	value = settings.get("createmail/from","");
 	field = dhtml.getElementById("compose_email_from_address");
@@ -132,10 +151,22 @@ function compose_saveSettings(settings){
 	field = dhtml.getElementById("compose_autosave_interval");
 	settings.set("createmail/autosave_interval", Number(field.value));
 
+	// On message replies
+	field = dhtml.getElementById("mail_reply_prefix");
+	settings.set("createmail/on_message_replies", field.value);
+
+	// On message forwards
+	field = dhtml.getElementById("mail_forward_prefix");
+	settings.set("createmail/on_message_forwards", field.value);
+
 	// cursor position
 	field = dhtml.getElementById("compose_cursorposition");
 	settings.set("createmail/cursor_position", field.value);
 
+	// maximum height of TO/CC/BCC fields
+	field = dhtml.getElementById("compose_toccbcc_maxrows");
+	settings.set("createmail/toccbcc_maxrows", field.value);
+
 	// from address
 	field = dhtml.getElementById("compose_email_from_address");
 	var values = new Array();
