@@ -91,6 +91,25 @@ function compose_settings_html(){ ?>
 				<th colspan="2"><input id="compose_autosave" type="checkbox" class="checkbox"><label for="compose_autosave"><?=_("AutoSave unsent every:")?></label> <input id="compose_autosave_interval" type="text" class="text" style="width: 25px;"> <?=_('minutes')?></th>
 			</tr>
 
+			<tr>
+				<th><label for="mail_reply_prefix"><?=_("When replying a message")?></label></th>
+				<td>
+					<select id="mail_reply_prefix">
+						<option value="include_original_message"><?=_("Include original message text")?></option>
+						<option value="add_prefix"><?=_("Prefix each line of the original message")?></option>
+					</select>
+				</td>
+			</tr>
+			<tr>
+				<th><label for="mail_forward_prefix"><?=_("When forwarding a message")?></label></th>
+				<td>
+					<select id="mail_forward_prefix">
+						<option value="include_original_message"><?=_("Include original message text")?></option>
+						<option value="add_prefix"><?=_("Prefix each line of the original message")?></option>
+					</select>
+				</td>
+			</tr>
+
 			<tr>
 				<th><label for="compose_cursorposition"><?=_("Cursor position when replying")?></label></th>
 				<td>
@@ -101,6 +120,18 @@ function compose_settings_html(){ ?>
 				</td>
 			</tr>
 
+			<tr>
+				<th><label for="compose_toccbcc_maxrows"><?=_("Maximum height of TO/CC/BCC fields")?></label></th>
+				<td>
+					<select id="compose_toccbcc_maxrows">
+						<option value="1">1</option>
+						<option value="2">2</option>
+						<option value="3">3</option>
+						<option value="4">4</option>
+						<option value="5">5</option>
+					</select>
+				</td>
+			</tr>
 		</table>
 	</fieldset>
 
