@@ -66,6 +66,10 @@ function shortcuts_settings_html(){ ?>
 				<td><input id="shortcuts_off" type="radio" name="shortcuts_options"><?=_("OFF")?><br><input id="shortcuts_on" type="radio" name="shortcuts_options"><?=_("ON")?></td>
 			</tr>
 		</table>
+		<table >
+			<tr><th><label><?=_('Press keys together')?></label></th></tr>
+			<tr><th><?=_('For example, to open shared folder hold Z while pressing F')?></th></tr>
+		</table>
 	<fieldset>
 		<legend><?=_("For basic navigation")?></legend>
 		<table class="shortcuts">
@@ -139,6 +143,10 @@ function shortcuts_settings_html(){ ?>
 				<th><label><?=_("New Task")."  :"?></label>
 				<td><div id="new_task"></div></td>
 			</tr>
+			<tr>
+				<th><label><?=_("New Task Request")."  :"?></label>
+				<td><div id="new_taskrequest"></div></td>
+			</tr>
 			<tr>
 				<th><label><?=_("New Note")."  :"?></label>
 				<td><div id="new_note"></div></td>
