@@ -59,14 +59,14 @@ function vacation_loadSettings(settings){
 	field.checked = (value!="true");
 	vacation_signableChange();
 
-	// subject
-	value = settings.get("outofoffice/subject","");
+	// subject, set with default value
+	value = settings.get("outofoffice/subject",_("Out of Office"));
 	field = dhtml.getElementById("vacation_subject");
 	field.value = value;
 
 
-	// message
-	value = settings.get("outofoffice/message","");
+	// message, set with default value
+	value = settings.get("outofoffice/message",_("User is currently out of office")+".");
 	field = dhtml.getElementById("vacation_message");
 	field.value = value;
 }
