@@ -119,6 +119,10 @@ function getJavaScript_other(){ ?>
 			var tableWidget = null;
 			var FREEBUSY_DAYBEFORE_COUNT;
 			var FREEBUSY_NUMBEROFDAYS_COUNT;
+			var mrSetupNormal = 0; // New MR setup
+			var mrSetupOrganiser = 1; // Oraganizer MR setup
+			var mrSetupAttendee = 2; // Attendee MR setup
+
 <?php } // getJavaScript_other
 
 function getJavaScript_onload(){ 
@@ -159,9 +163,9 @@ function getJavaScript_onload(){
 					}
 					
 					if (window.location.search.indexOf("meeting=true")>0){
-						meetingRequestSetup(1);
+						meetingRequestSetup(mrSetupOrganiser);
 					}else{
-						meetingRequestSetup(0);
+						meetingRequestSetup(mrSetupNormal);
 					}
 					resizeBody();
 					tabbarControl = tabbar; // FIXME: this is a hack for the tabbar to make it global
@@ -169,6 +173,7 @@ function getJavaScript_onload(){
 					dhtml.addEvent(false, dhtml.getElementById("subject"), "contextmenu", forceDefaultActionEvent);
 					dhtml.addEvent(false, dhtml.getElementById("location"), "contextmenu", forceDefaultActionEvent);
 					dhtml.addEvent(false, dhtml.getElementById("html_body"), "contextmenu", forceDefaultActionEvent);
+					dhtml.addEvent(module, dhtml.getElementById("categories"), "blur", eventFilterCategories);
 
 					if (window.location.search.indexOf("allDayEvent=true")>0){
 						onChangeAllDayEvent(true);
@@ -198,6 +203,28 @@ function getJavaScript_onload(){
 						suggestEmailModule.addSuggestionList(suggestlistTO);
 					}
 
+					if (<?=get("counterproposal","false","'", NUMERIC_REGEX)?>) {
+						module.counterProposal = <?=get("counterproposal", "false", false, NUMERIC_REGEX)?>;
+						module.proposedStartDate = <?=get("proposedstartdate", "false", false, TIMESTAMP_REGEX)?>;
+						module.proposedEndDate = <?=get("proposedenddate", "false", false, TIMESTAMP_REGEX)?>;
+						module.viewAllProposals = <?=get("viewallproposals", "false", false, NUMERIC_REGEX)?>;
+					}
+					// check if we need to send the request to convert the selected message as appointment
+					if(window.windowData && window.windowData["action"] == "convert_item") {
+						module.sendConversionItemData(windowData);
+					}
+
+					// check whether we are draggging contact item to calendar folder
+					if(window.windowData && window.windowData["action"] == "convert_contact") {
+						dhtml.getElementById("toccbcc").value = window.windowData["emails"];
+						dhtml.getElementById("subject").focus();
+					}
+
+					// check whether we are draggging scheduled meeting to calendar folder
+					if(window.windowData && window.windowData["action"] == "convert_meeting") {
+						module.setBodyFromItemData(window.windowData["data"]);
+					}
+
 <?php } // getJavaScript_onload						
 					
 function getBody() { 
@@ -230,6 +257,9 @@ function getBody() {
 		<input id="commonassign" type="hidden" value="0">
 		<input id="sent_representing_email_address" type="hidden" value="">
 		<input id="sent_representing_entryid" type="hidden" value="">
+		<input id="sent_representing_name" type="hidden" value="">
+		<input id="sent_representing_addrtype" type="hidden" value="">
+		<input id="sent_representing_search_key" type="hidden" value="">
 		<input id="meeting" type="hidden" value="0">
 		
 		<!-- Recurring information -->
@@ -251,6 +281,7 @@ function getBody() {
 		<input id="nday" type=hidden value="">
 		<input id="numoccur" type=hidden value="">
 		<input id="recurring_pattern" type="hidden" value="">
+		<input id="recur_type" type="hidden" value="">
 		
 		<!-- Timezone for new recurring items -->
 		
@@ -389,6 +420,7 @@ function getBody() {
 							<option value="240">4 <?=_("hours")?></option>
 							<option value="480">8 <?=_("hours")?></option>
 							<option value="720">0,5 <?=_("day")?></option>
+							<option value="1080">18 <?=_("hours")?></option>
 							<option value="1440">1 <?=_("day")?></option>
 							<option value="2880">2 <?=_("days")?></option>
 							<option value="4320">3 <?=_("days")?></option>
@@ -418,7 +450,7 @@ function getBody() {
 			<table width="99%" border="0" cellpadding="1" cellspacing="0">
 				<tr>
 					<td class="propertynormal propertywidth" valign="top">
-						<input class="button" type="button" value="<?=_("Attachments")?>:" onclick="webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 350, '0');">
+						<input class="button" type="button" value="<?=_("Attachments")?>:" onclick="webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 370, '0');">
 					</td>
 					<td valign="top">
 						<div id="itemattachments">&nbsp;</div>
@@ -536,8 +568,15 @@ function getMenuButtons(){
 				'id'=>"attachment",
 				'name'=>"",
 				'title'=>_("Add Attachments"),
-				'callback'=>"function(){webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 350, '0');}"
+				'callback'=>"function(){webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 370, '0');}"
 			),
+/* Disable Attach item
+			array(
+				'id'=>"attach_item",
+				'name'=>"",
+				'title'=>_("Attach item"),
+				'callback'=>"function(){webclient.openModalDialog(module, 'attachitem', DIALOG_URL+'task=attachitem_modal&storeid=' + module.storeid + '&entryid=' + module.parententryid +'&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 480, false, false, {module : module});}"
+			), */
 			array(
 				'id'=>"seperator",
 				'name'=>"",
@@ -572,7 +611,7 @@ function getMenuButtons(){
 				'id'=>"inviteattendees",
 				'name'=>_("Invite Attendees"),
 				'title'=>_("Invite Attendees"),
-				'callback'=>"function(){meetingRequestSetup(1);}"
+				'callback'=>"function(){meetingRequestSetup(mrSetupOrganiser);}"
 			),
 			array(
 				'id'=>"cancelinviteattendees",
