@@ -138,6 +138,7 @@ function getJavaScript_onload(){
 						dhtml.addEvent(false, textareaElements[i], "contextmenu", forceDefaultActionEvent);
 					}
 					dhtml.addEvent(false, dhtml.getElementById("html_body"), "contextmenu", forceDefaultActionEvent);
+					dhtml.addEvent(module, dhtml.getElementById("categories"), "blur", eventFilterCategories);
 
 <?php	if (isset($_GET["address"])){ ?>
 					var address = parseEmailAddress(decodeURI("<?=get("address", STRING_REGEX)?>"));
@@ -149,8 +150,12 @@ function getJavaScript_onload(){
 						if (typeof(address.emailaddress) == "string"){
 							dhtml.getElementById("email_address").value = address.emailaddress;
 						}
-					}			
+					}
 <?php	} ?>
+					// check if we need to send the request to convert the selected message as contact
+					if(window.windowData && window.windowData["action"] == "convert_item") {
+						module.sendConversionItemData(windowData);
+					}
 
 <?php } // getJavaSctipt_onload						
 
@@ -246,6 +251,9 @@ function getBody() {
 		<input id="selected_phone_2" type="hidden" value="home">
 		<input id="selected_phone_3" type="hidden" value="business_fax">
 		<input id="selected_phone_4" type="hidden" value="cellular">
+		<!-- hidden fields for special date appointment-->
+		<input id="birthday_eventid" type="hidden" value="">
+		<input id="anniversary_eventid" type="hidden" value="">
 
 		<div id="conflict"></div>
 		
@@ -356,7 +364,7 @@ function getBody() {
 				<table width="100%" border="0" cellpadding="1" cellspacing="0">
 					<tr>
 						<td class="propertynormal propertywidth" valign="top">
-							<input class="button" type="button" value="<?=_("Attachments")?>:" onclick="webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 350, '0');">
+							<input class="button" type="button" value="<?=_("Attachments")?>:" onclick="webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 370, '0');">
 						</td>
 						<td valign="top">
 							<div id="itemattachments">&nbsp;</div>
@@ -532,7 +540,7 @@ function getBody() {
 						<?=_("Birthday")?>:
 					</td>
 					<td>
-						<input id="text_birthday" class="field" type="text">
+						<input id="text_birthday" class="field" type="text" onchange="eventDatePickerInputChange()">
 					</td>
 					<td>
 						<div id="text_birthday_button" class="datepicker">&nbsp;</div>
@@ -581,8 +589,15 @@ function getMenuButtons(){
 				'id'=>"attachment",
 				'name'=>"",
 				'title'=>_("Add Attachments"),
-				'callback'=>"function(){webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 350, '0');}"
+				'callback'=>"function(){webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 370, '0');}"
 			),
+/* Disable Attach item
+			array(
+				'id'=>"attach_item",
+				'name'=>"",
+				'title'=>_("Attach item"),
+				'callback'=>"function(){webclient.openModalDialog(module, 'attachitem', DIALOG_URL+'task=attachitem_modal&storeid=' + module.storeid + '&entryid=' + module.parententryid +'&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 480, false, false, {module : module});}"
+			), */
 			array(
 				'id'=>"seperator",
 				'name'=>"",
