@@ -64,6 +64,7 @@ function getDialogTitle() {
 function getIncludes(){
 	$includes = array(
 			"client/modules/".getModuleName().".js",
+			"client/widgets/elastictextarea.js",
 			"client/widgets/suggestionlist.js",
 			"client/modules/suggestemailaddressmodule.js",
 			"client/layout/css/suggestionlayer.css",
@@ -105,7 +106,22 @@ function getJavaScript_onload(){ ?>
 
 					module.init(moduleID);
 					module.setData(data);
-					module.open(<?=get("entryid", "false", "'", ID_REGEX)?>, rootentryid, attachNum);
+					
+					// If message_action is forwardasattachment then multiple items is been selected to be added as attachment to the new mail
+					if(data["message_action"] == "forwardasattachment"){
+						module.forwardMultipleItems(windowData);
+					}else{
+						module.open(<?=get("entryid", "false", "'", ID_REGEX)?>, rootentryid, attachNum);
+					}
+
+					// store references of email fields so we don't have to get it every time
+					var emailAddressElements = {
+						"to" : dhtml.getElementById("to"),
+						"cc" : dhtml.getElementById("cc"),
+						"bcc" : dhtml.getElementById("bcc"),
+						"subject" : dhtml.getElementById("subject"),
+						"from" : dhtml.getElementById("from")
+					};
 
 					// Load Suggest Email Address module for the TO, CC and BCC fields
 					var suggestEmailModule = webclient.dispatcher.loadModule("suggestEmailAddressModule");
@@ -113,13 +129,13 @@ function getJavaScript_onload(){ ?>
 						var suggestEmailModuleID = webclient.addModule(suggestEmailModule);
 						suggestEmailModule.init(suggestEmailModuleID);
 						// Setup TO field
-						suggestlistTO = new suggestionList("create_email_to_fld", dhtml.getElementById("to"), suggestEmailModule);
+						suggestlistTO = new suggestionList("create_email_to_fld", emailAddressElements["to"], suggestEmailModule);
 						suggestEmailModule.addSuggestionList(suggestlistTO);
 						// Setup CC field
-						suggestlistCC = new suggestionList("create_email_cc_fld", dhtml.getElementById("cc"), suggestEmailModule);
+						suggestlistCC = new suggestionList("create_email_cc_fld", emailAddressElements["cc"], suggestEmailModule);
 						suggestEmailModule.addSuggestionList(suggestlistCC);
 						// Setup BCC field
-						suggestlistBCC = new suggestionList("create_email_bcc_fld", dhtml.getElementById("bcc"), suggestEmailModule);
+						suggestlistBCC = new suggestionList("create_email_bcc_fld", emailAddressElements["bcc"], suggestEmailModule);
 						suggestEmailModule.addSuggestionList(suggestlistBCC);
 					}
 
@@ -154,7 +170,7 @@ function getJavaScript_onload(){ ?>
 						}else{
 							var settingsFromFieldValues = new Array();
 						}
-						var fromSelect = dhtml.getElementById("from", "select");
+						var fromSelect = emailAddressElements["from"];
 						if(fromSelect){
 							for(var i=0;i<settingsFromFieldValues.length;i++){
 								fromSelect.options[fromSelect.options.length] = new Option(settingsFromFieldValues[i], settingsFromFieldValues[i]);
@@ -180,19 +196,19 @@ function getJavaScript_onload(){ ?>
 
 					// Fetch all the attributes that are passed in the URL
 					<?	if (isset($_GET["to"])){ // for security reasons we need to urlencode this value for javascript?>
-							dhtml.getElementById("to").value = decodeURIComponent("<?=rawurlencode(get("to"))?>");
+							emailAddressElements["to"].value = decodeURIComponent("<?=rawurlencode(stripslashes(get("to")))?>");
 					<?	} ?>
 
 					<? if(isset($_GET["cc"])) { ?>
-							dhtml.getElementById("cc").value = decodeURIComponent("<?=rawurlencode(get("cc"))?>");
+							emailAddressElements["cc"].value = decodeURIComponent("<?=rawurlencode(stripslashes(get("cc")))?>");
 					<?  } ?>
 
 					<? if(isset($_GET["bcc"])) { ?>
-							dhtml.getElementById("bcc").value = decodeURIComponent("<?=rawurlencode(get("bcc"))?>");
+							emailAddressElements["bcc"].value = decodeURIComponent("<?=rawurlencode(stripslashes(get("bcc")))?>");
 					<?  } ?>
 
 					<? if(isset($_GET["subject"])) { ?>
-							dhtml.getElementById("subject").value = decodeURIComponent("<?=rawurlencode(get("subject"))?>");
+							emailAddressElements["subject"].value = decodeURIComponent("<?=rawurlencode(get("subject"))?>");
 					<?  } ?>
 
 					if(dhtml.getElementById("use_html").value == "false") {
@@ -205,16 +221,16 @@ function getJavaScript_onload(){ ?>
 						}
 					}
 
-					if(dhtml.getElementById("from")){
-						dhtml.addEvent(-1, dhtml.getElementById("from"), "change", changeFromAddress);
+					if(emailAddressElements["from"]){
+						dhtml.addEvent(-1, emailAddressElements["from"], "change", changeFromAddress);
 					}
 
-					setChangeHandlers(dhtml.getElementById("to"));
-					setChangeHandlers(dhtml.getElementById("cc"));
-					setChangeHandlers(dhtml.getElementById("bcc"));
-					setChangeHandlers(dhtml.getElementById("subject"));
+					setChangeHandlers(emailAddressElements["to"]);
+					setChangeHandlers(emailAddressElements["cc"]);
+					setChangeHandlers(emailAddressElements["bcc"]);
+					setChangeHandlers(emailAddressElements["subject"]);
 					setChangeHandlers(dhtml.getElementById("html_body"));
-					setChangeHandlers(dhtml.getElementById("from"));
+					setChangeHandlers(emailAddressElements["from"]);
 
 					resizeBody();
 
@@ -227,16 +243,26 @@ function getJavaScript_onload(){ ?>
 						opener.close();
 					}
 
-					dhtml.getElementById("to").focus();
+					emailAddressElements["to"].focus();
 					
-					// Specifically enable default action on text fields
-					dhtml.addEvent(false, dhtml.getElementById("to"), "contextmenu", forceDefaultActionEvent);
-					dhtml.addEvent(false, dhtml.getElementById("cc"), "contextmenu", forceDefaultActionEvent);
-					dhtml.addEvent(false, dhtml.getElementById("bcc"), "contextmenu", forceDefaultActionEvent);
-					dhtml.addEvent(false, dhtml.getElementById("from"), "contextmenu", forceDefaultActionEvent);
-					dhtml.addEvent(false, dhtml.getElementById("subject"), "contextmenu", forceDefaultActionEvent);
+					// Specifically enable default action on textfields / textareas
+					dhtml.addEvent(false, emailAddressElements["to"], "contextmenu", forceDefaultActionEvent);
+					dhtml.addEvent(false, emailAddressElements["cc"], "contextmenu", forceDefaultActionEvent);
+					dhtml.addEvent(false, emailAddressElements["bcc"], "contextmenu", forceDefaultActionEvent);
+					dhtml.addEvent(false, emailAddressElements["from"], "contextmenu", forceDefaultActionEvent);
+					dhtml.addEvent(false, emailAddressElements["subject"], "contextmenu", forceDefaultActionEvent);
 					dhtml.addEvent(false, dhtml.getElementById("html_body"), "contextmenu", forceDefaultActionEvent);
 					
+					// add functionality of auto expanding textareas
+					var elasticTextareaTo = new ElasticTextarea(emailAddressElements["to"], "createmail/toccbcc_maxrows", resizeBody);
+					var elasticTextareaCc = new ElasticTextarea(emailAddressElements["cc"], "createmail/toccbcc_maxrows", resizeBody);
+					var elasticTextareaBcc = new ElasticTextarea(emailAddressElements["bcc"], "createmail/toccbcc_maxrows", resizeBody);
+
+					// disable spell checking of firefox
+					emailAddressElements["to"].spellcheck = false;
+					emailAddressElements["cc"].spellcheck = false;
+					emailAddressElements["bcc"].spellcheck = false;
+
 					// Set flag to take necessary decisions on attachments 
 					module.messageAction = data["message_action"];
 
@@ -250,6 +276,17 @@ function getJavaScript_onload(){ ?>
 
 					// Notify the ZarafaDnD Firefox extension that this dialog accepts dragged files
 					allowDnDFiles();
+
+					// check if we need to send the request to convert the selected message as mail
+					if(window.windowData && window.windowData["action"] == "convert_item") {
+						module.sendConversionItemData(windowData);
+					}
+
+					// check whether we are draggging contact item to inbox folder
+					if(window.windowData && window.windowData["action"] == "convert_contact") {
+						dhtml.getElementById("to").value = window.windowData["emails"];
+						dhtml.getElementById("subject").focus();
+					}
 <?php } // getJavaScript_onload
 
 function getJavaScript_other(){
@@ -354,12 +391,16 @@ function getJavaScript_other(){
 			{
 				for(key in recips) {
 					if (key!="multiple" && key!="value"){
-						dhtml.getElementById(key).value = recips[key].value;
+						var fieldElement = dhtml.getElementById(key);
+						fieldElement.value = recips[key].value;
+						// fire on change event so textareas can be auto expanded
+						dhtml.executeEvent(fieldElement, "change");
 					}
 				}
 
-				dhtml.getElementById(abSelection).select();
-				dhtml.getElementById(abSelection).focus();
+				var selectionElement = dhtml.getElementById(abSelection);
+				selectionElement.select();
+				selectionElement.focus();
 			}
 			
 			function handleFCKeditorEvent(event)
@@ -401,6 +442,18 @@ function getBody(){
 		<input id="sent_representing_name" type="hidden" value="">
 		<input id="sent_representing_email_address" type="hidden" value="">
 		<input id="sent_representing_addrtype" type="hidden" value="SMTP">
+
+		<!-- properties for flags -->
+		<input id="flag_status" type="hidden" value="">
+		<input id="flag_icon" type="hidden" value="">
+		<input id="reminder_time" type="hidden" value="">
+		<input id="reminder_set" type="hidden" value="false">
+		<input id="flag_request" type="hidden" value="">
+		<input id="flag_due_by" type="hidden" value="">
+		<input id="flag_complete_time" type="hidden" value="">
+		<input id="reply_requested" type="hidden" value="">
+		<input id="reply_time" type="hidden" value="">
+		<input id="response_requested" type="hidden" value="">
 		
 		<div id="conflict"></div>
 
@@ -428,11 +481,11 @@ function getBody(){
 					{
 				?>
 					<tr>
-						<td class="propertynormal propertywidth" align="center">
+						<td class="propertynormal propertywidth" align="center" valign="top">
 							<input class="button" type="button" value="<?=$recipient?>..." onclick="abSelection='<?=$key?>'; webclient.openModalDialog(module, 'addressbook', DIALOG_URL+'task=addressbook_modal&storeid=' + module.storeid + '&<?=$fields?>dest=<?=$key?>', 800, 500, abCallBack);">
 						</td>
 						<td>
-							<input id="<?=$key?>" class="field" type="text">
+							<textarea id="<?=$key?>" class="field"></textarea>
 						</td>
 					</tr>
 				<?
@@ -449,7 +502,7 @@ function getBody(){
 				</tr>
 				<tr>
 					<td class="propertynormal propertywidth" valign="top">
-						<input class="button" type="button" value="<?=_("Attachments")?>:" onclick="webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 350, '0');">
+						<input class="button" type="button" value="<?=_("Attachments")?>:" onclick="webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 370, '0');">
 					</td>
 					<td valign="top">
 						<div id="itemattachments">&nbsp;</div>
@@ -483,12 +536,25 @@ function getMenuButtons(){
 				'title'=>_("Save"),
 				'callback'=>'function(){submit_createmail(false);}'
 			),
+			array(
+				'id'=>"print",
+				'name'=>"",
+				'title'=>_("Print"),
+				'callback'=>'function(){webclient.openModalDialog(this, "printing", DIALOG_URL+"task=printitem_modal", 600, 600)}'
+			),
 			array(
 				'id'=>"attachment",
 				'name'=>"",
 				'title'=>_("Add Attachments"),
-				'callback'=>"function(){setMessageChanged();webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 350, '0');}"
+				'callback'=>"function(){setMessageChanged();webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 370, '0');}"
 			),
+/* Disable Attach item
+			array(
+				'id'=>"attach_item",
+				'name'=>"",
+				'title'=>_("Attach item"),
+				'callback'=>"function(){webclient.openModalDialog(module, 'attachitem', DIALOG_URL+'task=attachitem_modal&storeid=' + module.storeid + '&entryid=' + module.parententryid +'&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 480, false, false, {module : module});}"
+			), */
 			array(
 				'id'=>"seperator",
 				'name'=>"",
@@ -554,6 +620,12 @@ function getMenuButtons(){
 				'name'=>_("Options"),
 				'title'=>_("Options"),
 				'callback'=>"function(){setMessageChanged();webclient.openModalDialog(module, 'options', DIALOG_URL+'task=mailoptions_modal', 310, 220, mailOptionsCallBack);}"
+			),
+			array(
+				'id'=>"flag_status_red",
+				'name'=>"",
+				'title'=>_("Flag"),
+				'callback'=>"function(){webclient.openModalDialog(module, 'flag', DIALOG_URL+'task=flag_modal&store_values=true', 350, 180);}"
 			)
 		);
 }  // getMenuButtons
