@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -54,7 +56,7 @@ function getDialogTitle() {
 }
 
 function getJavaScript_onload(){ ?>
-<?php } // getJavaScript_onload						
+<?php } // getJavaScript_onload
 
 function getIncludes(){
 	return array(
@@ -63,8 +65,8 @@ function getIncludes(){
 }
 
 function getJavaScript_other(){ ?>
-        function openAppointment(){
-                var openOcc = dhtml.getElementById("occ");
+		function openAppointment(){
+				var openOcc = dhtml.getElementById("occ");
 
 				var entryid = dhtml.getElementById("entryid").value;
 				var storeid = dhtml.getElementById("storeid").value;
@@ -72,23 +74,18 @@ function getJavaScript_other(){ ?>
 				var parententryid = dhtml.getElementById("parententryid").value;
 
 				var uri = DIALOG_URL+"task=appointment_standard&storeid=" + storeid + "&entryid=" + entryid + "&parententryid=" + parententryid;
+				if (openOcc.checked) {
+					// Open the occurrence
+					uri += "&basedate=" + basedate;
+				}
 
-                if (openOcc.checked) {
-                	// Open the occurrence
-                	uri += "&basedate=" + basedate;
-			        parentWebclient.openWindow(this, "appointment", uri);				
-				} else {
-					// Open the series
-			        parentWebclient.openWindow(this, "appointment", uri);				
-				}
+				// Open new appointment window, and set focus on it.
+				var apptWin = parentWebclient.openWindow(-1, "appointment", uri);
+				apptWin.focus();
 				window.close();
-				if(window.BROWSER_IE8){
-					parentWebclient.window.focus();
-				}
-        }
+	}
 <? } // javascript other
 
-                                                
 function getBody(){ ?>
 		<div id="occurrence">
 			<?=_("This is a recurring appointment. Do you want to open only this occurrence or the series?");?>
