@@ -107,6 +107,10 @@ function getBody(){ ?>
 		
 		<div class="properties">
 			<input id="entryid" type="hidden" value="">
+			<input id="ismeetingrequest" type="hidden" value="">
+			<input id="ismeetingcancel" type="hidden" value="">
+
+			<!-- properties for flags -->
 			<input id="flag_status" type="hidden" value="">
 			<input id="flag_icon" type="hidden" value="">
 			<input id="reminder_time" type="hidden" value="">
@@ -117,9 +121,7 @@ function getBody(){ ?>
 			<input id="reply_requested" type="hidden" value="">
 			<input id="reply_time" type="hidden" value="">
 			<input id="response_requested" type="hidden" value="">
-			<input id="ismeetingrequest" type="hidden" value="">
-			<input id="ismeetingcancel" type="hidden" value="">
-					
+
 			<div id="conflict"></div>
 			<div id="extrainfo"></div>
 			
@@ -244,6 +246,18 @@ function getBody(){ ?>
 
 function getMenuButtons(){
 	return array(
+			array(
+				'id'=>"accept_proposal",
+				'name'=>_("Accept Proposal"),
+				'title'=>_("Accept Proposal"),
+				'callback'=>"function(){ openMeeting();}"
+			),
+			array(
+				'id'=>"view_all_proposals",
+				'name'=>_("View All Proposals"),
+				'title'=>_("View All Proposals"),
+				'callback'=>"function(){ openMeeting(true);}"
+			),
 			array(
 				'id'=>"accept",
 				'name'=>_("Accept"),
