@@ -108,7 +108,7 @@ function getBody(){ ?>
 <?php }
 
 function getMenuButtons(){
-	return array(
+	$menuItems = array(
 		array(
 			'id'=>"restore_item",
 			'name'=>_("Restore"),
@@ -120,25 +120,34 @@ function getMenuButtons(){
 			'name'=>_("Restore All"),
 			'title'=>_("Restore all"),
 			'callback'=>'permanent_restore_all'
-		),
-		array(
-			'id'=>"seperator",
-			'name'=>"",
-			'title'=>"",
-			'callback'=>""
-		),
-		array(
-			'id'=>"purge",
-			'name'=>_("Permanent Delete"),
-			'title'=>_("Permanent delete selected items"),
-			'callback'=>'permanent_delete_items'
-		),
-		array(
-			'id'=>"deleteall",
-			'name'=>_("Delete All"),
-			'title'=>_("Permanent delete All"),
-			'callback'=>'permanent_delete_all'
-		),
+		)
+	);
+
+	// add delete buttons only when DISABLE_DELETE_IN_RESTORE_ITEMS config is set to false
+	if(!DISABLE_DELETE_IN_RESTORE_ITEMS) {
+		array_push($menuItems,
+			array(
+				'id'=>"purge",
+				'name'=>_("Permanent Delete"),
+				'title'=>_("Permanent delete selected items"),
+				'callback'=>'permanent_delete_items'
+			),
+			array(
+				'id'=>"deleteall",
+				'name'=>_("Delete All"),
+				'title'=>_("Permanent delete All"),
+				'callback'=>'permanent_delete_all'
+			),
+			array(
+				'id'=>"seperator",
+				'name'=>"",
+				'title'=>"",
+				'callback'=>""
+			)
+		);
+	}
+
+	array_push($menuItems,
 		array(
 			'id'=>"seperator",
 			'name'=>"",
@@ -152,5 +161,7 @@ function getMenuButtons(){
 			'callback'=>"function(){window.close();}"
 		)
 	);
+
+	return $menuItems;
 }
 ?>
\ No newline at end of file
