@@ -56,7 +56,7 @@ require("client/layout/tabbar.class.php");
 function initWindow(){
 	global $tabbar, $tabs;
 
-	$tabs = array("task" => _("Task"), "details" => _("Details"));
+	$tabs = array("task" => _("Task"), "disabledtask" => _("Task"),"details" => _("Details"));
 	$tabbar = new TabBar($tabs, key($tabs));
 }
 
@@ -81,6 +81,9 @@ function getIncludes(){
 			"client/layout/js/date-picker-language.js",
 			"client/layout/js/date-picker-setup.js",
 			"client/layout/css/date-picker.css",
+			"client/layout/css/suggestionlayer.css",
+			"client/widgets/suggestionlist.js",
+			"client/modules/suggestemailaddressmodule.js",
 			"client/modules/".getModuleName().".js"
 		);
 }
@@ -90,6 +93,8 @@ function getJavaScript_onload(){
 	
 	$tabbar->initJavascript("tabbar", "\t\t\t\t\t");
  ?>
+					tabbarControl = tabbar;
+					window.taskrequest = "<?=get("taskrequest","false")?>";
  					module.init(moduleID);
 					module.setData(<?=get("storeid","false","'", ID_REGEX)?>, <?=get("parententryid","false","'", ID_REGEX)?>);
 
@@ -108,7 +113,7 @@ function getJavaScript_onload(){
 					module.open(<?=get("entryid","false","'", ID_REGEX)?>, <?=get("rootentryid","false","'", ID_REGEX)?>, attachNum);
 				
 					Calendar.setup({
-						inputField	:	"text_duedate",				// id of the input field
+						inputField	:	"text_commonend",				// id of the input field
 						ifFormat	:	_('%d-%m-%Y'),					// format of the input field
 						button		:	"text_duedate_button",		// trigger for the calendar (button ID)
 						step		:	1,							// show all years in drop-down boxes (instead of every other year as default)
@@ -116,7 +121,7 @@ function getJavaScript_onload(){
 					});
 					
 					Calendar.setup({
-						inputField	:	"text_startdate",			// id of the input field
+						inputField	:	"text_commonstart",			// id of the input field
 						ifFormat	:	_('%d-%m-%Y'),					// format of the input field
 						button		:	"text_startdate_button",	// trigger for the calendar (button ID)
 						step		:	1,							// show all years in drop-down boxes (instead of every other year as default)
@@ -168,9 +173,43 @@ function getJavaScript_onload(){
    					//Set events for filtering categories.
    					var categories = dhtml.getElementById("categories");
    					dhtml.addEvent(module, categories, "change", eventFilterCategories);
+
+					// check if we need to send the request to convert the selected message as task
+					if(window.windowData && window.windowData["action"] == "convert_item") {
+						module.sendConversionItemData(windowData);
+					}
+   					
+					// Set up buttons
+					setTaskRequestMode(window.taskrequest == "true" ? tdsOWNNEW : tdsNOM, window.taskrequest == "true" ? tdmtTaskReq : tdmtNothing);
+
+					var suggestEmailModule = webclient.dispatcher.loadModule("suggestEmailAddressModule");
+					if(suggestEmailModule != null) {
+						var suggestEmailModuleID = webclient.addModule(suggestEmailModule);
+						suggestEmailModule.init(suggestEmailModuleID);
+						// Setup TO field
+						suggestlistTO = new suggestionList("taskrequest", dhtml.getElementById("to"), suggestEmailModule);
+						suggestEmailModule.addSuggestionList(suggestlistTO);
+					}
 					
-<?php } // getJavaSctipt_onload						
-			
+<?php } // getJavaSctipt_onload
+
+function getJavaScript_other(){
+?>
+		function abCallBack(recips)
+		{
+			for(key in recips) {
+				if (key!="multiple" && key!="value"){
+					var fieldElement = dhtml.getElementById(key);
+					fieldElement.value = recips[key].value;
+				}
+			}
+
+			var selectionElement = dhtml.getElementById("to");
+			selectionElement.select();
+			selectionElement.focus();
+		}
+
+<?php }
 function getBody() {
 	global $tabbar, $tabs;
 	
@@ -190,7 +229,7 @@ function getBody() {
 		<input id="flagdueby" type="hidden" value="">
 		<input id="previousReminderValue" type="hidden" value="0">
 		<input id="reminder" type="hidden" value="0">
-		<input id="reminder_time" type="hidden" value="">
+<!--		<input id="reminder_time" type="hidden" value="">  -->
 		<input id="reminderdate" type="hidden" value="">
 		<input id="totalwork" type="hidden" value="">
 		<input id="actualwork" type="hidden" value="">
@@ -201,7 +240,38 @@ function getBody() {
 		<input id="commonstart" type="hidden" value="">
 		<input id="commonend" type="hidden" value="">
 		<input id="commonassign" type="hidden" value="0">
-		
+
+		<input id="taskstate" type="hidden" value="1">
+		<input id="taskhistory" type="hidden" value="0">
+		<input id="tasklastdelegate" type="hidden" value="0">
+		<input id="assignedtime" type="hidden" value="0">
+		<input id="taskaccepted" type="hidden" value="0">
+		<input id="taskmode" type="hidden" value="0">
+		<input id="ownership" type="hidden" value="0">
+		<input id="delegationstate" type="hidden" value="0">
+
+		<!-- Recurring information -->
+
+		<input id="recurring" type=hidden value="0">
+		<input id="recurring_reset" type=hidden value="0">
+		<input id="startocc" type=hidden value="">
+		<input id="endocc" type=hidden value="">
+		<input id="start" type=hidden value="">
+		<input id="end" type=hidden value="">
+		<input id="term" type=hidden value="">
+		<input id="regen" type=hidden value="">
+		<input id="everyn" type=hidden value="">
+		<input id="subtype" type=hidden value="">
+		<input id="type" type=hidden value="">
+		<input id="weekdays" type=hidden value="">
+		<input id="month" type=hidden value="">
+		<input id="monthday" type=hidden value="">
+		<input id="nday" type=hidden value="">
+		<input id="numoccur" type=hidden value="">
+		<input id="recurring_pattern" type="hidden" value="">
+
+		<div id="extrainfo"></div>
+		<div id="recurtext"></div>
 		<div id="conflict"></div>
 		
 		<div class="properties">
@@ -209,10 +279,12 @@ function getBody() {
 				<table width="100%" border="0" cellpadding="1" cellspacing="0">
 					<tr>
 						<td class="propertynormal propertywidth">
-							<input type="button" class="button" value="<?=_("To")?>:">
+							<input type="button" class="button" value="<?=_("To")?>:" onclick="webclient.openModalDialog(module, 'addressbook', DIALOG_URL+'task=addressbook_modal&dest=to&fields[to]=<?=urlencode(_("To"))?>&storeid='+module.storeid, 800, 500, abCallBack);">
 						</td>
 						<td>
-							<input id="to" class="field" type="text">
+							<input id="to" name="recipient" class="field">
+							<input id="cc" name="recipient" class="field" type="hidden">
+							<input id="bcc" name="recipient" class="field" type="hidden">
 						</td>
 					</tr>
 				</table>
@@ -237,7 +309,7 @@ function getBody() {
 						<?=_("Due Date")?>:
 					</td>
 					<td width="120">
-						<input id="text_duedate" class="fieldsize" type="text" value="<?=_("None")?>" onchange="onChangeDate();">
+						<input id="text_commonend" class="fieldsize" type="text" value="<?=_("None")?>" onchange="onChangeDate(this.id);">
 					</td>
 					<td width="30">
 						<div id="text_duedate_button" class="datepicker">&nbsp;</div>
@@ -260,7 +332,7 @@ function getBody() {
 						<?=_("Start Date")?>:
 					</td>
 					<td>
-						<input id="text_startdate" class="fieldsize" type="text" value="<?=_("None")?>" onchange="onChangeDate();">
+						<input id="text_commonstart" class="fieldsize" type="text" value="<?=_("None")?>" onchange="onChangeDate(this.id);">
 					</td>
 					<td>
 						<div id="text_startdate_button" class="datepicker">&nbsp;</div>
@@ -326,18 +398,18 @@ function getBody() {
 				<table border="0" cellpadding="1" cellspacing="0">
 					<tr>
 						<td width="10">
-							<input id="keepcopy" type="checkbox" checked>
+							<input id="taskupdates" type="checkbox" checked>
 						</td>
 						<td class="propertynormal" nowrap>
-							<label for="keepcopy"><?=_("Keep copy of task in task list")?>.</label>
+							<label for="taskupdates"><?=_("Keep copy of task in task list")?>.</label>
 						</td>
 					</tr>
 					<tr>
 						<td width="10">
-							<input id="statusrapport" type="checkbox" checked>
+							<input id="tasksoc" type="checkbox" checked>
 						</td>
-						<td class="propertynormal" nowrap>
-							<label for="statusrapport"><?=_("Send me a status rapport when task is completed")?>.</label>
+						<td class="tasksoc" nowrap>
+							<label for="tasksoc"><?=_("Send me a status report when task is completed")?>.</label>
 						</td>
 					</tr>
 				</table>
@@ -348,7 +420,7 @@ function getBody() {
 			<table width="99%" border="0" cellpadding="1" cellspacing="0">
 				<tr>
 					<td class="propertynormal propertywidth" valign="top">
-						<input class="button" type="button" value="<?=_("Attachments")?>:" onclick="webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 350, '0');">
+						<input class="button" type="button" value="<?=_("Attachments")?>:" onclick="webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 370, '0');">
 					</td>
 					<td valign="top">
 						<div id="itemattachments">&nbsp;</div>
@@ -386,6 +458,63 @@ function getBody() {
 <?php 
 	$tabbar->endTab();
 	
+	$tabbar->beginTab("disabledtask");
+?>
+		<div id="disabled_extrainfo"></div>
+		<div class="properties">
+			<table width="100%" border="0" cellpadding="1" cellspacing="0">
+				<tr>
+					<td class="propertynormal propertywidth">
+						<?=_("Subject")?>:
+					</td>
+					<td colspan="5">
+						<div id="disabled_subject" class="disabledfield"></div>
+					</td>
+				</tr>
+				<tr>
+					<td class="propertynormal propertywidth">
+						<?=_("Due Date")?>:
+					</td>
+					<td colspan="5">
+						<div id="disabled_duedate" class="disabledfield"></div>
+					</td>
+				</tr>
+				<tr>
+					<td class="propertynormal propertywidth">
+						<?=_("Status")?>:
+					</td>
+					<td width="110">
+						<div id="disabled_status" class="disabledfield"></div>
+					</td>
+					<td class="propertynormal disabledproperty">
+						<?=_("Priority")?>:
+					</td>
+					<td width="110">
+						<div id="disabled_priority" class="disabledfield"></div>
+					</td>
+					<td class="propertynormal disabledproperty">
+						% <?=_("Complete")?>:
+					</td>
+					<td>
+						<div id="disabled_percentcomplete" class=""></div>
+					</td>
+				</tr>
+				<tr>
+					<td class="propertynormal propertywidth">
+						<?=_("Owner")?>:
+					</td>
+					<td colspan="5">
+						<div id="disabled_owner" class="disabledfield"></div>
+					</td>
+				</tr>
+			</table>
+		</div>
+
+		<textarea id="disabled_html_body" cols="60" rows="12" disabled></textarea>
+
+<?php 
+	$tabbar->endTab();
+	
 	$tabbar->beginTab("details");
 ?>
 	
@@ -451,6 +580,24 @@ function getBody() {
 				</tr>
 			</table>
 		</div>
+
+		<div>
+			<table width="100%" border="0" cellpadding="1" cellspacing="0">
+				<tr>
+					<td class="propertynormal propertywidth">
+						<?=_("Update List")?>:
+					</td>
+					<td colspan="4">
+						<input id="display_cc" class="field" type="text" disabled style="width:99%">
+					</td>
+				</tr>
+				<tr>
+					<td colspan="4">
+						<input id="create_unassigned_copy" type="button" value="<?=_("Create Unassigned Copy")?>" disabled onclick="createUnassignedCopy();">
+					</td>
+				</tr>
+			</table>
+		</div>
 	
 <?php
 	$tabbar->endTab();
@@ -458,17 +605,35 @@ function getBody() {
 
 function getMenuButtons(){
 	return array(
-			/*array(
+			array(
+				'id'=>"return_tasklist",
+				'name'=>_("Return to Task List"),
+				'title'=>_("Return to Task List"),
+				'callback'=>'function(){reclaimOwnerShip();}'
+			),
+			array(
+				'id'=>"accept",
+				'name'=>_("Accept"),
+				'title'=>_("Accept"),
+				'callback'=>'function(){submitTask("accept");}'
+			),
+			array(
+				'id'=>"decline",
+				'name'=>_("Decline"),
+				'title'=>_("Decline"),
+				'callback'=>'function(){submitTask("decline");}'
+			),
+			array(
 				'id'=>"send",
 				'name'=>_("Send"),
 				'title'=>_("Send"),
-				'callback'=>'function(){}'
-			),*/
+				'callback'=>'function(){submitTask("request");}'
+			),
 			array(
 				'id'=>"save",
 				'name'=>_("Save"),
 				'title'=>_("Save"),
-				'callback'=>'function(){submitTask()}'
+				'callback'=>'function(){submitTask();}'
 			),
 			array(
 				'id'=>"seperator",
@@ -480,9 +645,22 @@ function getMenuButtons(){
 				'id'=>"attachment",
 				'name'=>"",
 				'title'=>_("Add Attachments"),
-				'callback'=>"function(){webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 350, '0');}"
+				'callback'=>"function(){webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 370, '0');}"
 			),
-			/*array(
+/* Disable Attach item
+			array(
+				'id'=>"attach_item",
+				'name'=>"",
+				'title'=>_("Attach item"),
+				'callback'=>"function(){webclient.openModalDialog(module, 'attachitem', DIALOG_URL+'task=attachitem_modal&storeid=' + module.storeid + '&entryid=' + module.parententryid +'&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 480, false, false, {module : module});}"
+			), */
+			array(
+				'id'=>"checknames",
+				'name'=>"",
+				'title'=>_("Check Names"),
+				'callback'=>'function(){checkNames(checkNamesCallBackTask);}'
+			),
+			array(
 				'id'=>"seperator",
 				'name'=>"",
 				'title'=>"",
@@ -492,15 +670,14 @@ function getMenuButtons(){
 				'id'=>"recurrence",
 				'name'=>_("Recurrence"),
 				'title'=>_("Recurrence"),
-				'callback'=>"function(){}"
-			),*/
+				'callback'=>"function(){webclient.openModalDialog(module, 'recurrence', DIALOG_URL+'task=recurrence_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value + '&taskrecurrence=true', 550, 370, callBackTaskRecurrence);}"
+			),
 			array(
 				'id'=>"seperator",
 				'name'=>"",
 				'title'=>"",
 				'callback'=>""
 			),
-			/*
 			array(
 				'id'=>"assigntask",
 				'name'=>_("Assign Task"),
@@ -509,10 +686,16 @@ function getMenuButtons(){
 			),
 			array(
 				'id'=>"cancelassigntask",
-				'name'=>_("Cancel Assign Task"),
-				'title'=>_("Cancel Assign Task"),
-				'callback'=>"function(){assignTask();}"
-			),*/
+				'name'=>_("Cancel Assignment"),
+				'title'=>_("Cancel Assignment"),
+				'callback'=>"function(){cancelAssignTask();}"
+			),
+			array(
+				'id'=>"seperator",
+				'name'=>"",
+				'title'=>"",
+				'callback'=>""
+			),
 			array(
 				'id'=>"taskcomplete",
 				'name'=>"",
@@ -529,7 +712,7 @@ function getMenuButtons(){
 				'id'=>"delete",
 				'name'=>"",
 				'title'=>_("Delete"),
-				'callback'=>"function(){delete_item()}"
+				'callback'=>"function(){delete_task_item()}"
 			)
 		);
 }
