@@ -276,10 +276,12 @@
 			
 			window.onresize = function()
 			{
-				var data = new Object();
-				data["task"] = "<?=$task?>";
-				data["plugin"] = <?=(($plugin)?'"'.$plugin.'"':"false")?>;
-				webclient.pluginManager.triggerHook("client.dialog.general.onresize.after", data);
+				if(webclient){
+					var data = new Object();
+					data["task"] = "<?=$task?>";
+					data["plugin"] = <?=(($plugin)?'"'.$plugin.'"':"false")?>;
+					webclient.pluginManager.triggerHook("client.dialog.general.onresize.after", data);
+
 <?php
 	
 	if(function_exists("getJavaScript_onresize")) {
@@ -290,10 +292,11 @@
 		}
 	}
 ?>
-				var data = new Object();
-				data["task"] = "<?=$task?>";
-				data["plugin"] = <?=(($plugin)?'"'.$plugin.'"':"false")?>;
-				webclient.pluginManager.triggerHook("client.dialog.general.onresize.before", data);
+					var data = new Object();
+					data["task"] = "<?=$task?>";
+					data["plugin"] = <?=(($plugin)?'"'.$plugin.'"':"false")?>;
+					webclient.pluginManager.triggerHook("client.dialog.general.onresize.before", data);
+				}
 			}
 
 			window.onbeforeunload = function()
