@@ -176,14 +176,13 @@ function addSelectedContacts(destId)
 
 function addressBookSearchKeyInput(moduleObj, element, event)
 {
-	if (event.keyCode == 13){
-		searchAddressBook();
-		return;
-	}
 	var keycode = event.keyCode;
-	
+
 	// skip the search functionality on following keys
 	switch(keycode){
+		case 13:
+			searchAddressBook();
+			return;
 		case 16: // escape shift key
 		case 17: // escape ctrl key
 		case 18: // escape alt key
@@ -193,10 +192,15 @@ function addressBookSearchKeyInput(moduleObj, element, event)
 		case 40: // escape down arrow key
 				return;
 	}
+
+	// fix loss-of-scope in setTimeout function
+	var moduleObject = moduleObj;
+	var textBoxElement = element;
+
 	if(searchKeyInputTimer) window.clearTimeout(searchKeyInputTimer);
 	searchKeyInputTimer = window.setTimeout(
-							function(moduleObj, element){
-								addressBookPerformQuickSearch(moduleObj, element, keycode);
+							function(){
+								addressBookPerformQuickSearch(moduleObject, textBoxElement, keycode);
 							}, 500
 						);
 }
@@ -210,30 +214,35 @@ function addressBookPerformQuickSearch(moduleObj, element, keycode)
 		var divElem = dhtml.getElementById("divelement");
 		if(divElem) divElem.scrollTop = 0;
 		// get the selected row and deselect that
-		eventDeselectMessages(this.module, element, window.event);
+		eventDeselectMessages(moduleObj, element, window.event);
 		return;
 	}
-	// get the sorting option on which we have to search 
-	var searchon = this.module.sort[0]["_content"];
+
+	// get the sorting option on which we have to search
+	var searchon = false;
+	if(typeof moduleObj.sort[0] != "undefined" && typeof moduleObj.sort[0]["_content"] != "undefined") {
+		searchon = moduleObj.sort[0]["_content"];
+	}
+
 	// assign the full AB for searching.
-	if((typeof this.module.searchList == "undefined") || (this.module.searchList == null) || (value.trim() == "") || (keycode == 8)){
-		this.module.searchList = this.module.itemProps;
+	if((typeof moduleObj.searchList == "undefined") || (moduleObj.searchList == null) || (value.trim() == "") || (keycode == 8)){
+		moduleObj.searchList = moduleObj.itemProps;
 	}
 	
-	this.module.searchList = this.module.itemProps;
+	moduleObj.searchList = moduleObj.itemProps;
 	// escape some special characters from value.
 	value = value.replace(/[\\|\*|\+|\(|\)|?]/g, "");
 	var pattern = new RegExp("^"+value,"i");
 	var firstChar = new RegExp("^"+value.substring(0,1),"i");
-	var itemProperties = this.module.searchList;
-	this.module.searchList = null;
+	var itemProperties = moduleObj.searchList;
+	moduleObj.searchList = null;
 	var arr = [];
 	for(key in itemProperties){
 		var item = (typeof itemProperties[key][searchon] != "undefined") ? itemProperties[key][searchon] : itemProperties[key]["display_name"]; 
 		if(pattern.test(item)){
-			if(!this.module.searchList) this.module.searchList = new Object();
-			this.module.searchList[key] = new Object();
-			this.module.searchList[key][searchon] = item;
+			if(!moduleObj.searchList) moduleObj.searchList = new Object();
+			moduleObj.searchList[key] = new Object();
+			moduleObj.searchList[key][searchon] = item;
 			arr.push(item);
 		}
 		if(arr.length >0 && !firstChar.test(item)){
@@ -244,9 +253,9 @@ function addressBookPerformQuickSearch(moduleObj, element, keycode)
 		for(key in itemProperties){
 			var item = (typeof itemProperties[key][searchon] != "undefined") ? itemProperties[key][searchon] : itemProperties[key]["display_name"]; 
 			if(value < item){
-				if(!this.module.searchList) this.module.searchList = new Object();
-				this.module.searchList[key] = new Object();
-				this.module.searchList[key][searchon] = item;
+				if(!moduleObj.searchList) moduleObj.searchList = new Object();
+				moduleObj.searchList[key] = new Object();
+				moduleObj.searchList[key][searchon] = item;
 				arr.push(item);
 				break;
 			}
@@ -259,7 +268,7 @@ function addressBookPerformQuickSearch(moduleObj, element, keycode)
 		if(html_entity_decode(allDivs[i].innerHTML) == arr[0]){
 			var selectElem = allDivs[i].parentNode.parentNode;
 			var selElemTop = dhtml.getElementTop(selectElem);
-			dhtml.getElementById("divelement").scrollTop = parseInt(selectElem.id) * 18;
+			dhtml.getElementById("divelement").scrollTop = parseInt(selectElem.id, 10) * 18;
 			dhtml.executeEvent(selectElem, "mousedown");
 			break;
 		}
@@ -610,10 +619,12 @@ function eventAddressbookListClickAlfabetItem(moduleObject, element, event)
 /**
 * This function will open new mail dialog with selected contacts in TO fields.
 */
-function eventABSendMailTo()
+function eventABSendMailTo(moduleObject, element, event)
 {
 	// Clear the text-field.
 	dhtml.getElementById("anonymous").value = "";
 	addSelectedContacts("anonymous");
-	webclient.openWindow(this, "createmail", DIALOG_URL+"task=createmail_standard&to="+escape(dhtml.getElementById("anonymous").value));
+	if(element)
+		element.parentNode.style.display = "none";
+	webclient.openWindow(this, "createmail", DIALOG_URL+"task=createmail_standard&to="+encodeURIComponent(dhtml.getElementById("anonymous").value));
 }
