@@ -113,14 +113,25 @@ function initAppointment()
 		var responseStatus = parseInt(dhtml.getElementById("responsestatus").value);		
 		meetingRequestSetup(responseStatus);
 	} else {
-		meetingRequestSetup(0);
+		meetingRequestSetup(mrSetupNormal);
 	}
 
 	// Set visible cumulative field
 	var toFld = dhtml.getElementById("to").value;
 	var ccFld = dhtml.getElementById("cc").value;
 	var bccFld = dhtml.getElementById("bcc").value;
-	dhtml.getElementById("toccbcc").value = toFld + " " + ccFld + " " + bccFld;
+
+	// Set all values in array.
+	var toccbccArray = new Array();
+	if(toFld)
+		toccbccArray.push(toFld);
+	if(ccFld)
+		toccbccArray.push(ccFld);
+	if(bccFld)
+		toccbccArray.push(bccFld);
+
+	// Set toccbcc field value by joining array values.
+	dhtml.getElementById("toccbcc").value = toccbccArray.join("; ");
 
 	if(typeof module.itemProps.recipients != "undefined" && typeof module.itemProps.recipients.recipient != "undefined"){
 		var tableData = new Array();
@@ -483,28 +494,35 @@ function submitAppointment(send, requestStatus)
 	
 	// Contacts
 	dhtml.getElementById("contacts_string").value = dhtml.getElementById("contacts").value;
+	// Get receipients for the appointment.
+	var recepientsList = getRecipients();
 	if (!send){
 		// check meeting request
 		var isMeeting = module.itemProps.meeting && module.itemProps.meeting==1;
 		var isOrganizer = module.itemProps.responsestatus && module.itemProps.responsestatus==1;
 		var endtime = dhtml.getElementById("commonend").value * 1000;
-		if (isMeeting && isOrganizer)
-			if( endtime>(new Date().getTime()))
+		if (isMeeting && isOrganizer) {
+			// Check whether there are any recepients in MR or not.
+			if( endtime>(new Date().getTime()) && recepientsList.length > 0) {
 				send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
-
-
+			}
+		}
+	} else if (recepientsList.length == 0) {
+		// If there is no recpients in MR than confirm with user whether he wants to send MR or not.
+		if(!confirm(_("This meeting cannot be sent because there are no recipients added. Would you like to save and close this meeting instead.")))
+			return;
 	}
 
 	if(module){
 		var props = getPropsFromDialog();
 
-		if(module.isMeeting && validateEmailAddress(dhtml.getElementById("toccbcc").value)){
+		if(module.isMeeting && validateEmailAddress(dhtml.getElementById("toccbcc").value, false, module.resolveForSendingMR?false:true)){
 			dhtml.getElementById("meeting").value = "1";
 			if(!module.itemProps.entryid || (module.itemProps.responsestatus && module.itemProps.responsestatus==1))
 				dhtml.getElementById("responsestatus").value = "1";
 		
 			var recipients = new Object();
-			recipients["recipient"] = createCompatibleRecipientList(getRecipients());
+			recipients["recipient"] = createCompatibleRecipientList(recepientsList);
 
 			/**
 			 * Add the proposednewtimes of the existing recipients to the current recipients.
@@ -544,6 +562,16 @@ function submitAppointment(send, requestStatus)
 		}else if(!module.isMeeting){
 			module.save(props, send, false, dhtml.getElementById("dialog_attachments").value);
 			module.saving = true;
+		} else if (module.resolveForSendingMR !== true) {
+			// Set status for the resolver to know he has to call this function again
+			module.resolveForSendingMR = true;
+			// Save arguments in module to use in checkNamesCallBackAppointment
+			module.send = send;
+			module.requestStatus = requestStatus;
+			checkNames(checkNamesCallBackAppointment);
+		}else{
+			// Reset status for the resolver to know he does not have to call this function again
+			module.resolveForSendingMR = false;
 		}
 	}
 }
@@ -575,7 +603,7 @@ function sendMRMailConfirmationCallback(noResponse, requestStatus)
 			module.tentativeMeetingRequest(noResponse, basedate, body);
 			break;
 		case "decline":
-			module.declineMeetingRequest(basedate, body);
+			module.declineMeetingRequest(noResponse, basedate, body);
 			break;
 	}
 	module.savingMeetingRequest = true;
@@ -605,7 +633,7 @@ function cancelInvitation()
 	} if(responseStatus == 3 || responseStatus == 5) {
 		// We're an attendee, we cannot cancel
 	} else {
-		meetingRequestSetup(0);
+		meetingRequestSetup(mrSetupNormal);
 	}
 }
 
@@ -620,8 +648,9 @@ function deleteAppointment()
 {
 	var basedate = dhtml.getElementById("basedate").getAttribute("unixtime");
 	basedate = basedate ? parseInt(basedate, 10) : 0;
-	module.deleteMessage(basedate);
-	window.close();
+
+	if (!module.deleteMessage(basedate))
+		window.close();
 }
 
 function onChangeReminder()
@@ -635,12 +664,19 @@ function onChangeReminder()
 		if(checkbox_reminder.checked) {
 			select_reminder_minutes.disabled = false;
 			select_reminder_minutes.style.background = "#FFFFFF";
-			
+			// if reminder is checked and is all day then set reminder time to 18hours 
+			if(dhtml.getElementById("checkbox_alldayevent").checked){
+				select_reminder_minutes.value = "1080";
+			}
 			reminder.value = "1";
 		} else {
 			select_reminder_minutes.disabled = true;
 			select_reminder_minutes.style.background = "#DFDFDF";
-			
+			// if reminder is unchecked and is all day then set reminder time to default value
+			if(dhtml.getElementById("checkbox_alldayevent").checked){
+				select_reminder_minutes.value = parentWebclient.settings.get("calendar/reminder_minutes",15);
+			}
+
 			reminder.value = "-1";
 		}
 	}
@@ -660,10 +696,28 @@ function onChangeAllDayEvent(forceFlag)
 		appoint_dtp.startPicker.timeElement.hide();
 		appoint_dtp.endPicker.timeElement.hide();
 		dhtml.setValue(dhtml.getElementById("select_busystatus"), "0");
-	} else {
+		// when an allday event is created, if the default reminder is on in setting, we need to set reminder time to 18hrs and if not to default value.
+		if(dhtml.getElementById("checkbox_reminder").checked){
+			dhtml.setValue(dhtml.getElementById("select_reminder_minutes"), "1080");
+		}else{
+			dhtml.setValue(dhtml.getElementById("select_reminder_minutes"), parentWebclient.settings.get("calendar/reminder_minutes",15));
+		}
+	}else if(dhtml.getElementById("entryid").value != "" || window.location.search.indexOf("allDayEvent=true")>0 ){
+		//set the start time as work day starttime when an allday appointment is unchecked
+		var dayStart_time = parseInt(webclient.settings.get("calendar/workstartday","540"));
+		var time_resolution = parseInt(60/webclient.settings.get("calendar/appointment_time_size","2"));
+		appoint_dtp.startPicker.timeElement.setValue(dayStart_time * 60);
+		appoint_dtp.endPicker.timeElement.setValue((dayStart_time + time_resolution) * 60);
+
 		appoint_dtp.startPicker.timeElement.show();
 		appoint_dtp.endPicker.timeElement.show();
 		dhtml.setValue(dhtml.getElementById("select_busystatus"), "2");
+		dhtml.setValue(dhtml.getElementById("select_reminder_minutes"), parentWebclient.settings.get("calendar/reminder_minutes",15));
+	}else{
+		appoint_dtp.startPicker.timeElement.show();
+		appoint_dtp.endPicker.timeElement.show();
+		dhtml.setValue(dhtml.getElementById("select_busystatus"), "2");
+		dhtml.setValue(dhtml.getElementById("select_reminder_minutes"), parentWebclient.settings.get("calendar/reminder_minutes",15));
 	}
 }
 
@@ -808,7 +862,7 @@ function onAppointmentTabChange(newTab,oldTab)
 			    } 
 			}
 			
-			if (module.itemProps && module.itemProps.sent_representing_name) {
+			if (!organizer && module.itemProps && module.itemProps.sent_representing_name) {
 				organizer = module.itemProps.sent_representing_name;
 			} else if (!organizer) {
 				var organizerStore = parentWebclient.hierarchy.getStore(module.storeid);
@@ -824,7 +878,6 @@ function onAppointmentTabChange(newTab,oldTab)
 			//update the meetingtime in freebusy tab
 			fb_module.setStartMeetingTime(module.getStartTime());
 			fb_module.setEndMeetingTime(module.getEndTime());
-			fb_module.updatePicker();
 
 			// Disable the picker when opening the whole serie of a recurrent item.
 			var recurring = dhtml.getElementById("recurring").value;
@@ -834,7 +887,10 @@ function onAppointmentTabChange(newTab,oldTab)
 				if(fb_module) fb_module.disablePicker();
 			}else{
 				// Enable the picker in the Scheduling tab when recurrent
-				if(fb_module) fb_module.enablePicker();
+				if(fb_module){
+					fb_module.updatePicker();
+					fb_module.enablePicker();
+				}
 			}
 		}
 		else{
@@ -860,13 +916,19 @@ function onAppointmentTabChange(newTab,oldTab)
 				// Check wheather the username is the organiser or not to set menubar in Appointment module 
 				var meetingRecipientStatus = false;
 				for (var j = 0; j < fbUserlist.length; j++){
-					if(fbUserlist[j]["emailaddress"] != undefined && fbUserlist[j]["emailaddress"].toLowerCase() == webclient.emailaddress.toLowerCase() && fbUserlist[j]["recipient_flags"] != 3)
+					// Get emailaddress of opened folder-object, to check organizer status
+					var storeObject = parentWebclient.hierarchy.getStore(module.storeid);
+					var storeEmail = webclient.emailaddress.toLowerCase();
+					if(storeObject && storeObject.emailaddress)
+						storeEmail = storeObject.emailaddress.toLowerCase();
+
+					if(fbUserlist[j]["emailaddress"] != undefined && fbUserlist[j]["emailaddress"].toLowerCase() == storeEmail && fbUserlist[j]["recipient_flags"] && fbUserlist[j]["recipient_flags"] == (recipSendable | recipOrganizer))
 						meetingRecipientStatus = true;
 				}
-				meetingRecipientStatus? meetingRequestSetup(2): meetingRequestSetup(1);
+				meetingRecipientStatus? meetingRequestSetup(mrSetupOrganiser): meetingRequestSetup(mrSetupAttendee);
 			}
 			else{
-				meetingRequestSetup(0);
+				meetingRequestSetup(mrSetupNormal);
 			}
 			module.setUserList(fbUserlist);
 		}
@@ -1408,7 +1470,15 @@ function eventAppointmentDialogProposeNewTimeClick(moduleObject)
 		meetingrequest_duedate_value = false;
 	}
 
-	webclient.openModalDialog(-1, 'appointmentitem_proposenewtimedialog', DIALOG_URL+'task=advprompt_modal', 325,250, appointmentdialogProposenewtime_dialog_callback, {
+	/**
+	 * For this instance we open the advprompt dialog as a normal window. If we would open it as a 
+	 * modal dialog than we would have a problem when sending the proposal message. When callback in
+	 * this appointment dialog is invoked it will send the proposal imediately. It wants to close the 
+	 * appointment dialog, but then finds out (in IE this is an issue) that the modal dialog is still 
+	 * open. It cannot close the window. By making the advprompt a normal window this issue is 
+	 * avoided.
+	 */
+	webclient.openWindow(-1, 'appointmentitem_proposenewtimedialog', DIALOG_URL+'task=advprompt_modal', 325,250, true, appointmentdialogProposenewtime_dialog_callback, {
 			moduleObject: moduleObject
 		}, {
 			windowname: _("Propose new time"),
@@ -1441,6 +1511,8 @@ function appointmentdialogProposenewtime_dialog_callback(result, callbackData){
 			basedate = dhtml.getElementById("basedate").getAttribute("unixtime");
 
 		callbackData.moduleObject.proposalMeetingRequest(parseInt(result.combineddatetimepicker.start,10), parseInt(result.combineddatetimepicker.end,10), result.body, basedate);
+
+		window.close();
 	}
 
 }
@@ -1450,7 +1522,7 @@ function appointmentdialogProposenewtime_dialog_callback(result, callbackData){
  */
 function checkNamesCallBackAppointment(resolveObj)
 {
-	checkNamesCallBack(resolveObj);
+	checkNamesCallBack(resolveObj, false);
 
 	var elements = new Array("to", "cc", "bcc");
 	var toccbcc = dhtml.getElementById("toccbcc");
@@ -1462,6 +1534,10 @@ function checkNamesCallBackAppointment(resolveObj)
 		var value = dhtml.getElementById(elements[i]).value;
 		toccbcc.value += (value.trim() != ";") ? value : "";
 	}
+	// Send Meeting Request
+	if(module.resolveForSendingMR === true){
+		submitAppointment(module.send, module.requestStatus);
+	}
 }
 
 /*
@@ -1535,4 +1611,54 @@ function eventOpenPrintAppointmentItemDialog(moduleObject)
 function suggestionListCallBackAppointment()
 {
 	syncRecipientFields();
+}
+
+/**
+ * Function which popups option to attendee when he/she deletes any meeting item.
+ *@param object moduleObject module object
+ *@param string subject subject of meeting
+ *@param integer basedate basedate if it is an occurrence else false
+ */
+function sendConfirmationDeleteAppointmentItem(moduleObject, subject, basedate)
+{
+	var windowData = new Array();
+	windowData["module"] = moduleObject;
+	windowData["confirmDelete"] = true;
+	windowData["basedate"] = basedate;
+	windowData["subject"] = subject;
+	webclient.openModalDialog(-1, 'sendMRMailConfirmation', DIALOG_URL+'task=sendMRMailConfirmation_modal', 350, 200, appointmentItemSendMRMailConfirmation_callback, moduleObject, windowData);
+}
+
+/**
+ * Callback function from sendMRConfirmation dialog
+ * this function decides whether to send response to organizer that attendee has deleted item.
+ * 
+ *@param object moduleObject module object
+ *@param boolean noResponse true if attendee doesn't want to send response on deletion else false
+ *@param integer basedate basedate if it an occurrence
+ */
+function appointmentItemSendMRMailConfirmation_callback(moduleObject, noResponse, basedate)
+{
+	if (!noResponse) {
+		moduleObject.sendDeclineMeetingRequest(noResponse, basedate);
+	} else {
+
+		if (basedate) {
+			//directlly delete passed occurrences.
+			var req = new Object;
+			req['store'] = moduleObject.storeid;
+			req['parententryid'] = moduleObject.parententryid;
+			req['entryid'] = moduleObject.messageentryid;
+			req['delete'] = 1;
+			req['props'] = new Object;
+			req['props']['entryid'] = moduleObject.messageentryid;
+			req['props']['basedate'] = parseInt(basedate, 10);
+
+			parentWebclient.xmlrequest.addData(moduleObject, 'save', req, webclient.modulePrefix);
+			parentWebclient.xmlrequest.sendRequest(true);
+		} else {
+			appointmentitemmodule.superclass.deleteMessage.call(moduleObject);
+		}
+	}
+	window.close();
 }
\ No newline at end of file
