@@ -112,6 +112,9 @@ function initContact()
 
 function submitContact()
 {
+	//A Contact item does not have the timezone property set by default so,
+	var timezone = false;
+
 	// before saving contents check for opened detailed dialogs
 	for(var dialogname in webclient.dialogs) {
 		if(dialogname.match("contactitem_detailfullnamedialog") != null && !window.BROWSER_IE) {
@@ -134,6 +137,12 @@ function submitContact()
 
 	// File As
 	dhtml.getElementById("fileas").value = dhtml.getValue(dhtml.getElementById("select_fileas"));
+	/**
+	 * this property contains fileas value format, but WA doesn't generate that value
+	 * so we need to reset it so OL will not consider this property when showing fileas
+	 * REF: MS_OXOCNTC 2.2.1.1.12 PidLidFileUnderId
+	 */
+	dhtml.getElementById("fileas_selection").value = "-1";
 
 	// Current Email Address
 	var selected_email_address = dhtml.getElementById("selected_email_address");
@@ -197,7 +206,11 @@ function submitContact()
 	// Contacts
 	dhtml.getElementById("contacts_string").value = dhtml.getElementById("contacts").value;
 	
-	submit_contact();
+	//check the Special Date's like birthday or Anniversary date to set the timezone properties
+	if((dhtml.getElementById("birthday").value).trim() != "" || (dhtml.getElementById("wedding_anniversary").value).trim() != ""){
+		timezone = getTimeZone();
+	}
+	submit_contact(timezone);
 }
 
 /**
@@ -206,7 +219,8 @@ function submitContact()
  */
 function setFileAs()
 {
-	var fileas = dhtml.getElementById("fileas").value;
+	//replacing space or non-breaking space with NBSP so the we can compare strings in same format
+	var fileas = dhtml.getElementById("fileas").value.replace(/\xA0|\x20/g, NBSP);
 	var select_fileas = dhtml.getElementById("select_fileas");
 	var display_name = dhtml.getElementById("display_name");
 
@@ -225,8 +239,9 @@ function setFileAs()
 	// Remove prefix and suffix of name.
 	var name = display_name.value.replace(dhtml.getElementById("display_name_prefix").value, "").replace(dhtml.getElementById("generation").value, "").replace(",", "").replace(" ", NBSP);
 	
-	// Split display name ([0] => SURNAME, [1] => GIVENNAME, [2] => MIDDLENAME)
-	var names = name.split(NBSP);
+	// Split display name ([0] => GIVENNAME, [1] => MIDDLENAME, [2] => SURNAME)
+	// \u0020 => space, \u00a0 => No-break space
+	var names = name.split(/\xA0|\x20/g);
 
 	// Remove white spaces in array
 	var tmpnames = names;
@@ -240,12 +255,12 @@ function setFileAs()
 
 	if(names.length > 0) {
 		// Build up two different options (SURNAME, GIVENNAME MIDDLENAME and GIVENNAME MIDDLENAME SURNAME)
-		var	surname = names.join(NBSP);
-		var givenname = "";
+		var givenname = names.join(NBSP);
+		var surname = "";
 		if(names.length > 1) {
-			givenname = names[names.length-1] + "," + NBSP;
+			surname = names[names.length-1] + "," + NBSP;
 			names.splice(names.length-1,1);
-			givenname += names.join(NBSP);
+			surname += names.join(NBSP);
 		}
 		
 		// Add the two options to select list
@@ -378,7 +393,7 @@ function onChangeMailingAddress(element)
 function eventContactItemSendMailTo()
 {
 	var toValue = dhtml.getElementById("display_name").value+" <"+dhtml.getElementById("email_address").value+">";
-	webclient.openWindow(this, "createmail", DIALOG_URL+"task=createmail_standard&to="+escape(toValue));
+	webclient.openWindow(this, "createmail", DIALOG_URL+"task=createmail_standard&to="+encodeURIComponent(toValue));
 }
 
 function categoriesCallBack(categories)
@@ -834,4 +849,23 @@ function eventContactItemKeyCtrlSave(moduleObject, element, event, keys)
 			submitContact();
 			break;
 	}
+}
+
+/**
+ * Function will check wheather the date in inputField is a valid Date or not.Thus will display 
+ * an alert message for invalid Date
+ */
+function eventDatePickerInputChange()
+{
+	var oldValue = dhtml.getElementById("text_birthday").value;
+	var valueArr = oldValue.trim().split("-"); // get the values as dd - mm - yyyy
+	if(valueArr.length > 0 && valueArr[0] != ""){	
+		var result = checkDateValidation(valueArr[0], valueArr[1], valueArr[2]);
+		if(result){
+			dhtml.getElementById("text_birthday").value = oldValue;
+		}else{
+			alert(_("You must specify a valid date"));
+			dhtml.getElementById("text_birthday").value = '';
+		}
+	}
 }
\ No newline at end of file
