@@ -150,39 +150,15 @@ function getPropsFromDialog() {
 	}else{
 		var body = dhtml.getElementById("html_body");
 		if (body) {
-			props["body"] = filterXSS(body.value);
+			props["body"] = body.value;
 		}
 	}
 	
 	return props;
 }
 
-/**
- * Function will remove unneccessary expression written in style attribute in div element
- * @param string text content to be filtered.
- * @return string cleaned string.
- */
-function filterXSS(text)
-{
-	// filter out and convert unicode characters: \0065, \u0065, \U0065
-	text = text.replace(/\\[uU]?([0-9]+)/mig, function(match, p1) { return String.fromCharCode('0x'+p1); });
-
-	// filter out and convert unicode characters: &#x0065;
-	text = text.replace(/&#x?([0-9]*);/mig, function(match, p1) { return String.fromCharCode('0x'+p1); });
-
-	// filter out comments
-	text = text.replace(/\/\*((?:.|\n)*?\*\/)/mig, '');
-
-	// replace '\[character]' with only '[character]'
-	text = text.replace(/\\(.)/mig, '$1');
-
-	// replace `[property] : expression (` with `[property] : no_expression(` 
-	text = text.replace(/(<div([A-Z0-9]*)\b[^>]*(\w+)\W*:\W*)expression\W*\(/mig, '$1 : no_expression(');
-
-	return text;
-}
-
-function getRecipients() {
+function getRecipients(keepDuplicate) {
+	keepDuplicate = keepDuplicate || false;
 	var recipients = new Array();
 	var types = new Array("to", "cc", "bcc");
 
@@ -228,20 +204,23 @@ function getRecipients() {
 			}
 		}
 	}
-	/**
-	 * create a temp object on basis of email addresses
-	 * which basically removes the duplicate recipients from recipients array
-	 */
-	var tempRecipientObject = new Object();
-	for(var i=recipients.length-1;i>=0;i--){
-		tempRecipientObject[recipients[i]["address"]] = recipients[i];
-	}
-	//empty the recipient list
-	recipients = new Array();
 
-	// create the array again from unique recipient Object.
-	for(var address in tempRecipientObject){
-		recipients.push(tempRecipientObject[address]);
+	if (!keepDuplicate) {
+		/**
+		 * create a temp object on basis of email addresses
+		 * which basically removes the duplicate recipients from recipients array
+		 */
+		var tempRecipientObject = new Object();
+		for(var i=recipients.length-1;i>=0;i--){
+			tempRecipientObject[recipients[i]["address"]] = recipients[i];
+		}
+		//empty the recipient list
+		recipients = new Array();
+
+		// create the array again from unique recipient Object.
+		for(var address in tempRecipientObject){
+			recipients.push(tempRecipientObject[address]);
+		}
 	}
 	return recipients;
 }
@@ -309,36 +288,41 @@ function submit_stickynote() {
 		window.close();
 	}
 }
-
-function submit_contact()
+/**
+ * Function will send a save request to server with all contact's data from client
+ * @param object timezone data is passed if any specialDate events are set in contact Details.  
+ */
+function submit_contact(timezone)
 {
 	if(module) {
 		var props = getPropsFromDialog();
+		props["timezone"] = timezone;
 		
-		var email_addresses = new Object();
-		email_addresses["email_address"] = new Array();
-		
-		for(var i = 1; i < 4; i++)
-		{
-			var email_address_element = dhtml.getElementById("email_address_" + i);
-			var email_address_display_name_element = dhtml.getElementById("email_address_display_name_" + i);
-			
-			if(email_address_element && email_address_element.value != "") {
-				var email_address = new Object();
-				email_address["id"] = i;
-				email_address["name"] = (email_address_display_name_element && email_address_display_name_element.value != ""?email_address_display_name_element.value:email_address_element.value);
-				email_address["address"] = email_address_element.value;
-				email_addresses["email_address"].push(email_address);
-			}
-		}
-					
-		module.save(props, email_addresses, dhtml.getElementById("dialog_attachments").value);
+		module.save(props, dhtml.getElementById("dialog_attachments").value);
 		window.close();
 	}
 }
 
-function submit_task() {
+function submit_task(send) {
 	if(module) {
+
+		/* Task has been assigned to someone, check if correct email-address is given
+		 * if not then do auto resolvenames 
+		 */
+		if (send == "request") {
+			if (validateEmailAddress(dhtml.getElementById("to").value, false, !window.resolveForSendingMessage)) {
+			} else if (window.resolveForSendingMessage != true) {
+				// Set status for the resolver to know he has to call this function again
+				window.resolveForSendingMessage = true;
+				checkNames(checkNamesCallBackTask);
+				return false;
+			} else {
+				// Reset status for the resolver to know he does not have to call this function again
+				window.resolveForSendingMessage = false;
+				return false;
+			}
+		}
+
 		var props = getPropsFromDialog();
 
 		// check for precent complete value
@@ -360,8 +344,35 @@ function submit_task() {
 			props["reminder"] = "0";
 		}
 
-		module.save(props, false, false, dhtml.getElementById("dialog_attachments").value);
-		window.close();
+		var recipients = new Object();
+		var recipientList = getRecipients(true);
+		if(recipientList.length > 0){
+			recipients["recipient"] = recipientList;
+
+			var filter = new RegExp(/^\[([^[]+)\]$/);	// To search for a group
+			var multipleRecips = 0;
+			for(var i in recipientList) {
+				if (recipientList[i]["type"] == "mapi_to") {
+					multipleRecips++;
+
+					// User cannot send a task request himself/herself.
+					if (recipientList[i]["address"] == webclient.emailaddress) {
+						alert(_("You cannot sent a task request to yourself."));
+						return false;
+					}
+
+					// Prompt that task updates will not be mentained if more than one assignee
+					if ((recipientList[i]["address"] && filter.test(recipientList[i]["address"].trim())) || multipleRecips > 1) {
+						if (!confirm(_("This task is addressed to more than one recipient. Your copy of task will not be updated.")))
+							return false;
+						props['taskmultrecips'] = true;
+					}
+				}
+			}
+		}
+		module.save(props, send, recipients, dhtml.getElementById("dialog_attachments").value);
+
+		return true;
 	}
 }
 
@@ -581,8 +592,9 @@ function checkNames(callBackFunction)
 /**
  * Function is the callback function of resolveNames and will replace the resolved names
  * @param = "Object" of the resolved names
+ * @param fireChangeEvent after updating field whether change event should fire or not.
  */ 
-function checkNamesCallBack(resolveObj)
+function checkNamesCallBack(resolveObj, fireChangeEvent)
 {
 	for(var i in resolveObj){
 		if(dhtml.getElementById(i) && dhtml.getElementById(i).value){
@@ -611,6 +623,11 @@ function checkNamesCallBack(resolveObj)
 					newString += unResolved[j]+";";
 			}
 			dhtml.getElementById(i).value = newString;
+
+			// also fire change event if change event is happen on to, cc, bcc fields (growing fields) of createmail
+			if(typeof fireChangeEvent != "undefined" && fireChangeEvent) {
+				dhtml.executeEvent(dhtml.getElementById(i), "change");
+			}
 		}
 	}
 }
@@ -699,12 +716,12 @@ function timeSpinnerDown(time_element)
 	onChangeDate();	
 }
 
-function onChangeDate()
+function onChangeDate(fieldName)
 {
-	var text_startdate = dhtml.getElementById("text_startdate");
+	var text_startdate = dhtml.getElementById("text_commonstart");
 	var text_startdate_time = dhtml.getElementById("text_startdate_time");
 	
-	var text_duedate = dhtml.getElementById("text_duedate");
+	var text_duedate = dhtml.getElementById("text_commonend");
 	var text_duedate_time = dhtml.getElementById("text_duedate_time");
 	
 	if(text_duedate.value.toLowerCase() == _("None").toLowerCase()) {
@@ -714,14 +731,43 @@ function onChangeDate()
 	var startdate = Date.parseDate(text_startdate.value + " " + (text_startdate_time?text_startdate_time.value:"00:00"), _("%d-%m-%Y") + " " + _("%H:%M"));
 	var duedate =   Date.parseDate(text_duedate.value + " " + (text_duedate_time?text_duedate_time.value:"00:00"), _("%d-%m-%Y") + " " + _("%H:%M"));
 
-	if(duedate && startdate) {
-		if(startdate > duedate) {
-			text_startdate.value = text_duedate.value;
+	switch(fieldName)
+	{
+		case 'text_commonstart':
+			var old_startdate = text_startdate.getAttribute("oldvalue") ? Date.parseDate(text_startdate.getAttribute("oldvalue"), _("%d-%m-%Y")) : 0;
+			var diffInSeconds = (old_startdate == 0) ? 0 : duedate - old_startdate;
 
-			if(text_startdate_time && text_duedate_time) {
-				text_startdate_time.value = text_duedate_time.value;
+			if (diffInSeconds > 0) {
+				text_duedate.value = strftime(_("%d-%m-%Y"), (startdate.getTime() + diffInSeconds)/1000);
+			} else {
+				if(old_startdate != 0 || startdate > duedate)
+					text_duedate.value = strftime(_("%d-%m-%Y"), (startdate.getTime())/1000);
 			}
-		}
+			break;
+		case 'text_commonend':
+			if ((text_startdate.value.toLowerCase() != _("None").toLowerCase() && text_duedate.value.toLowerCase() != _("None").toLowerCase())) {
+				if ((duedate && startdate) && (startdate > duedate))
+					text_duedate.value = text_duedate.getAttribute('oldvalue');
+			}
+			break;
+		default:
+			if(duedate && startdate) {
+				if(startdate > duedate) {
+					text_startdate.value = text_duedate.value;
+
+					if(text_startdate_time && text_duedate_time) {
+						text_startdate_time.value = text_duedate_time.value;
+					}
+				}
+			}
+	}
+
+	if(text_startdate.value.toLowerCase() != _("None").toLowerCase()) text_startdate.setAttribute('oldvalue', text_startdate.value);
+	if(text_duedate.value.toLowerCase() != _("None").toLowerCase()) {
+		text_duedate.setAttribute('oldvalue', text_duedate.value);
+
+		var reminder = dhtml.getElementById("text_reminderdate");
+		if (reminder) reminder.value = text_duedate.value;
 	}
 }
 
@@ -812,7 +858,7 @@ function cleanHTML(html)
 	html = html.replace(/<o:p>(.*?)<\/o:p>/g, "<p>$1</p>") ;
 
 	// Remove mso-xxx styles.
-	html = html.replace( /\s*mso-[^:]+:[^;"]+;?/gi, '' ) ;
+	html = html.replace( /\s*mso-[^:]+:[^;"'}]+;?/gi, '' ) ;
 
 	html = html.replace( /\s*TEXT-INDENT: 0cm\s*;/gi, '' ) ;
 	html = html.replace( /\s*TEXT-INDENT: 0cm\s*"/gi, "\"" ) ;
@@ -925,4 +971,36 @@ function IE_tracCursorInEditor()
 	if (fckEditor && fckEditor.HasFocus){
 		if (fckEditor.Selection.GetSelection().type != "None") fckEditor.Selection.Save();
 	}
+}
+
+/**
+ * Function which insert the data at the selected cursor position
+ * in the Textarea
+ */
+function insertAtCursor(textArea, value) {
+	var newCursorPos=0;
+	//IE support
+	if (document.selection) {
+		textArea.focus();
+		//in effect we are creating a text range with zero length at the cursor location and replacing it
+		//with value
+		var cursorPosition = document.selection.createRange();
+		cursorPosition.move('character', window.start);
+		cursorPosition.text = value;
+
+	}else if (textArea.selectionStart || textArea.selectionStart == '0') {//Mozilla/Firefox support
+		
+		//start of the selection and from the end point of the selection to the end of the field value.
+		//Then we concatenate the first substring, value,and the second substring to get the new value.
+		var startPos = textArea.selectionStart;
+		var endPos = textArea.selectionEnd;
+		textArea.value = textArea.value.substring(0, startPos) + value + textArea.value.substring(endPos, textArea.value.length);
+
+		newCursorPos = textArea.value.substring(0, startPos).length + value.length;
+		textArea.setSelectionRange(newCursorPos , newCursorPos );
+
+	} else {
+		textArea.value += value;
+	}
+	
 }
\ No newline at end of file
