@@ -52,6 +52,13 @@ function showRule(rule)
 {
     dhtml.getElementById("name").value = rule.rule_name.value;
     dhtml.getElementById("sequence").value = rule.rule_sequence.value;
+
+	var processRule = false;
+	if(rule.rule_state.value.indexOf("ST_EXIT_LEVEL") > 0)
+		processRule = true;
+
+	dhtml.getElementById("stop_processing_more_rules").checked = processRule;
+
     
     if(rule.rule_condition.restype && rule.rule_condition.restype.value == "RES_AND") {
 		// first try the condition as a single condition (with multiple restrictions)
@@ -154,6 +161,7 @@ function showAction(action, state)
     if(action.action.value == "OP_MOVE") {
 		if (action.folderentryid.value == parentwindow.module.wastebasket && state.value.match("ST_EXIT_LEVEL")){
 			dhtml.getElementById("action_delete").checked = true;
+			dhtml.getElementById("stop_processing_more_rules").disabled = true;
 		}else{
 	        dhtml.getElementById("action_move").checked = true;
 	        dhtml.getElementById("action_move_folder").folderentryid = action.folderentryid.value;
@@ -301,7 +309,7 @@ function submitRule()
     
 	result.rule_state = new Object;
     result.rule_state.value = "ST_ENABLED";
-	if (dhtml.getElementById("action_delete").checked){
+	if (dhtml.getElementById("action_delete").checked || dhtml.getElementById("stop_processing_more_rules").checked){
 		result.rule_state.value += " | ST_EXIT_LEVEL";
 	}
 
@@ -694,3 +702,10 @@ function createOneOff(displayname, addrtype, emailaddress)
 function getEmailAddressFromString()
 {
 }
+function eventActionSelectionChanged(moduleObject, element, event)
+{
+	if(element && element.id == "action_delete")
+		dhtml.getElementById("stop_processing_more_rules").disabled = true;
+	else
+		dhtml.getElementById("stop_processing_more_rules").disabled = false;
+}
