@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -46,21 +48,47 @@
  */
 
 function submitFolder() {
-    var selectedFolderId = module.selectedFolder;
-    
-    if(!module.selectedFolder)
-        return;
-        
-    var selectedFolderElement = dhtml.getElementById(selectedFolderId);
-    
-    var result = new Object;
-    
-    result.folderentryid = selectedFolderId;
-    result.foldername = selectedFolderElement.displayname;
-    result.storeentryid = selectedFolderElement.storeid;
-    
-    if(window.resultCallBack(result, window.callBackData))
-        window.close();
-    else
-        window.focus();
+	if(module.multipleSelection) {
+		// for multiple selection
+		var selectedFolderElement;
+		var selectedFoldersId = module.selectedMultipleFolders;
+
+		if(typeof selectedFoldersId != "object" || selectedFoldersId.length <= 0) {
+			alert(_("Please select atleast one folder") + ".");
+			return;
+		}
+
+		var result = new Object();
+		result["subfolders"] = dhtml.getElementById("subfolders_checkbox").checked;
+		result["selected_folders"] = new Object();
+		result["storeid"] = module.selectedMultipleFolderStoreIds[0];
+
+		for(var key in selectedFoldersId) {
+			selectedFolderElement = dhtml.getElementById(selectedFoldersId[key]);
+
+			result["selected_folders"][key] = new Object();
+			result["selected_folders"][key]["folderentryid"] = selectedFoldersId[key];
+			result["selected_folders"][key]["foldername"] = selectedFolderElement.displayname;
+			result["selected_folders"][key]["storeentryid"] = selectedFolderElement.storeid;
+		}
+	} else {
+		// for single selection
+		var selectedFolderId = module.selectedFolder;
+		
+		if(!module.selectedFolder)
+			return;
+			
+		var selectedFolderElement = dhtml.getElementById(selectedFolderId);
+		
+		var result = new Object;
+		
+		result.folderentryid = selectedFolderId;
+		result.foldername = selectedFolderElement.displayname;
+		result.storeentryid = selectedFolderElement.storeid;
+	}
+
+	if(window.resultCallBack(result, window.callBackData))
+		window.close();
+	else
+		window.focus();
 }
