@@ -56,10 +56,10 @@ function initTask()
 	dhtml.setValue(dhtml.getElementById("select_priority"), dhtml.getElementById("importance").value);
 
 	// Duedate
-	dhtml.setDate(dhtml.getElementById("duedate"));
+	dhtml.setDate(dhtml.getElementById("commonend"));
 	
 	// Startdate
-	dhtml.setDate(dhtml.getElementById("startdate"));
+	dhtml.setDate(dhtml.getElementById("commonstart"));
 	
 	// Complete
 	var complete = dhtml.getElementById("complete");
@@ -128,7 +128,8 @@ function initTask()
 
 }
 
-function submitTask()
+/* send, accept and decline are all exclusive */
+function submitTask(send)
 {
 	// Status
 	dhtml.getElementById("status").value = dhtml.getValue(dhtml.getElementById("select_status"));
@@ -140,22 +141,28 @@ function submitTask()
 	onChangeDate();
 	
 	// Duedate
-    var duedate = Date.parseDate(dhtml.getElementById("text_duedate").value, _("%d-%m-%Y"), true, true);
+    var duedate = Date.parseDate(dhtml.getElementById("text_commonend").value, _("%d-%m-%Y"), true, true);
 
     if(duedate) {
         dhtml.getElementById("duedate").value = duedate.getTime()/1000;
-        dhtml.getElementById("commonend").value = duedate.getTime()/1000;
+        dhtml.getElementById("commonend").value = Date.parseDate(dhtml.getElementById("text_commonend").value, _("%d-%m-%Y"), false, true).getTime()/1000;
+
+		var currentDate = Date.parseDate(new Date().toDate(), _("%d-%m-%Y"), false, true);
+
+		if (send == "request" && currentDate.getTime() > duedate.getTime()) {
+			if (!confirm(_("The due date for this task has passed. Are you sure you want to continue?"))) return false;
+		}
     } else {
         dhtml.getElementById("duedate").value = "";
         dhtml.getElementById("commonend").value = "";
     }
 
 	// Startdate
-    var startdate = Date.parseDate(dhtml.getElementById("text_startdate").value, _("%d-%m-%Y"), true, true);
+    var startdate = Date.parseDate(dhtml.getElementById("text_commonstart").value, _("%d-%m-%Y"), true, true);
     
     if(startdate) {
         dhtml.getElementById("startdate").value = startdate.getTime()/1000;
-        dhtml.getElementById("commonstart").value = startdate.getTime()/1000;
+        dhtml.getElementById("commonstart").value = Date.parseDate(dhtml.getElementById("text_commonstart").value, _("%d-%m-%Y"), false, true).getTime()/1000;
     } else {
         dhtml.getElementById("startdate").value = "";
         dhtml.getElementById("commonstart").value = "";
@@ -165,15 +172,15 @@ function submitTask()
 	var dateRegExPattern = /^((((0?[1-9]|[12]\d|3[01])[\.\-\/](0?[13578]|1[02])[\.\-\/]((1[6-9]|[2-9]\d)?\d{2}))|((0?[1-9]|[12]\d|30)[\.\-\/](0?[13456789]|1[012])[\.\-\/]((1[6-9]|[2-9]\d)?\d{2}))|((0?[1-9]|1\d|2[0-8])[\.\-\/]0?2[\.\-\/]((1[6-9]|[2-9]\d)?\d{2}))|(29[\.\-\/]0?2[\.\-\/]((1[6-9]|[2-9]\d)?(0[48]|[2468][048]|[13579][26])|((16|[2468][048]|[3579][26])00)|00)))|(((0[1-9]|[12]\d|3[01])(0[13578]|1[02])((1[6-9]|[2-9]\d)?\d{2}))|((0[1-9]|[12]\d|30)(0[13456789]|1[012])((1[6-9]|[2-9]\d)?\d{2}))|((0[1-9]|1\d|2[0-8])02((1[6-9]|[2-9]\d)?\d{2}))|(2902((1[6-9]|[2-9]\d)?(0[48]|[2468][048]|[13579][26])|((16|[2468][048]|[3579][26])00)|00))))$/;
 	
 	//duedate validation
-	if(dhtml.getElementById("text_duedate").value.toLowerCase() != _("None").toLowerCase() && !dateRegExPattern.test(Date.parseDate(dhtml.getElementById("text_duedate").value, _("%d-%m-%Y"), true).toDate())){
+	if(dhtml.getElementById("text_commonend").value.toLowerCase() != _("None").toLowerCase() && !dateRegExPattern.test(Date.parseDate(dhtml.getElementById("text_commonend").value, _("%d-%m-%Y"), true).toDate())){
 		alert(_("Please enter correct date"));
-		dhtml.getElementById("text_duedate").focus();
+		dhtml.getElementById("text_commonend").focus();
 		return false;
 	}
 	//startdate validation
-	if(dhtml.getElementById("text_startdate").value.toLowerCase() != _("None").toLowerCase() && !dateRegExPattern.test(Date.parseDate(dhtml.getElementById("text_startdate").value, _("%d-%m-%Y"), true).toDate())){
+	if(dhtml.getElementById("text_commonstart").value.toLowerCase() != _("None").toLowerCase() && !dateRegExPattern.test(Date.parseDate(dhtml.getElementById("text_commonstart").value, _("%d-%m-%Y"), true).toDate())){
 		alert(_("Please enter correct date"));
-		dhtml.getElementById("text_startdate").focus();
+		dhtml.getElementById("text_commonstart").focus();
 		return false;
 	}
 
@@ -210,10 +217,7 @@ function submitTask()
 	// Reminder Date
 	if (dhtml.getElementById("text_reminderdate").value != "" && dhtml.getElementById("text_reminderdate").value.toLowerCase() != _("None").toLowerCase()){
 		dhtml.getElementById("reminderdate").value =  Date.parseDate(dhtml.getElementById("text_reminderdate").value + " " + dhtml.getElementById("text_reminderdate_time").value, _("%d-%m-%Y") + " " + _("%H:%M")).getTime()/1000;
-		// set flagdueby value at first time only
-		if(dhtml.getElementById("flagdueby").value == "") {
-			dhtml.getElementById("flagdueby").value = dhtml.getElementById("reminderdate").value;		// flagdueby property used in reminders
-		}
+		dhtml.getElementById("flagdueby").value = dhtml.getElementById("reminderdate").value;		// flagdueby property used in reminders
 	}
 
 	// Date Completed
@@ -254,7 +258,7 @@ function submitTask()
 	// Contacts
 	dhtml.getElementById("contacts_string").value = dhtml.getElementById("contacts").value;
 	
-	submit_task();
+	if (submit_task(send)) window.close();
 }
 
 function onChangeStatus()
@@ -267,10 +271,12 @@ function onChangeStatus()
 			dhtml.getElementById("text_percent_complete").value = "100%";
 			//check reminder and turn it off
 			setReminderOnComplete();
+			showHideRecurrenceMenu(true);
 		} else {
 			dhtml.getElementById("text_percent_complete").value = (dhtml.getElementById("percent_complete").value * 100) + "%";
 			//check reminder and turn it on
 			setReminderOnComplete(true);
+			showHideRecurrenceMenu(false);
 		}
 		
 		dhtml.getElementById("status").value = selected;
@@ -377,7 +383,7 @@ function onChangeReminder()
 			if(text_reminderdate.value == _("None") || text_reminderdate.value == "") {
 				var date = new Date();
 				
-				var unixtime = Date.parseDate(dhtml.getElementById("text_duedate").value, _("%d-%m-%Y"), true).getTime()/1000;
+				var unixtime = Date.parseDate(dhtml.getElementById("text_commonend").value, _("%d-%m-%Y"), true).getTime()/1000;
 				if(unixtime) {
 					date = new Date(unixtime * 1000);
 				}
@@ -407,34 +413,148 @@ function onChangeReminder()
 
 function assignTask()
 {
+	setTaskRequestMode(tdsOWNNEW, tdmtTaskReq);
+}
+
+function cancelAssignTask()
+{
+	setTaskRequestMode(tdsOWN, tdmtNothing);
+}
+
+function setTaskRequestMode(taskstate, taskmode)
+{
+	taskstate = taskstate || dhtml.getElementById("taskstate").value;
+	var taskhistory = dhtml.getElementById("taskhistory").value;
+	var tasklastdelegate = dhtml.getElementById("tasklastdelegate").value;
+	var assignedtime = dhtml.getElementById("assignedtime").getAttribute("unixtime");
+	var taskaccepted = dhtml.getElementById("taskaccepted").value;
+	taskmode = taskmode || dhtml.getElementById("taskmode").value;
+
 	var taskrequest_recipient = dhtml.getElementById("taskrequest_recipient");
 	var taskrequest_settings = dhtml.getElementById("taskrequest_settings");
 	var sendbutton = dhtml.getElementById("send");
+	var savebutton = dhtml.getElementById("save");
 	var assigntaskbutton = dhtml.getElementById("assigntask");
 	var taskcompletebutton = dhtml.getElementById("taskcomplete");
 	var cancelassigntaskbutton = dhtml.getElementById("cancelassigntask");
 	var remindervalues = dhtml.getElementById("remindervalues");
-	
-	if(taskrequest_recipient) {
-		if(taskrequest_recipient.style.display == "block") {
-			taskrequest_recipient.style.display = "none";
-			taskrequest_settings.style.display = "none";
-			sendbutton.style.display = "none";
-			cancelassigntaskbutton.style.display = "none";
-			
-			assigntaskbutton.style.display = "block";
-			taskcompletebutton.style.display = "block";
-			remindervalues.style.display = "block";
-		} else {
+	var extrainfo = dhtml.getElementById("extrainfo");
+	var acceptbutton = dhtml.getElementById("accept");
+	var declinebutton = dhtml.getElementById("decline");
+	var checknamesbutton = dhtml.getElementById("checknames");
+	var recurbutton = dhtml.getElementById("recurrence");
+	var rettasklistbutton = dhtml.getElementById("return_tasklist");
+
+	var assignee = true;
+
+	taskrequest_recipient.style.display = "none";
+	taskrequest_settings.style.display = "none";
+	sendbutton.style.display = "none";
+	rettasklistbutton.style.display = "none";
+	cancelassigntaskbutton.style.display = "none";
+	assigntaskbutton.style.display = "none";
+	cancelassigntaskbutton.nextSibling.style.display = "none";	// Separator
+	taskcompletebutton.style.display = "none";
+	taskcompletebutton.nextSibling.style.display = "none";		// Separator
+	remindervalues.style.display = "none";
+	savebutton.style.display = "none";
+	acceptbutton.style.display = "none";
+	declinebutton.style.display = "none";
+	checknamesbutton.style.display = "none";
+	recurbutton.style.display = "none";
+	recurbutton.nextSibling.style.display = "none";
+	dhtml.addClassName(dhtml.getElementById("tab_disabledtask"), "tab_hide");
+
+	if(taskstate == tdsOWNNEW) {
+		if(taskmode == tdmtTaskReq) {
+			// Unsent assigned task
+			assignee = false;
 			taskrequest_recipient.style.display = "block";
 			taskrequest_settings.style.display = "block";
 			sendbutton.style.display = "block";
 			cancelassigntaskbutton.style.display = "block";
-			
-			assigntaskbutton.style.display = "none";
-			taskcompletebutton.style.display = "none";
-			remindervalues.style.display = "none";
+			checknamesbutton.style.display = "block";
+		} else {
+			// Normal task
+			savebutton.style.display = "block";
+			assigntaskbutton.style.display = "block";
+			cancelassigntaskbutton.nextSibling.style.display = "block";	// Separator
+			remindervalues.style.display = "block";
+			taskcompletebutton.style.display = "block";
+			taskcompletebutton.nextSibling.style.display = "block";
 		}
+		recurbutton.style.display = "block";
+		recurbutton.nextSibling.style.display = "block";
+	} else if(taskstate == tdsACC || taskstate == tdsNOM) {
+		// Assigner's view of task
+		assignee = false;
+		taskrequest_recipient.style.display = "block";
+		taskrequest_settings.style.display = "block";
+
+		changeTaskEditingState(true, taskstate);
+	} else if(taskstate == tdsDEC) {
+		// Assigner's view of task, assignee declined
+		assignee = false;
+
+		// Assigner's is reassigning this decline task request
+		if (taskmode == tdmtTaskReq) {
+			sendbutton.style.display = "block";
+			checknamesbutton.style.display = "block";
+			cancelassigntaskbutton.style.display = "block";
+			cancelassigntaskbutton.nextSibling.style.display = "block";	// Separator
+			taskrequest_recipient.style.display = "block";
+			taskrequest_settings.style.display = "block";
+
+			changeTaskEditingState(false, tdsACC);
+		} else {
+			rettasklistbutton.style.display = "block";
+			assigntaskbutton.style.display = "block";
+			cancelassigntaskbutton.nextSibling.style.display = "block";	// Separator
+
+			changeTaskEditingState(true, taskstate);
+		}
+	} else if(taskstate == tdsOWN) {
+		// Assignee's view of task
+		if(!parseInt(taskaccepted)) {
+			acceptbutton.style.display = "block";
+			declinebutton.style.display = "block";
+			changeTaskEditingState(true, taskstate);
+		} else {
+			savebutton.style.display = "block";
+			assigntaskbutton.style.display = "block";
+			cancelassigntaskbutton.nextSibling.style.display = "block";	// Separator
+			remindervalues.style.display = "block";
+
+			taskcompletebutton.style.display = "block";
+			taskcompletebutton.nextSibling.style.display = "block";
+		}
+	}
+
+	var taskhistorydesc;
+
+	if(assignee || (dhtml.getElementById("taskstate").value == tdsOWN)) {
+		taskhistorydesc = { 	1 : _("Accepted by %u on %d"),
+								2 : _("Declined by %u on %d"),
+								3 : _("Last update was sent by %u on %d"),
+								5 : _("Assigned by %u on %d") };
+	} else {
+		taskhistorydesc = { 	1 : _("Accepted by %u on %d"),
+								2 : _("Declined by %u on %d"),
+								3 : _("Last update was received from %u on %d"),
+								5 : _("Waiting for response from recipient") };
+	}
+
+	if(taskhistorydesc[taskhistory]) {
+		var history = taskhistorydesc[taskhistory];
+
+		var time = new Date(assignedtime*1000);
+
+		history = history.replace("%u", tasklastdelegate);
+		history = history.replace("%d", time.strftime(_("%d/%m/%Y %H:%M")));
+
+		extrainfo.style.display = "block";
+		extrainfo.innerHTML = "<p>" + history + "</p>";
+		copyExtraInfo();
 	}
 	
 	resizeBody();
@@ -534,3 +654,161 @@ function eventTaskListKeyCtrlSave(moduleObject, element, event, keys)
 			break;
 	}
 }
+
+function callBackTaskRecurrence(recurrence) {
+	module.setRecurrence(recurrence);
+}
+
+function showHideRecurrenceMenu(hide) {
+	var recur_menu = dhtml.getElementById('recurrence');
+	if (recur_menu) {
+		recur_menu.style.display = hide ? 'none' : 'block';
+		recur_menu.nextSibling.style.display = hide ? 'none' : 'block';		//Separator
+	}
+}
+
+function delete_task_item()
+{
+	if (module.messageentryid) {
+		var taskstate = dhtml.getElementById("taskstate").value;
+		var complete = dhtml.getElementById("complete").value;
+		var windowData = new Object();
+		windowData['subject'] = module.itemProps['subject'];
+		windowData['parentModule'] = module;
+
+		if ((taskstate == 2 && complete != 1) || (parseInt(module.itemProps['recurring']) && !parseInt(module.itemProps['dead_occurrence'], 10))) {
+			if (taskstate == 2) windowData['taskrequest'] = true;
+
+			webclient.openModalDialog(module, "deletetaskoccurrence", DIALOG_URL+"task=deletetaskoccurrence_modal&entryid="+ module.messageentryid +"&storeid="+ module.storeid +"&parententryid="+ module.parententryid, 300, 220, null, null, windowData);
+		} else {
+			module.deleteMessage(false);
+		}
+	}
+}
+
+function showTaskRecurrence()
+{
+	var recurring = dhtml.getElementById("recurring").value;
+	if (recurring == 1) {
+		var recurr = {
+			startocc : dhtml.getElementById("startocc").value,
+			endocc : dhtml.getElementById("endocc").value,
+			start : dhtml.getElementById("start").value,
+			end : dhtml.getElementById("end").value,
+			term : dhtml.getElementById("term").value,
+			regen : dhtml.getElementById("regen").value,
+			everyn : dhtml.getElementById("everyn").value,
+			type : dhtml.getElementById("type").value,
+			subtype : dhtml.getElementById("subtype").value,
+			weekdays : dhtml.getElementById("weekdays").value,
+			month : dhtml.getElementById("month").value,
+			monthday : dhtml.getElementById("monthday").value,
+			nday : dhtml.getElementById("nday").value,
+			numoccur : dhtml.getElementById("numoccur").value
+		};
+		var recurtext = getTaskRecurrencePattern(recurr);
+		var extrainfo = dhtml.getElementById("recurtext");
+
+		extrainfo.style.display = "block";
+		extrainfo.innerHTML = recurtext;
+		copyExtraInfo();
+	}
+}
+
+function checkNamesCallBackTask(resolveObj)
+{
+	checkNamesCallBack(resolveObj, true);
+
+	//Send Task
+	if(window.resolveForSendingMessage === true){
+		if (submit_task("request")) window.close();
+	}
+}
+
+/**
+ * Function which enables/disables editing of fields in task dialog.
+ *@param boolean disable true if disable editing else false
+ *@param integer taskstate denotes state of task whether own or assigned
+ */
+function changeTaskEditingState(disable, taskstate)
+{
+	// Disable all input fields of 'Details' Tab
+	var details_tab = dhtml.getElementById("details_tab");
+	var elements = details_tab.getElementsByTagName("input");
+	for(var i=0; i < elements.length; i++) {
+		elements[i].disabled = disable;
+	}
+
+	// Switch to Disabled Task tab
+	if (disable) {
+		// Hide original 'Task' tab and show disabled task tab which shows only properties
+		dhtml.addClassName(dhtml.getElementById("tab_task"), "tab_hide");
+		dhtml.addClassName(dhtml.getElementById("tab_task"), "selectedtab");
+
+		// Hide datepicker trigger for datecompleted field in 'Details' tab
+		dhtml.getElementById("text_datecompleted_button").style.display = "none";
+
+		tabbarControl.change("disabledtask");
+	} else {
+		dhtml.removeClassName(dhtml.getElementById("tab_task"), "tab_hide");
+		dhtml.addClassName(dhtml.getElementById("tab_disabledtask"), "tab_hide");
+
+		dhtml.getElementById("text_datecompleted_button").style.display = "block";
+		tabbarControl.change("task");
+	}
+
+	if (typeof taskstate != "undefined" && taskstate == tdsACC) dhtml.getElementById("create_unassigned_copy").disabled = !disable;
+	dhtml.getElementById("display_cc").disabled = true;
+}
+
+/**
+ * Function which creates unassigned copy of already sent/assigned task.
+ */
+function createUnassignedCopy()
+{
+	if (confirm(_("If you create an unassigned copy of this task, you will own the copy, and you will no longer receive updates for the task you assigned."))) {
+		dhtml.getElementById("taskstate").value = tdsOWNNEW;
+		dhtml.getElementById("taskhistory").value = thNone;
+		dhtml.getElementById("ownership").value = olNewTask;
+		dhtml.getElementById("delegationstate").value = olTaskNotDelegated;
+
+		// Owner
+		dhtml.getElementById("owner").value = webclient.fullname;
+
+		// Subject
+		var subject = dhtml.getElementById("subject");
+		subject.value = subject.value +" (copy)";
+
+		submit_task("unassign");
+		setTaskRequestMode();
+		changeTaskEditingState(false);
+	}
+}
+
+/**
+ * Function which reclaims ownership of a declined task
+ */
+function reclaimOwnerShip()
+{
+	if (module) {
+		dhtml.getElementById('taskstate').value = tdsOWNNEW;
+		dhtml.getElementById('taskhistory').value = thNone;
+		dhtml.getElementById('ownership').value = olNewTask;
+		dhtml.getElementById('delegationstate').value = olTaskNotDelegated;
+		dhtml.getElementById('icon_index').value = 1280;
+		dhtml.getElementById('owner').value = webclient.fullname;
+		dhtml.getElementById("to").value = "";
+
+		submit_task("reclaim");
+		setTaskRequestMode();
+		changeTaskEditingState(false);
+	}
+}
+
+function copyExtraInfo()
+{
+	var disabledExtraInfo = dhtml.getElementById("disabled_extrainfo");
+	disabledExtraInfo.style.display = "block";
+	disabledExtraInfo.innerHTML = dhtml.getElementById("extrainfo").innerHTML;
+	disabledExtraInfo.innerHTML += dhtml.getElementById("recurtext").innerHTML;
+}
