@@ -75,7 +75,11 @@ addressbooklistmodule.prototype.init = function(id, element, title, data)
     delete this.events["menu"];
 
 	var items = new Array();
-	items.push(webclient.menu.createMenuItem("select", _("Select"), false, eventListContextMenuOpenMessage));
+	if (data["showsendmail"] == "true") {
+		items.push(webclient.menu.createMenuItem("createmail", _("Email Message"), false, eventABSendMailTo));
+	} else {
+		items.push(webclient.menu.createMenuItem("select", _("Select"), false, eventListContextMenuOpenMessage));
+	}
 	this.contextmenu = items;
 }
 
