@@ -334,77 +334,6 @@ AdvancedFindListModule.prototype.deleteItems = function(action)
 	this.item(action);
 }
 
-/**
- * Function will get properties of items from XML and store it in itemProps,
- * attributes in properties will be truncated
- * @param		Array		items		array of item XMLNodes
- */
-AdvancedFindListModule.prototype.getItemPropsFromXML = function(items)
-{
-	// remember item properties
-	this.itemProps = new Object();
-
-	for(var index = 0; index < items.length; index++) {
-		this.updateItemProps(items[index]);
-	}
-}
-
-/**
- * Function will parse column data from XML
- * @param		XMLNode		action		action XML tag
- */
-AdvancedFindListModule.prototype.getColumnDataFromXML = function(action)
-{
-	// reset variables
-	this.propertylist = new Array();
-	this.properties = new Array();
-
-	var properties = action.getElementsByTagName("column");
-
-	// Columns
-	for(var index = 0; index < properties.length; index++) {
-		var id = dhtml.getXMLValue(properties[index], "id", false);
-
-		if(id !== false) {
-			var property = new Object();
-			property["id"] = id;
-			property["order"] = dhtml.getXMLValue(properties[index], "order", false);
-			property["name"] = dhtml.getXMLValue(properties[index], "name", false);
-			property["title"] = dhtml.getXMLValue(properties[index], "title", false);
-			property["length"] = dhtml.getXMLValue(properties[index], "length", false);
-			property["visible"] = dhtml.getXMLValue(properties[index], "visible", false);
-			property["type"] = dhtml.getXMLValue(properties[index], "type", false);
-
-			this.propertylist.push(property);
-
-			if(property["visible"]) {
-				this.properties.push(property);
-			}
-		}
-	}
-}
-
-/**
- * Function will create a object of sort data that is retrived from XML
- * @param		XMLNode		action		action XML tag
- */
-AdvancedFindListModule.prototype.getSortDataFromXML = function(action)
-{
-	var sort = dhtml.getXMLNode(action, "sort");
-
-	if(sort && sort.firstChild) {
-		var sortColumn = dhtml.getXMLValue(action, "sort");
-		var sortDirection = sort.getAttribute("direction");
-
-		// old way
-		var column = new Object();
-		column["attributes"] = new Object();
-		column["attributes"]["direction"] = sortDirection;
-		column["_content"] = sortColumn;
-		this.sort = new Array(column);
-	}
-}
-
 /**
  * Function which takes care of the paging element
  * @param		object		action		the action tag 
@@ -1301,13 +1230,11 @@ function advFindCategoriesCallBack(categories, userData) {
  * @param		Object			event				event data object
  */
 function eventAdvFindContextMenuDeleteMessage(moduleObject, element, event) {
-	var rowId = moduleObject.advFindTableWidget.getSelectedRowID(0);
+	var selectedRowData = moduleObject.advFindTableWidget.getSelectedRowData();
 
-	if(typeof rowId != "undefined" && rowId) {
-		var selectedItem = moduleObject.advFindTableWidget.getDataByRowID(rowId);
-		var selectedRowElement = moduleObject.advFindTableWidget.getRowByRowID(rowId);
-
-		moduleObject.deleteMessage(selectedItem["entryid"], selectedRowElement.id);
+	for(var index = 0; index < selectedRowData.length; index++) {
+		var elemId = moduleObject.advFindTableWidget.getRowByRowID(selectedRowData[index]["rowID"]).id;
+		moduleObject.deleteMessage(selectedRowData[index]["entryid"], elemId);
 	}
 
 	// remove context menu
