@@ -94,6 +94,14 @@ appointmentitemmodule.prototype.executeOnLoad = function()
 			dhtml.addClassName(tab_tracking, "tab_hide");
 		}
 	}
+
+	if (this.counterProposal) {
+		if (this.viewAllProposals) {
+			dhtml.executeEvent(dhtml.getElementById('tab_scheduling'), 'click');
+		} else {
+			initDate(new Date(this.proposedStartDate * 1000), new Date(this.proposedEndDate * 1000));
+		}
+	}
 }
 
 appointmentitemmodule.prototype.setStartTime = function(unixtime)
@@ -292,6 +300,7 @@ appointmentitemmodule.prototype.setRecurrence = function(recurrence)
 		dhtml.getElementById('icon_index').value = 1024;
 		dhtml.getElementById('recurring_reset').value = "";
 		dhtml.getElementById('recurtext').innerHTML = "";
+		dhtml.getElementById('recur_type').value = 0;
 	}
 
 	showRecurrence();
@@ -314,15 +323,24 @@ appointmentitemmodule.prototype.deleteMessage = function (basedate)
 	var send = false;
 	var meeting = parseInt(this.itemProps["meeting"], 10);
 	var recurring = parseInt(this.itemProps["recurring"], 10);
+	var isMeetingOrganized = parseInt(this.itemProps["responsestatus"], 10) == olResponseOrganized;
 
 	if(basedate) {
 		//occurrence end date
 		var end = dhtml.getElementById("duedate").getAttribute("unixtime");
 		var endtime = new Date(end * 1000);
 		
-		// if occurrence is later then send confirmation message for cancellation message.
-		if(meeting !== 0 && (endtime.getTime() > (new Date().getTime()))) {
-			send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
+		if (meeting !== 0 && (endtime.getTime() > (new Date().getTime()))) {
+			/**
+			 * if occurrence is later then send confirmation message for cancellation message.
+			 * Check whether there are any recepients in MR or not.
+			 */
+			if (isMeetingOrganized && !(this.itemProps.requestsent && this.itemProps.requestsent != "1")) {
+				send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
+			} else {
+				sendConfirmationDeleteAppointmentItem(this, this.itemProps["subject"], basedate);
+				return true;
+			}
 		} else {
 			//directlly delete passed occurrences.
 			var req = new Object;
@@ -364,7 +382,13 @@ appointmentitemmodule.prototype.deleteMessage = function (basedate)
 
 		// if recurrence is later then send confirmation message for cancellation message.
 		if(meeting !== 0 && endtime.getTime() > (new Date().getTime())) {
-			send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
+			// Check whether there are any recepients in MR or not.
+			if (isMeetingOrganized && !(this.itemProps.requestsent && this.itemProps.requestsent != "1")) {
+				send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
+			} else {
+				sendConfirmationDeleteAppointmentItem(this, this.itemProps["subject"]);
+				return true;
+			}
 		} else {
 			//directlly delete passed MRs.
 			appointmentitemmodule.superclass.deleteMessage.call(this);
@@ -380,6 +404,8 @@ appointmentitemmodule.prototype.deleteMessage = function (basedate)
 			parentWebclient.xmlrequest.sendRequest(true);
 		}
 	}
+
+	return false;
 }
 
 appointmentitemmodule.prototype.saveMessage = function (props, send, recipients, dialog_attachments)
@@ -393,11 +419,33 @@ appointmentitemmodule.prototype.execute = function (type, action)
 	{
 		case "item":
 			this.item(action);
+
+			/** 
+			 * If MR is recurring then attandees are not allowed
+			 * to propose new time on whole reccurrence.
+			 * http://msdn.microsoft.com/en-us/library/ee217972%28EXCHG.80%29.aspx
+			 */
+			var recurring = parseInt(dhtml.getXMLValue(action, "recurring", 0), 10);
+			var basedate = parseInt(dhtml.getXMLValue(action, "basedate", 0), 10);
+			var proposeNewTimeElem = dhtml.getElementById("proposenewtime");
+
+			if(recurring && !basedate && proposeNewTimeElem)
+				proposeNewTimeElem.style.display = "none"; 
+
 			webclient.menu.showMenu();
 			break;
 		case "saved":
 			this.messageSaved(action);
 			break;
+		case "error":
+			this.handleError(action);
+			break;
+		case "convert_item":
+			this.setBodyFromItemData(action);
+			break;
+		case "getAttachments":		// Uploaded Attachment list.
+			this.attachmentsList(action);
+			break;
 	}
 }
 
@@ -416,7 +464,7 @@ appointmentitemmodule.prototype.save = function(props, send, recipients, dialog_
 
 	if(this.isMeeting == true && props["entryid"] == ""){
 		// Add human readable BODY Text.
-		props["body"] = this.addMeetingTimeInfoToBody(props["body"], props['startdate'], props['duedate'], props['location']);
+		props["body"] = this.addMeetingTimeInfoToBody(props["body"], props['startdate'], props['duedate'], props['location'], props["recurring"] ? props["recurring_pattern"] : false);
 	}
 
 	if(this.parententryid)
@@ -514,8 +562,7 @@ appointmentitemmodule.prototype.messageSaved = function(action)
 				alert(_("\"%s\" is already booked for this specified time. You must use another time or find another resource.").sprintf(name));
 				break;
 			default:
-				//alert(_("Unable to directly book a resource for this meeting."));
-				alert(_("Meeting was not scheduled.").sprintf(name));
+				alert(_("Meeting was not scheduled."));
 				break;
 		}
 	}
