@@ -234,9 +234,17 @@ appointmentlistmodule.prototype.setDays = function(timestamp)
 	}
 }
 
-appointmentlistmodule.prototype.list = function(useTimeOut)
+/**
+ * Function which sends a request to the server, with the action "list".
+ * @param boolean useTimeOut use a time out for the request (@TODO check this parameter is not used anymore)
+ * @param boolean noLoader use loader
+ * @param boolean storeUniqueIds store selected items' unique ids before reloading listmodule
+ */ 
+appointmentlistmodule.prototype.list = function(useTimeOut, noLoader, storeUniqueIds)
 {
-	if(this.storeid && this.entryid) {
+	// As startdate and enddate are set to false for Calendar listview 
+	// there is no need to send the restriction to server.
+	if(this.selectedview != "table" && this.storeid && this.entryid) {
 		var data = new Object();
 		data["store"] = this.storeid;
 		data["entryid"] = this.entryid;
@@ -247,9 +255,10 @@ appointmentlistmodule.prototype.list = function(useTimeOut)
 		
 		webclient.xmlrequest.addData(this, "list", data);
 		this.viewController.loadMessage();
-	}
+	}else{
 	//called superclass list method to set restriction for sorting and paging
-	appointmentlistmodule.superclass.list.call(this, useTimeOut);
+	appointmentlistmodule.superclass.list.call(this, useTimeOut, noLoader, storeUniqueIds);
+	}
 }
 
 appointmentlistmodule.prototype.getAppointmentProps = function(starttime, endtime, subject, location, label, busystatus, remindertime, alldayevent)
@@ -285,7 +294,9 @@ appointmentlistmodule.prototype.getAppointmentProps = function(starttime, endtim
 	
 	props["reminder"] = "false";
 	props["reminder_minutes"] = 15;
-	if(remindertime && remindertime > 0) {
+
+	// If reminder time is set to zero or any other values then save it in props
+	if(typeof remindertime != "undefined" && remindertime >= 0) {
 		props["reminder"] = "true";
 		props["reminder_minutes"] = remindertime;
 	}
@@ -354,14 +365,27 @@ appointmentlistmodule.prototype.deleteAppointment = function(entryid, basedate,
 
 	if(basedate) {
 		//occurrence end date
-		var end = (selectedElement.end)? selectedElement.end: (selectedElement.getAttribute("end"))? selectedElement.getAttribute("end"): selectedElement.getAttribute("duedate");
+		var end = (selectedElement.end)? selectedElement.end: (selectedElement.getAttribute("end"))? selectedElement.getAttribute("end"): (selectedElement.getAttribute("duedate"))? selectedElement.getAttribute("duedate") : selectedElement.duedate;
 		var endtime = new Date(end * 1000);
 
-		// if occurrence is later then send confirmation message for cancellation message.
-		if(selectedElement.meetingrequest && parseInt(selectedElement.meetingrequest, 10) == 1) {
-			if(endtime.getTime() > (new Date().getTime()))
-				send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
+		/**
+		 * if occurrence is later then send confirmation message for cancellation message.
+
+		 * If MR is just saved (not send) then requestsent attribute (MeetingRequestWasSent Property) is set to '0'
+		 * If MR was sent to recpients then requestsent attribute (MeetingRequestWasSent Property) is set to '1'
+		 * so if request is not sent to recipients then dont ask to update them while saving MR.
+		 */
+		if(endtime.getTime() > (new Date().getTime()) && !(selectedElement.requestsent && selectedElement.requestsent != "1")) {
+			if(selectedElement.meetingrequest && parseInt(selectedElement.meetingrequest, 10) == 1) {
+				send = confirm(_("Would you like to send an update to the attendees regarding cancellation of this meeting?"));
+				//if user does not want to cancel/delete the meeting,we want like to ignore this action
+				if(send == false) return true;
+			} else if (selectedElement.meetingrequest && parseInt(selectedElement.meetingrequest, 10) != 0) {
+				sendConfirmationDeleteAppointmentList(this, selectedElement, basedate);
+				return true;
+			}
 		}
+
 		if(send) {
 			// delete occurrence and send cancellation message
 			var data = new Array();
@@ -391,11 +415,23 @@ appointmentlistmodule.prototype.deleteAppointment = function(entryid, basedate,
 		var end = this.itemProps[entryid].enddate_recurring;
 		var endtime = new Date(end * 1000);
 
-		// if recurrence is later then send confirmation message for cancellation message.
-		if(selectedElement.meetingrequest && parseInt(selectedElement.meetingrequest, 10) == 1) {
-			if(endtime.getTime() > (new Date().getTime()))
-				send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
+		/**
+		 * If MR is just saved (not send) then requestsent attribute (MeetingRequestWasSent Property) is set to '0'
+		 * If MR was sent to recpients then requestsent attribute (MeetingRequestWasSent Property) is set to '1'
+		 * so if request is not sent to recipients then dont ask to update them while saving MR.
+		 */
+		if (endtime.getTime() > (new Date().getTime()) && !(selectedElement.requestsent && selectedElement.requestsent != "1")) {
+			// if recurrence is later then send confirmation message for cancellation message.
+			if(selectedElement.meetingrequest && parseInt(selectedElement.meetingrequest, 10) == 1) {
+				send = confirm(_("Would you like to send an update to the attendees regarding cancellation of this meeting?"));
+				//if user does not want to cancel/delete the meeting,we want like to ignore this action
+				if(send == false) return true;
+			} else if (selectedElement.meetingrequest && parseInt(selectedElement.meetingrequest, 10) != 0) {
+				sendConfirmationDeleteAppointmentList(this, selectedElement, false);
+				return true;
+			}
 		}
+
 		if(send) {
 			// delete MR and send cancellation message
 			var data = new Array();
@@ -453,15 +489,24 @@ appointmentlistmodule.prototype.deleteAppointments = function(messages, promptoc
 		}
 	}else{
 		// do a normal delete
-		var meetingrequestResponseStatusOrganizer = (itemEl.meetingrequest && Number(itemEl.meetingrequest)==1);
-		if (meetingrequestResponseStatusOrganizer) { // 1 = olResponseOrganized
-			// calculated end date of appointment to check whether the update to attendees is send or not, for different views of calendar. 
-			var end = (itemEl.end)? itemEl.end: itemEl.getAttribute("duedate"); 
-			var endtime = new Date(end * 1000);
-			if( endtime.getTime()>(new Date().getTime())){
+		// calculated end date of appointment to check whether the update to attendees is send or not, for different views of calendar. 
+		var end = (itemEl.end)? itemEl.end: itemEl.getAttribute("duedate"); 
+		var endtime = new Date(end * 1000);
+		if( endtime.getTime()>(new Date().getTime())){
+			// IF MR status is set then set its value otherwise set to olResponseNone
+			var MRResponseStatusOrganizer = itemEl.meetingrequest ? Number(itemEl.meetingrequest) : olResponseNone;
+			/**
+			 * If MR is just saved (not send) then requestsent attribute (MeetingRequestWasSent Property) is set to '0'
+			 * If MR was sent to recpients then requestsent attribute (MeetingRequestWasSent Property) is set to '1'
+			 * so if request is not sent to recipients then dont ask to update them while saving MR.
+			 */
+			if (MRResponseStatusOrganizer == olResponseOrganized && !(itemEl.requestsent && itemEl.requestsent != "1")) {
 				// don't ask for meeting requests which are occuring in past
 				send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
 				deleteMessage = false;
+			} else if (MRResponseStatusOrganizer != olResponseNone && MRResponseStatusOrganizer != olResponseOrganized) {	//its attendee
+				sendConfirmationDeleteAppointmentList(this, itemEl, false, softDelete);
+				return true;
 			}
 		}
 
@@ -490,6 +535,33 @@ appointmentlistmodule.prototype.handleActionFailure = function(action)
 			if(errorMessageString != false)
 				alert(errorMessageString);
 			break;
+		case "bookresource":
+			var name = (dhtml.getXMLValue(action, "displayname"))?dhtml.getXMLValue(action, "displayname"):'(Unknown)';
+			/**
+			 * Error codes:
+			 * 1: No access/permissions.
+			 * 2: Resource does not automatically accept meeting requests (disabled atm, mail is sent instead).
+			 * 3: Resource declines recurring meeting requests.
+			 * 4: Resource declines conflicting meeting requests.
+			 */
+			switch(Number(dhtml.getXMLValue(action, "errorcode"))){
+				case 1:
+					alert(_("You marked \"%s\" as a resource. You cannot schedule a meeting with \"%s\" because you do not have the appropiate permissions for that account. Either enter the name as a required or optional attendee or talk to your administrator about giving you permission to schedule \"%s\".").sprintf(name, name, name));
+					break;
+				case 2:
+					alert(_("\"%s\" has declined your meeting because \"%s\" does not automatically accept meeting requests. ").sprintf(name, name));
+					break;
+				case 3:
+					alert(_("\"%s\" has declined your meeting because it is recurring. You must book each meeting separetly with this recurrence.").sprintf(name));
+					break;
+				case 4:
+					alert(_("\"%s\" is already booked for this specified time. You must use another time or find another resource.").sprintf(name));
+					break;
+				default:
+					alert(_("Meeting was not scheduled."));
+					break;
+			}
+			break;
 	}
 }
 
@@ -523,21 +595,14 @@ appointmentlistmodule.prototype.openCreateAppointmentDialog = function(type, all
 		uri += 	"&startdate=" + starttime +
 				"&enddate=" + endtime ;
 		uri += (type) ?"&meeting=true":"";
-	}else{
-		uri += 	"&entryid=" + this.entryids[this.getSelectedMessages()];
 	}
+
 	if(allDayFlag){
 		uri += 	"&allDayEvent=true";
 	}
-	var el = dhtml.getElementById(this.getSelectedMessages());
-	var basedate = (el && (typeof el.getAttribute("basedate") != "undefined" || el.getAttribute("basedate") != null))?el.getAttribute("basedate") : false;
-	if(basedate) { // any item with a basedate is recurring
-		uri += "&task=occurrence_standard&basedate=" + basedate;
-		webclient.openWindow(this, "occurrence", uri, 300, 200);
-	} else {
-		uri += "&task=appointment_standard";
-		webclient.openWindow(this, "appointment", uri);
-	}
+
+	uri += "&task=appointment_standard";
+	webclient.openWindow(this, "appointment", uri);
 }
 
 function eventAppointmentListDblClickMessage(moduleObject, element, event)
@@ -548,7 +613,7 @@ function eventAppointmentListDblClickMessage(moduleObject, element, event)
 	
 	var entryid = moduleObject.entryids[element.id];
 
-	if(element.getAttribute("basedate")) { // any item with a basedate is recurring
+	if(parseInt(element.getAttribute("basedate"), 10)) { // any item with a basedate is recurring
 		basedate = element.attributes["basedate"].value;
 
 		// please note that this url is also printed, so make it more "interesting" by first set the entryid
@@ -652,3 +717,78 @@ function eventCalendarContextMenuClickCreateAppointment(moduleObject, element, e
 	}
 	moduleObject.openCreateAppointmentDialog(type, true, element);
 }
+
+
+/**
+ * Function which popups option to attendee when he/she deletes any meeting item.
+ *@param object moduleObject module object
+ *@param element html element of meeting
+ *@param timestamp basedate if item is an occurrence then basedate is passed
+ *@param boolean softdelete if shift+del
+ */
+function sendConfirmationDeleteAppointmentList(moduleObject, element, basedate, softdelete)
+{
+	var windowData = new Array();
+	windowData["module"] = moduleObject;
+	windowData["confirmDelete"] = true;
+	windowData["elementId"] = element.id;
+	windowData["subject"] = "";
+
+	if(basedate)
+		windowData["basedate"] = basedate;
+
+	if (typeof element.subject != "undefined") {
+		windowData["subject"] = element.subject;
+	} else {
+		if (moduleObject.itemProps[moduleObject.entryids[element.id]])
+			windowData["subject"] = moduleObject.itemProps[moduleObject.entryids[element.id]].subject;
+	}
+
+	if (element.id.indexOf("_") > 0)
+		windowData["entryid"] = element.id.substring(0, element.id.indexOf('_'));
+	else
+		windowData["entryid"] = element.id;
+
+	if (typeof softDelete != "undefined")
+		windowData["softDelete"] = softDelete;
+
+	webclient.openModalDialog(-1, 'sendMRMailConfirmation', DIALOG_URL+'task=sendMRMailConfirmation_modal', 350, 200, appointmentListSendMRMailConfirmation_callback, moduleObject, windowData);
+}
+/**
+ * Callback function from sendMRConfirmation dialog
+ * this function decides whether to send response to organizer that attendee has deleted item.
+ * 
+ *@param object moduleObject module object
+ *@param boolean sendResponse true if attendee wants to send response on deletion else false
+ *@param integer basedate basedate if it an occurrence
+ *@param object callBackData extra information about the deleted item like 
+ */
+function appointmentListSendMRMailConfirmation_callback(moduleObject, sendResponse, basedate, callBackData)
+{
+	var entryid = callBackData.elementId;
+
+	if (entryid.indexOf('_') > 0) entryid = entryid.substring(0, entryid.indexOf('_'));
+
+	var req = new Object;
+	req['store'] = moduleObject.storeid;
+	req['parententryid'] = moduleObject.entryid;
+	req['props'] = new Object;
+	req['props']['entryid'] = entryid;
+
+	if (basedate)
+		req['props']['basedate'] = parseInt(basedate, 10);
+
+	if (sendResponse) {
+		webclient.xmlrequest.addData(moduleObject, 'declineMeeting', req, webclient.modulePrefix);
+		webclient.xmlrequest.sendRequest(true);
+	} else {
+		if (basedate) {
+			req['delete'] = 1;
+			webclient.xmlrequest.addData(moduleObject, 'save', req, webclient.modulePrefix);
+			webclient.xmlrequest.sendRequest(true);
+		} else {
+			// Use superclass deleteMessages to actually delete the items
+			appointmentlistmodule.superclass.deleteMessages.call(moduleObject, new Array(callBackData.elementId));
+		}
+	}
+}
\ No newline at end of file
