@@ -130,7 +130,7 @@ contactitemmodule.prototype.executeOnLoad = function()
 	webclient.inputmanager.bindKeyControlEvent(this, KEYS["mail"], "keyup", eventContactItemKeyCtrlSave);
 }
 
-contactitemmodule.prototype.save = function(props, email_addresses, dialog_attachments)
+contactitemmodule.prototype.save = function(props, dialog_attachments)
 {
 	var data = new Object();
 	if(this.storeid) {
@@ -143,7 +143,6 @@ contactitemmodule.prototype.save = function(props, email_addresses, dialog_attac
 	
 	data["props"] = props;
 	data["dialog_attachments"] = dialog_attachments;
-	data["email_addresses"] = email_addresses;
 	
 	if(parentWebclient) {
 		parentWebclient.xmlrequest.addData(this, "save", data, webclient.modulePrefix);
@@ -162,11 +161,11 @@ contactitemmodule.prototype.save = function(props, email_addresses, dialog_attac
  * @return object result[key] => value
  */
 contactitemmodule.prototype.parseDetailedInfo = function (data, type, returnResult) {
+	this.result = {};
+
 	switch(type) {
 		case "full_name":
 			// parse full name and return an object with all fields
-			this.result = {};
-
 			if(data.length >= 1) {
 				this.result = this.parsingObject.parseDetailedFullNameInfo(data);
 			}
@@ -198,8 +197,6 @@ contactitemmodule.prototype.parseDetailedInfo = function (data, type, returnResu
 			break;
 		case "address":
 			// parse address and return an object with all fields
-			this.result = {};
-
 			if(data.length >= 1) {
 				this.result = this.parsingObject.parseDetailedAddressInfo(data);
 			}
@@ -298,4 +295,30 @@ contactitemmodule.prototype.storeDetailedInfo = function (data, type, show) {
 			webclient.settings.set("addressbook/show_detailed_address_dialog", (data["setting"] == true) ? "true" : "false");
 			break;
 	}
+}
+
+/**
+ * Function which will add the selected items as text in body of the composing contact.
+ * @param object action the action tag
+ */ 
+contactitemmodule.prototype.setBodyFromItemData = function(action)
+{
+	var message = action.getElementsByTagName("item");
+	//set the body of contact item
+	for(var i=0;i<message.length;i++){
+		this.setBody(message[i], true, false, true);
+	}
+	// setting focus and also setting displayname and emailaddreass for single items
+	if(message.length == 1){
+		var displayname = dhtml.getXMLValue(message[0], "sent_representing_name", "").toLowerCase();
+		
+		dhtml.getElementById("display_name").value = displayname ;
+		dhtml.getElementById("email_address_display_name").value = displayname;
+		dhtml.getElementById("email_address").value = dhtml.getXMLValue(message[0], "sent_representing_email_address", "").toLowerCase();
+		setFileAs();
+
+		dhtml.getElementById("html_body").focus();
+	}else{
+		dhtml.getElementById("display_name").focus();
+	}
 }
\ No newline at end of file
