@@ -188,9 +188,107 @@ contactlistmodule.prototype.execute = function(type, action)
 		case "search_error":
 			this.handleSearchError(action);
 			break;
+		case "convert_contact":
+			this.convertSelectedContactItem(action);
+			break;
 	}
 }
 
+/**
+ * Function which does error handling while converting the selected contact item
+ * @param object action the action tag 
+ *
+ * @TODO:
+ * we can also drag an contact item to Task Folder but 
+ * This is currently not implemented as it is not possible to send Task Request from WA.
+ */
+
+contactlistmodule.prototype.convertSelectedContactItem = function(action)
+{
+	var message = action.getElementsByTagName("item");
+	var targetFolder = dhtml.getTextNode(action.getElementsByTagName("targetfolder")[0],"");
+	var parentEntryid = dhtml.getTextNode(action.getElementsByTagName("targetfolderentryid")[0],"");
+
+	var recipientString = "";
+	for(var i=0;i < message.length; i++){
+		var messageClass = dhtml.getXMLValue(message[i], "message_class", "").split(".");
+		var objectType  = parseInt(dhtml.getXMLValue(message[i], "objecttype"),10);
+		
+		if(messageClass[1] == "DistList"){
+			switch (objectType){
+				case MAPI_DISTLIST:		// groups in GAB
+					recipientString += '[' + dhtml.getXMLValue(message[i], "dl_name") + "]";
+					break;
+				case MAPI_MESSAGE:		// groups in contact folders
+					recipientString += this.mergeABItems(message[i]);
+					break;
+			}
+		}else{
+			var isEmailEmpty = true;
+			for (var j=1; j <= 3 ; j++){
+				var email = dhtml.getXMLValue(message[i], "email_address_"+j, "");
+				if(email != ""){
+					var email_displayname = dhtml.getXMLValue(message[i], "email_address_display_name_"+j, "").replace("("+email+")","");
+					email_displayname = email_displayname +"<"+ email +">";
+					recipientString += email_displayname +";";
+					isEmailEmpty = false;
+				}
+			}
+			if(isEmailEmpty) var emailStringEmpty = true;
+		}
+	}
+	
+	//show an alert message for contacts which do not have e-mail address specified
+	if(emailStringEmpty){
+		if(message.length < 2){
+			if(!confirm(_("You must first entert valid e-mail address for this contacts before you can send a mail to it")))
+				return;
+		}else{
+			if(!confirm(_("Some of these contacts do not have e-mail addresses. You may need to add the e-mail address to send them a mail")))
+				return;
+		}
+	}
+
+	var uri = DIALOG_URL+"task=" + targetFolder + "_standard&storeid=" + this.storeid+ "&parententryid=" + parentEntryid;
+	if(targetFolder == "appointment") uri += "&meeting=true";
+		webclient.openWindow(this, 
+							targetFolder, 
+							uri,
+							720, 580, 
+							true, null, null, 
+							{
+								"emails" : recipientString, 
+								"action" : "convert_contact"
+							});
+}
+
+/**
+ * Function which gives groups items as recipients depending on address book type
+ * @param object message the mesasge.
+ * @return string of the recipients in groups
+ */
+contactlistmodule.prototype.mergeABItems = function(message)
+{
+	var result = "";
+	var members = message.getElementsByTagName("members")[0];
+
+	if(members){	
+		var member = members.getElementsByTagName("member");
+		for (var j = 0; j < member.length; j++){
+			var displayName = dhtml.getXMLValue(member[j], "display_name", "");
+			var emailAddress = dhtml.getXMLValue(member[j], "email_address", "");
+			var objectType = parseInt(dhtml.getXMLValue(member[j], "objecttype"),10);
+
+			if(objectType == MAPI_DISTLIST) {
+				if(emailAddress)	result += "[" + emailAddress +  "]; ";
+			} else {
+				result += displayName + " <" + emailAddress + ">;" ;
+			}
+		}
+	}
+	return result;
+}
+
 /**
  * Function will save the email address from the contacts in action
  * @param string type the action type
@@ -296,7 +394,7 @@ contactlistmodule.prototype.initSearchBar = function()
 	dhtml.addEvent(this, searchFilterInputBox, "selectstart", eventContactListSearchBarFilterMouseMove);
 	dhtml.addEvent(this, searchFilterInputBox, "focus", eventContactListSearchFilterFocus);
 	dhtml.addEvent(this, searchFilterInputBox, "blur", eventContactListSearchFilterFocus);
-	dhtml.addEvent(this, searchFilterTarget, "mousedown", eventStopBubbling);
+	dhtml.addEvent(this, searchFilterTarget, "mousedown", function(){event.stopPropagation()});
 
 	// subfolder search
 	// Only show subfolders when store supports search folders
