@@ -119,6 +119,19 @@ createmailitemmodule.prototype.execute = function(type, action)
 		case "success":		// mail sent successfully
 			window.close();
 			break;
+
+		case "convert_item":
+			this.setBodyFromItemData(action);
+			break;
+
+		// will built attachment items while composing mail
+		case "attach_items":		
+			webclient.menu.showMenu();
+			this.setAttachItemData(action);
+			break;		
+		case "getAttachments":		// Uploaded Attachment list.
+			this.attachmentsList(action);
+			break;
 	}
 }
 
@@ -129,15 +142,19 @@ Function which updates entryid element, before sending the mail, so that draft m
 createmailitemmodule.prototype.updateMessage = function(action)
 {
 	var item = action.getElementsByTagName("item")[0];
-	var entryid = item.getElementsByTagName("entryid")[0];
-	var parententryid = item.getElementsByTagName("parententryid")[0];	
+	var entryid = dhtml.getXMLValue(item, "entryid", false);
+	var parententryid = dhtml.getXMLValue(item, "parententryid", false);
+	var storeid = dhtml.getXMLValue(item, "storeid", false);
 
 	var property = new Object();
-	property["entryid"] = (entryid && entryid.firstChild ?entryid.firstChild.nodeValue:false);
-	property["parententryid"] = (parententryid && parententryid.firstChild ?parententryid.firstChild.nodeValue:false);
+	property["entryid"] = entryid;
+	property["parententryid"] = parententryid;
+	//set the store of the message to be sent to server, for a case in which any delagate store is open
+	property["storeid"] = storeid ? storeid : this.storeid;
 	
 	// Update message entryID.
 	this.messageentryid = property["entryid"];
+	this.setData(property);
 	
 	var entryidElement = dhtml.getElementById("entryid");
 	var parententryidElement = dhtml.getElementById("parent_entryid");
@@ -236,7 +253,6 @@ createmailitemmodule.prototype.item = function(action)
 				}
 			}
 		}
-
 		switch(this.message_action)
 		{
 			case "reply":
@@ -395,8 +411,19 @@ createmailitemmodule.prototype.setSender = function(message)
 			}
 		}
 	} else {
+		/**
+		 * Get "sent_representing_email_address" and "sent_representing_name"
+		 * If "sent_representing_email_address"  and "sent_representing_name" are not set 
+		 * then get sender email address from "sender_email_address" and "sender_name"
+		 * This happens when mail is sended using sendas option(not on behalf of).
+		 */
 		var sent_representing_email_address = dhtml.getTextNode(message.getElementsByTagName("sent_representing_email_address")[0],"");		
+		if(sent_representing_email_address == "")
+			sent_representing_email_address = dhtml.getXMLValue(message, "sender_email_address", "").toLowerCase();
+		
 		var sent_representing_name = dhtml.getTextNode(message.getElementsByTagName("sent_representing_name")[0],"");
+		if(sent_representing_name == "")
+			sent_representing_name = dhtml.getXMLValue(message, "sender_name", "");
 		
 		element.value = nameAndEmailToString(sent_representing_name,sent_representing_email_address,MAPI_MAILUSER,false) + "; ";
 	}
@@ -404,7 +431,7 @@ createmailitemmodule.prototype.setSender = function(message)
 
 createmailitemmodule.prototype.setSubjectBody = function(message, type)
 {
-	var subject = message.getElementsByTagName("subject")[0];
+	var subject = message.getElementsByTagName("normalized_subject")[0];
 
 	var subjectElement = dhtml.getElementById("subject");
 	if(subject && subject.firstChild) {
@@ -421,7 +448,14 @@ createmailitemmodule.prototype.setSubjectBody = function(message, type)
 	this.setBody(message, true, false);
 }
 
-createmailitemmodule.prototype.setBody = function(message, isReply, isConcept)
+/**
+ * Function which sets the body
+ * @param object message the action tag 
+ * @param boolean isReply checks the mail is a reply to a mail 
+ * @param boolean isConcept 
+ * @param boolean addAsText checks whether any attachment is added as text to mail body
+ */ 
+createmailitemmodule.prototype.setBody = function(message, isReply, isConcept, addAsText)
 {
 	var html_body = dhtml.getElementById("html_body");
 	var use_html = dhtml.getElementById("use_html");
@@ -437,122 +471,69 @@ createmailitemmodule.prototype.setBody = function(message, isReply, isConcept)
 		var htmlFormat = use_html.value == "true" ? true : false;
 
 		if(message) {
-			var sent_representing_email_address = dhtml.getTextNode(message.getElementsByTagName("sent_representing_email_address")[0],"");		
-			var sent_representing_name = dhtml.getTextNode(message.getElementsByTagName("sent_representing_name")[0],"");
-			var message_delivery_time = dhtml.getTextNode(message.getElementsByTagName("message_delivery_time")[0]);
-				if(message_delivery_time){
-					message_delivery_time = strftime(_("%a %x %X"), message_delivery_time);
-				}
-				
-			var received_by_email_address = dhtml.getTextNode(message.getElementsByTagName("received_by_email_address")[0],"");
-			// Escaping the HTML tag in subject body
-			var subject = dhtml.getTextNode(message.getElementsByTagName("subject")[0],"").htmlEntities();
-			var body = message.getElementsByTagName("body")[0];
-			var isHTML = dhtml.getTextNode(message.getElementsByTagName("isHTML")[0],false);
-
-			sent_representing_email_address = nameAndEmailToString(sent_representing_name,sent_representing_email_address,MAPI_MAILUSER,htmlFormat);
+			// check the selected items message_class to build the template, 
+			// which will be displayed in body of mail.
+			var message_class = dhtml.getXMLValue(message, "message_class", "").split(".");
+			switch(message_class[1]){
+				case "Appointment":
+					data = this.createAppointmentTemplate(message, htmlFormat);
+					break;
+				case "Contact":
+					data = this.createContactTemplate(message, htmlFormat);
+					break;
+				case "StickyNote":
+					data = this.createStickyNoteTemplate(message, htmlFormat);
+					break;
+				case "Task":
+					data = this.createTaskTemplate(message, htmlFormat);
+					break;
+				default:
+					data = this.createMailTemplate(message, htmlFormat);
+					break;
+			}
 			
-			if(body && body.firstChild) {
-				var element = body.firstChild;
-				for(var i = 0; i < body.childNodes.length; i++)
-				{
-					content += element.nodeValue;
-					element = element.nextSibling;
-				}
-			}
-
-			// HTML reply with a HTML email
-			if(isHTML && htmlFormat){
-				// Get index of the start of the body content
-				var bodyOpenIndex = content.search(/<body/gi);
-				if(bodyOpenIndex > 0){
-					// Fetch index after body tag
-					bodyOpenIndex = content.indexOf(">", bodyOpenIndex) + 1;
-				}else{
-					bodyOpenIndex = 0;
-				}
-				// Get index of the end of the body content
-				var bodyCloseIndex = content.search(/<\/body/gi);
-				if(bodyCloseIndex == -1){
-					bodyCloseIndex = content.length;
-				}
-				// Extract body content
-				content = content.slice(bodyOpenIndex, bodyCloseIndex);
-
-				// Remove some more tags
-				content = removeTagFromSource(content, "head", true, true);
-				content = removeTagFromSource(content, "style", true);
-				content = removeTagFromSource(content, "script", false);
-				content = removeTagFromSource(content, "title", true);
-				content = removeTagFromSource(content, "meta", false);
-				content = removeTagFromSource(content, "base", false);
-				content = removeTagFromSource(content, "link", false);
-
-				// HACK: Remove newlines to fix HTML
-				content = content.replace(/\n/g, " ");
-				content = content.replace(/\r/g, " ");
-			}
-
-			if (!isHTML && htmlFormat){
-				// please note that currently all replies and forwards are plain text!
-				content = content.replace(/&/g, "&amp;");
-				content = content.replace(/</g, "&lt;");
-				content = content.replace(/>/g, "&gt;");
-				content = content.replace(/ {2}/g, " &nbsp;");
-			}
-
+			//get the body content to form the text of message
 			if(isReply) {
-				//get Recipients
-				var recipients = message.getElementsByTagName("recipients")[0].getElementsByTagName("recipient");
-				var recipientList = new Object();
-				for(var i=0; i<recipients.length; i++){
-					var resDisplayName = dhtml.getTextNode(recipients[i].getElementsByTagName("display_name")[0],"");
-					var resEmailAddress = dhtml.getTextNode(recipients[i].getElementsByTagName("email_address")[0],"");
-					var resType = dhtml.getTextNode(recipients[i].getElementsByTagName("type")[0],"");
-					var resObjectType = dhtml.getTextNode(recipients[i].getElementsByTagName("objecttype")[0],"");
-					if (resType != "bcc"){
-						switch(resType){
-							case "to":
-								resType = _("To");
-								break;
-							case "cc":
-								resType = _("CC");
-								break;
-						}
-						if(!recipientList[resType]){
-							recipientList[resType] = "";
-						}
-						
-						recipientList[resType] += nameAndEmailToString(resDisplayName,resEmailAddress,resObjectType,htmlFormat)+"; ";
-					}
-				}
-							
+				var isMailPrefix;
+				if (this.message_action == "forward")
+					isMailPrefix = webclient.settings.get("createmail/on_message_forwards", "add_prefix");
+				else
+					isMailPrefix = webclient.settings.get("createmail/on_message_replies", "add_prefix");
+
 				if(htmlFormat) {
 					reply_seperator = "<p>&nbsp;<br/>&nbsp;</p>";
-					contentprefix = "<blockquote style='border-left: 2px solid #325FBA; padding-left: 5px;margin-left:5px;'>";
-					replyinfo = "-----" + _("Original message") + "-----<br />";
-					replyinfo += "<strong>" + _("From") + ":</strong> " + sent_representing_email_address + "<br />";
-					replyinfo += "<strong>" + _("Sent") + ":</strong> " + message_delivery_time + "<br />";
-					for(var resType in recipientList){
-						replyinfo += "<strong>" + resType + ":</strong> " + recipientList[resType] + "<br />";
-					}				
-					replyinfo += "<strong>" + _("Subject") + ":</strong> " + subject + "<br /><br />";
-					contentpostfix = "</blockquote>";
+					if(isMailPrefix == "add_prefix") {
+						contentprefix = "<blockquote style='border-left: 2px solid #325FBA; padding-left: 5px;margin-left:5px;'>";
+						contentpostfix = "</blockquote>";
+					}
+					replyinfo = addAsText ? "" : "-----" + _("Original message") + "-----<br />";
+					//build the Template data to display
+					for(var key in data){
+						if(key == "body"){
+							content = data[key].value;
+						}else{
+							replyinfo += "<strong>" + data[key].label + ":</strong>\t" + data[key].value + "<br />";
+						}
+					}
 				} else {
 					reply_seperator = "\n\n";
-					replyinfo = "-----" + _("Original message") + "-----\n";
-					replyinfo += _("From") + ": " + sent_representing_email_address + "\n";
-					replyinfo += _("Sent") + ": " + message_delivery_time + "\n";
-					for(var resType in recipientList){
-						replyinfo += resType + ": " + recipientList[resType] + "\n";
+					replyinfo = addAsText ? "" :"-----" + _("Original message") + "-----\n";
+					for(var key in data){
+						if(key == "body"){
+							content = data[key].value;
+						}else{
+							replyinfo += data[key].label + ":\t" + data[key].value + "\n";
+						}
 					}
-					replyinfo += _("Subject") + ": " + subject + "\n\n";
-
 					// plain text reply/forward, use ">" to quote the message
 					content = content.wordWrap(80,"\n")
-					content = content.replace(/^/g,"> ");
-					content = content.replace(/\n/g,"\n> ");
+					if(isMailPrefix == "add_prefix") {
+						content = content.replace(/^/g,"> ");
+						content = content.replace(/\n/g,"\n> ");
+					}
 				}
+			} else if(isConcept) {
+				content = data.body.value;
 			}
 		}
 
@@ -587,16 +568,19 @@ createmailitemmodule.prototype.setBody = function(message, isReply, isConcept)
 				signature = signature_seperator + signature;
 			}
 		}
-		
 
 		// If cursorPos is set at end then don't add signature now.
 		var cursorPos = webclient.settings.get("createmail/cursor_position", "start");
 
 		if(cursorPos == "end" && isReply) {
-			this.signature = signature;
+		this.signature = addAsText ? "": signature;
 			content = contentprefix + replyinfo + content + contentpostfix + reply_seperator;
 		} else {
-			content = signature + reply_seperator + contentprefix + replyinfo + content + contentpostfix;
+			if(addAsText){
+				content = reply_seperator + contentprefix + replyinfo + content + contentpostfix;
+			}else{
+				content = signature + reply_seperator + contentprefix + replyinfo + content + contentpostfix;
+			}
 		}
 
 		if(htmlFormat) {
@@ -615,12 +599,17 @@ createmailitemmodule.prototype.setBody = function(message, isReply, isConcept)
 			// If the editor is already available and fully loaded we can set the body already.
 			if(document.fckEditor){
 				window.bodyset = true;
-				setContentInBodyArea();
+				setContentInBodyArea(addAsText);
 				setCursorPosition(this.messageAction);
 			}
 		} else {
-			html_body.value = content;
-			setCursorPosition(this.messageAction);
+			if(addAsText){
+				// as we need the attach item text at same place of the position on the cursor
+				insertAtCursor(html_body, content);
+			}else{
+				html_body.value = content;
+				setCursorPosition(this.messageAction);
+			}
 		}
 	}
 }
@@ -714,11 +703,25 @@ createmailitemmodule.prototype.getSignatureData = function(id){
 	return sig_content;
 }
 
-function setContentInBodyArea()
+/**
+ * Checks wheather fckEditor is loaded, and then set the content in fckEditor's body
+ * @param boolean addAsText checks if the content has any attachment added as text
+ */
+function setContentInBodyArea(addAsText)
 {
 	if(document.fckEditor && document.fckEditor.SetHTML) {
-		document.fckEditor.SetHTML(document.fckEditorContent);
-		document.fckEditor = false;
+		
+		if(addAsText ){
+			//this checks the case in which we add attachment as text to a replying or forwarding mail
+			document.fckEditor.Selection.Restore();
+			document.fckEditor.InsertHtml(document.fckEditorContent);
+		}else{
+			document.fckEditor.SetHTML(document.fckEditorContent);
+		}
+		// if the content is already loaded and there is no further action for 
+		// attaching any item as text then set fckEditor as false.
+		if(!addAsText && module.messageAction == "undefined")	document.fckEditor = false;
+		
 		document.fckEditorContent = false;
 	} else {
 		window.setTimout(setBody, '500');
