@@ -197,7 +197,8 @@ freebusymodule.prototype.initView = function(zoom,user,recips)
 			}
 			user = new Array();
 			// if any user is organiser then not add him in userList as he is already added as c_user.
-			if((parseInt(recips[i]["recipient_flags"],10) & recipOrganizer) != recipOrganizer){
+			if (((parseInt(recips[i]["recipient_flags"],10) & recipOrganizer) != recipOrganizer)
+				&& recips[i]['fullname'] != this.user) {
 				user['resolvename'] = recips[i]['fullname'];
 				user['recipienttype'] = recips[i]['recipienttype'];
 				user['recipient_flags'] = recips[i]['recipient_flags'];
@@ -324,11 +325,18 @@ freebusymodule.prototype.createUsers = function(inputList)
 		webclient.xmlrequest.addData(this, "add", data);
 
 	}
+
+	// Get emailaddress of opened folder-object, to check organizer status
+	var storeObject = parentWebclient.hierarchy.getStore(module.storeid);
+	var storeEmail = webclient.emailaddress.toLowerCase();
+	if(storeObject && storeObject.emailaddress)
+		storeEmail = storeObject.emailaddress.toLowerCase();
+
 	// create meeting request (module is the global appointment module)
-	if(this.userCount == 0 || (this.userList["c_user"]["emailaddress"] == "") || (this.userList["c_user"]["emailaddress"].toLowerCase() == webclient.emailaddress.toLowerCase())){
-		meetingRequestSetup(1)
+	if(this.userCount == 0 || (this.userList["c_user"]["emailaddress"] == "") || (this.userList["c_user"]["emailaddress"].toLowerCase() == storeEmail)){
+		meetingRequestSetup(mrSetupOrganiser)
 	}else{
-		meetingRequestSetup(2);
+		meetingRequestSetup(mrSetupAttendee);
 	}
 
 	module.setUserList(this.getUserList());
@@ -353,7 +361,7 @@ freebusymodule.prototype.removeUsers = function (inputList){
 			// remove meeting request when there are no users left
 			var fbUserlist = this.getUserList();
 			if(fbUserlist.length==0){
-				meetingRequestSetup(0);
+				meetingRequestSetup(mrSetupNormal);
 			}
 		}
 	}
