@@ -472,7 +472,15 @@ hierarchymodule.prototype.createHierarchyList = function(load)
 			if (store["root"]["entryid"] == this.defaultstore["root"]["entryid"] && typeof this.openedFolders[store["root"]["entryid"]] == "undefined"){
 				this.openedFolders[store["root"]["entryid"]] = "open";
 			}
-	
+			
+			// folder_extra is to display count of unread item in shared folders
+			var folder_extra = false;
+			if(store["type"] == "other" && Number(store["root"]["content_unread"]) > 0){
+				folder_extra = new Object();
+				folder_extra["class"] = "unread_count";
+				folder_extra["text"] = "("+store["root"]["content_unread"]+")";
+			}
+			
 			var tree = new Tree(this.id, this.contentElement, this.treeEvents);
 			this.tree = tree;
 			store["tree"] = tree;
@@ -483,7 +491,8 @@ hierarchymodule.prototype.createHierarchyList = function(load)
 							"store folder_icon_"+store["foldertype"], 
 							store["root"]["subfolders"], 
 							(this.openedFolders[store["root"]["entryid"]] == "open"?true:false), 
-							this.folderEvents
+							this.folderEvents,
+							folder_extra
 							);
 			
 			for(var j = 0; j < store["folders"].length; j++)
@@ -553,6 +562,7 @@ hierarchymodule.prototype.createHierarchyList = function(load)
 			}
 			
 			tree.buildTree();
+			tree.addEventHandler("statechange", this.updateOpenedFolder, this);
 		}else{
 			//delete user if you have no access
 			webclient.settings.deleteSetting("otherstores/"+store["username"].toLowerCase());
@@ -675,7 +685,22 @@ hierarchymodule.prototype.changeFolder = function(treeObject, type, folder)
 					node["extra"]["class"] = "unread_count";
 					node["extra"]["text"] = "("+folder["content_unread"]+")";
 				}
-				treeObject.moveNode(node);
+				//check the parentNode to see wheather the node is deleted its so that expanding behaviour of node is taken care
+				var parentNode = treeObject.getNode(folder["parent_entryid"]);
+				if(parentNode && parentNode["id"] == this.defaultstore.defaultfolders.wastebasket){
+					parentNode["open"] = (this.openedFolders[folder["parent_entryid"]] == "open")?true:false;
+					
+					//if there is no child element of the parentNode then we need to remove the branch container and set the folderstate as close 
+					if(parentNode["hasChildNodes"] == "-1"){
+						parentNode["open"] = false;		
+					
+						var branchElement = dhtml.getElementById("branch"+parentNode["id"], "div", this.contentElement);
+						if(branchElement)
+							dhtml.deleteAllChildren(branchElement);
+							dhtml.deleteElement(branchElement);
+					}
+				}
+				treeObject.moveNode(node, parentNode["open"]);
 			}
 			break;
 	}
@@ -793,7 +818,7 @@ hierarchymodule.prototype.emptyFolder = function(folder)
 			data["store"] = folder["storeid"];
 			data["entryid"] = folder["entryid"];
 			webclient.xmlrequest.addData(this, "emptyfolder", data);
-			this.reloadListModule(folder["entryid"]);
+			this.reloadListModule(folder["entryid"], false);
 		}
 	}
 }
@@ -846,14 +871,19 @@ hierarchymodule.prototype.setReadFlags = function()
 		data["entryid"] = folder["entryid"];
 		
 		webclient.xmlrequest.addData(this, "readflags", data);
-		this.reloadListModule(folder["entryid"]);
+		this.reloadListModule(folder["entryid"], true);
 
 	}
 	
 	eventHierarchyCheckSelectedContextFolder(this);
 }
 
-hierarchymodule.prototype.reloadListModule = function(entryid)
+/**
+ * reload listmodule that is loaded in a particular folder
+ * @param HexString entryid entryid of folder that should be reloaded
+ * @param boolean storeUniqueIds store entryids of currently selected items to reselect it after reload
+ */
+hierarchymodule.prototype.reloadListModule = function(entryid, storeUniqueIds)
 {
 	// reload listmodule if needed
 	var moduleIDs = webclient.layoutmanager.getModuleIDs();
@@ -862,19 +892,28 @@ hierarchymodule.prototype.reloadListModule = function(entryid)
 		if (webclient.getModule(moduleIDs[i]) instanceof ListModule){
 			var listmodule = webclient.getModule(moduleIDs[i]);
 			if (listmodule.entryid == entryid){
-				listmodule.list();
+				listmodule.list(false, false, storeUniqueIds);
 			}
 		}
 	}
 }
 
-
-
 hierarchymodule.prototype.getStore = function(entryid)
 {
+	/**
+	 * Opened delegate folders have entryids like [entryid]_calendar,
+	 * [entryid]_contact etc., so remove that string part from the entryid.
+	 */
+	entryid = (entryid.indexOf('_') > 0) ? entryid.substr(0, entryid.indexOf('_')) : entryid;;
 	var result = false;
 	for(var i = 0; i < this.stores.length; i++) {
-		if (this.stores[i].id == entryid) {
+		/**
+		 * Opened delegate folders have storeids like storeid_calendar,
+		 * storeid_contact etc., so remove that string part from the storeid.
+		 */
+		var tmpEntryid = this.stores[i].id;
+		tmpEntryid = (tmpEntryid.indexOf('_') > 0) ? tmpEntryid.substr(0, tmpEntryid.indexOf('_')) : tmpEntryid;;
+		if (compareEntryIds(tmpEntryid, entryid)) {
 			result = this.stores[i];
 		}
 	}
@@ -1055,12 +1094,12 @@ hierarchymodule.prototype.openSharedFolder = function(username, foldertype, subf
 		}
 	}
 
-	webclient.settings.set("otherstores/"+username+"/"+foldertype, foldertype);
+	webclient.settings.set("otherstores/"+username+"/"+foldertype+"/type", foldertype);
+	webclient.settings.set("otherstores/"+username+"/"+foldertype+"/show_subfolders", subfolders);
 
 	var data = new Object();
 	data["username"] = username;
 	data["foldertype"] = foldertype;
-	data["subfolders"] = subfolders;
 	webclient.xmlrequest.addData(this, "opensharedfolder", data);
 	
 	return true;
@@ -1104,6 +1143,20 @@ hierarchymodule.prototype.setDocumentTitle = function (folder)
 	}
 }
 
+/**
+ * Function which updates state of folder.
+ *@param HTMLElement element folder element whose state is changed
+ *@param integer state state of folder either 'open' or 'closed'
+ */
+hierarchymodule.prototype.updateOpenedFolder = function(element, state)
+{
+	if(this.openedFolders) {
+		this.openedFolders[element.id] = (state == this.tree.FOLDER_STATE_OPEN) ? "open" : "closed";
+	}
+
+	this.setOpenedFolders();
+}
+
 function eventHierarchyCheckSelectedContextFolder(moduleObject, element, event)
 {
 	if(moduleObject.selectedContextFolder) {
@@ -1331,7 +1384,6 @@ function eventHierarchyModifyFolder(moduleObject, element, event)
 function eventHierarchyMarkMessagesRead(moduleObject, element, event)
 {
 	element.parentNode.style.display = "none";
-	storeOldSelectedEmailEntryId();
 	moduleObject.setReadFlags();
 }
 
@@ -1362,7 +1414,7 @@ function eventHierarchyPropertiesFolder(moduleObject, element, event)
 
 function eventSharedFoldersClick(moduleObject, element, event)
 {
-	webclient.openModalDialog(moduleObject, "sharedfolder", DIALOG_URL+"task=sharedfolder_modal&storeid="+moduleObject.defaultstore["id"], 285, 200, callBackSharedFolder, this);
+	webclient.openModalDialog(moduleObject, "sharedfolder", DIALOG_URL+"task=sharedfolder_modal&storeid="+moduleObject.defaultstore["id"], 300, 230, callBackSharedFolder, this);
 }
 
 function eventAdvancedCalendarClick(moduleObject, element, event)
@@ -1478,7 +1530,13 @@ function eventHierarchyKeyCtrlNewItem(moduleObject, element, event)
 		case this.keys["new"]["task"]:			// New Task
 		case this.keys["new"]["contact"]:		// New Contact
 		case this.keys["new"]["note"]:			// New Note
+		case this.keys["new"]["taskrequest"]:	// New Task Request
 			item = array_search(event.keyCombination, this.keys["new"]);
+			if (item == "taskrequest") {
+				item = (item == "taskrequest")? "task" : item;
+				extraParams = "taskrequest=true";
+			}
+
 			if (containerClass.toLowerCase().indexOf(item) == -1) {
 				folderEntryID = moduleObject.defaultstore.defaultfolders[item];
 				storeID = moduleObject.defaultstore.id;
@@ -1533,11 +1591,11 @@ function eventHierarchyKeyCtrlOpenFolder(moduleObject, element, event, keys)
 			break;
 		case this.keys["open"]["shared_folder"]:
 			windowData["sharetype"] = "folder";
-			webclient.openModalDialog(moduleObject, "sharedfolder", DIALOG_URL+"task=sharedfolder_modal&storeid="+ moduleObject.defaultstore["id"], 285, 200, callBackSharedFolder, this, windowData);
+			webclient.openModalDialog(moduleObject, "sharedfolder", DIALOG_URL+"task=sharedfolder_modal&storeid="+ moduleObject.defaultstore["id"], 300, 230, callBackSharedFolder, this, windowData);
 			break;
 		case this.keys["open"]["shared_store"]:
 			windowData["sharetype"] = "store";
-			webclient.openModalDialog(moduleObject, "sharedfolder", DIALOG_URL+"task=sharedfolder_modal&storeid="+ moduleObject.defaultstore["id"], 285, 200, callBackSharedFolder, this, windowData);
+			webclient.openModalDialog(moduleObject, "sharedfolder", DIALOG_URL+"task=sharedfolder_modal&storeid="+ moduleObject.defaultstore["id"], 300, 230, callBackSharedFolder, this, windowData);
 			break;
 	}
 
