@@ -79,6 +79,7 @@ maillistmodule.prototype.init = function(id, element, title, data)
 	var items = new Array();
 	items.push(webclient.menu.createMenuItem("open", _("Open"), false, eventListContextMenuOpenMessage));
 	items.push(webclient.menu.createMenuItem("print", _("Print"), false, eventListContextMenuPrintMessage));
+	items.push(webclient.menu.createMenuItem("edit", _("Edit as New Message"), false, eventListContextMenuEditMessage));
 	items.push(webclient.menu.createMenuItem("seperator", ""));
 	items.push(webclient.menu.createMenuItem("reply", _("Reply"), false, eventMailListContextMenuReply));
 	items.push(webclient.menu.createMenuItem("replyall", _("Reply All"), false, eventMailListContextMenuReplyAll));
@@ -87,6 +88,8 @@ maillistmodule.prototype.init = function(id, element, title, data)
 	items.push(webclient.menu.createMenuItem("markread", _("Mark Read"), false, eventMailListContextMenuMessageFlag));
 	items.push(webclient.menu.createMenuItem("markunread", _("Mark Unread"), false, eventMailListContextMenuMessageFlag));
 	items.push(webclient.menu.createMenuItem("categories", _("Categories")+"...", false, eventListContextMenuCategoriesMessage));
+	/* Disable Attach Item
+	items.push(webclient.menu.createMenuItem("forward_items", _("Forward Items"), false, eventListContextMenuForwardMultipleItems)); */
 	items.push(webclient.menu.createMenuItem("seperator", ""));
 	items.push(webclient.menu.createMenuItem("flag_status_red", _("Red Flag"), false, eventMailListContextMenuRedFlag));
 	items.push(webclient.menu.createMenuItem("flag_status_complete", _("Flag Complete"), false, eventMailListContextMenuFlagComplete));
@@ -96,6 +99,8 @@ maillistmodule.prototype.init = function(id, element, title, data)
 	items.push(webclient.menu.createMenuItem("delete", _("Delete"), false, eventListContextMenuDeleteMessage));
 	//items.push(webclient.menu.createMenuItem("copy", _("Copy/Move Message"), false, eventListContextMenuCopyMessage));
 	items.push(webclient.menu.createMenuItem("seperator", ""));
+	items.push(webclient.menu.createMenuItem("task", _("Convert to Task"), false, eventListContextMenuTask));
+	items.push(webclient.menu.createMenuItem("seperator", ""));
 	items.push(webclient.menu.createMenuItem("options", _("Options")+"...", false, eventListContextMenuMessageOptions));
 
 	webclient.pluginManager.triggerHook('client.module.maillistmodule.contextmenu.buildup', {contextmenu: items});
@@ -168,6 +173,62 @@ maillistmodule.prototype.execute = function(type, action)
 		case "search_error":
 			this.handleSearchError(action);
 			break;
+		case "error":
+			this.handleError(action);
+			break;
+		//it check whether a task is created or not,thus does the error handling.
+		case "task_created":
+			if(dhtml.getXMLValue(action, "success", false))
+				alert(_("A new task has been created and is moved into task folder"));
+			else
+				alert(_("You have insufficient privileges to create a new task for this item"));
+			break;
+		case "convert_meeting":
+			this.convertSelectedMeetingItem(action);
+			break;
+	}
+}
+
+/**
+ * Function which does error handling while converting the selected meeting item
+ * @param object action the action tag 
+ */ 
+maillistmodule.prototype.convertSelectedMeetingItem = function(action)
+{
+	var message = action.getElementsByTagName("item");
+	var targetFolder = dhtml.getTextNode(action.getElementsByTagName("targetfolder")[0],"");
+	var parentEntryid = dhtml.getTextNode(action.getElementsByTagName("targetfolderentryid")[0],"");
+
+	for(var i=0;i < message.length; i++){
+		var entryid = dhtml.getXMLValue(message[i], "entryid");
+		var messageClass = dhtml.getXMLValue(message[i], "message_class", "").trim();
+		var delegator = dhtml.getXMLValue(message[i], "rcvd_representing_name");
+		var meetingType = parseInt(dhtml.getXMLValue(message[i], "out_of_date"),10);
+		var responseStatus = parseInt(dhtml.getXMLValue(message[i], "responsestatus"),10);
+	
+		//show an error message for dragged meeting requests which do not have correct privileges set
+		if(messageClass == "IPM.Schedule.Meeting.Request"){
+			if(delegator){
+				alert(_("Cannot copy this item. Cannot open calendar for user %s Access Denied.").sprintf(delegator));
+			}else if(meetingType){
+				alert(_("You received a more recent update to this meeting. This meeting request is out of date. You cannot respond this request"));
+			}else if(responseStatus == olResponseNotResponded){
+				this.sendConfirmationAcceptFromMailList(entryid);
+				alert(_("The meeting has been accepted and moved to your calendar. A response has been sent to the meeting organiser"));
+			}
+
+		}else{
+			var uri = DIALOG_URL+"task=" + targetFolder + "_standard&storeid=" + this.storeid+ "&parententryid=" + parentEntryid;
+			webclient.openWindow(this, 
+								targetFolder, 
+								uri,
+								720, 580, 
+								true, null, null, 
+								{
+									"data" : action, 
+									"action" : "convert_meeting"
+								});
+		}
 	}
 }
 
@@ -199,6 +260,31 @@ maillistmodule.prototype.messageList = function(action)
     maillistmodule.superclass.messageList.call(this, action);
 }
 
+/**
+ * Function which adds or updates an item in the view.
+ * this function additionally updates flags in previewitem module and then
+ * calls parent class' item method for default handling
+ * 
+ * @param XMLObject action the action tag 
+ */ 
+maillistmodule.prototype.item = function(action)
+{
+	// update message flags in previewitem module
+	if(this.previewreadmailitemmodule) {
+		var items = action.getElementsByTagName("item");
+		for(var index = 0; index < items.length; index++) {
+			var item = items[index];
+			var entryid = dhtml.getXMLValue(item, "entryid", false);
+
+			if(compareEntryIds(this.previewreadmailitemmodule.messageentryid, entryid)) {
+				this.previewreadmailitemmodule.updateMessageFlags(item);
+			}
+		}
+	}
+
+    maillistmodule.superclass.item.call(this, action);
+}
+
 function eventLayoutSwitchPreviewpane(moduleObject, element, event){
 	element.parentNode.style.display = "none";
 	var previewMode;
@@ -245,8 +331,6 @@ maillistmodule.prototype.initializeView = function()
 				webclient.layoutmanager.updateElements("right");
 			}
 		}
-	}else{
-		this.previewPane = false;
 	}
 
 	this.initSearchBar();
@@ -383,7 +467,7 @@ maillistmodule.prototype.initSearchBar = function()
 	dhtml.addEvent(this, searchFilterInputBox, "blur", eventMailListSearchBarFilterFocus);
 	dhtml.addEvent(this, searchFilterInputBox, "keydown", eventMailListSearchBarFilterKey);
 	dhtml.addEvent(this, searchFilterInputBox, "selectstart", eventMailListSearchBarFilterMouseMove);
-	dhtml.addEvent(this, filterTarget, "mousedown", eventStopBubbling);
+	dhtml.addEvent(this, filterTarget, "mousedown", function(){event.stopPropagation()});
 
 	this.searchBarContainer.appendChild(searchFilterInputBox);
 	this.searchBarContainer.searchFilterInputBox = searchFilterInputBox; // add reference to DOM
@@ -428,7 +512,7 @@ maillistmodule.prototype.onDeleteItem = function(entryid)
 {
 	// Remove message in previewpane when selected message is deleted/moved
 	if(this.previewPane && this.previewreadmailitemmodule && 
-		this.previewreadmailitemmodule.itemEntryID == entryid) 
+		compareEntryIds(this.previewreadmailitemmodule.messageentryid, entryid)) 
 	{
 		this.previewreadmailitemmodule.destructor();
 	}
@@ -437,38 +521,44 @@ maillistmodule.prototype.onDeleteItem = function(entryid)
 maillistmodule.prototype.onSelectItem = function(entryid)
 {
 	if(this.previewreadmailitemmodule) {
-		if(this.previewreadmailitemmodule.messageentryid != entryid) {
-			eventListPreviewTimer(this.id, entryid);
+		// if we are first time loading previewitem then messageentryid will be false
+		// if we pass false as entryid then compareEntryIds will return false
+		if(!compareEntryIds(this.previewreadmailitemmodule.messageentryid, entryid)) {
+			eventListPreviewTimer(this, entryid);
 		}
 	}
 }
 
 /**
- * The previewpane needs to be updated when we sent a readreceipt (even if the 
- * user refuses to send one). The previewreadmailitemmodule is not updated like 
- * a listmodule, so it will not receive the updated message flags indicating the
- * read receipt has been sent. That is why we manually notify the previewpane of
- * this fact after we have handled the sending of the readreceipt.
- *
- * @param element HTMLElement TableRow of the selected message
+ * Function which popups option to attendee when user drags any meeting item which is not responded.
+ *@param string messageEntryid entryid of the dragged message
+ *@param timestamp basedate date to the occurence
+ *@param boolean noResponse flag to set response flag
  */
-maillistmodule.prototype.sendReadReceipt = function(entryID)
+maillistmodule.prototype.sendConfirmationAcceptFromMailList = function(entryid, noResponse, basedate)
 {
-	if(this.previewreadmailitemmodule) {
-		this.previewreadmailitemmodule.readReceiptSent = true;
-	}
-	return maillistmodule.superclass.sendReadReceipt.call(this, entryID);
+	var req = new Object;
+	req['entryid'] = entryid;
+	req['store'] = this.storeid;
+
+	if (typeof basedate != 'undefined' && basedate !== "false" && basedate)
+		req['basedate'] = basedate;
+
+	// if sendResponse flag is set then attach sendResponse flag with request data.
+	if(typeof(noResponse) != "undefined" && noResponse)
+		req['noResponse'] = noResponse;
+
+	webclient.xmlrequest.addData(this, 'acceptMeeting', req);
+	webclient.xmlrequest.sendRequest(true);
 }
 
-function eventListPreviewTimer(moduleID, entryid)
+function eventListPreviewTimer(moduleObject, entryid)
 {
-	moduleObject = webclient.getModule(moduleID);
-
 	window.clearTimeout(moduleObject.previewTimer);
 	moduleObject.previewTimer = null;
 
 	if(moduleObject.previewreadmailitemmodule) {
-		if(moduleObject.previewreadmailitemmodule.messageentryid != entryid) {
+		if(!compareEntryIds(moduleObject.previewreadmailitemmodule.messageentryid, entryid)) {
 			moduleObject.previewreadmailitemmodule.open(entryid, entryid);
 			moduleObject.previewreadmailitemmodule.loadMessage();
 		}
@@ -539,9 +629,16 @@ function eventMailListContextMenuMessageFlag(moduleObject, element, event)
 			flags = flag;
 		}
 		moduleObject.setReadFlag(moduleObject.entryids[items[i]], flags);
+
+		// after manually setting the read flag we have to reset timer that is used to automatically
+		// set read flag through previewitem module
+		if(this.previewreadmailitemmodule && compareEntryIds(this.previewreadmailitemmodule.messageentryid, moduleObject.entryids[items[i]])) {
+			this.previewreadmailitemmodule.clearReadFlagTimer();
+		}
 	}
+
 	// deselect selected message
-	eventListCheckSelectedContextMessage(this);
+	eventListCheckSelectedContextMessage(moduleObject);
 }
 
 function eventMailListContextMenuRedFlag(moduleObject, element, event)
@@ -710,7 +807,8 @@ function eventMailListRules(moduleObject, element, event)
  * @param event event Event name
  */
 function eventSendReceiveItems(moduleObject, element, event){
-	moduleObject.list();
+	// Save old selected messages.
+	moduleObject.list(false, false, true);
 }
 
 /**
