@@ -60,11 +60,8 @@ function previewreadmailitemmodule(id, element)
 
 previewreadmailitemmodule.prototype.destructor = function()
 {
-	//this.itemEntryID will set previous message as read
-	if(this.itemEntryID) {
-		this.setReadFlag(this.itemEntryID, (this.sendReadReceipt()?"read,receipt":"read,noreceipt"));
-		this.itemMessageFlags = MSGFLAG_READ|MSGFLAG_UNMODIFIED; // reset message flags to read/unmodified, because I don't want to do another request for just to get these flags.
-	}
+	// clear timer for read flag
+	this.clearReadFlagTimer();
 
 	this.messageentryid = false;
 
@@ -76,6 +73,8 @@ previewreadmailitemmodule.prototype.destructor = function()
 
 previewreadmailitemmodule.prototype.init = function(id, element)
 {
+	this.readFlagTimer = false;
+
 	dhtml.addClassName(element,"previewpane");
 	previewreadmailitemmodule.superclass.init.call(this, id, element);
 
@@ -135,7 +134,30 @@ previewreadmailitemmodule.prototype.initializeView = function()
 	meetingrequestData += "</table>";
 	meetingrequestData += '</div>';
 	recipients.innerHTML = table + meetingrequestData;
-	
+
+	// Task Request
+	var taskrequestData = "<div id='taskrequest_data' style='display:none;'>";
+	taskrequestData += "<table border='0' cellpadding='0' cellspacing='0'>";
+	taskrequestData += "	<tr id='taskrequest_data_duedate_row'>";
+	taskrequestData += "		<td class='property' width='40' nowrap>" + _("Due date") + ": </td>";
+	taskrequestData += "		<td><div id='taskrequest_duedate' class='property_data'></div></td>";
+	taskrequestData += "	</tr>";
+	taskrequestData += "	<tr id='taskrequest_data_status_row'>";
+	taskrequestData += "		<td class='property' width='40' nowrap>" + _("Status") + ": </td>";
+	taskrequestData += "		<td><div id='taskrequest_status' class='property_data'></div></td>";
+	taskrequestData += "	</tr>";
+	taskrequestData += "	<tr id='taskrequest_data_priority_row'>";
+	taskrequestData += "		<td class='property' width='40' nowrap>" + _("Priority") + ": </td>";
+	taskrequestData += "		<td><span id='taskrequest_priority'></span></td>";
+	taskrequestData += "	</tr>";
+	taskrequestData += "	<tr id='taskrequest_data_complete_row'>";
+	taskrequestData += "		<td class='property' width='40' nowrap>" + _("Complete") + ": </td>";
+	taskrequestData += "		<td><div id='taskrequest_complete' class='property_data'></div></td>";
+	taskrequestData += "	</tr>";
+	taskrequestData += "</table>";
+	taskrequestData += '</div>';
+	recipients.innerHTML += taskrequestData;
+
 	var atachments = dhtml.addElement(header, "div", false, "attachment_data");
 	var table = "<table border='0' cellpadding='0' cellspacing='0'>";
 	table += "<tr><td class='property' width='100' nowrap>" + _("Attachments") + ":</td><td><div id='attachments' class='property_data' style='padding: 5px;'></div></td></tr>";
@@ -187,12 +209,9 @@ previewreadmailitemmodule.prototype.initializeView = function()
 
 previewreadmailitemmodule.prototype.item = function(action)
 {
-	//this.itemEntryID will set previous message as read
-	if(this.itemEntryID){
-		this.setReadFlag(this.itemEntryID, (this.sendReadReceipt()?"read,receipt":"read,noreceipt"));
-		this.itemMessageFlags = MSGFLAG_READ|MSGFLAG_UNMODIFIED; // reset message flags to read/unmodified, because I don't want to do another request for just to get these flags.
-	}
-	
+	// started loading a new message so remove timer set for read flag
+	this.clearReadFlagTimer();
+
 	this.deleteLoadMessage();
 
 	var message = action.getElementsByTagName("item")[0];
@@ -202,6 +221,14 @@ previewreadmailitemmodule.prototype.item = function(action)
 	this.initializeView();
 	// remember item properties
 	this.updateItemProps(message);
+
+	/**
+	 * Update module object properties with new received item properties. Could also do with this.setData() but this function
+	 * takes only storeid and parententryid as agruments.
+	 */
+	this.rootentryid = this.itemProps['entryid'];
+	this.messageentryid = this.itemProps['entryid'];
+
 	this.setConflictInfo(message);
 
 	if(message && message.childNodes) {
@@ -232,7 +259,7 @@ previewreadmailitemmodule.prototype.item = function(action)
 		// Only set the meeting request fields when we are dealing with a Meeting Request.
 		if(dhtml.getXMLValue(message,"message_class","").indexOf("IPM.Schedule.Meeting") === 0){
 			dhtml.getElementById("meetingrequest").style.display = "block";
-			dhtml.getElementById("meetingrequest_data").style.display = "";
+			dhtml.getElementById("taskrequest_data").style.display = "none";
 
 			dhtml.getElementById("meetingrequest_startdate").innerHTML = strftime( _("%a %x %X"), dhtml.getXMLValue(message, "startdate", "") ); 
 			dhtml.getElementById("meetingrequest_duedate").innerHTML   = strftime( _("%a %x %X"), dhtml.getXMLValue(message, "duedate", "") );
@@ -302,6 +329,10 @@ previewreadmailitemmodule.prototype.item = function(action)
 
 			// Determine whether the message is a response and the buttons should be hidden
 			if(dhtml.getXMLValue(message,"message_class","").indexOf("IPM.Schedule.Meeting.Resp") === 0){
+				if (dhtml.getXMLValue(action, 'appt_not_found', false)) {
+					this.showextrainfo(_("This meeting is not in the Calendar; it may have been moved or deleted."));
+				}
+
 				dhtml.getElementById("meetingrequest").style.display = "none";
 				// Set the meeting response text
 				var textMeetingResponseText = "";
@@ -328,7 +359,87 @@ previewreadmailitemmodule.prototype.item = function(action)
 				}
 			}
 
-		}else{
+		} else if (dhtml.getXMLValue(message, "message_class", "").indexOf("IPM.TaskRequest") === 0) {
+			// Task request stuff
+			dhtml.getElementById("taskrequest_data").style.display = "";
+			dhtml.getElementById("meetingrequest_data").style.display = "none";
+
+			// User has received task assignment
+			if (dhtml.getXMLValue(message, "message_class", "") == "IPM.TaskRequest") {
+				// Show only accept.decline buttons
+				dhtml.getElementById("meetingrequest").style.display = "block";
+				dhtml.getElementById("accept").style.display = "block";
+				dhtml.getElementById("decline").style.display = "block";
+				dhtml.getElementById("tentative").style.display = "none";
+				dhtml.getElementById("proposenewtime").style.display = "none";
+				dhtml.getElementById("notcurrent").style.display = "none";
+				dhtml.getElementById("removefromcalendar").style.display = "none";
+			}
+
+			// Display task details in headers
+			var duedate = dhtml.getXMLValue(message, "duedate", false);
+			var duedate_text = "";
+			if (duedate) {
+				var startdate = dhtml.getXMLValue(message, "startdate", false);
+				if (startdate) duedate_text += _("Starts on %s").sprintf(strftime("%a %x %x", startdate)) + ", ";
+
+				if (duedate_text.length == 0) duedate_text += _("Due on %s").sprintf(strftime("%a %x %X", duedate));
+				else duedate_text += _("due on %s").sprintf(strftime("%a %x %X", duedate));
+
+				this.showextrainfo(_("Due on %s").sprintf(strftime("%a %x %X", duedate)), true);
+			} else {
+				duedate_text += _("None");
+			}
+			dhtml.getElementById("taskrequest_duedate").innerHTML = duedate_text;
+
+			//show recurrence
+			if (this.itemProps.recurring == 1 && this.itemProps.recurrProps)
+				this.showextrainfo(getTaskRecurrencePattern(this.itemProps.recurrProps));
+
+			// Task status
+			var status = dhtml.getXMLValue(message, "status", 0);
+			if (status == 0) status = _("Not Started");
+			else if (status == 1) status = _("In Progress");
+			else if (status == 2) status = _("Complete");
+			else if (status == 3) status = _("Wait for other person");
+			else if (status == 4) status = _("Deferred");
+			dhtml.getElementById("taskrequest_status").innerHTML = status;
+
+			// Task Importance
+			var importance = dhtml.getXMLValue(message, "importance", IMPORTANCE_LOW);
+			if (importance == IMPORTANCE_LOW) importance = _("Low");
+			else if (importance == IMPORTANCE_NORMAL) importance = _("Normal");
+			else if (importance == IMPORTANCE_HIGH) importance = _("High");
+			dhtml.getElementById("taskrequest_priority").innerHTML = importance;
+
+			dhtml.getElementById("taskrequest_complete").innerHTML = dhtml.getXMLValue(message, "percent_complete", 0)*100 +"%";
+
+			var taskhistorydesc;
+			var taskstate = dhtml.getXMLValue(message, "taskstate", tdsNOM);
+			var taskhistory = dhtml.getXMLValue(message, "taskhistory", thNone);
+			if(taskstate == tdsOWN) {
+				taskhistorydesc = { 	1 : _("Accepted by %u on %d"),
+										2 : _("Declined by %u on %d"),
+										3 : _("Last update was sent by %u on %d"),
+										5 : _("Assigned by %u on %d") };
+			} else {
+				taskhistorydesc = { 	1 : _("Accepted by %u on %d"),
+										2 : _("Declined by %u on %d"),
+										3 : _("Last update was received from %u on %d"),
+										5 : _("Waiting for response from recipient") };
+			}
+
+			if(taskhistorydesc[taskhistory]) {
+				var history = taskhistorydesc[taskhistory];
+
+				var time = new Date(dhtml.getXMLValue(message, "assignedtime", 0)*1000);
+
+				history = history.replace("%u", dhtml.getXMLValue(message, "tasklastdelegate", ""));
+				history = history.replace("%d", time.strftime(_("%d/%m/%Y %H:%M")));
+
+				this.showextrainfo(history);
+			}
+		} else {
 			dhtml.getElementById("meetingrequest").style.display = "none";
 			dhtml.getElementById("meetingrequest_data").style.display = "none";
 		}
@@ -353,15 +464,8 @@ previewreadmailitemmodule.prototype.item = function(action)
 
 	dhtml.addEvent(this.id, window, "resize", eventPreviewItemResize);
 
-	//this.itemEntryID will save the entryid and will mark it at destructing or next mail as read
-	var entryid = message.getElementsByTagName("entryid")[0];
-	this.itemEntryID = dhtml.getTextNode(entryid,"");
-	this.itemMessageFlags = parseInt(dhtml.getXMLValue(message,"message_flags",0),10);
-	/**
-	 * We have to keep track of whether we sent a readreceipt already because we
-	 * do not get an update from the server with the new message flags.
-	 */
-	this.readReceiptSent = false;
+	// update message flags in object level variable
+	this.updateMessageFlags(message);
 
 	// use timeout to give the browser some time to render the message when it is html
 	var isHTML = message.getElementsByTagName("isHTML")[0];
@@ -370,15 +474,73 @@ previewreadmailitemmodule.prototype.item = function(action)
 	}else{
 		eventPreviewLoaded(this.id);
 	}
+
+	// message is loaded now, so start read flag timer
+	if(message) this.setReadFlagTimer();
+
+	var headerElem = dhtml.getElementById("header");
+	dhtml.addEvent(this, headerElem, "mousedown", forceDefaultActionEvent);
+	dhtml.addEvent(this, headerElem, "mouseup", forceDefaultActionEvent);
+	dhtml.addEvent(this, headerElem, "selectstart", forceDefaultActionEvent);
+	dhtml.addEvent(this, headerElem, "mousemove", forceDefaultActionEvent);
 }
 
-previewreadmailitemmodule.prototype.setReadFlag = function(messageEntryid, flag)
+/**
+ * Function will create a timer based on user specified time in settings
+ * so after user specified time message will be marked as read and also read receipt
+ * will be sent
+ */
+previewreadmailitemmodule.prototype.setReadFlagTimer = function()
 {
-	if ((this.itemMessageFlags & MSGFLAG_READ)!=MSGFLAG_READ){ // prevent request if message was already marked as read
+	if(this.messageentryid){
+		var readFlagTime = webclient.settings.get("global/mail_readflagtime", "0");
+		var module = this;		// Fix loss of scope in timeout
+		this.readFlagTimer = window.setTimeout(function() {
+			module.setReadFlag((module.sendReadReceipt() ? "read,receipt" : "read,noreceipt"));
+		}, parseInt(readFlagTime, 10) * 1000);
+	}
+}
+
+/**
+ * Function will clear the timer that was set for marking a mail as read
+ * after user specified time
+ */
+previewreadmailitemmodule.prototype.clearReadFlagTimer = function()
+{
+	if(this.readFlagTimer){
+		window.clearTimeout(this.readFlagTimer);
+		this.readFlagTimer = false;
+	}
+}
+
+/**
+ * Function will update message flags value to object level variable
+ * when an update of message arrives in maillistmodule, it checks if message is loaded in preview pane
+ * then it updates this variable so previewitem module timer will not again send request for setting
+ * a read flag
+ */
+previewreadmailitemmodule.prototype.updateMessageFlags = function(message)
+{
+	var flags = parseInt(dhtml.getXMLValue(message, "message_flags", 0), 10);
+
+	if(!isNaN(flags)) {
+		this.itemMessageFlags = flags;
+	}
+}
+
+/**
+ * Funtion will send a request to server to set read flag for an unread message
+ *
+ * @param String flag comma seperated string of flags (receipt, noreceipt, read)
+ */
+previewreadmailitemmodule.prototype.setReadFlag = function(flag)
+{
+	// prevent request if message was already marked as read
+	if ((this.itemMessageFlags & MSGFLAG_READ) != MSGFLAG_READ){
 		var data = new Object();
 		data["store"] = this.storeid;
 		data["parententryid"] = this.parententryid;
-		data["entryid"] = messageEntryid;
+		data["entryid"] = this.messageentryid;
 
 		if(flag) {
 			data["flag"] = flag;
@@ -408,10 +570,14 @@ previewreadmailitemmodule.prototype.resize = function()
 	}
 }
 
+/**
+ * Function will show a message to user if he wants to send a read receipt or not
+ * message should be displayed or not is decided upon user specified settings
+ */
 previewreadmailitemmodule.prototype.sendReadReceipt = function()
 {
 	var result = false;
-	if (!this.readReceiptSent && (this.itemMessageFlags & MSGFLAG_RN_PENDING) == MSGFLAG_RN_PENDING){
+	if ((this.itemMessageFlags & MSGFLAG_RN_PENDING) == MSGFLAG_RN_PENDING){
 		switch(webclient.settings.get("global/readreceipt_handling", "ask")){
 			case "ask":
 				result = confirm(_("The sender of this message has asked to be notified when you read this message.")+"\n"+_("Do you wish to notify the sender?"));
@@ -423,12 +589,24 @@ previewreadmailitemmodule.prototype.sendReadReceipt = function()
 				result = true;
 				break;
 		}
-		// We have to set the readReceiptSent to true because we do not get an update from the server with the new message flags.
-		this.readReceiptSent = true;
 	}
 	return result;
 }
 
+/**
+ * Function will show an error message returned by server.
+ * @param XMLNode action the action tag
+ */
+previewreadmailitemmodule.prototype.handleError = function(action)
+{
+	// show error message to user
+	var errorMessage = dhtml.getXMLValue(action, "message", false);
+
+	if(errorMessage) {
+		alert(errorMessage);
+	}
+}
+
 function eventPreviewLoaded(moduleID)
 {
 	// Remove contextmenu and other elements onmousedown and onscroll in iFrame.
@@ -475,10 +653,15 @@ function eventPreviewItemMouseUp()
 
 function eventPreviewItemAcceptClick(moduleObject, element, event)
 {
-	var windowData = new Object();
-	windowData['module'] = moduleObject;
-	windowData['requestStatus'] = 'accept';
-	webclient.openModalDialog(-1, 'sendMRMailConfirmation', DIALOG_URL+'task=sendMRMailConfirmation_modal', 320, 280, previewreadmailitemSendMRMailConfirmation_dialog_callback, null, windowData);
+	var messageClass = moduleObject.itemProps["message_class"];
+	if (messageClass == "IPM.TaskRequest") {
+		moduleObject.sendAcceptTaskRequest();
+	} else {
+		var windowData = new Object();
+		windowData['module'] = moduleObject;
+		windowData['requestStatus'] = 'accept';
+		webclient.openModalDialog(-1, 'sendMRMailConfirmation', DIALOG_URL+'task=sendMRMailConfirmation_modal', 320, 280, previewreadmailitemSendMRMailConfirmation_dialog_callback, null, windowData);
+	}
 }
 
 function eventPreviewItemTentativeClick(moduleObject, element, event)
@@ -491,10 +674,15 @@ function eventPreviewItemTentativeClick(moduleObject, element, event)
 
 function eventPreviewItemDeclineClick(moduleObject, element, event)
 {
-	var windowData = new Object();
-	windowData['module'] = moduleObject;
-	windowData['requestStatus'] = 'decline';
-	webclient.openModalDialog(-1, 'sendMRMailConfirmation', DIALOG_URL+'task=sendMRMailConfirmation_modal', 320, 280, previewreadmailitemSendMRMailConfirmation_dialog_callback, null, windowData);
+	var messageClass = moduleObject.itemProps["message_class"];
+	if (messageClass == "IPM.TaskRequest") {
+		moduleObject.sendDeclineTaskRequest();
+	} else {
+		var windowData = new Object();
+		windowData['module'] = moduleObject;
+		windowData['requestStatus'] = 'decline';
+		webclient.openModalDialog(-1, 'sendMRMailConfirmation', DIALOG_URL+'task=sendMRMailConfirmation_modal', 320, 280, previewreadmailitemSendMRMailConfirmation_dialog_callback, null, windowData);
+	}
 }
 
 function eventPreviewItemProposeNewTimeClick(moduleObject, element, event)
@@ -516,6 +704,7 @@ function eventPreviewItemProposeNewTimeClick(moduleObject, element, event)
 			moduleObject: moduleObject
 		}, {
 			windowname: _("Propose new time"),
+			dialogtitle: _("Propose new time"),
 			fields: [{
 				name: "combineddatetimepicker",
 				label_start: _("Start time"),
@@ -553,9 +742,10 @@ function previewreadmailitemSendMRMailConfirmation_dialog_callback(noResponse)
 		noResponse = noResponse.type;
 	}
 
-	if(this.windowData)
+	if(this.windowData) {
 		var moduleObject = this.windowData["module"]; 
 		var requestStatus = this.windowData["requestStatus"]; 
+	}
 
 	switch(requestStatus)
 	{
@@ -566,7 +756,7 @@ function previewreadmailitemSendMRMailConfirmation_dialog_callback(noResponse)
 			moduleObject.tentativeMeetingRequest(noResponse, false, body);
 			break;
 		case "decline":
-			moduleObject.declineMeetingRequest(false, body);
+			moduleObject.declineMeetingRequest(noResponse, false, body);
 			break;
 	}
 }
