@@ -249,6 +249,33 @@ printitemmodule.prototype.item = function(action)
 		this.printpreview.init(this, printing_frame);
 	}
 }
+/**
+ * Function to handle the print preview from create mail dialog.
+ */
+printitemmodule.prototype.printFromUnsaved = function(parentwindow){
+	// get the properties required for print preview.
+	this.propData = parentwindow.getPropsFromDialog();
+	
+	// creates the attachment data for printpreview.
+	var attachs = opener.module.attachments;
+	var attachNames = new Array();
+	for(var i=0;i<attachs.length;i++){
+		attachNames.push(attachs[i]["name"]);
+	}
+	var newattachs = opener.module.newattachments;
+	for(var i=0;i<newattachs.length;i++){
+		attachNames.push(newattachs[i]["name"]);
+	}
+	this.propData["attachments"] = attachNames.join(", ");
+
+	// initialize the printpreview 
+	this.printpreview = new printMessageItem();
+	this.printpreview.init(this, dhtml.getElementById("printing_frame").contentWindow, true);
+
+	// show the menu of printpreview
+	webclient.menu.showMenu(); 
+}
+
 function eventPrintItemKeyCtrlPrint(moduleObject, element, event)
 {
 	if (printing_frame){
