@@ -59,8 +59,9 @@ function printMessageItem()
 *
 *@param object moduleObject The PrintItemModule object
 *@param	window frame The iframe window object where to write the print preview to.
+*@param	boolean unSavedMessageFlag The flag to determine that data to be shown if from unsaved or saved.
 */
-printMessageItem.prototype.init = function(moduleObject, frame)
+printMessageItem.prototype.init = function(moduleObject, frame, unSavedMessageFlag)
 {
 	// initialize data
 	this.frame = frame;
@@ -68,10 +69,14 @@ printMessageItem.prototype.init = function(moduleObject, frame)
 	this.props = this.module.propData;
 	this.doc = this.frame.document;
 
-	this.createHTML();
+	this.createHTML(unSavedMessageFlag);
 }
-
-printMessageItem.prototype.createHTML = function()
+/**
+ * Function which creates the HTML for print.
+ *
+ * @param	boolean unSavedMessageFlag The flag to determine that data to be shown if from unsaved or saved.
+ */
+printMessageItem.prototype.createHTML = function(unSavedMessageFlag)
 {
 	// set content/type
 	this.doc.open("text/html");
@@ -87,10 +92,25 @@ printMessageItem.prototype.createHTML = function()
 	this.doc.writeln('		<h1 style="font-family: sans-serif; font-size: 12pt;border-bottom: 3px solid #000;">'+webclient.fullname+'</h1>');
 
 	// populate from/to/cc/bcc fields for name and email address
-	this.populateNameFields();
+	this.populateNameFields(unSavedMessageFlag);
 
 	// write mail properties (from/to/cc/subject etc)
 	this.doc.writeln('		<table cellspacing=0 cellpadding=0 style="font-family: sans-serif; font-size: 10pt">');
+
+	if(parentWebclient.hierarchy.defaultstore.defaultfolders.sent == this.props.parent_entryid){ // sent folder
+		if(this.props.sender_name && this.props.sender_email_address && (this.props.sender_name.length >0 || this.props.sender_email_address.length > 0) && this.props.sender_email_address != this.props.sent_representing_email_address){
+			this.props.from_email_combined = nameAndEmailToString(this.props.sender_name, this.props.sender_email_address, false, true) + 
+											 NBSP + _("on behalf of") + NBSP + 
+											 nameAndEmailToString(this.props.sent_representing_email_address, this.props.sent_representing_email_address, false, true);
+		}
+	}
+	if(!this.props.client_submit_time){ // drafts folder
+		if(this.props.sender_email_address != this.props.sent_representing_email_address){
+			this.props.from_email_combined = _("on behalf of") + NBSP +
+											 nameAndEmailToString(this.props.sent_representing_email_address, this.props.sent_representing_email_address, false, true);
+		}
+	}
+
 	this.writeLine(_("From"),"from_email_combined");
 	this.writeLine(_("Sent"),"message_delivery_time");
 	this.writeLine(_("To"),"to_email_combined");
@@ -191,7 +211,7 @@ printMessageItem.prototype.createHTML = function()
 	this.doc.writeln('		<br>');
 
 	// write mail
-	this.writeBody();
+	this.writeBody(unSavedMessageFlag);
 	this.doc.body.setAttribute("style","word-wrap:break-word");
 
 	// write footer
@@ -205,25 +225,37 @@ printMessageItem.prototype.createHTML = function()
 * This function makes sure that the body of the mail is written correctly. 
 * In Firefox for example there are multiple textnodes that holds the 
 * message, so get them all.
+*
+* @param	boolean unSavedMessageFlag The flag to determine that data to be shown if from unsaved or saved.
 */
-printMessageItem.prototype.writeBody = function()
+printMessageItem.prototype.writeBody = function(unSavedMessageFlag)
 {
 	var body = this.props["body"];
-	
-	if(body && body.childNodes.length > 0) {
-		var content = "";
-		var element = body.firstChild;
-		for(var i = 0; i < body.childNodes.length; i++)
-		{
-			content += element.nodeValue;
-			element = element.nextSibling;
-		}
+	if(!unSavedMessageFlag){
+		if(body && body.childNodes && body.childNodes.length > 0) {
+			var content = "";
+			var element = body.firstChild;
+			for(var i = 0; i < body.childNodes.length; i++)
+			{
+				content += element.nodeValue;
+				element = element.nextSibling;
+			}
 
-		if (!this.props["isHTML"] || this.props["isHTML"]=="0"){
-			content = convertPlainToHtml(content);
+			if (!this.props["isHTML"] || this.props["isHTML"]=="0"){
+				content = convertPlainToHtml(content);
+				content = "<pre style=\"white-space: -moz-pre-wrap; white-space: -pre-wrap; white-space: -o-pre-wrap; white-space: pre-wrap; word-wrap: break-word;\">" + content + "</pre>";
+			}
+
+			this.doc.write(content);
+		}
+	}else{
+		if(this.props["use_html"] == "true"){// (!this.props["isHTML"] || this.props["isHTML"]=="0"){
+			var content = "<style> body{font-family: Arial, Verdana, Sans-Serif; font-size: 12px;padding: 5px 5px 5px 5px;margin: 0px;border-style: none;background-color: #ffffff;}"+
+						  "p, ul, li{margin-top: 0px;margin-bottom: 0px;} </style>" + body;
+		}else{ 
+			var content = convertPlainToHtml(body);
 			content = "<pre style=\"white-space: -moz-pre-wrap; white-space: -pre-wrap; white-space: -o-pre-wrap; white-space: pre-wrap; word-wrap: break-word;\">" + content + "</pre>";
 		}
-
 		this.doc.write(content);
 	}
 }
@@ -231,7 +263,7 @@ printMessageItem.prototype.writeBody = function()
 printMessageItem.prototype.writeLine = function(label, field, msgClass)
 {
 	if (this.props[field] && (!msgClass || msgClass == this.props["message_class"])){		
-		this.doc.writeln('			<tr><th align="left" width=160px>'+label+':</th><td style="padding-left: 10px">'+this.props[field].replace(/</g,"&lt;").replace(/>/g,"&gt;")+'</td></tr>');
+		this.doc.writeln('			<tr><th align="left" width=160px style="vertical-align:top">'+label+':</th><td style="padding-left: 10px">'+this.props[field].replace(/</g,"&lt;").replace(/>/g,"&gt;")+'</td></tr>');
 	}
 	if(label == "" && field == "" && msgClass == this.props["message_class"]){
 		this.doc.writeln('			<tr><th align="left">'+NBSP+'</th><td style="padding-left: 10px">'+NBSP+'</td></tr>');
@@ -267,23 +299,33 @@ printMessageItem.prototype.writeMembers = function(msgClass) {
 
 /**
  * Populate the display name with email in a string representing to respective fields.
+ * @param	boolean unSavedMessageFlag The flag to determine that data to be shown if from unsaved or saved.
  */
-printMessageItem.prototype.populateNameFields = function() {
+printMessageItem.prototype.populateNameFields = function(unSavedMessageFlag) {
 	// populate from field
 	if(this.props["sent_representing_name"])
 		this.props["from_email_combined"] = this.props["sent_representing_name"] + " &lt;" + this.props["sent_representing_email_address"] +"&gt;";
 
 	// populate to/cc/bcc fields
 	var tempObj = new Object();
-	if(this.props.recipients && this.props.recipients.recipient){
-		for (var i=0;i<this.props.recipients.recipient.length;i++){
-			var recip = this.props.recipients.recipient[i];
-			var displayName = recip["display_name"] + " &lt;" + recip["email_address"] +"&gt;";
-			var type = recip["type"];
-			if(typeof tempObj[type] == "undefined")
-				tempObj[type] = new Array();
-			tempObj[type].push(displayName);
+	if(!unSavedMessageFlag){
+		if(this.props.recipients && this.props.recipients.recipient && this.props.recipients.recipient.length && this.props.recipients.recipient.length>0){
+			for (var i=0;i<this.props.recipients.recipient.length;i++){
+				var recip = this.props.recipients.recipient[i];
+				var displayName = recip["display_name"] + " &lt;" + recip["email_address"] +"&gt;";
+				var type = recip["type"];
+				if(typeof tempObj[type] == "undefined")
+					tempObj[type] = new Array();
+				tempObj[type].push(displayName);
+			}
+		}else{
+			if(this.props.recipients.recipient)
+				tempObj["to"] = [this.props.recipients.recipient["display_name"] + " &lt;" + this.props.recipients.recipient["email_address"] +"&gt;"];
 		}
+	}else{
+		tempObj["to"] = [this.props["to"]];
+		tempObj["cc"] = [this.props["cc"]];
+		tempObj["bcc"] = [this.props["bcc"]];
 	}
 	if(tempObj["to"]) this.props["to_email_combined"] = tempObj["to"].join(", ");
 	if(tempObj["cc"]) this.props["cc_email_combined"] = tempObj["cc"].join(", ");
