@@ -187,6 +187,7 @@ readmailitemmodule.prototype.setRepliedForwardedInfo = function(message)
 readmailitemmodule.prototype.setAttachments = function(message)
 {
 	var attachments = message.getElementsByTagName("attachment");
+	var showDownloadAll = false;
 
 	if(attachments && attachments.length > 0) {
 		var attachmentsElement = dhtml.getElementById("attachments");
@@ -217,10 +218,18 @@ readmailitemmodule.prototype.setAttachments = function(message)
 						dhtml.addEvent(this, attachmentElement, "mousedown", eventAttachmentClick);
 					}
 				}
+				var attach_method = dhtml.getXMLValue(attachment, "attach_method", "");
+				if(attach_method != "5" && attach_method != "false"){
+					showDownloadAll = true;
+				}
 			}
-			
-			if(attachmentsElement.offsetHeight > 30) {
-				attachmentsElement.style.height = "34px";
+			if(attachments.length > 0 && attachmentsElement.getElementsByTagName("a").length > 1 && showDownloadAll){
+				var downAllAttach = dhtml.addElement(null, "span", "downloadAllAttach", "", _("Download all attachments"));
+				attachmentsElement.insertBefore(downAllAttach, attachmentsElement.getElementsByTagName("a")[0]);
+				dhtml.addEvent(this, downAllAttach, "mousedown", eventDownloadAllAttachmentsAsZipArchive);
+			}
+			if(attachmentsElement.offsetHeight > 43) {
+				attachmentsElement.style.height = "45px";
 			}
 		}
 	}else{
@@ -368,9 +377,22 @@ readmailitemmodule.prototype.setMeetingrequest = function(message)
 		if(isCounterProposal && dhtml.getXMLValue(message,"message_class","").indexOf("IPM.Schedule.Meeting.Resp") === 0){
 			// Show ProposeNewTime row when message is a counter proposal
 			showMeetingElements.push("meetingrequest_proposed_row");
+
+			if (dhtml.getXMLValue(message, 'appt_not_found', false)) {
+				var elemExtraInfo = dhtml.getElementById("extrainfo");
+				dhtml.addElement(elemExtraInfo, "p", false, false, _("This meeting is not in the Calendar; it may have been moved or deleted."));
+				elemExtraInfo.style.display = "block";
+				hideMeetingElements.push("accept_proposal");
+				hideMeetingElements.push("view_all_proposals");
+			} else {
+				showMeetingElements.push("accept_proposal");
+				showMeetingElements.push("view_all_proposals");
+			}
 		} else {
 			// Hide ProposeNewTime row when message is NOT a counter proposal
 			hideMeetingElements.push("meetingrequest_proposed_row");
+			hideMeetingElements.push("accept_proposal");
+			hideMeetingElements.push("view_all_proposals");
 		}
 	}else{
 		// Hide meetingrequest pane (location and startstart/duedate or when)
@@ -382,6 +404,8 @@ readmailitemmodule.prototype.setMeetingrequest = function(message)
 		hideMeetingElements.push("removefromcalendar");
 		hideMeetingElements.push("proposenewtime");
 		hideMeetingElements.push("not_current");
+		hideMeetingElements.push("accept_proposal");
+		hideMeetingElements.push("view_all_proposals");
 	}
 
 	for(var elID in hideMeetingElements){
@@ -489,21 +513,21 @@ readmailitemmodule.prototype.setRecipients = function(message)
 		}
 		
 		var toElement = dhtml.getElementById("to");
-		if(toElement && toElement.offsetHeight > 30) {
-			toElement.style.height = "32px";
+		if(toElement && toElement.offsetHeight > 43) {
+			toElement.style.height = "45px";
 		}
 		
 		var ccElement = dhtml.getElementById("cc");
-		if(ccElement && ccElement.offsetHeight > 30) {
-			ccElement.style.height = "32px";
+		if(ccElement && ccElement.offsetHeight > 43) {
+			ccElement.style.height = "45px";
 		}
 		if (ccElement && ccElement.innerHTML.trim() == ""){
 			ccElement.parentNode.parentNode.style.display = "none";
 		}
 
 		var bccElement = dhtml.getElementById("bcc");
-		if(bccElement && bccElement.offsetHeight > 30) {
-			bccElement.style.height = "32px";
+		if(bccElement && bccElement.offsetHeight > 43) {
+			bccElement.style.height = "45px";
 		}
 		if (bccElement && bccElement.innerHTML.trim() == ""){
 			bccElement.parentNode.parentNode.style.display = "none";
@@ -560,6 +584,30 @@ readmailitemmodule.prototype.setWindowTitle = function(message){
 	document.title = subject;
 }
 
+/**
+ * Function which opens corresponding meeting from Calendar.
+ * @param boolean viewAllProposals true if we want to view all proposals else false
+ */
+readmailitemmodule.prototype.openMeeting = function(viewAllProposals){
+	if (parentWebclient && this.itemProps && this.itemProps.appointment){
+		var extraParams = ""
+
+		extraParams += "&counterproposal=1";
+		extraParams += "&proposedstartdate="+ this.itemProps.proposed_start_whole;
+		extraParams += "&proposedenddate="+ this.itemProps.proposed_end_whole;
+		if(typeof this.itemProps.appointment.basedate != "undefined") {
+			extraParams += "&basedate="+ this.itemProps.appointment.basedate;
+		}
+
+		if (viewAllProposals)
+			extraParams += "&viewallproposals=1";
+
+		// Open window with reference to main webclient because ReadMail dialog is going to be closed.
+		parentWebclient.openWindow(-1, "appointment", DIALOG_URL+"task=appointment_standard&storeid="+ this.itemProps.appointment.storeid +"&parententryid="+ this.itemProps.appointment.parententryid +"&entryid="+ this.itemProps.appointment.entryid + extraParams).focus();
+	}
+	window.close();
+}
+
 function eventReadmailAddressContextMenu(moduleObject, element, event)
 {
 	var items = new Array();
@@ -592,6 +640,10 @@ function eventReadmailContextAddContact(moduleObject, element, event)
 function eventReadmailClickEmail(moduleObject, element, event)
 {
 	var email = dhtml.getTextNode(element,"");
+	var validEmail = parseEmailAddress(email);
+	// If it is not valid email address then it must be a group, so added brackets.
+	if(!validEmail)
+		email = "[" + email + "]";
 	webclient.openWindow(this, "createmail", DIALOG_URL+"task=createmail_standard&to=" + email);
 }
 
