@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -67,6 +69,11 @@ reminderlistmodule.prototype.init = function(id, element, title, data)
 
 	this.timer = window.setTimeout("webclient.reminder.getReminders()",15000);
 	this.lastrowchecksum = "";
+	
+	/**
+	 * row id of next reminder which should be selected by default after snoozing or dismissing a reminder
+	 */
+	this.nextSelectionRowId = false;
 }
 
 
@@ -261,10 +268,13 @@ reminderlistmodule.prototype.showData = function()
 	}
 
 	this.tableWidget.generateTable(items);
-	if (this.tableWidget && this.tableWidget.widgetID && items[0] && items[0]["rowID"]) {
-		var firstRowElement = this.reminderWindow.dhtml.getElementById("tablewidget_crow[" + this.tableWidget.widgetID + "]" + "[" + items[0]["rowID"] + "]");
-		if(firstRowElement)
-			this.reminderWindow.dhtml.executeEvent(firstRowElement, "mousedown");
+
+	if(this.tableWidget && this.nextSelectionRowId !== false) {
+		// select row based on previous saved value of row id
+		this.tableWidget.selectRow(this.nextSelectionRowId, true);
+	} else  if (this.tableWidget && items[0] && items[0]["rowID"]) {
+		// select first row
+		this.tableWidget.selectRow(items[0]["rowID"], false);
 	}
 }
 
@@ -296,8 +306,6 @@ reminderlistmodule.prototype.eventRowSelection = function(widget, type, selected
 		if (itemData["message_class"].substr(0, 15).toLowerCase() == "ipm.appointment"){
 			fieldStartDate.innerHTML = _("Startdate: %s").sprintf((new Date(parseInt(itemData["appointment_startdate"])*1000)).strftime(_("%a %x %X")));
 		}
-
-
 	}
 	
 	//Open item on doubleclick
@@ -316,10 +324,51 @@ reminderlistmodule.prototype.eventDismiss = function(moduleObject, element, even
 		for(var i=0;i<items.length;i++){
 			entryids.push(items[i]["entryid"]);
 		}
+
+		// store row id of next reminder, so when reloading we can select the next reminder
+		this.nextSelectionRowId = this.getNextSelectionRow(this.tableWidget, items[0]["entryid"]);
+
 		moduleObject.dismissItems(entryids);
 	}
 }
 
+/**
+ * get next/previous non-selected row id, so it will be used to select the row
+ * when we will be reloading reminders dialog
+ * @param {Object} tableWidget table widget object
+ * @param {HexString} rowId row id of currently selected reminder
+ * @return {HexString} row id of next reminder which should be selected on reload
+ */
+reminderlistmodule.prototype.getNextSelectionRow = function(tableWidget, rowId)
+{
+	var nextRowId = rowId;
+	do {
+		nextRowId = tableWidget.nextRowID(nextRowId);
+
+		if(!nextRowId) {
+			// no more next rows left
+			break;
+		}
+	} while(tableWidget.isRowIDSelected(nextRowId));
+
+	if(!nextRowId) {
+		// re-assign original value as nextRowId will be false here
+		nextRowId = rowId;
+
+		// no next row then select previous row
+		do {
+			nextRowId = tableWidget.prevRowID(nextRowId);
+
+			if(!nextRowId) {
+				// no more previous rows left
+				break;
+			}
+		} while(tableWidget.isRowIDSelected(nextRowId));
+	}
+
+	return nextRowId;
+}
+
 reminderlistmodule.prototype.eventDismissAll = function(moduleObject, element, event)
 {
 	var entryids = new Array();
@@ -338,6 +387,10 @@ reminderlistmodule.prototype.eventSnooze = function(moduleObject, element, event
 		for(var i=0;i<items.length;i++){
 			entryids.push(items[i]["entryid"]);
 		}
+
+		// store row id of next reminder, so when reloading we can select the next reminder
+		this.nextSelectionRowId = this.getNextSelectionRow(this.tableWidget, items[0]["entryid"]);
+
 		moduleObject.snoozeItems(entryids, snoozetime);
 	}
 }
