@@ -111,8 +111,9 @@ resolvenamesmodule.prototype.execute = function(type, action)
  * @param resolveObj = "Object" like:  ["to"] = "fran;mi"
  *                                     ["cc"] = "vee;erk"
  * @param handler = "Function" this param will be called when all the names are resolved
+ * @param excludeusercontacts in boolean which specify the type of contacts folder to check while resolving the names.
  */ 
-resolvenamesmodule.prototype.resolveNames = function(resolveObj,handler)
+resolvenamesmodule.prototype.resolveNames = function(resolveObj, handler, excludeusercontacts)
 {
 	this.resolveQue = new Array();
 	this.returnList = new Object();
@@ -130,8 +131,9 @@ resolvenamesmodule.prototype.resolveNames = function(resolveObj,handler)
 			names.push(name);
 		}
 	}
+	
 	this.handler = handler;
-	this.verifyNames(names);
+	this.verifyNames(names, excludeusercontacts);
 }
 
 /**
@@ -176,13 +178,16 @@ resolvenamesmodule.prototype.verifiedName = function(type,nameid,nameObj)
  * @param names = "Array of Objects" like:  [0]["id"] = "fra";
  *                                             ["type"] = "to";
  *                                          [1]["id"] = "mi";
- *                                             ["type"] = "to";  
+ *                                             ["type"] = "to"; 
+ * @param excludeusercontacts in boolean which specify the type of contacts folder to check for resolving the names.
  */ 
-resolvenamesmodule.prototype.verifyNames = function(names)
+resolvenamesmodule.prototype.verifyNames = function(names, excludeusercontacts)
 {
 	if(names) {
 		var data = new Object();
+		data["excludeusercontacts"] = excludeusercontacts;
 		data["name"] = names;
+
 		webclient.xmlrequest.addData(this, "checknames", data);
 		webclient.xmlrequest.sendRequest();
 	}
