@@ -105,8 +105,8 @@ suggestEmailAddressModule.prototype.execute = function(type, action){
 				result.push(resultcollection[i].firstChild.nodeValue);
 			}
 		}
-		searchstring = action.getElementsByTagName("searchstring")[0].firstChild.nodeValue;
-		var returnId = action.getElementsByTagName("returnid")[0].firstChild.nodeValue;
+		searchstring = dhtml.getXMLValue(action, "searchstring", "");
+		var returnId = dhtml.getXMLValue(action, "returnid", false);
 
 		this.cache[searchstring] = result;
 	}
