@@ -77,6 +77,7 @@ tasklistmodule.prototype.init = function(id, element, title, data)
 	items.push(webclient.menu.createMenuItem("seperator", ""));
 	items.push(webclient.menu.createMenuItem("markread", _("Mark Read"), false, eventMailListContextMenuMessageFlag));
 	items.push(webclient.menu.createMenuItem("markunread", _("Mark Unread"), false, eventMailListContextMenuMessageFlag));
+	items.push(webclient.menu.createMenuItem("assigntask", _("Assign Task"), false, eventTaskListContextMenuMessageAssignTask))
 	items.push(webclient.menu.createMenuItem("categories", _("Categories"), false, eventListContextMenuCategoriesMessage));
 	items.push(webclient.menu.createMenuItem("seperator", ""));
 	items.push(webclient.menu.createMenuItem("delete", _("Delete"), false, eventListContextMenuDeleteMessage));
@@ -107,15 +108,40 @@ tasklistmodule.prototype.messageList = function(action)
 }
 
 
+/**
+ * Function which is used for setting a message complete (task)
+ * @param string messageEntryid entryid of the message
+ * @param boolean complete true - set message complete  
+ */ 
+tasklistmodule.prototype.completeStatus = function(messageEntryid, complete)
+{
+	var msgProps = this.itemProps[messageEntryid];
+
+	if (msgProps.taskstate && (msgProps.taskstate == 3 || msgProps.taskstate == 4))
+		alert(_("You do not own this task. Your changes may be overwritten by the task owner."));
+
+	tasklistmodule.superclass.completeStatus.call(this, messageEntryid, complete);
+}
 
 /**
 * Saves tasks
 * @param element table row element which contains the item.
 */
 tasklistmodule.prototype.SubmitMessage = function (moduleObject, element, event)
-{	
+{
+	var entryid = false;
+	if (moduleObject.itemProps[moduleObject.entryids[element.id]]) {
+		entryid = moduleObject.itemProps[moduleObject.entryids[element.id]]["entryid"];
+
+		var msgProps = this.itemProps[entryid];
+		if (msgProps.taskstate && (msgProps.taskstate == 3 || msgProps.taskstate == 4))
+			alert(_("You do not own this task. Your changes may be overwritten by the task owner."));
+	}
+
 	var property = "editprops";
 	var props = new Object();
+	var commonstart = false;
+	var commonend = false;
 	
 	if (element.id == "insertrow"){
 		property = "insertprops";
@@ -127,6 +153,7 @@ tasklistmodule.prototype.SubmitMessage = function (moduleObject, element, event)
 	if (text_startdate && text_startdate.value) {
 		dhtml.getElementById(property +"_module"+ moduleObject.id +"_startdate").value = Date.parseDate(text_startdate.value, _("%d-%m-%Y"), true).getTime()/1000;			
 		startdate = Date.parseDate(text_startdate.value, _("%d-%m-%Y"), true).getTime()/1000;			
+		commonstart = Date.parseDate(text_startdate.value, _("%d-%m-%Y"), false).getTime()/1000;
 	}
 
 	//Duedate
@@ -135,10 +162,12 @@ tasklistmodule.prototype.SubmitMessage = function (moduleObject, element, event)
 	if (text_duedate && text_duedate.value) {
 		dhtml.getElementById(property +"_module"+ moduleObject.id +"_duedate").value = Date.parseDate(text_duedate.value, _("%d-%m-%Y"), true).getTime()/1000;
 		duedate = Date.parseDate(text_duedate.value, _("%d-%m-%Y"), true).getTime()/1000;
+		commonend = Date.parseDate(text_duedate.value, _("%d-%m-%Y"), false).getTime()/1000;
 	} else {
 		if (startdate){
 			dhtml.getElementById(property +"_module"+ moduleObject.id +"_duedate").value = startdate;
 			duedate = startdate;
+			commonend = commonstart;
 		}
 	}
 
@@ -172,26 +201,34 @@ tasklistmodule.prototype.SubmitMessage = function (moduleObject, element, event)
 	if (categories) {
 		moduleObject.filtercategories(categories, categories.value);
 	}
-	
-	var entryid = false;
-	if (moduleObject.itemProps[moduleObject.entryids[element.id]]){
-		entryid = moduleObject.itemProps[moduleObject.entryids[element.id]]["entryid"];
-	}
+
 	//get properties from input fields
 	props = getProps(element, this.properties, entryid);
 	
 	/*The following code can only be implemented after calling 'getProps()' function on 'props' object*/
 
-	//status
-	var status = dhtml.getElementById(property +"_module"+ moduleObject.id +"_status");
-	if (!status || percent) {
+	if (commonstart)
+		props["commonstart"] = commonstart;
+
+	if (commonend)
+		props["commonend"] = commonend;
+
+	//complete
+	var complete = dhtml.getElementById(property +"_module"+ moduleObject.id +"_complete");
+	// Complete column is not visible
+	if (!complete || percent) {
 		if (percent && percent == 100){
 			props["status"] = "2";
-			props["complete"] = "1";				
+			props["complete"] = "1";
+			props["datecompleted"] = parseInt((new Date()).getTime()/1000);
 		}else if(percent > 0){
 			props["status"] = "1";
 			props["complete"] = "-1";
 		}
+	} else if (complete && complete.checked) {
+		props["complete"] = "1";
+		props["datecompleted"] = parseInt((new Date()).getTime()/1000);
+		props["status"] = "2";
 	}
 	
 	//Owner
@@ -209,6 +246,104 @@ tasklistmodule.prototype.SubmitMessage = function (moduleObject, element, event)
 	return true;
 }
 
+/**
+ * this function is called when delete button is pressed from menu
+ *@param array messages list of selected messages
+ *@param boolean softDelete message should be soft deleted or not (for Shift + Del)
+ */
+tasklistmodule.prototype.deleteMessages = function (messages, softDelete)
+{
+	var data = new Object();
+	data["store"] = this.storeid;
+	data["parententryid"] = this.entryid;
+
+	var folder = webclient.hierarchy.getFolder(this.entryid);
+	
+	if (folder && (folder.rights["deleteowned"] > 0 || folder.rights["deleteany"] > 0)) {
+		if (softDelete && !confirm(_("Are you sure that you want to permanently delete the selected item(s)?")))
+			return;
+
+		// pass softdelete variable value to the server
+		data["softdelete"] = true;
+		
+		data["entryid"] = new Array();
+
+		if (messages.length > 0) {
+			if (this.itemProps[this.entryids[messages[0]]]['taskstate'] == 2) {
+				var windowData = new Object();
+				windowData['subject'] = this.itemProps[this.entryids[messages[0]]]['subject'];
+				windowData['parentModule'] = this;
+				windowData['softDelete'] = softDelete;
+				windowData['taskrequest'] = true;
+				webclient.openModalDialog(this, "deletetaskoccurrence", DIALOG_URL+"task=deletetaskoccurrence_modal&entryid="+ this.entryids[messages[0]] +"&storeid="+ this.storeid +"&parententryid="+ this.entryid, 300, 220, null, null, windowData);
+
+				messages.splice(0, 1);
+			} else if (parseInt(this.itemProps[this.entryids[messages[0]]]['recurring'], 10) && !parseInt(this.itemProps[this.entryids[messages[0]]]['dead_occurrence'], 10)) {
+				// if first message is recurring then ask for deleting occurrence or series.
+				var windowData = new Object();
+				windowData['subject'] = this.itemProps[this.entryids[messages[0]]]['subject'];
+				windowData['parentModule'] = this;
+				windowData['softDelete'] = softDelete;
+				webclient.openModalDialog(this, "deletetaskoccurrence", DIALOG_URL+"task=deletetaskoccurrence_modal&entryid="+ this.entryids[messages[0]] +"&storeid="+ this.storeid +"&parententryid="+ this.entryid, 300, 220, null, null, windowData);
+
+				messages.splice(0, 1);
+			}
+
+			// Anyways! delete rest of the selected messages
+			for(var i = 0; i < messages.length; i++) {
+				// check row is not selected for editing...
+				if (this.editMessage !== this.selectedMessages[i]){
+					data["entryid"].push(this.entryids[messages[i]]);
+				}
+			}
+		}
+
+		data["start"] = this.rowstart;
+		data["rowcount"] = this.rowcount;
+
+		if (this.sort) {
+			data["sort"] = new Object();
+			data["sort"]["column"] = this.sort;
+		}
+
+		if(data["entryid"].length > 0) {
+			// don't send request if entryid is empty
+			webclient.xmlrequest.addData(this, "delete", data);
+			webclient.xmlrequest.sendRequest(true);
+		}
+	}
+}
+/**
+ * Function which requests server to delete a task
+ *@param boolean deleteOccurrence true if delete only occurrence else false to delete whole series
+ *@param string entryid entryid of task
+ *@param boolean softDelete message should be soft deleted or not (for Shift + Del)
+ */
+tasklistmodule.prototype.deleteMessage = function (deleteFlag, entryid, softDelete)
+{
+	var data = new Object();
+	data["store"] = this.storeid;
+	data["parententryid"] = this.entryid;
+	data["entryid"] = new Array(entryid);
+	data["start"] = this.rowstart;
+	data["rowcount"] = this.rowcount;
+	data["softdelete"] = softDelete;
+
+	if (this.sort) {
+		data["sort"] = new Object();
+		data["sort"]["column"] = this.sort;
+	}
+
+	data["deleteFlag"] = deleteFlag;
+
+	if (deleteFlag == 'complete')
+		data["dateCompleted"] = parseInt((new Date()).getTime()/1000);
+
+	// don't send request if entryid is empty
+	webclient.xmlrequest.addData(this, "delete", data);
+	webclient.xmlrequest.sendRequest(true);
+}
+
 
 function getProps(element, properties, entryid)
 {
@@ -225,54 +360,34 @@ function getProps(element, properties, entryid)
 
 	for (var i = 0; i < input.length; i++) {
 			//prepare xml tagname from id of input fields...
-			position = input[i].id.indexOf("_") + 1;
-			tagname = input[i].id.substr(position);
+			var position = input[i].id.indexOf("_") + 1;
+			var tagname = input[i].id.substr(position);
 			position = tagname.indexOf("_") + 1;
 			tagname = tagname.substr(position);
 
 			// assign the properties to props only when the properties contain that tagname property.
 			// check all values only if we have entryid (means we are in edit mode/ on creation mode check everything)
 			if(entryid){
-				if(checkProps[tagname]){
-					if (input[i].id) {
-						switch (input[i].type)
-						{
-							case "checkbox":
-								if (input[i].checked) {
-									props[tagname] = "2";
-									props["complete"] = "1";
-								} else {
-									props[tagname] = "0";
-									props["complete"] = "-1";
-								}
-								break;
-							case "hidden":
-							case "text":
-							default:					
-								props[tagname] = input[i].value;
-								break;
-						}
-					}
+				if(typeof checkProps[tagname] == "undefined"){
+					continue;
 				}
-			}else{
-				if (input[i].id) {
-					switch (input[i].type)
-					{
-						case "checkbox":
-							if (input[i].checked) {
-								props[tagname] = "2";
-								props["complete"] = "1";
-							} else {
-								props[tagname] = "0";
-								props["complete"] = "-1";
-							}
-							break;
-						case "hidden":
-						case "text":
-						default:					
-							props[tagname] = input[i].value;
-							break;
-					}
+			}
+
+			if (input[i].id) {
+				switch (input[i].type)
+				{
+					case "checkbox":
+						if (input[i].checked) {
+							props[tagname] = "1";
+						} else {
+							props[tagname] = "-1";
+						}
+						break;
+					case "hidden":
+					case "text":
+					default:					
+						props[tagname] = input[i].value;
+						break;
 				}
 			}
 		}
@@ -393,7 +508,7 @@ function completeSpinnerDown(text_percent,statusid)
 function percentchange(moduleid, property)
 {		
 	//check whether percent_complete columns exists.
-	if (dhtml.getElementById(property +"_module"+ moduleid +"_status").checked) {
+	if (dhtml.getElementById(property +"_module"+ moduleid +"_complete").checked) {
 		if(dhtml.getElementById(property +"_module"+ moduleid +"_text_percent_complete")) {
 			dhtml.getElementById(property +"_module"+ moduleid +"_text_percent_complete").value = "100%";
 		}
@@ -438,4 +553,13 @@ tasklistmodule.prototype.item = function(action)
 {
 	this.setDateOnlyFields(action);
 	tasklistmodule.superclass.item.call(this, action);
+}
+
+function eventTaskListContextMenuMessageAssignTask(moduleObject, element, event)
+{
+	element.parentNode.style.display = "none";
+
+	var messages = moduleObject.getSelectedMessages();
+
+	webclient.openWindow(moduleObject, "task", DIALOG_URL+"task=task_standard&storeid=" + moduleObject.storeid +"&parententryid="+ moduleObject.entryid +"&entryid="+ moduleObject.entryids[messages[0]] +"&taskrequest=true");
 }
\ No newline at end of file
