@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -101,6 +103,7 @@ CalendarDatePickerView.prototype.initView = function()
 	
 	var table = dhtml.addElement(monthElement, "table");
 	table.width = "100%";
+	table.height = "100%";
 	table.cellPadding = 0;
 	table.cellSpacing = 0;
 	table.border = 0;
@@ -204,6 +207,12 @@ CalendarDatePickerView.prototype.execute = function(items, properties, action)
 CalendarDatePickerView.prototype.addList = function(items)
 {
 	this.clearEntryAndDayList();
+
+	// Set a date object that will start at the start of the shown month
+	var currMonthStart = (new Date())
+	currMonthStart.setTimeStamp(1, this.month+1, this.year);
+	currMonthStart = new Date(timeToZero(currMonthStart.getTime()/1000)*1000);
+
 	for(var i = 0; i < items.length; i++)
 	{
 		var startdate = items[i].getElementsByTagName("startdate")[0];
@@ -230,12 +239,16 @@ CalendarDatePickerView.prototype.addList = function(items)
 				itemObject["entryid"] = entryID;
 				itemObject["subject"] = subject;
 
+				if(date.getTime() < currMonthStart.getTime()){
+					date = new Date(currMonthStart.getTime());
+				}
 				while(date){
 					this.addItemToDay(itemObject,date.getTime());
 					//switch to next day
 					date.addDays(1);
-					//if current day is not end day of apppointment,the date will be set false
-					if(date.getTime() >= (dueunixtime * 1000))
+					// Set date to false when the appointment ends to stop marking the days in the datepicker.
+					// When the appointments lasts for the whole month, it stops as soon as the next month is reached.
+					if(date.getTime() >= (dueunixtime * 1000) || date.getMonth() != currMonthStart.getMonth())
 						date = false;
 				}
 			}			
@@ -264,7 +277,7 @@ CalendarDatePickerView.prototype.addItemToDay = function(itemObject,timeStampOfD
 	var oldTimeStampOfDay = this.entryList[itemObject["entryid"]];
 	
 	//when the item have bean moved
-	if((this.entryList[itemObject["entryid"]]) > 0 && this.dayList[timeStampOfDay] && (this.dayList[timeStampOfDay].lenght == 1)){
+	if((this.entryList[itemObject["entryid"]]) > 0 && this.dayList[timeStampOfDay] && (this.dayList[timeStampOfDay].length == 1)){
 		if(element){
 			dhtml.removeClassName(element, "hasappointments");
 		}
@@ -292,9 +305,8 @@ CalendarDatePickerView.prototype.addItemToDay = function(itemObject,timeStampOfD
 
 CalendarDatePickerView.prototype.removeItemOfDay = function(entryID)
 {
-	var element = dhtml.getElementById(timeStampOfDay);
 	var timeStampOfDay = this.entryList[entryID];
-	
+	var element = dhtml.getElementById(timeStampOfDay);
 	//when the item have bean moved
 	if(timeStampOfDay && this.dayList[timeStampOfDay].length == 1){
 		if(element){
