@@ -123,6 +123,10 @@ CalendarDayView.prototype.setData = function(data)
 	}
 	
 	this.setDayHeaders();
+	
+	// if selected date has been changed then we should reset selection
+	this.clearSelection();
+	this.resetSelection();
 }
 
 // Initializes the static background. This is not date-dependant
@@ -164,14 +168,15 @@ CalendarDayView.prototype.initView = function()
 			break;
 	}
 	var extraElement = dhtml.addElement("","span");
+
+	// title string
+	this.rangeElement = dhtml.addElement(extraElement,"span","","");
+	
 	// previous button 
 	var prevButton = dhtml.addElement(extraElement,"span","prev_button","",NBSP);
 	dhtml.addEvent(this.moduleID,prevButton,"click",eventDayViewClickPrev);
 	prevButton.title = prevTitle;
 	
-	// title string
-	this.rangeElement = dhtml.addElement(extraElement,"span","","");
-	
 	// next button
 	var nextButton =dhtml.addElement(extraElement,"span","next_button","",NBSP);
 	dhtml.addEvent(this.moduleID,nextButton,"click",eventDayViewClickNext);
@@ -507,9 +512,13 @@ CalendarDayView.prototype.updateItem = function(element, item, properties)
 		// Item switched to a day which is beyond the view
 		// then just delete the item from that view and return
 		if(itemDay >= days.length || itemDay < 0) {
+			// Calculate endday of the item.
+			var itemEndDay = Math.floor((itemData["duedate"].getAttribute("unixtime") - (this.days[0]/1000))/86400);
+
 			// Check if either one of the elements of multiday appointment is coming on first day or not.
 			// if not then delete and return else skip all this loop and go to deleting of elements.
-			if((itemDay+1) < 0){
+			// If startday and endday, both are in past then start of view range then delete element.
+			if((itemDay+1) < 0 && itemEndDay < 0){
 				// if the updated item was multiday appointment
 				if(element.getAttribute("multipleDayElementCount")){
 					for(var x in elementObjs){
@@ -667,7 +676,9 @@ CalendarDayView.prototype.createAppointmentElement = function(daysElement, appoi
 	if (itemData["reminderSet"] && itemData["reminderSet"].firstChild && itemData["reminderSet"].firstChild.nodeValue == "1"){
 		dhtml.addElement(appointment, "span", "reminder", false, NBSP);
 	}
-	
+	if(itemData["requestsent"]) {
+		appointment.requestsent = itemData["requestsent"];
+	}
 	if(itemData["meeting"] && itemData["meeting"].firstChild) {
 		appointment.meetingrequest = itemData["responseStatus"]; // store responseStatus in DOM tree
 		switch(itemData["meeting"].firstChild.nodeValue)
@@ -694,7 +705,7 @@ CalendarDayView.prototype.createAppointmentElement = function(daysElement, appoi
 	}
 	
 	if(itemData["subject"] && itemData["subject"].firstChild) {
-		appointment.innerHTML += itemData["subject"].firstChild.nodeValue;
+		dhtml.addElement(appointment, "span", false, false, itemData["subject"].firstChild.nodeValue);
 		appointment.subject = itemData["subject"].firstChild.nodeValue;
 	}else{
 		appointment.innerHTML += "&nbsp;";
@@ -702,7 +713,7 @@ CalendarDayView.prototype.createAppointmentElement = function(daysElement, appoi
 	}
 	
 	if(itemData["location"] && itemData["location"].firstChild) {
-		appointment.innerHTML += " (" + itemData["location"].firstChild.nodeValue + ")";
+		dhtml.addElement(appointment, "div", false, false, "(" + itemData["location"].firstChild.nodeValue + ")");
 		appointment.location = itemData["location"].firstChild.nodeValue;
 	}
 	
@@ -942,13 +953,17 @@ CalendarDayView.prototype.createAllDayItem = function(appointElement, itemData)
 	var duration = itemData["duration"];
 	var label = itemData["label"];
 	var alldayevent = itemData["alldayevent"];
+	var meeting = itemData["meeting"];
 	var location = "";
 	if(itemData["location"] && itemData["location"].childNodes.length > 0){
 		location = " ("+itemData["location"].firstChild.nodeValue+")";
 	}
 	
-	if(startUnixtime >= this.duedate/1000 || endUnixtime <= this.startdate/1000)
-	    return; // Item we received is not within our viewing range
+	if(startUnixtime >= this.duedate/1000 || endUnixtime <= this.startdate/1000){
+		// deleteing the created allday appointment element, as it does not falls in the range.
+		dhtml.deleteElement(appointElement);
+		return; // Item we received is not within our viewing range
+	}
 
 	//body of item
 	dhtml.deleteAllChildren(appointElement);
@@ -970,6 +985,11 @@ CalendarDayView.prototype.createAllDayItem = function(appointElement, itemData)
 	appointElement.setAttribute("start",startUnixtime);
 	appointElement.setAttribute("end",endUnixtime);
 	appointElement.setAttribute("alldayevent", itemData["alldayevent"]);
+
+	appointElement.start = startUnixtime;
+	appointElement.end = endUnixtime;
+	appointElement.meetingrequest = itemData["responseStatus"]; // store responseStatus in DOM tree
+
 	//style
 	var className = "ipm_appointment allday_appointment";
 	if(itemData["busystatus"] && itemData["busystatus"].firstChild) {
@@ -1396,6 +1416,8 @@ CalendarDayView.prototype.fetchDataForApptObjectFromXML = function(item){
 			dataObj["privateSensitivity"] = item.getElementsByTagName("sensitivity")[0];
 			
 			dataObj["reminderSet"] = item.getElementsByTagName("reminder")[0];
+			// get MeetingRequestWasSent property and check that is MR really sent or not.
+			dataObj["requestsent"] = dhtml.getTextNode(item.getElementsByTagName("requestsent")[0]);
 			dataObj["meeting"] = item.getElementsByTagName("meeting")[0];
 			if(dataObj["meeting"]) {
 				dataObj["responseStatus"] = dhtml.getTextNode(item.getElementsByTagName("responsestatus")[0], 0);
@@ -1700,7 +1722,7 @@ CalendarDayView.prototype.translateXCoordToAllDayTimelineCell = function(element
  */
 CalendarDayView.prototype.getStartEndTimeOfSelection = function(contextMenuFlag){
 	var elements = this.selectionRange;
-	if(elements.length > 0){
+	if(typeof elements != 'undefined' && elements.length > 0){
 		//if selection is on normal calendar timeline
 		if(!this.selectionInAllDay){
 			var startOffsetDay = elements[0].offsetDay;
@@ -1906,9 +1928,10 @@ function eventQuickAppointmentKey(moduleObject, element, event)
 				var subject = moduleObject.quickElem.value;
 				var viewObject = moduleObject.viewController.viewObject;
 				var startEndTime = viewObject.getStartEndTimeOfSelection();
-				var reminderTime = null;
+				var reminderTime;
 				if(webclient.settings.get("calendar/reminder","true") == "true"){
-					reminderTime = webclient.settings.get("calendar/reminder_minutes", 15);
+					// while creating an quick allday appointment, default reminder is set then we need to set reminder time to 18hrs or else to default value.
+					reminderTime = viewObject.selectionInAllDay? "1080" : webclient.settings.get("calendar/reminder_minutes", 15);
 				}
 				if (subject.trim()!=""){
 					moduleObject.createAppointment(startEndTime[0], startEndTime[1], subject, null, null, null, reminderTime, (viewObject.selectionInAllDay)?1:0);
@@ -1948,6 +1971,18 @@ function eventQuickAppointmentMouse(moduleObject, element, event){
 // Called with moduleObject == module, NOT this view object.
 function eventAppointmentListDragDropTarget(moduleObject, targetElement, element, event)
 {
+	/**
+	 * If MR appointment is moved by attandee than show user an alert message.
+	 * If MR is just saved (not send) then requestsent attribute (MeetingRequestWasSent Property) is set to '0'
+	 * If MR was sent to recpients then requestsent attribute (MeetingRequestWasSent Property) is set to '1'
+	 * so if request is not sent to recipients then dont ask to update them while saving MR.
+	 */
+	if(element && element.meetingrequest && element.meetingrequest == "3" && !(element.requestsent && element.requestsent != "1")) { // MR attendee
+		if (!confirm(_("You are changing details for a meeting on your calendar while you are not the meeting organizer. If the organizer sends a meeting update, your changes will be lost. Do you want to continue?"))) {
+			moduleObject.list();
+			return;
+		}
+	}
 	// We only use the targetElement to see which day we are in, for the start/end we
 	// just look at the dragged element's height and location.
 	var offsetDay = targetElement.offsetDay;
@@ -1971,22 +2006,68 @@ function eventAppointmentListDragDropTarget(moduleObject, targetElement, element
 	var startTimeOffset = getTimeOffsetByPixelOffset(firstTargetElement, topOffset);
 	var endTimeOffset = getTimeOffsetByPixelOffset(firstTargetElement, bottomOffset);
 
-	var starttime = new Date(dayStart);
-	starttime.addUnixTimeStampToDate(startTimeOffset * 60);
-	var endtime = new Date(dayStart);
-	endtime.addUnixTimeStampToDate(endTimeOffset * 60);
+	var actionType = element.getAttribute("action");
+	var starttime = false;
+	var endtime = false;
+
+	// Set stattime and endtime for the appointment.
+	if(actionType != null && actionType == "resize-bottom") { 
+		endtime = new Date(dayStart);
+		endtime.addUnixTimeStampToDate(endTimeOffset * 60);
+		starttime = new Date(element.start * 1000);
+	} else if(actionType != null && actionType == "resize-top") {
+		starttime = new Date(dayStart);
+		starttime.addUnixTimeStampToDate(startTimeOffset * 60);
+		endtime = new Date(element.end * 1000);
+	} else {
+		// when moving an appointment it's duration time should not be changed
+		starttime = new Date(dayStart);
+		starttime.addUnixTimeStampToDate(startTimeOffset * 60);
+
+		endtime = new Date(dayStart);
+		var duration = parseInt(element.end, 10) - parseInt(element.start, 10);
+		if(!isNaN(duration)) {
+			endtime.addUnixTimeStampToDate(duration + (startTimeOffset * 60));
+		} else {
+			// fallback to old way (not needed)
+			endtime.addUnixTimeStampToDate(endTimeOffset * 60);
+		}
+	}
 
 	var props = new Object();
 	props["store"] = moduleObject.storeid;
 	props["parent_entryid"] = moduleObject.entryid;
-				
 	props["entryid"] = moduleObject.entryids[element.id];
-	props["startdate"] = starttime.getTime()/1000;
-	props["duedate"] = endtime.getTime()/1000;
-	props["commonstart"] = props["startdate"];
-	props["commonend"] = props["duedate"];
-	props["duration"] = (props["duedate"]-props["startdate"])/60;
-	props["remindertime"] = parseInt(props["startdate"]);
+
+	if(starttime) {
+		props["startdate"] = parseInt(starttime.getTime()/1000, 10);
+		props["commonstart"] = props["startdate"];
+		props["remindertime"] = props["startdate"];
+	} else if(element && element.positionStartTime) {
+		starttime = new Date(element.positionStartTime * 1000);
+		//starttime.setTime(element.positionStartTime * 1000)
+	}
+
+	// Set flagdueby property to show reminder on correcttime.
+	if(props["startdate"] && props["entryid"] && moduleObject.itemProps[props["entryid"]])
+		props["flagdueby"] = props["startdate"] - (moduleObject.itemProps[props["entryid"]].reminder_minutes*60);
+
+	/**
+	 * if user stretches the appointment to previous day or before the startdate
+	 * then it should become zero minute appointment.
+	 */
+	if(endtime && starttime && endtime <= starttime) {
+		endtime = starttime;
+	}
+	if(endtime) {
+		props["duedate"] = parseInt(endtime.getTime()/1000, 10);
+		props["commonend"] = props["duedate"];
+	}
+
+	if(starttime && endtime) {
+		props["duration"] = (props["duedate"] - props["startdate"]) / 60;
+	}
+	
 
 	var basedate = (element.getAttribute("basedate") == "undefined" || !element.getAttribute("basedate")?false:element.getAttribute("basedate"));
 	if(basedate) {
@@ -1996,8 +2077,9 @@ function eventAppointmentListDragDropTarget(moduleObject, targetElement, element
 	var occurrenceBaseDate = element.id.substring(element.id.indexOf("_")+1);
 	var send = false;
 	var moveOccAllowFlag = true;
-	if (element.meetingrequest && parseInt(element.meetingrequest) == 1) { // 1 = olResponseOrganized
-		if( endtime.getTime()>(new Date().getTime())) {
+	if (element.meetingrequest && parseInt(element.meetingrequest, 10) == 1) { // 1 = olResponseOrganized
+		// Check whether there are any recepients in MR or not.
+		if( endtime.getTime()>(new Date().getTime()) && !(element.requestsent && element.requestsent != "1")) {
 			send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
 		}
 	}else if(basedate){
