@@ -111,13 +111,15 @@ CalendarMonthView.prototype.initView = function()
 	// extratitle
 	var extraElement = dhtml.addElement("","span");
 
-	var prevButton = dhtml.addElement(extraElement,"span","prev_button","",NBSP);
-	dhtml.addEvent(this.moduleID,prevButton,"click",eventMonthViewClickPrev);
-	prevButton.title = MONTHS[(this.selecteddate.getMonth()==0)?11:this.selecteddate.getMonth()-1];
-	
 	var extraTitleString = MONTHS[this.selecteddate.getMonth()]+" "+this.selecteddate.getFullYear();
 	dhtml.addElement(extraElement,"span","",""," "+extraTitleString+" ");
 
+	// previous button 
+	var prevButton = dhtml.addElement(extraElement,"span","prev_button","",NBSP);
+	dhtml.addEvent(this.moduleID,prevButton,"click",eventMonthViewClickPrev);
+	prevButton.title = MONTHS[(this.selecteddate.getMonth()==0)?11:this.selecteddate.getMonth()-1];
+
+	// next button
 	var nextButton =dhtml.addElement(extraElement,"span","next_button","",NBSP);
 	dhtml.addEvent(this.moduleID,nextButton,"click",eventMonthViewClickNext);	
 	nextButton.title = MONTHS[(this.selecteddate.getMonth()==11)?0:this.selecteddate.getMonth()+1];
@@ -200,8 +202,15 @@ CalendarMonthView.prototype.initView = function()
 }
 
 CalendarMonthView.prototype.getStartEndTimeOfSelection = function(flag, element){
-	var starttime = element.getAttribute("unixtime");
-	return [starttime, starttime];
+	if(typeof element != 'undefined') {
+		var starttime = element.getAttribute("unixtime");
+		return [starttime, starttime];
+	} else {
+		var hourCount = webclient.settings.get("calendar/workdaystart",9 * 60) / 60;
+		var startTime = addHoursToUnixTimeStamp(this.selecteddate.getTime() / 1000, hourCount);
+
+		return [startTime, startTime + 1800];
+	}
 }
 
 CalendarMonthView.prototype.resizeView = function()
@@ -401,7 +410,11 @@ CalendarMonthView.prototype.createItem = function(item,element)
 
 				// subject
 				dhtml.addElement(AppointmentElement,"span","event_subject","",subject);
-				
+
+				// MeetingRequestWasSent
+				if(item.getElementsByTagName("requestsent") && item.getElementsByTagName("requestsent")[0]) {
+					AppointmentElement.requestsent = dhtml.getTextNode(item.getElementsByTagName("requestsent")[0]);;
+				}
 				// meeting
 				var meeting = item.getElementsByTagName("meeting")[0];
 				if(meeting && meeting.firstChild) {
@@ -545,6 +558,10 @@ function eventCalenderMonthViewDragDropTarget(moduleObject, targetElement, eleme
 	props["commonstart"] = newDraggableStartdate;
 	props["commonend"] = newDraggableDuedate;
 
+	// Set flagdueby property to show reminder on correcttime.
+	if(props["startdate"] && props["entryid"] && moduleObject.itemProps[props["entryid"]])
+		props["flagdueby"] = props["startdate"] - (moduleObject.itemProps[props["entryid"]].reminder_minutes*60);
+
 	if(draggableBasedate){
 		props["basedate"] = draggableBasedate;
 		var drag = true;
@@ -553,9 +570,12 @@ function eventCalenderMonthViewDragDropTarget(moduleObject, targetElement, eleme
 
 	var send = false;
 	var moveOccAllowFlag = true;
-	if (element.meetingrequest && element.meetingrequest==1) // 1 = olResponseOrganized
-		if( newDraggableDuedate>(new Date().getTime()/1000))
+	if (element.meetingrequest && element.meetingrequest == olResponseOrganized) {
+		// Check whether there are any recepients in MR or not.
+		if(newDraggableDuedate>(new Date().getTime()/1000) && !(element.requestsent && element.requestsent != "1")) {
 			send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
+		}
+	}
 
 	if(draggableBasedate){
 		moveOccAllowFlag = confirmAppointMoved(moduleObject, draggableBasedate, targetElement.getAttribute("unixtime"));
