@@ -154,15 +154,18 @@ CalendarWeekView.prototype.initView = function()
 
 	// week picker
 	var extraElement = dhtml.addElement("","span");
-	// previous button 
-	var prevButton = dhtml.addElement(extraElement,"span","prev_button","",NBSP);
-	dhtml.addEvent(this.moduleID,prevButton,"click",eventDayViewClickPrev);
-	prevButton.title = _("Previous week");
+	
 	// title string
 	var startDateObj = new Date(this.startdate);
 	var dueDateObj = new Date(this.duedate-ONE_DAY);			
 	var titleString = startDateObj.getDate()+" "+MONTHS[startDateObj.getMonth()]+" - "+dueDateObj.getDate()+" "+MONTHS[dueDateObj.getMonth()];
 	dhtml.addElement(extraElement,"span","","",titleString);	
+	
+	// previous button 
+	var prevButton = dhtml.addElement(extraElement,"span","prev_button","",NBSP);
+	dhtml.addEvent(this.moduleID,prevButton,"click",eventDayViewClickPrev);
+	prevButton.title = _("Previous week");
+	
 	// next button
 	var nextButton =dhtml.addElement(extraElement,"span","next_button","",NBSP);
 	dhtml.addEvent(this.moduleID,nextButton,"click",eventDayViewClickNext);
@@ -359,6 +362,10 @@ CalendarWeekView.prototype.createItem = function(item, element)
 					dhtml.addElement(AppointmentElement,"span","event_subject","",subject);
 				}			
 
+				// MeetingRequestWasSent
+				if(item.getElementsByTagName("requestsent") && item.getElementsByTagName("requestsent")[0]) {
+					AppointmentElement.requestsent = dhtml.getTextNode(item.getElementsByTagName("requestsent")[0]);;
+				}
 				// meeting
 				var meeting = item.getElementsByTagName("meeting")[0];
 				if(meeting && meeting.firstChild) {
@@ -450,8 +457,15 @@ CalendarWeekView.prototype.deleteLoadMessage = function()
 }
 
 CalendarWeekView.prototype.getStartEndTimeOfSelection = function(flag, element){
-	var starttime = element.getAttribute("unixtime");
-	return [starttime, starttime];
+	if(typeof element != 'undefined') {
+		var starttime = element.getAttribute("unixtime");
+		return [starttime, starttime];
+	} else {
+		var hourCount = webclient.settings.get("calendar/workdaystart",9 * 60) / 60;
+		var startTime = addHoursToUnixTimeStamp(this.selecteddate.getTime() / 1000, hourCount);
+
+		return [startTime, startTime + 1800];
+	}
 }
 
 // EVENTS
@@ -502,6 +516,10 @@ function eventCalenderWeekViewDragDropTarget(moduleObject, targetElement, elemen
 	props["commonstart"] = newDraggableStartdate;
 	props["commonend"] = newDraggableDuedate;
 
+	// Set flagdueby property to show reminder on correcttime.
+	if(props["startdate"] && props["entryid"] && moduleObject.itemProps[props["entryid"]])
+		props["flagdueby"] = props["startdate"] - (moduleObject.itemProps[props["entryid"]].reminder_minutes*60);
+
 	if(draggableBasedate){
 		props["basedate"] = draggableBasedate;
 		var drag = true;
@@ -510,9 +528,12 @@ function eventCalenderWeekViewDragDropTarget(moduleObject, targetElement, elemen
 
 	var send = false;
 	var moveOccAllowFlag = true;
-	if (element.meetingrequest && element.meetingrequest==1) // 1 = olResponseOrganized
-		if( newDraggableDuedate>(new Date().getTime()/1000))
+	if (element.meetingrequest && element.meetingrequest == olResponseOrganized) {
+		// Check whether there are any recepients in MR or not.
+		if( newDraggableDuedate>(new Date().getTime()/1000) && !(element.requestsent && element.requestsent != "1")) {
 			send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
+		}
+	}
 
 	if(draggableBasedate){
 		moveOccAllowFlag = confirmAppointMoved(moduleObject, draggableBasedate, targetElement.getAttribute("id").split("_")[2]);
