@@ -291,7 +291,6 @@ PrintCalendarMonthView.prototype.createItem = function(item) {
  */
 PrintCalendarMonthView.prototype.resizeView = function(iframe) {
 	if(typeof iframe != "undefined") {
-		var iframe = window.frames["printing_frame"];
 		var iframeDoc = iframe.document;
 		var printFooterHeight = iframeDoc.getElementById("print_footer").offsetHeight;
 		var printHeaderHeight = iframeDoc.getElementById("print_header").offsetHeight;
@@ -404,8 +403,8 @@ PrintCalendarMonthView.prototype.resizeView = function(iframe) {
 	} else {
 		var menubarHeight = dhtml.getElementById("menubar").offsetHeight + dhtml.getElementById("menubar").offsetTop;
 		var titleHeight = dhtml.getElementsByClassName("title")[0].offsetHeight;
-		var bodyHeight = document.getElementsByTagName("body")[0].offsetHeight;
-		var bodyWidth = document.getElementsByTagName("body")[0].offsetWidth;
+		var bodyHeight = dhtml.getBrowserInnerSize()["y"];
+		var bodyWidth = dhtml.getBrowserInnerSize()["x"];
 
 		var dialogContentHeight = bodyHeight - (menubarHeight + titleHeight);
 		dhtml.getElementById("dialog_content").style.height = dialogContentHeight + "px";
