@@ -130,8 +130,7 @@ TableView.prototype.initView = function()
 	this.divElement.style.overflowX = "hidden";
 	this.divElement.style.overflowY = "scroll";
 
-	// Prevent IE scrolling the pane when user does up/down/pgup/etc	
-	dhtml.addEvent(this, this.divElement, "keydown", this.onDivKeyDown);
+	this.setEventsOnLayoutElement();
 	
 	// add keyboard event
 	var module = webclient.getModule(this.moduleID);
@@ -246,6 +245,9 @@ TableView.prototype.execute = function(items, properties, action, groupID, input
 		}
 	}
 
+	// When layout is recreated registered events are lost, so set events again on layoutElement(i.e this.divElement)
+	this.setEventsOnLayoutElement();
+
 	return entryids;
 }
 
@@ -321,7 +323,7 @@ TableView.prototype.addColumns = function(columns, sortColumn, sortDirection)
 
 	var table = new Array();
 	table.push("<div id='columnbackground'>");
-	table.push("<table width='100%' border='0' cellpadding='0' cellspacing='0'><tr class='columns'>");
+	table.push("<table class='table' border='0' cellpadding='0' cellspacing='0'><tr class='columns'>");
 	this.columns = columns;
 	this.sortColumn = sortColumn;
 	this.sortDirection = sortDirection;
@@ -461,9 +463,9 @@ TableView.prototype.renderInputColumn = function (renderOnlyinput, moduleID, tab
 		}
 	}
 	
-	moduleid = "module"+ moduleID;
-	columnid = moduleid +"_"+ name;
-	statusfieldid = property +"_"+ moduleid +"_status";
+	var moduleid = "module"+ moduleID;
+	var columnid = moduleid +"_"+ name;
+	var statusfieldid = property +"_"+ moduleid +"_status";
 	fieldid = property +"_"+ moduleid +"_"+ fieldid;
 	
 	switch(type)
@@ -481,7 +483,7 @@ TableView.prototype.renderInputColumn = function (renderOnlyinput, moduleID, tab
 			break;
 			
 		case "checkbox":
-			if(value != 0)  value = "checked";			
+			value = (value != 0) ? "checked" : " ";
 			elementValue +="<input id='"+ fieldid +"' type='checkbox' class='status' "+ value +">";
 			break;
 			
@@ -508,7 +510,7 @@ TableView.prototype.renderInputColumn = function (renderOnlyinput, moduleID, tab
 		
 		case "hidden":
 			className = "hidden_column";
-			elementValue += this.getHiddenElements(property, moduleid);
+			elementValue += this.getHiddenElements(property, moduleID);
 		    break;
 		    
 		default:
@@ -550,15 +552,18 @@ TableView.prototype.renderInputColumn = function (renderOnlyinput, moduleID, tab
 //Function which returns hidden elements for particular module...
 TableView.prototype.getHiddenElements = function (property, moduleid)
 {
-	moduleID = moduleid.split("module")[1];
-	moduleObject = webclient.getModule(moduleID);
+	var moduleObject = webclient.getModule(moduleid);
+	var elementValue = "";
+
 	switch(moduleObject.getModuleName())
 	{
 		case "tasklistmodule":
-			elementValue  ="<input id='"+ property +"_"+ moduleid +"_message_class' type='hidden' value='IPM.Task'>";
-			elementValue +="<input id='"+ property +"_"+ moduleid +"_icon_index' type='hidden' value='1280'>";
-			elementValue +="<input id='"+ property +"_"+ moduleid +"_percent_complete' type='hidden' value='0'>";
-			elementValue +="<input id='"+ property +"_"+ moduleid +"_importance' type='hidden' value='1'>";
+			if (property == "insertprops") {
+				elementValue  ="<input id='"+ property +"_module"+ moduleid +"_message_class' type='hidden' value='IPM.Task'>";
+				elementValue +="<input id='"+ property +"_module"+ moduleid +"_icon_index' type='hidden' value='1280'>";
+			}
+			elementValue +="<input id='"+ property +"_module"+ moduleid +"_percent_complete' type='hidden' value='0'>";
+			elementValue +="<input id='"+ property +"_module"+ moduleid +"_importance' type='hidden' value='1'>";
 			break;
 		
 		default:
@@ -682,7 +687,8 @@ TableView.prototype.addRows = function(rows)
 			dragdrop.addDraggable(tableElement.rows[i], "folder",null,null,this.moduleID);
 		}
 		
-		if(this.events["row"]) {
+		// Here we are getting private property from "disabled_item" from rows(XML items) and dont add events for private items.
+		if(this.events["row"] && dhtml.getXMLValue(rows[i], "disabled_item", "0") != "1") {
 			dhtml.setEvents(this.moduleID, tableElement.rows[i], this.events["row"]);
 		}
 
@@ -1562,6 +1568,11 @@ TableView.prototype.getAllRowElements = function()
 	return elements;
 }
 
+TableView.prototype.setEventsOnLayoutElement = function()
+{
+	// Prevent IE scrolling the pane when user does up/down/pgup/etc	
+	dhtml.addEvent(this, this.divElement, "keydown", this.onDivKeyDown);
+}
 
 // FIXME FIXME this is called with 'mobuleObject' referring not to this view oject, but to our parent module!
 function eventTableViewKeyboard(moduleObject, element, event)
