@@ -158,8 +158,8 @@ combinedDateTimePicker.prototype.updateStart = function(obj,oldValue)
 	var oldStartValue = combiDTP.startOldValue;
 	var oldEndValue = combiDTP.endOldValue;
 	var duration = oldEndValue-oldStartValue;
-	
-	if(duration>0){
+	//as now we can create 0 duration app
+	if(duration >= 0){
 		var newEndValue = newStartValue+duration;
 	}
 	else{
@@ -200,7 +200,7 @@ combinedDateTimePicker.prototype.updateEnd = function(obj,oldValue)
 		combiDTP.setEndValue(newEndValue);
 	}
 	
-	if(oldStartValue >= newEndValue){
+	if(oldStartValue > newEndValue){
 		combiDTP.setStartValue(newEndValue-(HALF_HOUR/1000));
 	}
 
