@@ -62,6 +62,7 @@ function Menu()
 	this.defaultMenuItems.push(this.createMenuItem("contact", _("New"), _("Contact")));
 	this.defaultMenuItems.push(this.createMenuItem("distlist", _("New"), _("Distributionlist")));
 	this.defaultMenuItems.push(this.createMenuItem("task", _("New"), _("Task")));
+	this.defaultMenuItems.push(this.createMenuItem("assigntask", _("New"), _("Task Request")));
 	this.defaultMenuItems.push(this.createMenuItem("stickynote", _("New"), _("Note")));
 
 	this.menuBar = dhtml.getElementById("menubar");
@@ -408,6 +409,9 @@ function eventMenuNewDefaultMessage(moduleObject, element, event)
 			case "contact":
 				folderEntryID = hierarchymodule.defaultstore.defaultfolders.contact;
 				break;
+			case "assigntask":
+				messageClass = "task";
+				extraParams = "taskrequest=true";
 			case "task":
 				folderEntryID = hierarchymodule.defaultstore.defaultfolders.task;
 				break;
@@ -420,7 +424,7 @@ function eventMenuNewDefaultMessage(moduleObject, element, event)
 		webclient.openWindow(moduleObject, messageClass, DIALOG_URL+"task=" + messageClass + "_standard&storeid=" + storeID +"&parententryid="+folderEntryID+(extraParams?"&"+extraParams:""));
 	}
 	else{
-		webclient.openWindow(hierarchymodule, messageClass, DIALOG_URL+"task=createfolder_modal&parent_entryid=" + hierarchymodule.selectedFolder+(extraParams?"&"+extraParams:""), 300, 400, null, null, null, {parentModule: hierarchymodule});
+		webclient.openModalDialog(hierarchymodule, messageClass, DIALOG_URL+"task=createfolder_modal&parent_entryid=" + hierarchymodule.selectedFolder+(extraParams?"&"+extraParams:""), 300, 400, null, null, {parentModule: hierarchymodule});
 	}
 }
 /**
