@@ -33,7 +33,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -148,7 +150,7 @@ QuotaWidget.prototype.update = function(size, warn, soft, hard)
 		}
 
 		this.element.style.display = "block";
-		factor = this.barElement.offsetWidth / maxLimit;		// total width of qouta bar / max aouta limit
+		factor = this.barElement.offsetWidth / maxLimit;		// total width of qouta bar / max qouta limit
 
 		// Set label (current size / qouta size)
 		dhtml.deleteAllChildren(this.labelElement);
@@ -204,9 +206,9 @@ QuotaWidget.prototype.update = function(size, warn, soft, hard)
 		}
 
 		// Update view, set width of blocks
-		quota[0].element.style.width = (firstBlockSize > 0) ? firstBlockSize * factor + "px" : "0px";
-		quota[1].element.style.width = (secondBlockSize > 0) ? secondBlockSize * factor + "px" : "0px";
-		quota[2].element.style.width = (thirdBlockSize > 0) ? thirdBlockSize * factor + "px" : "0px";
+		quota[0].element.style.width = (firstBlockSize > 0) ? parseInt(firstBlockSize * factor, 10) + "px" : "0px";
+		quota[1].element.style.width = (secondBlockSize > 0) ? parseInt(secondBlockSize * factor, 10) + "px" : "0px";
+		quota[2].element.style.width = (thirdBlockSize > 0) ? parseInt(thirdBlockSize * factor, 10) + "px" : "0px";
 
 		// set starting position of blocks
 		quota[0].element.style.left = "0px";
