@@ -59,7 +59,7 @@ suggestionList.superclass = Widget.prototype;
  * @param {HtmlElement} element
  * @param {String} sourceModule
  */
-function suggestionList(id,inputfld,sourceModule, callBackFunction){
+function suggestionList(id, inputfld, sourceModule, callBackFunction){
 	if(arguments.length > 1) {
 		this.init(id, inputfld, sourceModule, callBackFunction);
 	}
@@ -76,7 +76,9 @@ suggestionList.prototype.init = function(id, inputfld, sourceModule, callBackFun
 
 	try{
 		// Disable autocomplete functionality of an input field
-		this.inputfld.setAttribute("autocomplete", "off");
+		if(this.inputfld.type == "text") {
+			this.inputfld.setAttribute("autocomplete", "off");
+		}
 
 		// Add events to the input field
 		dhtml.addEvent(this, this.inputfld, "keyup", eventSuggestionListOnTyping);
@@ -139,7 +141,7 @@ suggestionList.prototype.render = function(suggestions){
 		// Create suggestionlayer if it not already exists
 		if(typeof this.suggestlayerElement != "object"){
 			this.suggestlayerElement = 
-				dhtml.addElement(document.getElementsByTagName("body")[0], "div", "suggestlayer", "suggestlayer[" + this.id + "]");
+				dhtml.addElement(document.body, "div", "suggestlayer", "suggestlayer[" + this.id + "]");
 		}
 		// Remove content of suggestion layer
 		while(this.suggestlayerElement.childNodes.length){
@@ -223,18 +225,29 @@ suggestionList.prototype.selectSuggestion = function(selection){
 		}else{
 			l_iSelectionEndPos += l_iCaretPos;
 		}
+
 		// Select the whole section between the both ;  where the cursor is located in between
 		dhtml.setSelectionRange(this.inputfld, l_iPreStringChars, l_iSelectionEndPos);
 		// Replace the typed input and replace it with the selected suggestion.
 		dhtml.textboxReplaceSelection(this.inputfld, (l_iPreStringChars > 0 ? " " : "") + this.focusSuggestions[selection]);
+
 		// Test is the last element of the input field has content (= characters excl. spaces)
 		if(this.inputfld.value.split(";").pop().replace(" ", "").length > 0){
 			this.inputfld.value += "; ";
 		}
+
 		// Move cursor to the end
 		dhtml.setSelectionRange(this.inputfld, this.inputfld.value.length, this.inputfld.value.length);
+		if(this.inputfld.type == "textarea") {
+			this.inputfld.scrollTop = this.inputfld.scrollHeight;
+		}
+
 		this.removeSuggestionList();
 
+		// Fire change event on inputfield when selected suggestion is added in field.
+		if(this.inputfld)
+			dhtml.executeEvent(this.inputfld, "change");
+
 		if (this.callBackFunction){
 			this.callBackFunction();
 		}
@@ -299,6 +312,7 @@ function eventSuggestionListOnTyping(moduleObj, element, event){
 			case 39:	// Right
 			case 38:	// Up
 			case 40:	// Down
+			case 27:	// Esc
 				break;
 			default:
 				clearTimeout(this.timeout);
@@ -314,14 +328,18 @@ function eventSuggestionListOnTyping(moduleObj, element, event){
 function eventSuggestionListOnKeyDown(moduleObj, element, event){
 	switch(event.keyCode){
 		case 38:	// Up
-			moduleObj.moveSelection("previous");
-			// Event handler returns false to disable effect of UP key.
-			return false;
+			if(this.numResults > 0 && this.selected !== -1) {
+				moduleObj.moveSelection("previous");
+				// prevent default action of up key
+				event.preventDefault();
+			}
 			break;
 		case 40:	// Down
-			moduleObj.moveSelection("next");
-			// Event handler returns false to disable effect of DOWN key.
-			return false;
+			if(this.numResults > 0 && this.selected !== -1) {
+				moduleObj.moveSelection("next");
+				// prevent default action of down key
+				event.preventDefault();
+			}
 			break;
 		case 9:	// Tab
 			/**
@@ -330,20 +348,13 @@ function eventSuggestionListOnKeyDown(moduleObj, element, event){
 			 **/
 			if(moduleObj.selectSuggestion(moduleObj.selected)){
 				// Event handler returns false to disable effect of TAB key.
-				if (this.callBackFunction){
-					this.callBackFunction();
-				}
-
-				return false;
+				event.preventDefault();
 			}
 			break;
 		case 13:	// Enter
-			if(moduleObj.selectSuggestion(moduleObj.selected)){
-				// Event handler returns false to disable effect of ENTER key.
-				if (this.callBackFunction){
-					this.callBackFunction();
-				}
-			}
+			moduleObj.selectSuggestion(moduleObj.selected);
+			// Don't allow newline character in email address field
+			event.preventDefault();
 			break;
 		case 27:	// Esc
 		case 37:	// Left
