@@ -78,6 +78,7 @@ TableWidget.prototype.init = function(element, multipleSelect, windowObj, noLoad
 	this.numSelected = 0;
 	this.multipleSelect = (typeof multipleSelect != "undefined")? Boolean(multipleSelect) : true;
 	this.noLoader = (typeof noLoader != "undefined")? Boolean(noLoader) : false;
+	this.prevSelectedMessageID = false;
 
 	this.columnResizeListeners = new Array();
 	this.eventRowListeners = new Array();
@@ -132,6 +133,7 @@ TableWidget.prototype.resetWidget = function()
 	this.numSelected = 0;
 	this.eventRowListeners = new Array();
 	this.columnResizeListeners = new Array();
+	this.prevSelectedMessageID = false;
 }
 
 TableWidget.prototype.addColumn = function(id, columnName, columnWidth, columnOrder){
@@ -243,7 +245,7 @@ TableWidget.prototype.generateTable = function(data){
 
 		content += '</div>';
 
-		content += '<div id="tablewidget['+this.widgetID+'][contentcontainer]" style="width: 100%; height:'+availableContentHeight+'px; overflow-x: hidden; overflow-y: scroll; position: relative;">';
+		content += '<div id="tablewidget['+this.widgetID+'][contentcontainer]" style="width: 100%; height:'+availableContentHeight+'px; overflow-x: hidden; overflow-y: auto; position: relative;">';
 
 
 		content += '<table  width="100%" id="tablewidget['+this.widgetID+'][contenttable]" class="table" border="0" cellpadding="0" cellspacing="0"><tbody>';
@@ -580,7 +582,11 @@ TableWidget.prototype.deleteRow = function(rowID){
 /**
  * Selection methods
  */
-TableWidget.prototype.clearSelection = function(){
+TableWidget.prototype.clearSelection = function(resetPrevRowID){
+	if(typeof resetPrevRowID == "undefined" || resetPrevRowID == null) {
+		resetPrevRowID = true;
+	}
+
 	var deselected = new Array();
 	for(var i in this.selected){
 		var row = this.getRowByRowID(this.selected[i]);
@@ -591,16 +597,23 @@ TableWidget.prototype.clearSelection = function(){
 	}
 	this.selected = new Object();
 	this.numSelected = 0;
+
+	if(resetPrevRowID)
+		this.prevSelectedMessageID = false;
 	
 	// Notify external systems of update
 	if(deselected.length > 0)
 		this.callRowListener("deselect", {change: deselected});
 }
-TableWidget.prototype.deselectRow = function(rowID){
+TableWidget.prototype.deselectRow = function(rowID, resetPrevRowID){
 	var deselected = new Array();
 	if(typeof rowID != "object")
 		rowID = [rowID];
 
+	if(typeof resetPrevRowID == "undefined" || resetPrevRowID == null) {
+		resetPrevRowID = true;
+	}
+
 	for(var i in rowID){
 		if(this.selected[rowID[i]]){
 			var row = this.getRowByRowID(rowID[i]);
@@ -609,6 +622,10 @@ TableWidget.prototype.deselectRow = function(rowID){
 				this.numSelected--;
 				dhtml.removeClassName(row, "rowselected");
 				deselected.push(rowID[i]);
+
+				if(this.prevSelectedMessageID == rowID[i] && resetPrevRowID) {
+					this.prevSelectedMessageID = false;
+				}
 			}
 		}
 	}
@@ -617,7 +634,7 @@ TableWidget.prototype.deselectRow = function(rowID){
 		this.callRowListener("deselect", {change: deselected});
 	}
 }
-TableWidget.prototype.selectRow = function(rowID, adjustScroller){
+TableWidget.prototype.selectRow = function(rowID, adjustScroller, overWritePrevRowID){
 	var selected = new Array();
 	if(typeof rowID != "object")
 		rowID = [rowID];
@@ -626,6 +643,10 @@ TableWidget.prototype.selectRow = function(rowID, adjustScroller){
 		adjustScroller = false;
 	}
 
+	if(typeof overWritePrevRowID == "undefined" || overWritePrevRowID == null) {
+		overWritePrevRowID = true;
+	}
+
 	for(var i in rowID){
 		if(!this.selected[rowID[i]]){
 			var row = this.getRowByRowID(rowID[i]);
@@ -634,6 +655,9 @@ TableWidget.prototype.selectRow = function(rowID, adjustScroller){
 				this.numSelected++;
 				dhtml.addClassName(row, "rowselected");
 				selected.push(rowID[i]);
+
+				if(overWritePrevRowID)
+					this.prevSelectedMessageID = rowID[i];
 			}
 		}
 	}
@@ -774,9 +798,18 @@ function eventTableWidgetClickRow(moduleObject, element, event){
 	if(typeof moduleObject == "undefined")
 		return false;
 
-	if(element.getAttribute("rowID")){
-		var rowID = element.getAttribute("rowID");
+	event.preventDefault();
+	event.stopPropagation();
 
+	var button = 0;
+	if(event.button) {			// FF
+		button = event.button;
+	} else if(event.which) {	// IE
+		button = event.which;
+	}
+
+	if(element.getAttribute("rowID") && button != 2) {
+		var rowID = element.getAttribute("rowID");
 
 		/**
 		 * This table defines what should happen when the user clicks on a row
@@ -797,16 +830,48 @@ function eventTableWidgetClickRow(moduleObject, element, event){
 		 * +----------+------+----------++----------+-------------+
 		 */
 		// Deselect only this selected message with use of the ctrl key
-		if(moduleObject.selected[rowID] && event.ctrlKey){
+		if(moduleObject.selected[rowID] && event.ctrlKey) {
 			moduleObject.deselectRow(rowID);
 		// Only do something when the clicked row is not the only row that is selected
-		}else if(!moduleObject.isRowIDSelected(rowID) || moduleObject.getNumSelectedRows() != 1){
-			if(!event.ctrlKey || !this.multipleSelect)
+		} else if(!moduleObject.isRowIDSelected(rowID) || moduleObject.getNumSelectedRows() != 1) {
+			if((!event.ctrlKey && !event.shiftKey) || !this.multipleSelect)
 				moduleObject.clearSelection();
 
-			moduleObject.selectRow(rowID);
-		}
+			if(event.shiftKey && this.multipleSelect) {
+				var prevRowElement = moduleObject.getRowByRowID(moduleObject.prevSelectedMessageID);
+				var rowTopLeft = dhtml.getElementTopLeft(element);
+				var prevRowTopLeft = dhtml.getElementTopLeft(prevRowElement);
 
+				// clear previous selection, if selection is changed
+				moduleObject.clearSelection(false);
+
+				// up to down selection
+				if(rowTopLeft[1] > prevRowTopLeft[1]) {
+					var nextRowID = moduleObject.prevSelectedMessageID;
+					while(nextRowID && nextRowID != rowID) {
+						moduleObject.selectRow(nextRowID, false, false);
+						nextRowID = moduleObject.nextRowID(nextRowID);
+					}
+
+					// select the last row
+					if(nextRowID)
+						moduleObject.selectRow(nextRowID, false, false);
+				// down to up selection
+				} else {
+					var prevRowID = moduleObject.prevSelectedMessageID;
+					while(prevRowID && prevRowID != rowID) {
+						moduleObject.selectRow(prevRowID, false, false);
+						prevRowID = moduleObject.prevRowID(prevRowID);
+					}
+
+					// select the last row
+					if(prevRowID)
+						moduleObject.selectRow(prevRowID, false, false);
+				}
+			} else {
+				moduleObject.selectRow(rowID);
+			}
+		}
 	}
 }
 
