@@ -194,6 +194,13 @@ timePicker.prototype.render = function()
 }
 
 /**
+ * Event Function which will get fired when user changes any data in time inputfield
+ * this also checks follwoing time formats entered by the user and parse them as required,thus making time edit more User-friendly
+ * for example  0700 => 07:00
+ *			     700 => 07:00
+ *				  07 => 07:00
+ *                 7 => 07:00
+ *               4pm => 04:00 pm 
  * @param {Object} moduleObject
  * @param {HtmlElement} element
  * @param {Object} event
@@ -202,12 +209,53 @@ function eventTimePickerInputChange(moduleObject, element, event)
 {
 	var dtpObj = element.timePickerObject;
 	var oldValue = dtpObj.value;
-	var newValue = element.value;
+	var newValue = element.value.trim();
 	var regTime = /^[0-2]?[0-9][:][0-6]?[0-9]$/; //time
+	// This will seprate the text part from input time format i.e. am/pm.
+	var formatType;
 
 	// If time is in am/pm format then change the regular expression
-	if(_("%H:%M") != "%H:%M")
+	if(_("%H:%M") != "%H:%M"){
 		regTime = /^[0-2]?[0-9][:][0-6]?[0-9]([ ]?[apAP][.]?[Mm][.]?)?$/;
+		formatType = newValue.match(/([apAP][.]?[Mm][.]?)/g);
+		if(formatType)	
+			newValue = newValue.substring(0, newValue.indexOf(formatType)).trim();
+		else
+			newValue = newValue.trim();
+	}
+
+	if(newValue.length < 5 && newValue.match(/\D/g) == null){
+		switch(newValue.length){
+			case 4:
+			var hh = newValue.substring(0,2);
+			var mm = newValue.substring(2,4);
+			newValue = hh +':'+ mm;
+			break;
+			
+			case 3:
+			var hh = newValue.substring(0,1);
+			var mm = newValue.substring(1,3);
+			newValue = hh +':'+ mm;
+			break;
+
+			case 2:
+			var hh = newValue.substring(0,2);
+			newValue = hh +':'+ 00;
+			break;
+
+			case 1:
+			var hh = newValue.substring(0,1);
+			newValue = hh +':'+ 00;
+			break;
+			
+			default:
+			alert(_("You must specify a valid date and/or time. Check your entries in this dialog box to make sure they represent a valid date and/or time.")); 		
+			break;
+		}
+		if(_("%H:%M") != "%H:%M" && formatType)
+			newValue = newValue + " " + formatType;
+	}
+
 	if(!regTime.test(newValue)){
 		if(newValue.length >= 0){
 			alert(_("You must specify a valid date and/or time. Check your entries in this dialog box to make sure they represent a valid date and/or time."));
