@@ -181,9 +181,15 @@ Tree.prototype.node = function(element, node)
 	}
 }
 
-Tree.prototype.addNode = function(node)
+/**
+ * Adds node in the tree view 
+ * @param Object the node which is to be added in the tree
+ * @param boolean states wheather the parentNode should expand the folder while adding the node
+ */
+Tree.prototype.addNode = function(node, expand)
 {
 	var parentNode = this.getNode(node["parentid"]);
+	parentNode["open"] = expand? true : false;
 
 	if(parentNode) {
 		var parentSubNodes = dhtml.getElementById("branch" + parentNode["id"],"div", this.contentElement);
@@ -202,7 +208,7 @@ Tree.prototype.addNode = function(node)
 			var parentElement = dhtml.getElementById(parentNode["id"], "div", this.contentElement);
 
 			if(parentElement) {
-				var nodeSubNodes = dhtml.addElement(false, "span", "branch", "branch" + parentNode["id"]);
+				var nodeSubNodes = dhtml.addElement(false, "div", "branch", "branch" + parentNode["id"]);
 				if(parentNode["open"]) {
 					nodeSubNodes.style.display = "block";
 				}
@@ -226,6 +232,11 @@ Tree.prototype.addNode = function(node)
 			return false;
 		}
 	}
+	//update folderstate of the particular node in hierarchy
+	var element = dhtml.getElementById(parentNode["id"], "div", this.contentElement);
+	var state = parentNode["open"]?this.FOLDER_STATE_OPEN : this.FOLDER_STATE_CLOSED
+	this.sendEvent('statechange', element, state);
+	
 	return true;
 }
 
@@ -251,7 +262,7 @@ Tree.prototype.changeNode = function(node)
 				}
 			}
 			
-			if(node["open"]) {
+			if(node["open"] && node["hasChildNodes"] == "1") {
 				var subnodes = dhtml.getElementById("branch" + node["id"], "div", this.contentElement);
 				if(subnodes) {
 					subnodes.style.display = "block";
@@ -272,6 +283,9 @@ Tree.prototype.changeNode = function(node)
 		}else{
 			dhtml.removeClassName(nodeName, "folder_highlight");
 		}
+	//update folderstate of the particular node in hierarchy
+	var state = node["open"]?this.FOLDER_STATE_OPEN : this.FOLDER_STATE_CLOSED
+	this.sendEvent('statechange', nodeElement, state);
 	}
 }
 
@@ -281,7 +295,7 @@ Tree.prototype.deleteNode = function(nodeID, deleteFromNodeList)
 	dhtml.deleteAllChildren(nodeElement);
 	dhtml.deleteElement(nodeElement);
 
-	branchElement = dhtml.getElementById("branch"+nodeID, "div", this.contentElement);
+	var branchElement = dhtml.getElementById("branch"+nodeID, "div", this.contentElement);
 	dhtml.deleteAllChildren(branchElement);
 	dhtml.deleteElement(branchElement);
 
@@ -320,10 +334,15 @@ Tree.prototype.getChildren = function(node, includeSubNodes)
 	return result;
 }
 
-Tree.prototype.moveNode = function(node)
+/**
+ * Moves a node from one folder to another in tree view 
+ * @param Object the node which is to be added in the tree
+ * @param boolean states wheather the parentNode should expand the folder while adding the node
+ */
+Tree.prototype.moveNode = function(node, expand)
 {
 	this.deleteNode(node["id"]);
-	this.addNode(node);
+	this.addNode(node, expand);
 }
 
 Tree.prototype.getNode = function(nodeID)
@@ -376,11 +395,15 @@ Tree.prototype.toggleFolderState = function(element){
 }
 
 Tree.prototype.hoverOnNode = function(element){
+	var state = this.FOLDER_STATE_OPEN;
+
 	// expand folder only when it is closed.
 	if(element.folderstateNode.className.indexOf("close") > 0){
-		this.toggleBranch(element.id);
+		state = this.toggleBranch(element.id);
 		this.toggleFolderState(element.folderstateNode);
 	}
+
+	this.sendEvent('statechange', element, state);
 }
 
 function eventTreeSwapFolder(moduleObject, element, event)
