@@ -57,4 +57,28 @@
  */
 
 if(!defined('UPLOADED_ATTACHMENT_MAX_LIFETIME')) define('UPLOADED_ATTACHMENT_MAX_LIFETIME', 6*60*60);
+if(!defined('DISABLE_FULL_CONTACTLIST_THRESHOLD')) define('DISABLE_FULL_CONTACTLIST_THRESHOLD', -1);
+if(!defined('ENABLE_PUBLIC_FOLDERS')) define('ENABLE_PUBLIC_FOLDERS', true);
+if(!defined('FILE_UPLOAD_LIMIT')) define('FILE_UPLOAD_LIMIT', 50);
+if(!defined('FILE_QUEUE_LIMIT')) define('FILE_QUEUE_LIMIT', 50);
+
+/**
+ * When set to true this disables the fitlering of the HTML body.
+ */
+if(!defined('DISABLE_HTMLBODY_FILTER')) define('DISABLE_HTMLBODY_FILTER', false);
+if(!defined('DISABLE_DELETE_IN_RESTORE_ITEMS')) define('DISABLE_DELETE_IN_RESTORE_ITEMS', false);
+/**
+ * When set to true this disables the login with the REMOTE_USER set by apache.
+ */
+if(!defined('DISABLE_REMOTE_USER_LOGIN')) define('DISABLE_REMOTE_USER_LOGIN', false);
+
+/**
+ * When set to true, enable the multi-upload feature of the attachment dialog. This has the following caveats:
+ * - In FireFox, you can only upload to HTTPS when the certificate is recognized as an official (not self-signed
+ *   SSL certificate)
+ * - In Linux, some versions of flash do not support this feature and can crash during upload. Updating to the latest
+ *   version of flash should fix the issue.
+ * - In Windows, upload fails if the internet status is 'offline' - open internet explorer to reconnect
+ */
+if(!defined('ENABLE_MULTI_UPLOAD')) define('ENABLE_MULTI_UPLOAD', false);
 ?>
\ No newline at end of file
