@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -323,7 +325,9 @@ class Conversion {
 				$properties[$name] = Conversion::mapProp2XML($property, $message_properties[$property]);
 
 			} else if($name == "body") {
-				$properties[$name] = windows1252_to_utf8($message_properties[$property]);
+				if(isset($message_properties[$property])) {
+					$properties[$name] = windows1252_to_utf8($message_properties[$property]);
+				}
 			}
 		}
 
@@ -642,7 +646,11 @@ class Conversion {
 				}
 				$action["adrlist"] = $adrlist;
 			}
-			
+
+			if (isset($xmlitem["proptag"])){
+				$action["proptag"][Conversion::propTagFromXML($xmlitem["proptag"])] = null;
+			}
+
 			$binaryentries = array("storeentryid", "folderentryid", "replyentryid", "replyguid");
 			foreach($binaryentries as $entry){
 				if (isset($xmlitem[$entry])){
@@ -707,6 +715,11 @@ class Conversion {
 						break;
 	
 					case "proptag":
+						if(is_array($val) && count($val) > 0) {
+							// assume there will be only one proptag
+							$xml_action["proptag"] = Conversion::getPropertyName(key($val));
+						}
+						break;
 					case "code":
 					case "dam":
 						// currently not used
@@ -862,9 +875,9 @@ class Conversion {
 			$tag = $xmlprop;
 		}
 		if (defined($tag)) {
-			$tag = constant($tag);
+			$tag = (int) constant($tag);
 		}else{
-			$tag = hexdec($tag);
+			$tag = (int) hexdec($tag);
 		}
 		return $tag;
 	}
@@ -959,6 +972,178 @@ class Conversion {
 		
 		return implode(" | ",$levels);
 	}
+
+	/******** JSON related functions **********/
+
+	/**
+	 * Convert an JSON restriction structure into a MAPI SRestriction array
+	 *
+	 * @access		private
+	 * @param		array		$json		The parsed JSON array data
+	 * @return		array					MAPI restriction array compatible with MAPI extension restriction format
+	 */
+	function json2restriction($json)
+	{
+		if (!is_array($json)){
+			return $json;
+		}
+
+		switch($json[0]){
+			case RES_AND:
+			case RES_OR:
+				if(isset($json[1][0]) && is_array($json[1][0])) {
+					foreach(array_keys($json[1]) as $key) {
+						$json[1][$key] = Conversion::json2restriction($json[1][$key]);
+					}
+				} else if(isset($json[1]) && $json[1]) {
+					$json[1] = Conversion::json2restriction($json[1]);
+				}
+				break;
+			case RES_NOT:
+				$json[1][0] = Conversion::json2restriction($json[1][0]);
+				break;
+			case RES_COMMENT:
+				foreach(array_keys($json[1][PROPS]) as $key){
+					$prop = &$json[1][PROPS][$key];		// PHP 4 does not support pass by reference in foreach loop
+					$propTag = $prop[ULPROPTAG];
+
+					if(!isset($prop[VALUE][$propTag])) {
+						/**
+						 * multi valued properties uses single valued counterpart in
+						 * VALUES part, so use it get values
+						 */
+						$propTagForValue = Conversion::convertToSingleValuedProperty($propTag);
+						$propValue = $prop[VALUE][$propTagForValue];
+					} else {
+						$propTagForValue = $propTag;
+						$propValue = $prop[VALUE][$propTag];
+					}
+
+					if(isset($json[1][VALUE]["type"]) && $json[1][VALUE]["type"] == "binary") {
+						// convert hex value to binary
+						$propValue = hex2bin($propValue);
+					} else if(is_string($propValue)) {
+						// convert utf-8 to windows-1252
+						$propValue = u2w($propValue);
+					}
+
+					$propTag = Conversion::propTagFromJSON($propTag);
+					$propTagForValue = Conversion::propTagFromJSON($propTagForValue);
+
+					// remove non restriction data
+					unset($prop[VALUE]);
+
+					$prop[ULPROPTAG] = $propTag;
+					$prop[VALUE] = array();
+					$prop[VALUE][$propTagForValue] = $propValue;
+				}
+				$json[1][RESTRICTION] = Conversion::json2restriction($json[1][RESTRICTION]);
+				break;
+			case RES_PROPERTY:
+			case RES_CONTENT:
+				$propTag = $json[1][ULPROPTAG];
+
+				if(!isset($json[1][VALUE][$propTag])) {
+					/**
+					 * multi valued properties uses single valued counterpart in
+					 * VALUES part, so use it to get values
+					 */
+					$propTagForValue = Conversion::convertToSingleValuedProperty($propTag);
+					$propValue = $json[1][VALUE][$propTagForValue];
+				} else {
+					$propTagForValue = $propTag;
+					$propValue = $json[1][VALUE][$propTag];
+				}
+
+				if(isset($json[1][VALUE]["type"]) && $json[1][VALUE]["type"] == "binary") {
+					// convert hex value to binary
+					$propValue = hex2bin($propValue);
+				} else if(is_string($propValue)) {
+					// convert utf-8 to windows-1252
+					$propValue = u2w($propValue);
+				}
+
+				$propTag = Conversion::propTagFromJSON($propTag);
+				$propTagForValue = Conversion::propTagFromJSON($propTagForValue);
+
+				// remove non restriction data
+				unset($json[1][VALUE]);
+
+				$json[1][ULPROPTAG] = $propTag;
+				$json[1][VALUE] = array();
+				$json[1][VALUE][$propTagForValue] = $propValue;
+				break;
+			case RES_COMPAREPROPS:
+				$json[1][ULPROPTAG1] = Conversion::propTagFromJSON($json[1][ULPROPTAG1]);
+				$json[1][ULPROPTAG2] = Conversion::propTagFromJSON($json[1][ULPROPTAG2]);
+				break;
+			case RES_BITMASK:
+			case RES_SIZE:
+			case RES_EXIST:
+				$json[1][ULPROPTAG] = Conversion::propTagFromJSON($json[1][ULPROPTAG]);
+				break;
+			case RES_SUBRESTRICTION:
+				$json[1][ULPROPTAG] = Conversion::propTagFromJSON($json[1][ULPROPTAG]);
+				$json[1][RESTRICTION] = Conversion::json2restriction($json[1][RESTRICTION]);
+				break;
+		}
+
+		return $json;
+	}
+
+	/**
+	* Retrieves the property tag from a JSON array structure
+	*
+	* The property tag can be located in various places and this function 
+	* searches for the location of the property tag and returns that value
+	*
+	* @param		array		$propTag		The JSON array structure
+	* @return		int							The MAPI property tag (eg 0x0037001e)
+	*/
+	function propTagFromJSON($propTag)
+	{
+		if(defined($propTag)) {
+			$propTag = constant($propTag);
+		} else {
+			$propTag = hexdec($propTag);
+		}
+
+		if($propTag >= PHP_INT_MAX) {
+			/**
+			 * arrays in php can have only string or integer index and 
+			 * integer value can not be greater than PHP_INT_MAX value
+			 * so if we are crossing integer boundary when converting
+			 * property tag to integer value then we are manually
+			 * typecasting it to integer so we can use it in arrays
+			 */
+			$propTag = (int) $propTag;
+		}
+
+		return $propTag;
+	}
+
+	/**
+	* Retrieves singlevalued counterpart of a multivalued property
+	*
+	* Multivalued properties has different property tags in VALUES part
+	* so we need to find that singlevalued property tag
+	*
+	* here we can't do bitwise operation because property tags are passed
+	* as a string from client ($propTag ^ MV_FLAG)
+	*
+	* @param		String		$propTag		The multivalued property tag in string
+	* @return		String						The singlevalued property tag
+	*/
+	function convertToSingleValuedProperty($propTag)
+	{
+		// get property type from property tag
+		$propType = substr($propTag, 6);
+		$propId = substr($propTag, 0, 6);
+
+		$propTag = $propId . "0" . substr($propType, 1);
+
+		return $propTag;
+	}
 }
 
 /**
