@@ -198,6 +198,7 @@
 			$properties["last_modification_time"] = PR_LAST_MODIFICATION_TIME;
 			$properties["creation_time"] = PR_CREATION_TIME;
 			$properties["remindertime"] = "PT_SYSTIME:PSETID_Common:0x8502";
+			$properties["requestsent"] = "PT_BOOLEAN:PSETID_Appointment:0x8229";
 			$properties["body"] = PR_BODY;
 			// Conflict properties
 			$properties["conflictitems"] = PR_CONFLICT_ITEMS;
@@ -212,7 +213,7 @@
 
 			$properties["deleted_on"] = PR_DELETED_ON;
 			$properties["updatecounter"] = "PT_LONG:PSETID_Appointment:0x8201";
-
+			$properties["recur_type"] = "PT_LONG:PSETID_Appointment:0x8231";
 			
 			return getPropIdsFromStrings($this->store, $properties);
 		}
@@ -348,6 +349,9 @@
 			$properties["postal_code"] = PR_POSTAL_CODE;
 			$properties["state"] = PR_STATE_OR_PROVINCE;
 			$properties["street"] = PR_STREET_ADDRESS;
+			// Special Date such as birthday n anniversary appoitment's entryid is store
+			$properties["birthday_eventid"] = "PT_BINARY:PSETID_Address:0x804D";
+			$properties["anniversary_eventid"] = "PT_BINARY:PSETID_Address:0x804E";
 
 			return getPropIdsFromStrings($this->store, $properties);
 		}
@@ -455,7 +459,7 @@
 			$properties["office_phone"] = PR_OFFICE_TELEPHONE_NUMBER;
 			$properties["location"] = PR_OFFICE_LOCATION;
 			$properties["fax"] = PR_PRIMARY_FAX_NUMBER;
-			$properties["department"] = PR_ORGANIZATIONAL_ID_NUMBER;
+			$properties["department"] = PR_DEPARTMENT_NAME;
 
 			return getPropIdsFromStrings($this->store, $properties);
 		}
@@ -478,6 +482,7 @@
 			$properties["display_cc"] = PR_DISPLAY_CC;
 			$properties["display_bcc"] = PR_DISPLAY_BCC;
 			$properties["subject"] = PR_SUBJECT;
+			$properties["normalized_subject"] = PR_NORMALIZED_SUBJECT;
 			$properties["importance"] = PR_IMPORTANCE;
 			$properties["sent_representing_name"] = PR_SENT_REPRESENTING_NAME;
 			$properties["sent_representing_email_address"] = PR_SENT_REPRESENTING_EMAIL_ADDRESS;
@@ -517,6 +522,7 @@
 			$properties["duedate"] = "PT_SYSTIME:PSETID_Appointment:0x820e";
 			$properties["location"] = "PT_STRING8:PSETID_Appointment:0x8208";
 			$properties["recurring_pattern"] = "PT_STRING8:PSETID_Appointment:0x8232";
+			$properties["recurring"] = "PT_BOOLEAN:PSETID_Appointment:0x8223";
 			// Conflict properties
 			$properties["conflictitems"] = PR_CONFLICT_ITEMS;
 			
@@ -530,9 +536,14 @@
 			$properties["updatecounter"] = "PT_LONG:PSETID_Appointment:0x8201";
 			$properties["hideattachments"] = "PT_BOOLEAN:PSETID_Common:0x8514";
 
+			// meeting request properties, which will give the response status
+			$properties["responsestatus"] = "PT_LONG:PSETID_Appointment:0x8218";
+
 			// meeting request properties, which will be set when mr is auto forwarded using delegate meeting request rule
 			$properties["rcvd_representing_name"] = PR_RCVD_REPRESENTING_NAME;
 			$properties["delegated_by_rule"] = PR_DELEGATED_BY_RULE;
+			$properties["goid"] = "PT_BINARY:PSETID_Meeting:0x3";
+			$properties["goid2"] = "PT_BINARY:PSETID_Meeting:0x23";
 
 			return getPropIdsFromStrings($this->store, $properties);
 		}
@@ -578,6 +589,7 @@
 			$properties = array();
 			$properties["entryid"] = PR_ENTRYID;
 			$properties["parent_entryid"] = PR_PARENT_ENTRYID;
+			$properties["store_entryid"] = PR_STORE_ENTRYID;
 			$properties["icon_index"] = PR_ICON_INDEX;
 			$properties["message_class"] = PR_MESSAGE_CLASS;
 			$properties["message_flags"] = PR_MESSAGE_FLAGS;
@@ -608,6 +620,8 @@
 			$properties["commonend"] = "PT_SYSTIME:PSETID_Common:0x8517";
 			$properties["commonassign"] = "PT_LONG:PSETID_Common:0x8518";
 			$properties["flagdueby"] = "PT_SYSTIME:PSETID_Common:0x8560";
+			$properties["recurring"] = "PT_BOOLEAN:PSETID_Task:0x8126";
+			$properties["dead_occurrence"] = "PT_BOOLEAN:PSETID_Task:0x8109";
 			// Conflict properties
 			$properties["conflictitems"] = PR_CONFLICT_ITEMS;
 
@@ -623,7 +637,25 @@
 			$properties["sender_addrtype"] = PR_SENDER_ADDRTYPE;
 			$properties["sender_entryid"] = PR_SENDER_ENTRYID;
 			$properties["sender_search_key"] = PR_SENDER_SEARCH_KEY;
-			
+
+			$properties["updatecount"] = "PT_LONG:PSETID_Task:0x8112";
+			$properties["taskstate"] = "PT_LONG:PSETID_Task:0x8113";
+			$properties["taskmultrecips"] = "PT_LONG:PSETID_Task:0x8120";
+			$properties["taskupdates"] = "PT_BOOLEAN:PSETID_Task:0x811b";
+			$properties["tasksoc"] = "PT_BOOLEAN:PSETID_Task:0x8119";
+			$properties["taskhistory"] = "PT_LONG:PSETID_Task:0x811a";
+			$properties["taskmode"] = "PT_LONG:PSETID_Common:0x8518";
+			$properties["taskglobalobjid"] = "PT_BINARY:PSETID_Common:0x8519";
+			$properties["assignedtime"] = "PT_SYSTIME:PSETID_Task:0x8115";
+			$properties["taskfcreator"] = "PT_BOOLEAN:PSETID_Task:0x0x811e";
+			$properties["tasklastuser"] = "PT_STRING8:PSETID_Task:0x8122";
+			$properties["tasklastdelegate"] = "PT_STRING8:PSETID_Task:0x8125";
+			$properties["taskaccepted"] = "PT_BOOLEAN:PSETID_Task:0x8108";
+			$properties["ownership"] = "PT_LONG:PSETID_Task:0x8129";
+			$properties["delegationstate"] = "PT_LONG:PSETID_Task:0x812a";
+
+			$properties["display_cc"] = PR_DISPLAY_CC;
+
 			return getPropIdsFromStrings($this->store, $properties);
 		}
 
@@ -694,6 +726,7 @@
 
 			$properties["task_duedate"] = "PT_SYSTIME:PSETID_Task:0x8105";				// PidLidTaskDueDate
 			$properties["task_resetreminder"] = "PT_BOOLEAN:PSETID_Task:0x8107";		// PidLidTaskResetReminder
+			$properties["task_recurring"] = "PT_BOOLEAN:PSETID_Task:0x8126";			// PidLidTaskFRecurring
 
 			$properties["appointment_recurring"] = "PT_BOOLEAN:PSETID_Appointment:0x8223";			// PidLidRecurring
 			$properties["appointment_startdate"] = "PT_SYSTIME:PSETID_Appointment:0x820d";
@@ -732,5 +765,39 @@
 			
 			return $properties;
 		}
+
+		/**
+		 * Returns the properties for archived items
+		 * @return array properties for archived items
+		 */
+		function getArchiverStubProperties()
+		{
+			$this->Init();
+			
+			// Z-archiver properties
+			$properties["store_entryids"] = "PT_MV_BINARY:Z_ARCHIVER:store-entryids";
+			$properties["item_entryids"] = "PT_MV_BINARY:Z_ARCHIVER:item-entryids";
+			$properties["stubbed"] = "PT_BOOLEAN:Z_ARCHIVER:stubbed";
+			$properties["original_sourcekey"] = "PT_BINARY:Z_ARCHIVER:original-sourcekey";
+
+			return getPropIdsFromStrings($this->store, $properties);
+		}
+
+		/**
+		 * Returns the properties that have to be restored when destubbing the 
+		 * a message that is archived.
+		 * @return array properties for archived items
+		 */
+		function getArchiverRestoreProperties()
+		{
+			$this->Init();
+			
+			// These properties will be copied to the stub message
+			$properties["rtf_compressed"] = PR_RTF_COMPRESSED;
+			$properties["message_class"] = PR_MESSAGE_CLASS;
+			$properties["icon_index"] = PR_ICON_INDEX;
+
+			return getPropIdsFromStrings($this->store, $properties);
+		}
 }
 ?>
