@@ -274,6 +274,7 @@ class TableColumns {
 		$this->addColumn($tableColumns, "percent_complete", false, 7, _("% Completed"), _("Sort On Percent Completed"), 100);
 		$this->addColumn($tableColumns, "hidden_column", true, 8);
 		$this->addColumn($tableColumns, "startdate", true, 9, _("Start Date"), _("Sort On Start Date"));
+		$this->addColumn($tableColumns, "recurring", false, 10, _("Recurring"), _("Sort on Recurring"));
 
 		return $tableColumns;
 	}
@@ -287,7 +288,7 @@ class TableColumns {
 		$tableColumns = array();
 
 		$this->addInputColumn($tableColumns, "icon", "null", true, "", 0, "icon_index",false,  23);
-		$this->addInputColumn($tableColumns, "status", "checkbox", true, "", 1, "complete",false,  23);
+		$this->addInputColumn($tableColumns, "complete", "checkbox", true, "", 1, "complete",false,  23);
 		$this->addInputColumn($tableColumns, "importance", "importance", true, "", 2, "importance",false);
 		$this->addInputColumn($tableColumns, "subject", "textbox", true, "", 3, "subject",_("Click here to add a new item"),PERCENTAGE);
 		$this->addInputColumn($tableColumns, "text_duedate", "datepicker", true, "readonly", 4,"duedate",false,150);
@@ -296,6 +297,7 @@ class TableColumns {
 		$this->addInputColumn($tableColumns, "text_percent_complete", "percent", false, "readonly", 7,"percent_complete",_("0%"), 100);
 		$this->addInputColumn($tableColumns, "hiddencolumn", "hidden", false, "", 8,"hidden_column");
 		$this->addInputColumn($tableColumns, "text_startdate", "datepicker", true, "readonly", 9, "startdate", false, 150);
+		$this->addInputColumn($tableColumns, "recurring", "null", false, "", 10, "recurring", false, 23);
 
 		/** 
 		 * structure of $columnData must be
