@@ -239,22 +239,22 @@
 				if(mapi_last_hresult() == NOERROR) {
 					$contentsTable = mapi_folder_getcontentstable($folder, MAPI_DEFERRED_ERRORS);
 
-					// apply restriction & sorting
-					mapi_table_restrict($contentsTable, $restriction, TBL_BATCH);
-					mapi_table_sort($contentsTable, $this->sort, TBL_BATCH);
-
 					/**
 					 * Check whether we have to disable the full contactlist listing using the config: 
 					 * DISABLE_FULL_CONTACTLIST_THRESHOLD. we are checking here if in case 
 					 * mapi_table_getrowcount returns number greater then this config value then we
 					 * don't have to do any processing, so it will lessen processing time
 					 */
-					if(defined('DISABLE_FULL_CONTACTLIST_THRESHOLD') && DISABLE_FULL_CONTACTLIST_THRESHOLD != -1 && !$searchPerformed) {
+					if(DISABLE_FULL_CONTACTLIST_THRESHOLD != -1 && !$searchPerformed) {
 						if(DISABLE_FULL_CONTACTLIST_THRESHOLD >= 0 && mapi_table_getrowcount($contentsTable) > DISABLE_FULL_CONTACTLIST_THRESHOLD) {
 							$disableFullContactlist = true;
 						}
 					}
 
+					// apply restriction & sorting
+					mapi_table_restrict($contentsTable, $restriction, TBL_BATCH);
+					mapi_table_sort($contentsTable, $this->sort, TBL_BATCH);
+
 					if(!$disableFullContactlist) {
 						// Get all rows
 						/**
@@ -317,7 +317,7 @@
 						 * will contain. Also note that when the user conducts a search the list should be displayed 
 						 * regardless of the number of items returned.
 						 */
-						if(defined('DISABLE_FULL_CONTACTLIST_THRESHOLD') && DISABLE_FULL_CONTACTLIST_THRESHOLD != -1 && !$searchPerformed){
+						if(DISABLE_FULL_CONTACTLIST_THRESHOLD != -1 && !$searchPerformed){
 							if(DISABLE_FULL_CONTACTLIST_THRESHOLD >= 0 && count($items) > DISABLE_FULL_CONTACTLIST_THRESHOLD){
 								$disableFullContactlist = true;
 							}
@@ -523,6 +523,11 @@
 							$item["fax"] = isset($user_data[$this->ab_properties["fax"]]) ? $user_data[$this->ab_properties["fax"]] : "";
 							$item["addrtype"] = "SMTP";
 							$item["search_key"] = bin2hex($user_data[$this->ab_properties["search_key"]]);
+
+							// Contacts from the GAL have email-address saved in smtp_address property.
+							if($item["email_address"].trim() == "") {
+								$item["email_address"] = $item["smtp_address"];
+							}
                             break;
                     }
 
