@@ -83,6 +83,7 @@
 				$exceptionatt = $recur->getExceptionAttachment($basedate);
 
 				if($exceptionatt) {
+					$exceptionattProps = mapi_getprops($exceptionatt, array(PR_ATTACH_NUM));
 					// Existing exception (open existing item, which includes basedate)
 					$exception = mapi_attach_openobj($exceptionatt, 0);
 				
@@ -105,7 +106,9 @@
             	    $data["item"]["entryid"] = bin2hex($entryid);
                     
                     // Make sure we are using the passed basedate and not something wrong in the opened item
-                    $data["item"]["basedate"] = $basedate;
+					$data["item"]["basedate"]["attributes"]["unixtime"] = $basedate;
+					$data["item"]["basedate"]["_content"] = strftime("%a %d-%m-%Y %H:%M", $basedate);
+					$data["item"]["occurrAttachNum"] = $exceptionattProps[PR_ATTACH_NUM];
                      
             	    array_push($this->responseData["action"], $data);
 					$GLOBALS["bus"]->addData($this->responseData);
@@ -117,11 +120,11 @@
 				$data["attributes"] = array("type" => "item");
 				$data["item"] = $GLOBALS["operations"]->getMessageProps($store, $message, $this->properties, true);
 				$data["item"]["basedate"]["attributes"]["unixtime"] = $basedate;
-				$data["item"]["basedate"]["_content"] = strftime("%a %d-%m-%Y %H:%M", $basedate);
+				$data["item"]["basedate"]["_content"] = $basedate;
 				$data["item"]["startdate"]["attributes"]["unixtime"] = $recur->getOccurrenceStart($basedate);
-				$data["item"]["startdate"]["_content"] = strftime("%a %d-%m-%Y %H:%M", $recur->getOccurrenceStart($basedate));
+				$data["item"]["startdate"]["_content"] = $recur->getOccurrenceStart($basedate);
 				$data["item"]["duedate"]["attributes"]["unixtime"] = $recur->getOccurrenceEnd($basedate);
-				$data["item"]["duedate"]["_content"] = strftime("%a %d-%m-%Y %H:%M", $recur->getOccurrenceEnd($basedate));
+				$data["item"]["duedate"]["_content"] = $recur->getOccurrenceEnd($basedate);
 				$data["item"]["commonstart"] = $data["item"]["startdate"];
 				$data["item"]["commonend"] = $data["item"]["duedate"];
 				unset($data["item"]["reminder_time"]);
