@@ -108,17 +108,41 @@
 		function messageList($store, $entryid, $action)
 		{
 			$result = false;
-			
+
+			// open localfreebusy folder for delegate permissions
+			$rootFolder = mapi_msgstore_openentry($store, null);
+			$rootFolderProps = mapi_getprops($rootFolder, array(PR_FREEBUSY_ENTRYIDS));
+			/**
+			 *	PR_FREEBUSY_ENTRYIDS contains 4 entryids
+			 *	PR_FREEBUSY_ENTRYIDS[0] gives associated freebusy folder in calendar
+			 *	PR_FREEBUSY_ENTRYIDS[1] Localfreebusy (used for delegate properties)
+			 *	PR_FREEBUSY_ENTRYIDS[2] global Freebusydata in public store
+			 *	PR_FREEBUSY_ENTRYIDS[3] Freebusydata in IPM_SUBTREE
+			 */
+			// get localfreebusy folder
+			$this->localFreeBusyFolder = mapi_msgstore_openentry($store, $rootFolderProps[PR_FREEBUSY_ENTRYIDS][1]);
+			if(mapi_last_hresult() !== NOERROR) {
+				$this->localFreeBusyFolder = false;
+			}
+
+			$this->storeProviderGuid = mapi_getprops($store, array(PR_MDB_PROVIDER));
+
 			if($store && $entryid) {
 				$type = false;
 				
 				if(isset($action["restriction"])) {
 					if(isset($action["restriction"]["startdate"])) {
 						$this->startdate = (int) $action["restriction"]["startdate"];
+					} else {
+						 // If start date is not passed then set it as false, otherwise it will use previously saved start date.
+						$this->startdate = false;
 					}
 					
 					if(isset($action["restriction"]["duedate"])) {
 						$this->enddate = (int) $action["restriction"]["duedate"];
+					} else {
+						// If end date is not passed then set it as false, otherwise it will use previously saved end date.
+						$this->enddate = false;
 					}
 				}
 				
@@ -190,23 +214,6 @@
 			$folder = mapi_msgstore_openentry($store, $entryid);
 			$table = mapi_folder_getcontentstable($folder);
 			$calendaritems = mapi_table_queryallrows($table, $this->properties, $restriction);
-			$storeProviderGuid = mapi_getprops($store, array(PR_MDB_PROVIDER));
-			
-			// open localfreebusy folder for delegate permissions
-			$rootFolder = mapi_msgstore_openentry($store, null);
-			$rootFolderProps = mapi_getprops($rootFolder, array(PR_FREEBUSY_ENTRYIDS));
-			/**
-			 *	PR_FREEBUSY_ENTRYIDS contains 4 entryids
-			 *	PR_FREEBUSY_ENTRYIDS[0] gives associated freebusy folder in calendar
-			 *	PR_FREEBUSY_ENTRYIDS[1] Localfreebusy (used for delegate properties)
-			 *	PR_FREEBUSY_ENTRYIDS[2] global Freebusydata in public store
-			 *	PR_FREEBUSY_ENTRYIDS[3] Freebusydata in IPM_SUBTREE
-			 */
-			// get localfreebusy folder
-			$localFreeBusyFolder = mapi_msgstore_openentry($store, $rootFolderProps[PR_FREEBUSY_ENTRYIDS][1]);
-			if(mapi_last_hresult() !== NOERROR) {
-				$localFreeBusyFolder = false;
-			}
 
 			foreach($calendaritems as $calendaritem)
 			{
@@ -228,12 +235,12 @@
 							$item["basedate"]["attributes"]["unixtime"] = $recuritem["basedate"];
 							$item["basedate"]["_content"] = strftime("%a %d-%m-%Y %H:%M", $recuritem["basedate"]);
 						}
-						$item = $this->disablePrivateItem($localFreeBusyFolder, $storeProviderGuid[PR_MDB_PROVIDER], $item);
+						$item = $this->disablePrivateItem($item);
 						array_push($items, $item);
 					}
 				} else {
 					$item = Conversion::mapMAPI2XML($this->properties, $calendaritem);
-					$item = $this->disablePrivateItem($localFreeBusyFolder, $storeProviderGuid[PR_MDB_PROVIDER], $item);
+					$item = $this->disablePrivateItem($item);
 					array_push($items,$item);
 				}
 
@@ -246,25 +253,23 @@
 		/**
 		 * Function to remove some properties when the item is private
 		 * and it will also check for delegate permissions
-		 * @param object $localFreeBusyFolder localfreebusy folder
-		 * @param object $storeproviderguid type of store
 		 * @param object $item item properties
 		 * @return object $item item with modified properties
 		 */
-		function disablePrivateItem($localFreeBusyFolder, $storeProviderGuid, $item)
+		function disablePrivateItem($item)
 		{
 			if(isset($item["private"]) && $item["private"] == true) {
 				// check for delegate permissions
-				if($storeProviderGuid == ZARAFA_STORE_DELEGATE_GUID) {
+				if($this->storeProviderGuid[PR_MDB_PROVIDER] == ZARAFA_STORE_DELEGATE_GUID) {
 					$hideItemData = false;
 
-					if($localFreeBusyFolder === false) {
+					if($this->localFreeBusyFolder === false) {
 						$hideItemData = true;
 					}
 
 					// find delegate properties
-					if($localFreeBusyFolder !== false) {
-						$localFreeBusyFolderProps = mapi_getprops($localFreeBusyFolder, array(PR_SCHDINFO_DELEGATE_ENTRYIDS, PR_DELEGATES_SEE_PRIVATE));
+					if($this->localFreeBusyFolder !== false) {
+						$localFreeBusyFolderProps = mapi_getprops($this->localFreeBusyFolder, array(PR_SCHDINFO_DELEGATE_ENTRYIDS, PR_DELEGATES_SEE_PRIVATE));
 						if(mapi_last_hresult() !== NOERROR) {
 							// no delegate properties exists
 							$hideItemData = true;
@@ -320,8 +325,19 @@
 				}
  				array_push($this->responseData["action"],$data);
  				$GLOBALS["bus"]->addData($this->responseData);
- 			}
-			// Send notifications that this object has changed					
+ 			} else if (isset($messageProps['error'])) {
+				$data = array();
+				$data["attributes"] = array("type" => "failed");
+				
+				$data["action_type"] = "bookresource";
+				$data["errorcode"] = $messageProps['error'];
+				$data["displayname"] = $messageProps['displayname'];
+
+				array_push($this->responseData["action"], $data);
+				$GLOBALS["bus"]->addData($this->responseData);
+			}
+
+			// Send notifications that this object has changed
 			if($messageProps){
 				$GLOBALS["bus"]->notify($this->entryid, TABLE_SAVE, $messageProps);
 				$result = true;
