@@ -254,14 +254,15 @@
 						// Update the client with the (new) entryid and parententryid to allow the draft message to be removed when submitting.						
 						// Retrieve entryid and parententryid of new mail.
 						$props = array();
-						$props = mapi_getprops($result, array(PR_ENTRYID, PR_PARENT_ENTRYID));
+						$props = mapi_getprops($result, array(PR_ENTRYID, PR_PARENT_ENTRYID, PR_STORE_ENTRYID));
 						// Send data to client
 						$data = array();
 						$data["attributes"] = array("type" => "update");
 						$data["item"] = array();
 						$data["item"]["entryid"] = bin2hex($props[PR_ENTRYID]);
 						$data["item"]["parententryid"] = bin2hex($props[PR_PARENT_ENTRYID]);
-
+						$data["item"]["storeid"] = bin2hex($props[PR_STORE_ENTRYID]);
+						
 						//send info to update attachments
 						/** 
 						 * We have to reopen the message because the PR_ATTACH_SIZE is calculated 
@@ -320,7 +321,7 @@
 					}
 					
 					// Reply/Reply All/Forward Actions (ICON_INDEX & LAST_VERB_EXECUTED)
-					if(isset($action["message_action"]) && isset($action["message_action"]["action_type"])) {
+					if(isset($action["message_action"]) && isset($action["message_action"]["action_type"]) && $action["message_action"]["action_type"] != "forwardasattachment") {
 						$props = array();
 						$props[$this->properties["entryid"]] = hex2bin($action["message_action"]["entryid"]);
 
