@@ -420,7 +420,7 @@
 				}
 				mapi_savechanges($folder);
 
-				if ($folderName == 'calendar' || $folderName == 'inbox'){
+				if ($folderName == 'calendar'){
 					if(isset($freebusy)){
 						// set permissions on free/busy message
 						foreach($acls as $acl) {
