@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -66,12 +68,8 @@
 		{
 			$this->properties = $GLOBALS["properties"]->getDistListProperties();
 
-			// Default available columns/fields for distribution list module
-			$this->tablecolumns = array();
-			$this->addColumn($this->tablecolumns, "icon_index", true, 0, _("Icon"), _("Icon"));
-			$this->addColumn($this->tablecolumns, "name", true, 1, _("Full Name"), _("Name"), PERCENTAGE);
-			$this->addColumn($this->tablecolumns, "address", true, 2, _("E-mail"), _("E-mail"), 400);
-			
+			$this->tablecolumns = $GLOBALS["TableColumns"]->getDistListTableColumns();
+
 			$this->plaintext = true;
 		
 			parent::ListModule($id, $data, array());
@@ -210,7 +208,8 @@
 					$data["item"] = $items;
 
 				// List columns visible
-				$this->parseVisibleColumns($action);
+				$GLOBALS["TableColumns"]->parseVisibleColumns($this->tablecolumns, $action);
+
 				// Add columns to data
 				$data["column"] = $this->tablecolumns;
 
