@@ -189,13 +189,14 @@
 							$store = $GLOBALS["mapisession"]->addUserStore($action["username"]);
 							$openingItem = ($action["foldertype"] == "all") ? _("store") : _("folder");
 							if ($store){
-								$data = $GLOBALS["operations"]->getHierarchyList($this->columns, HIERARCHY_GET_ONE, $store, $action["subfolders"]);
+								$data = $GLOBALS["operations"]->getHierarchyList($this->columns, HIERARCHY_GET_ONE, $store);
 								if(!mapi_is_error(mapi_last_hresult()) && (is_array($data["store"]) && count($data["store"]) > 0)) {
 									array_push($this->responseData["action"], $data);
 									$GLOBALS["bus"]->addData($this->responseData);	
 									$result = true;
 								} else {
 									// access denied
+									$data = array();
 									$data["attributes"] = array("type" => "error");
 									$data["error"] = array();
 									$data["error"]["hresult"] = mapi_last_hresult();
@@ -479,6 +480,29 @@
 						
 						if($folder) {
 							$folderProps = mapi_folder_getprops($folder, $this->columns);
+
+							// If this folder belongs to Favorites folder,then change PARENT_ENTRYID manually.
+							if (substr(bin2hex($folderProps[PR_ENTRYID]), 0, 8) == "00000001") {
+								$storeProps = mapi_getprops($store, array(PR_IPM_FAVORITES_ENTRYID));
+
+								if (isset($storeProps[PR_IPM_FAVORITES_ENTRYID])) {
+									$favFolder = mapi_msgstore_openentry($store, $storeProps[PR_IPM_FAVORITES_ENTRYID]);
+									$favHierarchyTable = mapi_folder_gethierarchytable($favFolder);
+
+									$folders = mapi_table_queryallrows($favHierarchyTable, array(PR_DISPLAY_NAME), array(RES_PROPERTY,
+																											array(  RELOP => RELOP_EQ,
+																													ULPROPTAG => PR_ENTRYID,
+																													VALUE => array (PR_ENTRYID => $folderProps[PR_ENTRYID])
+																											)
+																										)
+																	);
+
+									// Update folderProps to properties of folder which is under 'FAVORITES'
+									$folderProps[PR_DISPLAY_NAME] = $folders[0][PR_DISPLAY_NAME];
+									$folderProps[PR_PARENT_ENTRYID] = $storeProps[PR_IPM_FAVORITES_ENTRYID];
+								}
+							}
+							
 							$data["folder"] = $GLOBALS["operations"]->setFolder($folderProps);
 						}
 					}
