@@ -101,10 +101,29 @@
 					switch($action["attributes"]["type"])
 					{
 						case "open":
+							// Before opening restore the archived message if it is a stub
+							$this->destub($store, bin2hex($parententryid), $entryid);
 							$result = $this->open($store, $entryid, $action);
 							break;
 						case "save":
-							$result = $this->save($store, $parententryid, $action);
+							$accessToFolder = true;
+							/**
+							 * Check for the folder access.
+							 * If store and parententryid is not passed then it is
+							 * users default messagestore and user has permission on it.
+							 * For other folders check permissions on folder.
+							 */
+							if($store && $parententryid)
+								$accessToFolder = $GLOBALS["operations"]->checkFolderAccess($store, $parententryid);
+
+							if($accessToFolder) {
+								// If folder is accessible then save the message.
+								$result = $this->save($store, $parententryid, $action);
+							} else {
+								// If folder is not accessible then show error message.
+								$errorMessage = _("You have insufficient privileges to save items in this folder") . ".";
+								$this->sendFeedback(false, $errorMessage);
+							}
 							break;
 						case "delete":
 							$result = $this->delete($store, $parententryid, $entryid, $action);
@@ -130,25 +149,24 @@
 							$originalMessageProps = mapi_getprops($message, array(PR_MESSAGE_CLASS));
 							$req = new Meetingrequest($store, $message, $GLOBALS["mapisession"]->getSession());
 
-							if($action["attributes"]["type"] == 'acceptMeetingRequest') {      				
+							// sendResponse flag if it is set then send the mail response to the organzer.
+							$sendResponse = true;
+							if(isset($action["noResponse"]) && $action["noResponse"] == "true") {
+								$sendResponse = false;
+							}
+							$body = isset($action["body"]) ? $action["body"] : false;
+
+							if($action["attributes"]["type"] == 'acceptMeetingRequest') {
 								$tentative = isset($action["tentative"]) ? $action["tentative"] : false;
 								$newProposedStartTime = isset($action["proposed_starttime"]) ? $action["proposed_starttime"] : false;
 								$newProposedEndTime = isset($action["proposed_endtime"]) ? $action["proposed_endtime"] : false;
-								$body = isset($action["body"]) ? $action["body"] : false;
 
-								// sendResponse flag if it is set then send the mail response to the organzer.
-								$sendResponse = true;
-								if(isset($action["noResponse"]) && $action["noResponse"] == "true") {
-									$sendResponse = false;
-								}
+								// We are accepting MR from preview-read-mail so set delete the actual mail flag.
+								$delete = (stristr($originalMessageProps[PR_MESSAGE_CLASS], 'IPM.Schedule.Meeting') !== false) ? true : false;
 
-								// When accepting occurrence by opening occurrence itself , we dont move occurrence.
-								$move = (stristr($originalMessageProps[PR_MESSAGE_CLASS], 'IPM.Schedule.Meeting') !== false) ? true : false;
-
-								$req->doAccept($tentative, $sendResponse, $move, $newProposedStartTime, $newProposedEndTime, $body, true, $store, $basedate);
+								$req->doAccept($tentative, $sendResponse, $delete, $newProposedStartTime, $newProposedEndTime, $body, true, $store, $basedate);
 							} else {
-								$body = isset($action["body"]) ? $action["body"] : false;
-								$delete = $req->doDecline(true, $store, $basedate, $body);
+								$delete = $req->doDecline($sendResponse, $store, $basedate, $body);
 							}
 
 
@@ -163,11 +181,12 @@
 							 * check the PR_MESSAGE_CLASS and see if it is "IPM.Meeting*".
 							 */
 							$messageProps = mapi_getprops($message, array(PR_ENTRYID, PR_STORE_ENTRYID, PR_PARENT_ENTRYID, PR_MESSAGE_CLASS));
-							if(stristr($originalMessageProps[PR_MESSAGE_CLASS], 'IPM.Schedule.Meeting') !== false || $delete){
+
+							if($delete){
 								$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), TABLE_DELETE, $messageProps); // send TABLE_DELETE event because the message has moved
 							}
 
-							if ($action["attributes"]["type"] == "declineMeetingRequest" && !$delete)
+							if (!$delete)
 								$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageProps); // send TABLE_SAVE event because an occurrence is deleted
 							break;
 						case "cancelInvitation":
@@ -181,20 +200,168 @@
 						case "resolveConflict":
 							$result = $this->resolveConflict($store, $parententryid, $entryid, $action);
 							break;
+
+						//this will convert selected message into message of particular target folder.
+						case "convert_item":
+							$result = $this->getItemData($store, $parententryid, $action);
+							break;
+
+						case "attach_items":
+							$result = $this->forwardMultipleItems($store, $parententryid, $action);
+							break;
 							
+						case "getAttachments":
+							// Get list of uploaded attachments.
+							$result = $this->getAttachments($store, $entryid, $action);
+							break;
+
+						case "reclaimownership":
+							$message = $GLOBALS["operations"]->openMessage($store, $entryid);
+							$tr = new TaskRequest($store, $message, $GLOBALS["mapisession"]->getSession());
+							$tr->reclaimownership();
+							break;
+
+						case "acceptTaskRequest":
+						case "declineTaskRequest":
+							$message = $GLOBALS["operations"]->openMessage($store, $entryid);
+							// The task may be a delegated task, do an update if needed (will fail for non-delegated tasks)
+							$tr = new TaskRequest($store, $message, $GLOBALS["mapisession"]->getSession());
+							if ($action["attributes"]["type"] == "acceptTaskRequest") {
+								$result = $tr->doAccept(_("Task Accepted:") . " ");
+							} else {
+								$tr->doDecline(_("Task Declined:") . " ");
+							}
+							// Notify Inbox that task request has been deleted
+							if (isset($result) && $result) {
+								$GLOBALS["bus"]->notify(bin2hex($result[PR_PARENT_ENTRYID]), TABLE_DELETE, $result);
+							}
+							mapi_savechanges($message);
+							$result = true;
+							break;
 					}
 				}
 			}
 			
 			return $result;
 		}
+
+		/**
+		 * Function which get data of selected messages to send as response
+		 * @param object $store MAPI Message Store Object
+		 * @param string $parententryid entryid of the message
+		 * @param array $action the action data, sent by the client
+		 * @return boolean true on success or false on failure 
+		 */
+		function getItemData($store, $parententryid, $action)
+		{
+			$result = false;
+			$msg = array();
+			
+			if($store){
+				if(isset($action["messages"]["message"]) && is_array($action["messages"]["message"])){
+
+					if (!isset($action["messages"]["message"][0])){
+						$msg = array($action["messages"]["message"]);
+					}else{
+						$msg = $action["messages"]["message"];
+					}
+
+					$data = array();
+					$data["attributes"] = array("type" => "convert_item");
+					$data["item"] = array();
+					$messageIsDistList = false;
+
+					foreach($msg as $messageItem){
+						$items = array();
+						$message = mapi_msgstore_openentry($store, hex2bin($messageItem['id']));
+						
+						// get the properties of selected message
+						switch($messageItem['type']) {
+							case "Appointment":
+							case "Schedule":
+								$properties = $GLOBALS["properties"]->getAppointmentProperties();
+								break;
+							case "Contact":
+								$properties = $GLOBALS["properties"]->getContactProperties();
+								break;
+							case "DistList":
+								$messageIsDistList = true;
+								$props = mapi_getprops($message, array(PR_DISPLAY_NAME, PR_MESSAGE_CLASS, PR_BODY, PR_OBJECT_TYPE));
+
+								$memberItem = $GLOBALS["operations"]->expandDistributionList($store, hex2bin($messageItem['id']), false, $GLOBALS["properties"]->getContactABProperties(), $GLOBALS["properties"]->getAddressBookProperties());
+								
+								$items["dl_name"] = w2u($props[PR_DISPLAY_NAME]);
+								$items["message_class"] = w2u($props[PR_MESSAGE_CLASS]);
+								$items["body"] = w2u($props[PR_BODY]);
+								$items["objecttype"] = $props[PR_OBJECT_TYPE];
+								$items["addrtype"] = "ZARAFA";
+								$items["members"] = array("member"=>$memberItem);
+								break;
+							case "Task":
+								$properties = $GLOBALS["properties"]->getTaskProperties();
+								break;
+							case "StickyNote":
+								$properties = $GLOBALS["properties"]->getStickyNoteProperties();
+								break;
+							case "Note":
+							default:
+								$properties = $GLOBALS["properties"]->getMailProperties();
+						}
+						if(!$messageIsDistList)
+							$items = $GLOBALS["operations"]->getMessageProps($store, $message, $properties, true);
+						
+						array_push($data["item"], $items);
+					}
+
+					array_push($this->responseData["action"], $data);
+					$GLOBALS["bus"]->addData($this->responseData);
+					$result = true;
+				}
+			}
+			return $result;
+		}
+
+		/**
+		 * Function which sets selected messages as attachment to the item
+		 * @param object $store MAPI Message Store Object
+		 * @param string $parententryid entryid of the message
+		 * @param array $action the action data, sent by the client
+		 * @return boolean true on success or false on failure 
+		 */
+		function forwardMultipleItems($store, $parententryid, $action)
+		{
+			$result = false;
+			
+			if($store){
+				if(isset($action["entryids"]) && $action["entryids"]){
+					
+					if(!is_array($action["entryids"])){
+						$action["entryids"] = array($action["entryids"]);
+					}
+
+					//add attach items to session variables
+					$attachments = $GLOBALS["operations"]->setAttachmentInSession($store, $action["entryids"], $action["dialog_attachments"]);
+				}
+
+				$data = array();
+				$data["attributes"] = array("type" => "attach_items");
+				$data["item"] = array();
+				$data["item"]["parententryid"] = bin2hex($parententryid);
+				$data["item"]["attachments"] = $attachments;
+				array_push($this->responseData["action"], $data);
+				$GLOBALS["bus"]->addData($this->responseData);
+				$result = true;
+			}
+
+			return $result;
+		}
 		
 		/**
 		 * Function which opens an item.
 		 * @param object $store MAPI Message Store Object
 		 * @param string $entryid entryid of the message
 		 * @param array $action the action data, sent by the client
-		 * @return boolean true on success or false on failure		 		 
+		 * @return boolean true on success or false on failure 
 		 */
 		function open($store, $entryid, $action)
 		{
@@ -298,27 +465,52 @@
 				}
 
 				// Check for meeting request, do processing if necessary
-				$req = new Meetingrequest($store, $message, $GLOBALS["mapisession"]->getSession());
-				if($req->isMeetingRequestResponse()) {
-					if($req->isLocalOrganiser()) {
-						// We received a meeting request response, and we're the organiser
-						$req->processMeetingRequestResponse();
+				if(isset($data["item"]["message_class"]) && strpos($data["item"]["message_class"], "IPM.Schedule.Meeting") !== false) {
+					$req = new Meetingrequest($store, $message, $GLOBALS["mapisession"]->getSession());
+					if($req->isMeetingRequestResponse()) {
+						if($req->isLocalOrganiser()) {
+							// We received a meeting request response, and we're the organiser
+							$apptProps = $req->processMeetingRequestResponse();
+						}else if(isset($data["item"]["rcvd_representing_name"])){
+							// We can also received a meeting request response, when we are delegate
+							$apptProps = $req->processMeetingRequestResponseAsDelegate();
+						}
 						mapi_savechanges($message);
-					}
-				} else if($req->isMeetingRequest()) {
-					if(!$req->isLocalOrganiser()) {
-						if ($req->isMeetingOutOfDate()) {
-							$data["item"]["out_of_date"] = true;
-							$messageProps = mapi_getprops($message, array(PR_ENTRYID, PR_PARENT_ENTRYID, PR_STORE_ENTRYID));
-							$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageProps);
-						} else {
+
+						if (isset($apptProps))
+							$data["item"]["appointment"] = $apptProps;
+						else
+							$data["item"]["appt_not_found"] = true;
+					} else if($req->isMeetingRequest()) {
+						if(!$req->isLocalOrganiser()) {
+							if ($req->isMeetingOutOfDate()) {
+								$data["item"]["out_of_date"] = true;
+								$messageProps = mapi_getprops($message, array(PR_ENTRYID, PR_PARENT_ENTRYID, PR_STORE_ENTRYID));
+								$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageProps);
+							} else {
+								/**
+								 * put item in calendar 'tentatively' if this is latest update,
+								 * i.e if meeting request is not out of date.
+								 */
+								$req->doAccept(true, false, false);
+								// Publish updated free/busy information
+								$GLOBALS["operations"]->publishFreeBusy($store);
+							}
+
+							// We received a meeting request, show it to the user
+							$data["item"]["ismeetingrequest"] = 1;
+							// Show user whether meeting request conflict with other appointment or not.
+							$meetingConflicts = $req->isMeetingConflicting();
 							/**
-							 * put item in calendar 'tentatively' if this is latest update,
-							 * i.e if meeting request is not out of date.
+							 * if $meetingConflicts is boolean and true then its a normal meeting.
+							 * if $meetingConflictis is integer then it indicates no of instances of a recurring meeting which conflicts with Calendar.
 							 */
-							$req->doAccept(true, false, false);
-							// Publish updated free/busy information
-							$GLOBALS["operations"]->publishFreeBusy($store);
+							if (is_bool($meetingConflicts) && $meetingConflicts) {
+								$data["item"]["meetingconflicting"] = _('Conflicts with another appointment on your Calendar.');
+							} else if ($meetingConflicts) {
+								if ($meetingConflicts > 1) $data["item"]["meetingconflicting"] = $meetingConflicts .' '._('instances of this recurring appointment conflicts with other appointments on your Calendar.');
+								else $data["item"]["meetingconflicting"] = $meetingConflicts .' '._('instance of this recurring appointment conflicts with other appointment on your Calendar.');
+							}
 						}
 
 						// We received a meeting request, show it to the user
@@ -336,12 +528,32 @@
 							else $data["item"]["meetingconflicting"] = $meetingConflicts .' '._('instance of this recurring appointment conflicts with other appointment on your Calendar.');
 						}
 					}
-				} else if($req->isMeetingCancellation()) {
-					if(!$req->isLocalOrganiser()) {
-						// Let's do some processing of this Meeting Cancellation Object we received
-						$req->processMeetingCancellation();
-						// We received a cancellation request, show it to the user
-						$data["item"]["ismeetingcancel"] = 1;
+				}
+
+				if (isset($data["item"]["message_class"]) && strpos($data["item"]["message_class"], "IPM.TaskRequest") !== false) {
+					$tr = new TaskRequest($store, $message, $GLOBALS["mapisession"]->getSession());
+					$properties = $GLOBALS["properties"]->getTaskProperties();
+					
+					// @FIXME is this code used anywhere?
+					if($tr->isTaskRequest()) {
+						$tr->processTaskRequest();
+						$task = $tr->getAssociatedTask(false);
+						$taskProps = $GLOBALS["operations"]->getMessageProps($store, $task, $properties, true);
+						$data["item"] = $taskProps;
+
+						// notify task folder that new task has been created
+						$GLOBALS["bus"]->notify($taskProps["parent_entryid"]["_content"], TABLE_SAVE, array(
+							PR_ENTRYID => hex2bin($taskProps["entryid"]["_content"]),
+							PR_PARENT_ENTRYID => hex2bin($taskProps["parent_entryid"]["_content"]),
+							PR_STORE_ENTRYID => hex2bin($taskProps["store_entryid"]["_content"])
+						));
+					}
+					
+					if($tr->isTaskRequestResponse()) {
+						$tr->processTaskResponse();
+						$task = $tr->getAssociatedTask(false);
+
+						$data["item"] = $GLOBALS["operations"]->getMessageProps($store, $task, $properties, true);
 					}
 				}
 				
@@ -631,5 +843,78 @@
 			}
 			return $result;
 		}
+
+		/**
+		 * Function which returns list of uploaded files for perticular dialog
+		 * returns list of file as XML response.
+		 * @param object $store MAPI Message Store Object
+		 * @param string $entryid entryid of the message
+		 * @param array $action the action data, sent by the client
+		 */
+		function getAttachments($store, $entryid, $action)
+		{
+			// Create the data array of information, which will be send back to the client.
+			$data = array();
+			$data["attributes"] = array("type" => "getAttachments");
+			$dialog_attachments = $action["dialog_attachments"];
+			$data["files"] = array();
+
+			// Get uploaded attachments' information.
+			if(isset($_SESSION["files"]) && isset($_SESSION["files"][$dialog_attachments])) {
+				foreach($_SESSION["files"][$dialog_attachments] as $tmpname => $file)
+				{
+					$filedata = array();
+					$filedata["attach_num"] = $tmpname;
+					$filedata["filetype"] = $file["type"];
+					$filedata["name"] = $file["name"];
+					$filedata["size"] = $file["size"];
+					array_push($data["files"], $filedata);
+				}
+			}
+
+			// Add file information into response data.
+			array_push($this->responseData["action"], $data);
+			$GLOBALS["bus"]->addData($this->responseData);
+		}
+
+		/**
+		 * Function which destubs an archived item.
+		 * @param object $store MAPI Message Store Object
+		 * @param string $entryid list of entryids which will be copied or moved
+		 * @param string $parententryid entryid of the folder
+		 * @return boolean true on success or false on failure
+		 */
+		function destub($store, $parententryid, $entryid)
+		{
+			$result = false;
+			
+			if($store && $parententryid && $entryid) {
+				// Check if this message is an archived stub message
+				if($GLOBALS["zArchiverOperations"]->isStubbed($store, $entryid)){
+					// Destub the message
+					$result = $GLOBALS["zArchiverOperations"]->destub($store, $entryid);
+					if($result){
+						$storeProps = mapi_getprops($store, Array(PR_STORE_ENTRYID));
+						$props = Array(
+							PR_STORE_ENTRYID => $storeProps[PR_STORE_ENTRYID],
+							PR_PARENT_ENTRYID => hex2bin($parententryid),
+							PR_ENTRYID => $entryid
+						);
+						// Notify the other modules about the updated message
+						$GLOBALS["bus"]->notify($parententryid, TABLE_SAVE, $props);
+					}else{
+						// Destubbing message did not succeed
+						$errorMessage = _("Unable to restore archived message") . ".";
+						/**
+						 * The third argument set to false will mean the responsedata of the 
+						 * feedback will not be added to the Bus just yet. This will happen when the
+						 * open call is done and adds theirs.
+						 */
+						$this->sendFeedback(false, $errorMessage, false);
+					}
+				}
+			}
+			return $result;
+		}
 	}
-?>
+?>
\ No newline at end of file
