@@ -172,7 +172,24 @@
 							$result = $this->messageList($store, $entryid, $action);
 							break;
 						case "save":
-							$result = $this->save($store, $parententryid, $action);
+							$accessToFolder = true;
+							/**
+							 * Check for the folder access.
+							 * If store and parententryid is not passed then it is
+							 * users default messagestore and user has permission on it.
+							 * For other folders check permissions on folder.
+							 */
+							if($store && $parententryid)
+								$accessToFolder = $GLOBALS["operations"]->checkFolderAccess($store, $parententryid);
+
+							if($accessToFolder) {
+								// If folder is accessible then save the message.
+								$result = $this->save($store, $parententryid, $action);
+							} else {
+								// If folder is not accessible then show error message.
+								$errorMessage = _("You have insufficient privileges to save items in this folder") . ".";
+								$this->sendFeedback(false, $errorMessage);
+							}
 							break;
 						case "read_flag":
 							$result = $this->setReadFlag($store, $entryid, $action);
@@ -186,6 +203,23 @@
                         case "cancelInvitation":
                             $GLOBALS["operations"]->cancelInvitation($store, $entryid, $action);
                             break;
+						case "declineMeeting":
+							if (isset($action["props"]) && isset($action["props"]["entryid"])) {
+								$message = $GLOBALS["operations"]->openMessage($store, hex2bin($action["props"]["entryid"]));
+								$basedate = (isset($action["props"]['basedate']) ? $action["props"]['basedate'] : false);
+
+								$req = new Meetingrequest($store, $message, $GLOBALS["mapisession"]->getSession());
+
+								$body = isset($action["body"]) ? $action["body"] : false;
+								$req->doDecline(true, $store, $basedate, $body);
+
+								// Publish updated free/busy information
+								$GLOBALS["operations"]->publishFreeBusy($store);
+
+								$messageProps = mapi_getprops($message, array(PR_ENTRYID, PR_STORE_ENTRYID, PR_PARENT_ENTRYID));
+								$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), $basedate ? TABLE_SAVE : TABLE_DELETE, $messageProps);
+							}
+							break;
 					}
 				}
 			}
@@ -242,8 +276,19 @@
 				$data["sort"]["_content"] = array_search($firstSortColumn, $this->properties);
 				
 				// Get the table and merge the arrays
-				$data = array_merge($data, $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, $this->start, false, $this->searchRestriction, $this->generateRecipient));
-				
+				$items = $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, $this->start, false, $this->searchRestriction, $this->generateRecipient);
+
+				// if disablePrivateItem is available in listmodule then disable private appointments.
+				if(method_exists($this, disablePrivateItem)) {
+					foreach ($items["item"] as &$value)
+					{
+						// Disable private items
+						$value = $this->disablePrivateItem($value);
+					}
+				}
+
+				$data = array_merge($data, $items);
+
 				array_push($this->responseData["action"], $data);
 				$GLOBALS["bus"]->addData($this->responseData);
 
@@ -321,7 +366,7 @@
 					// if error in creating restriction then send error to client
 					$errorInfo = array();
 					$errorInfo["error_message"] = _("Error in search, please try again") . ".";
-					$errorInfo["original_error_message"] = "Error in parsing restrictions.";
+					$errorInfo["original_error_message"] = "Error setting restrictions on searchfolder.";
 
 					return $this->sendSearchErrorToClient($store, $entryid, $action, $errorInfo);
 				}
@@ -716,6 +761,11 @@
 						}
 					}
 				}
+				// adding selected message ID to sort array so we can return the particular item to 
+				// client while displaying the items in table
+				if(isset($action["sort"]["selectedmessageid"]) && $action["sort"]["selectedmessageid"]!= ""){
+					$this->sort["selectedmessageid"] = $action["sort"]["selectedmessageid"];
+				}
 			}
 			
 		}
@@ -793,6 +843,56 @@
 			
 			return $result;
 		}
+
+		/**
+		 * Function which create a task from a mail by copying its subject and body.
+		 * @param object $store MAPI Message Store Object
+		 * @param string $entryid entryid of the item
+		 * @return boolean true on success or false on failure		 		 
+		 */
+		function createTaskFromMail($store, $entryid)
+		{
+			$result = false;
+
+			if($store && $entryid) {
+				
+				$inbox = mapi_msgstore_getreceivefolder($store);
+				if(mapi_last_hresult() == NOERROR) {
+					$inboxprops = mapi_getprops($inbox, Array(PR_IPM_TASK_ENTRYID, PR_STORE_ENTRYID));
+					$parententryid = bin2hex($inboxprops[PR_IPM_TASK_ENTRYID]);
+				}
+				// open the userstore to fetch the name of the owner of the store.
+				$userstore = mapi_openmsgstore($GLOBALS["mapisession"]->getSession(),$inboxprops[PR_STORE_ENTRYID]);
+				$userstoreprops = mapi_getprops($userstore, Array(PR_MAILBOX_OWNER_NAME));
+
+				// open the mail to fetch the subject and body.
+				$message = mapi_msgstore_openentry($store, $entryid);
+				$msgprops= mapi_getprops($message, Array(PR_SUBJECT, PR_BODY));
+
+				$props = array ('message_class' => 'IPM.Task',
+								'icon_index' => '1280',
+								'subject' => w2u($msgprops[PR_SUBJECT]),
+								'body' => w2u($msgprops[PR_BODY]),
+								'owner' => w2u($userstoreprops[PR_MAILBOX_OWNER_NAME]),
+								'complete' => "false",
+								);
+				
+				$messageProps = array(); // returned props
+				$result = $GLOBALS["operations"]->saveMessage($store, hex2bin($parententryid),Conversion::mapXML2MAPI($GLOBALS["properties"]->getTaskProperties(), $props) , null, "", $messageProps);
+				
+				$data = array();
+				$data["attributes"] = array("type" => "task_created");
+				$data["success"] = $result;
+
+				array_push($this->responseData["action"], $data);
+				$GLOBALS["bus"]->addData($this->responseData);
+
+				if($result) {
+					$GLOBALS["bus"]->notify(bin2hex($parententryid), TABLE_SAVE, $messageProps);
+				}
+			}
+			return $result;
+		}
 		
 		/**
 		 * Function which deletes one or more items.
@@ -873,6 +973,14 @@
 					$moveMessages = true;
 				}
 
+				// drag & drop from a public store to other store should always be copy instead of move
+				$destStoreProps = mapi_getprops($dest_store, array(PR_MDB_PROVIDER));
+				$storeProps = mapi_getprops($store, array(PR_MDB_PROVIDER));
+
+				if($storeProps[PR_MDB_PROVIDER] == ZARAFA_STORE_PUBLIC_GUID && $destStoreProps[PR_MDB_PROVIDER] != ZARAFA_STORE_PUBLIC_GUID) {
+					$moveMessages = false;
+				}
+
 				$props = array();
 				$props[PR_PARENT_ENTRYID] = $parententryid;
 				$props[PR_ENTRYID] = $entryids;			
