@@ -169,6 +169,36 @@
 						case "cancelInvitation":
 							$GLOBALS["operations"]->cancelInvitation($store, $entryid);
 							break;
+						// will be called when a mail is converted into task  
+						case "createTask":
+							$result = $this->CreateTaskFromMail($store, $entryid);
+							break;
+						case "convert_meeting":
+							$result = $this->getMeetingData($store, $entryid, $action);
+							break;
+						case "acceptMeeting":
+							if (isset($action["entryid"])) {
+								$message = $GLOBALS["operations"]->openMessage($store, hex2bin($action["entryid"]));
+								/**
+								 * Get message class from original message. This can be changed to 
+								 * IPM.Appointment if the item is a Meeting Request in the maillist. 
+								 * After Accepting/Declining the message is moved and changed.
+								 */
+								$originalMessageProps = mapi_getprops($message, array(PR_MESSAGE_CLASS));
+								$req = new Meetingrequest($store, $message, $GLOBALS["mapisession"]->getSession());
+
+								$basedate = (isset($action['basedate']) ? $action['basedate'] : false);
+								// sendResponse flag if it is set then send the mail response to the organzer.
+								$sendResponse = true;
+								if(isset($action["noResponse"]) && $action["noResponse"] == "true") {
+									$sendResponse = false;
+								}
+								// We are accepting MR from maillist so set delete the actual mail flag.
+								$delete = (stristr($originalMessageProps[PR_MESSAGE_CLASS], 'IPM.Schedule.Meeting') !== false) ? true : false;
+
+								$req->doAccept(false, $sendResponse, $delete, false, false, false, true, $store, $basedate);
+							}
+							break;
 					}
 				}
 			}
@@ -177,6 +207,46 @@
 			return $result;
 		}
 
+		/**
+		 * Function which get data of selected meeting item to send as response
+		 * @param object $store MAPI Message Store Object
+		 * @param string $parententryid entryid of the message
+		 * @param array $action the action data, sent by the client
+		 * @return boolean true on success or false on failure 
+		 */
+		function getMeetingData($store, $parententryid, $action)
+		{
+			$result = false;
+			if($store){
+				if(isset($action["messages"]["message"]) && is_array($action["messages"]["message"])){
+
+					if (!isset($action["messages"]["message"][0])){
+						$msg = array($action["messages"]["message"]);
+					}else{
+						$msg = $action["messages"]["message"];
+					}
+
+					$data = array();
+					$data["attributes"] = array("type" => "convert_meeting");
+					$data["item"] = array();
+					$data["targetfolder"] = $action["targetfolder"];
+					$data["targetfolderentryid"] = $action["parententryid"];
+
+					foreach($msg as $messageItem){
+						$items = array();
+						$message = mapi_msgstore_openentry($store, hex2bin($messageItem['id']));
+						$items = $GLOBALS["operations"]->getMessageProps($store, $message, $this->properties, true);
+						array_push($data["item"], $items);
+					}
+
+					array_push($this->responseData["action"], $data);
+					$GLOBALS["bus"]->addData($this->responseData);
+					$result = true;
+				}
+			}
+			return $result;
+		}
+
 		function parseSearchRestriction($action)
 		{
 			// TODO: let javascript generate the MAPI restriction just as with the rules
@@ -347,4 +417,4 @@
 			$GLOBALS["bus"]->addData($this->responseData);
 		}
 	}
-?>
+?>
\ No newline at end of file
