@@ -184,7 +184,7 @@
 		 * @param boolean $success operation completed successfully or not
 		 * @param string $message the error message which will be shown to client on any failure of operation
 		 */
-		function sendFeedback($success = false, $message = "")
+		function sendFeedback($success = false, $message = "", $addResponseDataToBus = true)
 		{
 			if($success == true) {
 				// Send success message to client
@@ -192,7 +192,9 @@
 				$data["attributes"] = array("type" => "success");
 
 				array_push($this->responseData["action"], $data);
-				$GLOBALS["bus"]->addData($this->responseData);
+				if($addResponseDataToBus){
+					$GLOBALS["bus"]->addData($this->responseData);
+				}
 			} else {
 				// send error message to client
 				$data = array();
@@ -201,7 +203,9 @@
 				$data["error"]["message"] = $message;
 				
 				array_push($this->responseData["action"], $data);
-				$GLOBALS["bus"]->addData($this->responseData);
+				if($addResponseDataToBus){
+					$GLOBALS["bus"]->addData($this->responseData);
+				}
 			}
 		}
 
