@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -113,11 +115,11 @@
 							$data["count"] = $props[PR_CONTENT_COUNT];
 							$data["unread"] = $props[PR_CONTENT_UNREAD];
 
-							$quotaProps = mapi_getprops($GLOBALS["mapisession"]->getDefaultMessageStore(),array(PR_QUOTA_WARNING_THRESHOLD,PR_QUOTA_SEND_THRESHOLD,PR_QUOTA_RECEIVE_THRESHOLD,PR_MESSAGE_SIZE_EXTENDED));
-							$data["store_size"] = round($quotaProps[PR_MESSAGE_SIZE_EXTENDED]/1024);
-							$data["quota_warning"] = $quotaProps[PR_QUOTA_WARNING_THRESHOLD];
-							$data["quota_soft"] = $quotaProps[PR_QUOTA_SEND_THRESHOLD];
-							$data["quota_hard"] = $quotaProps[PR_QUOTA_RECEIVE_THRESHOLD];
+							$quotaDetails = $GLOBALS["operations"]->getQuotaDetails($store);
+							$data["store_size"] = $quotaDetails["store_size"];
+							$data["quota_warning"] = $quotaDetails["quota_warning"];
+							$data["quota_soft"] = $quotaDetails["quota_soft"];
+							$data["quota_hard"] = $quotaDetails["quota_hard"];
 							
 							array_push($this->responseData["action"], $data);
 							$GLOBALS["bus"]->addData($this->responseData);
