@@ -389,7 +389,13 @@
 					}else{
 						$newProps[$this->properties["reminder"]] = false;
 					}
-				}else{
+				} else if (strtolower(substr($props[$this->properties["message_class"]],0, 15)) == "ipm.task") {
+					$newProps[$this->properties["reminder"]] = false;
+
+					if (isset($props[$this->properties['task_recurring']]) && $props[$this->properties['task_recurring']] == 1) {
+						$newProps[$this->properties['task_resetreminder']] = true;
+					}
+				} else {
 					$newProps[$this->properties["reminder"]] = false;
 				}
 				
