@@ -34,7 +34,9 @@
  * sec. 7 b) of the GNU Affero General Public License, version 3, these
  * Appropriate Legal Notices must retain the logo of Zarafa or display
  * the words "Initial Development by Zarafa" if the display of the logo
- * is not reasonably feasible for technical reasons."
+ * is not reasonably feasible for technical reasons. The use of the logo
+ * of Zarafa in Legal Notices is allowed for unmodified and modified
+ * versions of the software.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -61,11 +63,9 @@
 		function RulesListModule($id, $data)
 		{
 			$this->properties = $GLOBALS["properties"]->getRulesProperties();
-		
+
 			// Default Columns
-			$this->tablecolumns = array();
-			$this->addColumn($this->tablecolumns, "name", true, 0, _("Rule name"), _("Sort on rule name"));
-			$this->addColumn($this->tablecolumns, "enabled", true, 1, _("Rule enabled"), _("Sort on rule enabled"));
+			$this->tablecolumns = $GLOBALS["TableColumns"]->getRuleListTableColumns();
 
 			parent::ListModule($id, $data, array());
 
@@ -121,11 +121,7 @@
 			
 			$data["item"] = $rules;
 			
-			$data["column"] = array(
-								array("id" => "rule_id", "visible" => false, "name" => _("Id"),      "title" => _("Sort on Id"),      "order" => 0 ),
-								array("id" => "rule_state", "visible" => true, "title" => _("Sort on Enabled"), "order" => 0, "type" => "checkbox|ST_ENABLED", "length" => 22 ),
-								array("id" => "rule_name", "visible" => true, "name" => _("Name"),    "title" => _("Sort on Name"),    "order" => 0, "length" => PERCENTAGE ),
-							  );
+			$data["column"] = $this->tablecolumns;
 			
 			return $data;
 		}
