@@ -50,6 +50,9 @@
 
 ?>
 <?php
+include_once('mapi/class.taskrecurrence.php');
+include_once("mapi/class.taskrequest.php");
+
 	/**
 	 * Task ItemModule
 	 * Module which openes, creates, saves and deletes an item. It 
@@ -73,6 +76,50 @@
 			parent::ItemModule($id, $data);
 		}
 
+		function open($store, $entryid, $action)
+		{
+			$message = mapi_msgstore_openentry($store, $entryid);
+			$tr = new TaskRequest($store, $message, $GLOBALS["mapisession"]->getSession());
+			
+			if($tr->isTaskRequest()) {
+				$tr->processTaskRequest();
+				$task = $tr->getAssociatedTask(false);
+				
+				$taskprops = mapi_getprops($task, array(PR_ENTRYID));
+				$entryid = $taskprops[PR_ENTRYID];
+			}
+			
+			if($tr->isTaskRequestResponse()) {
+				$tr->processTaskResponse();
+				$task = $tr->getAssociatedTask(false);
+				
+				$taskprops = mapi_getprops($task, array(PR_ENTRYID));
+				$entryid = $taskprops[PR_ENTRYID];
+			}
+
+			$result = false;
+			if($store && $entryid) {
+				$data = array();
+				$data["attributes"] = array("type" => "item");
+				$message = $GLOBALS["operations"]->openMessage($store, $entryid);
+				$data["item"] = $GLOBALS["operations"]->getMessageProps($store, $message, $this->properties, true);
+				// Get the recurrence information
+				$recur = new Taskrecurrence($store, $message);
+				$recurpattern = $recur->getRecurrence();
+
+				// Add the recurrence pattern to the data
+				if(isset($recurpattern) && is_array($recurpattern))
+					$data["item"] += $recurpattern;
+
+				array_push($this->responseData["action"], $data);
+				$GLOBALS["bus"]->addData($this->responseData);
+				
+				$result = true;
+			}
+			
+			return $result;
+		}
+
 		/**
 		 * Function which saves an item.
 		 * @param object $store MAPI Message Store Object
@@ -83,7 +130,7 @@
 		function save($store, $parententryid, $action)
 		{
 			$result = false;
-			
+
 			if(isset($action["props"])) {
 				$props = $action["props"];
 				
@@ -94,71 +141,11 @@
 					}
 				}
 
-				if($store && $parententryid) {
-					// Fetch message store properties of a current store.
-					$msgstoreProps = mapi_getprops($store, array(PR_USER_ENTRYID, PR_MDB_PROVIDER, PR_MAILBOX_OWNER_ENTRYID));
+				if ($store && $parententryid) {
+					$messageProps = $GLOBALS["operations"]->saveTask($store, $parententryid, $action);
 
-					// Get current session and open addressbook
-					$addrbook = $GLOBALS["mapisession"]->getAddressbook();
-					//$addrbook = mapi_openaddressbook($session);
-
-					// Open addressbook entry for current user.
-					$userObject = mapi_ab_openentry($addrbook, $msgstoreProps[PR_USER_ENTRYID]);
-
-					$props = $action["props"];
-
-					if(mapi_last_hresult() == NOERROR){
-						$userProps = mapi_getprops($userObject);
-						if(mapi_last_hresult() == NOERROR){
-							// Store PR_SENDER_* properties for task in props variable.
-							$props["sender_email_address"] = $userProps[PR_EMAIL_ADDRESS];
-							$props["sender_name"] = $userProps[PR_DISPLAY_NAME];
-							$props["sender_addrtype"] = $userProps[PR_ADDRTYPE];
-							$props["sender_entryid"] = bin2hex($userProps[PR_ENTRYID]);
-							$props["sender_search_key"] = $userProps[PR_SEARCH_KEY];
-						}
-					}
-
-					// Store PR_SENT_REPRESENTING_* properties for task according to store type.
-					switch ($msgstoreProps[PR_MDB_PROVIDER])
-					{
-						case ZARAFA_STORE_PUBLIC_GUID:
-							/**
-							 * store type is "public"
-							 * Store PR_SENT_REPRESENTING_* properties for task in props variable.
-							 */
-							$props["sent_representing_entryid"] = bin2hex($userProps[PR_ENTRYID]);
-							$props["sent_representing_name"] = $userProps[PR_DISPLAY_NAME];
-							$props["sent_representing_addrtype"] = $userProps[PR_ADDRTYPE];
-							$props["sent_representing_email_address"] = $userProps[PR_EMAIL_ADDRESS];
-							$props["sent_representing_search_key"] = $userProps[PR_SEARCH_KEY];
-							break;
-						case ZARAFA_SERVICE_GUID:
-							// store type is "default"
-						case ZARAFA_STORE_DELEGATE_GUID:
-							/**
-							 * store type is "delegate"
-							 * Open addressbook entry for mailbox owner.
-							 */
-							$ownerObject = mapi_ab_openentry($addrbook, $msgstoreProps[PR_MAILBOX_OWNER_ENTRYID]);
-							if(mapi_last_hresult() == NOERROR){
-								$ownerProps = mapi_getprops($ownerObject);
-								if(mapi_last_hresult() == NOERROR){
-									// Store PR_SENT_REPRESENTING_* properties for task in props variable.
-									$props["sent_representing_entryid"] = bin2hex($ownerProps[PR_ENTRYID]);
-									$props["sent_representing_name"] = $ownerProps[PR_DISPLAY_NAME];
-									$props["sent_representing_addrtype"] = $ownerProps[PR_ADDRTYPE];
-									$props["sent_representing_email_address"] = $ownerProps[PR_EMAIL_ADDRESS];
-									$props["sent_representing_search_key"] = $ownerProps[PR_SEARCH_KEY];
-								}
-							}
-							break;
-					}
-
-					$messageProps = array(); // returned props
-					$result = $GLOBALS["operations"]->saveMessage($store, $parententryid, Conversion::mapXML2MAPI($this->properties, $props), false, (isset($action["dialog_attachments"])?$action["dialog_attachments"]:null), $messageProps);
-					
-					if($result) {
+					if($messageProps) {
+						$result = true;
 						$GLOBALS["bus"]->notify(bin2hex($parententryid), TABLE_SAVE, $messageProps);
 					}
 				}
@@ -166,5 +153,38 @@
 			
 			return $result;
 		}
+
+		/**
+		 * Function which deletes an item.
+		 * @param object $store MAPI Message Store Object
+		 * @param string $parententryid parent entryid of the message
+		 * @param string $entryid entryid of the message		 
+		 * @param array $action the action data, sent by the client
+		 * @return boolean true on success or false on failure		 		 
+		 */
+		function delete($store, $parententryid, $entryids, $action)
+		{
+			$result = false;
+
+			if($store && $parententryid) {
+				$props = array();
+				$props[PR_PARENT_ENTRYID] = $parententryid;
+				$props[PR_ENTRYID] = $entryids;
+
+				$storeprops = mapi_getprops($store, array(PR_ENTRYID));
+				$props[PR_STORE_ENTRYID] = $storeprops[PR_ENTRYID];
+
+				$result = $GLOBALS["operations"]->deleteTask($store, $parententryid, $entryids, $action);
+
+				if (isset($result['occurrenceDeleted']) && $result['occurrenceDeleted']) {
+					// Occurrence deleted, update item
+					$GLOBALS["bus"]->notify(bin2hex($parententryid), TABLE_SAVE, $props);
+				} else {
+					$GLOBALS["bus"]->notify(bin2hex($parententryid), TABLE_DELETE, $props);
+				}
+			}
+
+			return $result;
+		}
 	}
 ?>
