@@ -50,6 +50,8 @@
 
 ?>
 <?php
+	include_once('mapi/class.taskrecurrence.php');
+
 	/**
 	 * Task Module
 	 */
@@ -118,76 +120,96 @@
 		function save($store, $parententryid, $action)
 		{
 			$result = false;
-			if($store && $parententryid && isset($action["props"])) {
-				// Fetch message store properties of a current store.
-				$msgstoreProps = mapi_getprops($store, array(PR_USER_ENTRYID, PR_MDB_PROVIDER, PR_MAILBOX_OWNER_ENTRYID));
-
-				// Get current session and open addressbook
-				$addrbook = $GLOBALS["mapisession"]->getAddressbook();
-				//$addrbook = mapi_openaddressbook($session);
-
-				// Open addressbook entry for current user.
-				$userObject = mapi_ab_openentry($addrbook, $msgstoreProps[PR_USER_ENTRYID]);
 
+			if(isset($action["props"])) {
 				$props = $action["props"];
-
-				if(mapi_last_hresult() == NOERROR){
-					$userProps = mapi_getprops($userObject);
-					if(mapi_last_hresult() == NOERROR){
-						// Store PR_SENDER_* properties for task in props variable.
-						$props["sender_email_address"] = $userProps[PR_EMAIL_ADDRESS];
-						$props["sender_name"] = $userProps[PR_DISPLAY_NAME];
-						$props["sender_addrtype"] = $userProps[PR_ADDRTYPE];
-						$props["sender_entryid"] = bin2hex($userProps[PR_ENTRYID]);
-						$props["sender_search_key"] = $userProps[PR_SEARCH_KEY];
+				
+				if(!$store && !$parententryid) {
+					if(isset($action["props"]["message_class"])) {
+						$store = $GLOBALS["mapisession"]->getDefaultMessageStore();
+						$parententryid = $this->getDefaultFolderEntryID($store, $action["props"]["message_class"]);
 					}
 				}
 
-				// Store PR_SENT_REPRESENTING_* properties for task according to store type.
-				switch ($msgstoreProps[PR_MDB_PROVIDER])
-				{
-					case ZARAFA_STORE_PUBLIC_GUID:
-						/**
-						 * store type is "public"
-						 * Store PR_SENT_REPRESENTING_* properties for task in props variable.
-						 */
-						$props["sent_representing_entryid"] = bin2hex($userProps[PR_ENTRYID]);
-						$props["sent_representing_name"] = $userProps[PR_DISPLAY_NAME];
-						$props["sent_representing_addrtype"] = $userProps[PR_ADDRTYPE];
-						$props["sent_representing_email_address"] = $userProps[PR_EMAIL_ADDRESS];
-						$props["sent_representing_search_key"] = $userProps[PR_SEARCH_KEY];
-						break;
-					case ZARAFA_SERVICE_GUID:
-						// store type is "default"
-					case ZARAFA_STORE_DELEGATE_GUID:
-						/**
-						 * store type is "delegate"
-						 * Open addressbook entry for mailbox owner.
-						 */
-						$ownerObject = mapi_ab_openentry($addrbook, $msgstoreProps[PR_MAILBOX_OWNER_ENTRYID]);
-						if(mapi_last_hresult() == NOERROR){
-							$ownerProps = mapi_getprops($ownerObject);
-							if(mapi_last_hresult() == NOERROR){
-								// Store PR_SENT_REPRESENTING_* properties for task in props variable.
-								$props["sent_representing_entryid"] = bin2hex($ownerProps[PR_ENTRYID]);
-								$props["sent_representing_name"] = $ownerProps[PR_DISPLAY_NAME];
-								$props["sent_representing_addrtype"] = $ownerProps[PR_ADDRTYPE];
-								$props["sent_representing_email_address"] = $ownerProps[PR_EMAIL_ADDRESS];
-								$props["sent_representing_search_key"] = $ownerProps[PR_SEARCH_KEY];
-							}
-						}
-						break;
-				}
+				if ($store && $parententryid) {
+					$messageProps = $GLOBALS["operations"]->saveTask($store, $parententryid, $action);
 
-				$messageProps = array();
-				$result = $GLOBALS["operations"]->saveMessage($store, $parententryid, Conversion::mapXML2MAPI($this->properties, $props), null, "", $messageProps);
-	
-				if($result) {
-					$GLOBALS["bus"]->notify($this->entryid, TABLE_SAVE, $messageProps);
+					if($messageProps) {
+						$result = true;
+						$GLOBALS["bus"]->notify(bin2hex($parententryid), TABLE_SAVE, $messageProps);
+					}
 				}
 			}
-			
+
+			return $result;
+		}
+
+		/**
+		 * Function will create search restriction based on restriction array
+		 * @param object $action the action data, sent by the client
+		 *
+		 * this function is normally used to add search restriction when getting data from listmodule
+		 * but this is a special case in which it is used to hide completed tasks based on user settings
+		 * in future if search is implemented in tasks then we have to combine that restriction with this one
+		 */
+		function parseSearchRestriction($action)
+		{
+			$this->searchRestriction = false;
+
+			if(isset($action["restriction"])) {
+				if(isset($action["restriction"]["start"])) {
+					// Set start variable
+					$this->start = (int) $action["restriction"]["start"];
+				}
+			}
+
+			// apply restriction for hiding completed tasks
+			$showCompletedTasks = $GLOBALS["settings"]->get("tasks/show_completed", "true");
+
+			if($showCompletedTasks === "false") {
+				$this->searchRestriction = Array(RES_PROPERTY,
+												Array(
+													RELOP => RELOP_EQ,
+													ULPROPTAG => $this->properties["complete"],
+													VALUE => false
+												)
+											);
+			}
+		}
+
+		/**
+		 * Function which deletes one or more items. Ite verifies if the delete
+		 * is a action on a recurring item and if only one occurrence should be
+		 * deleted in the recurrence.		  		 
+		 * @param object $store MAPI Message Store Object
+		 * @param string $parententryid entryid of the folder
+		 * @param array $entryid list of entryids which will be deleted		 
+		 * @param array $action the action data, sent by the client
+		 * @return boolean true on success or false on failure
+		 */
+		function delete($store, $parententryid, $entryids, $action)
+		{
+			$result = false;
+
+			if($store && $parententryid) {
+				$props = array();
+				$props[PR_PARENT_ENTRYID] = $parententryid;
+				$props[PR_ENTRYID] = $entryids;
+
+				$storeprops = mapi_getprops($store, array(PR_ENTRYID));
+				$props[PR_STORE_ENTRYID] = $storeprops[PR_ENTRYID];
+
+				$result = $GLOBALS["operations"]->deleteTask($store, $parententryid, $entryids, $action);
+
+				if (isset($result['occurrenceDeleted']) && $result['occurrenceDeleted']) {
+					// Occurrence deleted, update item
+					$GLOBALS["bus"]->notify($this->entryid, TABLE_SAVE, $props);
+				} else {
+					$GLOBALS["bus"]->notify($this->entryid, TABLE_DELETE, $props);
+				}
+			}
+
 			return $result;
 		}
 	}
-?>
+?>
\ No newline at end of file
