@@ -72,45 +72,56 @@
 						'size'     => $_FILES['attachments']['size'][$key]
 					);
 
-					if (!empty($FILE["size"]) && !(isset($_POST["MAX_FILE_SIZE"]) && $FILE["size"] > $_POST["MAX_FILE_SIZE"])) {
-						// Create unique tmpname
-						$tmpname = tempnam(TMP_PATH, stripslashes($FILE["name"]));
-						// Move the uploaded file the the tmpname
-						$result = move_uploaded_file($FILE["tmp_name"], $tmpname);
-
-						if($FILE["type"] == "message/rfc822") {
-							/**
-							 * check content type that is send by browser because content type for
-							 * eml attachments will be message/rfc822, but this content type is used 
-							 * for message-in-message embedded objects, so we have to send it as 
-							 * application/octet-stream.
-							 */
-							$FILE["type"] = "application/octet-stream";
-						}
-
-						// Check if there are no files uploaded
-						if(!isset($_SESSION["files"])) {
-							$_SESSION["files"] = array();
-						}
-						
-						// Check if no files are uploaded with this dialog_attachments
-						if(!isset($_SESSION["files"][$_POST["dialog_attachments"]])) {
-							$_SESSION["files"][$_POST["dialog_attachments"]] = array();
-						}
-
-						// stripping path details
-						$tmpname = basename($tmpname);
-
-						// Add file information to the session
-						$_SESSION["files"][$_POST["dialog_attachments"]][$tmpname] = Array(
-							"name"       => utf8_to_windows1252(stripslashes($FILE["name"])),
-							"size"       => $FILE["size"],
-							"type"       => $FILE["type"],
-							"sourcetype" => 'default'
-						);
-
-					}
 				}
+			} else if(isset($_FILES['attachments']['name'])){
+				// SWFUpload sends attachments array already in required format.
+				$FILE = $_FILES['attachments'];
+
+				/**
+				 * Get MIME type of the file, cause SWFUpload object doesn't return MIME type of the file.
+				 * for more information -> http://swfupload.org/forum/generaldiscussion/166
+				 */
+				$FILE["type"] = getMIMEType($FILE["name"]);
+			}
+
+			if (!empty($FILE["size"]) && !(isset($_POST["MAX_FILE_SIZE"]) && $FILE["size"] > $_POST["MAX_FILE_SIZE"])) {
+				// Create unique tmpname
+				$tmpname = tempnam(TMP_PATH, stripslashes($FILE["name"]));
+
+				// Move the uploaded file the the tmpname
+				$result = move_uploaded_file($FILE["tmp_name"], $tmpname);
+
+				if($FILE["type"] == "message/rfc822") {
+					/**
+					 * check content type that is send by browser because content type for
+					 * eml attachments will be message/rfc822, but this content type is used 
+					 * for message-in-message embedded objects, so we have to send it as 
+					 * application/octet-stream.
+					 */
+					$FILE["type"] = "application/octet-stream";
+				}
+
+				// Check if there are no files uploaded
+				if(!isset($_SESSION["files"])) {
+					$_SESSION["files"] = array();
+				}
+				
+				// Check if no files are uploaded with this dialog_attachments
+				if(!isset($_SESSION["files"][$_POST["dialog_attachments"]])) {
+					$_SESSION["files"][$_POST["dialog_attachments"]] = array();
+				}
+
+				// stripping path details
+				$tmpname = basename($tmpname);
+
+				// Add file information to the session
+				$_SESSION["files"][$_POST["dialog_attachments"]][$tmpname] = Array(
+					"name"       => utf8_to_windows1252(stripslashes($FILE["name"])),
+					"size"       => $FILE["size"],
+					"type"       => $FILE["type"],
+					"sourcetype" => 'default'
+				);
+
 			}
 		} else if(isset($_POST["deleteattachment"]) && isset($_POST["type"])) { // Delete uploaded file
 			// Check if the delete file is an uploaded or an attachment of a MAPI iMessage
