@@ -216,10 +216,18 @@
 	 */
 	function inline_img_attachments($match)
 	{
-		if (array_key_exists("2", $match)) {
-			return $match[1] . BASE_URL . "index.php?load=download_attachment&store=" . $GLOBALS["preg_replace"]["storeid"] . "&amp;entryid=" . $GLOBALS["preg_replace"]["entryid"] . "&amp;attachCid=" . $match[2] . "&amp;openType=inline" . $match[3];
+		// groups 1 contains value of src attribute
+		if (array_key_exists("1", $match)) {
+			// exclude external links to images
+			if(preg_match("/https{0,1}:\/\//msi", $match[1]) === 1) {
+				// return links as it is without changing anything
+				return "<img src=\"" . $match[1] . "\"";
+			}
+
+			$match[1] = str_replace("cid:", "", $match[1]);
+			return "<img src=\"" . BASE_URL . "index.php?load=download_attachment&store=" . $GLOBALS["preg_replace"]["storeid"] . "&amp;entryid=" . $GLOBALS["preg_replace"]["entryid"] . "&amp;attachCid=" . $match[1] . "&amp;openType=inline\"";
 		} else {
-			return "=''";
+			return "<img src=\"\"";
 		}
 	}
 	
@@ -265,27 +273,57 @@
 		return ((float)$usec + (float)$sec);
 	}
 
-
+	/**
+	 * gets maximum upload size of attachment from php ini settings
+	 * important settings are upload_max_filesize and post_max_size
+	 * upload_max_filesize specifies maximum upload size for attachments
+	 * post_max_size specifies maximum size of a post request, we are uploading attachment using post method
+	 * that's why we need to check this also
+	 * these values are overwritten in .htaccess file of WA
+	 */
 	function getMaxUploadSize($as_string = false)
 	{
-		$value = strtoupper(ini_get('upload_max_filesize'));
-		// calculate value to bytes
-		if (strpos($value, "K")!== false){
-			$value = ((int)$value) * 1024;
-		} else if (strpos($value, "M")!== false){
-			$value = ((int)$value) * 1024 * 1024;
-		} else if (strpos($value, "G")!== false){
-			$value = ((int)$value) * 1024 * 1024 * 1024; 
+		$upload_max_value = strtoupper(ini_get('upload_max_filesize'));
+		$post_max_value = strtoupper(ini_get('post_max_size'));
+
+		/**
+		 * if POST_MAX_SIZE is lower then UPLOAD_MAX_FILESIZE, then we have to check based on that value
+		 * as we will not be able to upload attachment larger then POST_MAX_SIZE (file size + header data)
+		 * so set POST_MAX_SIZE value to higher then UPLOAD_MAX_FILESIZE
+		 */
+
+		// calculate upload_max_value value to bytes
+		if (strpos($upload_max_value, "K")!== false){
+			$upload_max_value = ((int) $upload_max_value) * 1024;
+		} else if (strpos($upload_max_value, "M")!== false){
+			$upload_max_value = ((int) $upload_max_value) * 1024 * 1024;
+		} else if (strpos($upload_max_value, "G")!== false){
+			$upload_max_value = ((int) $upload_max_value) * 1024 * 1024 * 1024; 
 		}
-		
+
+		// calculate post_max_value value to bytes
+		if (strpos($post_max_value, "K")!== false){
+			$post_max_value = ((int) $post_max_value) * 1024;
+		} else if (strpos($post_max_value, "M")!== false){
+			$post_max_value = ((int) $post_max_value) * 1024 * 1024;
+		} else if (strpos($post_max_value, "G")!== false){
+			$post_max_value = ((int) $post_max_value) * 1024 * 1024 * 1024; 
+		}
+
+		// check which one is larger
+		$value = $upload_max_value;
+		if($upload_max_value > $post_max_value) {
+			$value = $post_max_value;
+		}
+
 		if ($as_string){
 			// make user readable string
-			if ($value>1073741824){
-				$value = round($value/1073741824, 1) ." ". _("GB");
-			}else if ($value>1048576){
-				$value = round($value/1048576, 1) ." ". _("MB");
-			}else if ($value>1024){
-				$value = round($value/1024, 1) ." ". _("KB");
+			if ($value > (1024 * 1024 * 1024)){
+				$value = round($value / (1024 * 1024 * 1024), 1) ." ". _("GB");
+			}else if ($value > (1024 * 1024)){
+				$value = round($value / (1024 * 1024), 1) ." ". _("MB");
+			}else if ($value > 1024){
+				$value = round($value / 1024, 1) ." ". _("KB");
 			}else{
 				$value = $value ." ". _("B");
 			}
@@ -433,5 +471,34 @@
 
 		return ceil($secondsLeft/60/60/24);
 	}
+	/**
+	 * getMIMEType
+	 * Returns the MIME type of the file or content type of the file,
+	 * it uses file's extention for getting MIME type.
+	 * @return string MIME type of the file.
+	 */
+	function getMIMEType($filename)
+	{
+		// Set default content type.
+		$contentType = "application/octet-stream";
+		// Parse the extension of the filename to get the content type
+		if(strrpos($filename, ".") !== false) {
+			$extension = strtolower(substr($filename, strrpos($filename, ".")));
+			if (is_readable(MIME_TYPES)){
+				$fh = fopen(MIME_TYPES,"r");
+				$ext_found = false;
+				while (!feof($fh) && !$ext_found){
+					$line = fgets($fh);
+					preg_match("/(\.[a-z0-9]+)[ \t]+([^ \t\n\r]*)/i", $line, $result);
+					if (count($result) > 0 && $extension == $result[1]){
+						$ext_found = true;
+						$contentType = $result[2];
+					}
+				}
+				fclose($fh);
+			}
+		}
+		return $contentType;
+	}
 
 ?>
