@@ -57,6 +57,7 @@
 	
 	// Include files
 	include("config.php");
+	include("defaults.php");
 	include("server/util.php");
 	require("server/PEAR/JSON.php");
 	
@@ -77,6 +78,7 @@
 	include("server/modules/class.listmodule.php");
 	include("server/modules/class.itemmodule.php");
 	include("server/core/class.operations.php");
+	include("server/core/class.zarchiver.php");
 	include("server/core/class.properties.php");
 	include("server/core/class.tablecolumns.php");
 	include("server/core/class.bus.php");
@@ -143,6 +145,8 @@
 
 		// Create global operations object
 		$GLOBALS["operations"] = new Operations();
+		// Create global operations object
+		$GLOBALS["zArchiverOperations"] = new ZArchiverOperations();
 		// Create global properties object
 		$GLOBALS["properties"] = new Properties();
 		// Create global tablecolumns object
